/**
 * console
 */
// 当某些调试场景下需要用到 JS 引擎自带的 console 时，保留其原生 console 对象，如没有则为 undefined
var __console__ = console
var __setTimeout__ = setTimeout
var __clearTimeout__ = clearTimeout
var __setInterval__ = setInterval
var __clearInterval__ = clearInterval
var console = (function() {
  var CONSOLE_TYPE_ENUM = {
    LOG: 0,
    INFO: 1,
    WARN: 2,
    ERROR: 3
  };
  var DEFAULT_LABEL = 'default';
  var timeMap = Object.create(null);
  return {
    log: function() {
      var msg = '';
      for (var i = 0, item; i < arguments.length; i++) {
        item = arguments[i];
        msg += (typeof item === 'string' ? item : JSON.stringify(item));
      }
      nativeLog(CONSOLE_TYPE_ENUM.LOG, msg);
    },
    info: function() {
      var msg = '';
      for (var i = 0, item; i < arguments.length; i++) {
        item = arguments[i];
        msg += (typeof item === 'string' ? item : JSON.stringify(item));
      }
      nativeLog(CONSOLE_TYPE_ENUM.INFO, msg);
    },
    warn: function() {
      var msg = '';
      for (var i = 0, item; i < arguments.length; i++) {
        item = arguments[i];
        msg += (typeof item === 'string' ? item : JSON.stringify(item));
      }
      nativeLog(CONSOLE_TYPE_ENUM.WARN, msg);
    },
    group: function() {
    },
    groupEnd: function() {
    },
    error: function() {
      var msg = '';
      for (var i = 0, item; i < arguments.length; i++) {
        item = arguments[i];
        msg += (typeof item === 'string' ? item : JSON.stringify(item));
      }
      nativeLog(CONSOLE_TYPE_ENUM.ERROR, msg);
    },
    time: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      timeMap[label] = Date.now();
    },
    timeLog: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + ((timeMap[label] = Date.now()) - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    },
    timeEnd: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        delete timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + (Date.now() - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    }
  };
})();


/**
 * Timeout & Interval
 */

var timeoutMap = {};
var timeoutId = 0;

var setTimeout = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++
  timeoutMap[funcId] = cb
  // native的方法
  setTimeoutNative(funcId, timeout)
  return funcId
}

// native 方法 ，需要暴露在全局
var setTimeoutCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      // 错误上报
      __appServiceSDK__.traceCoreDotting('app_error', {
        info: err && (err.message + err.stack),
        isError: true
      })
      var app = __appServiceEngine__.getApp()
      app && app.onError && app.onError(err.message + err.stack)
    } finally {
      timeoutMap[funcId] = null
      delete timeoutMap[funcId]
    }


  } else {
    console.error("[setTimeoutNative]: setTimeOut fn is not a fn " + funcId)
  }
}

var clearTimeout = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearTimeoutNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

var setInterval = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++;
  timeoutMap[funcId] = cb;
  setIntervalNative(funcId, timeout);
  return funcId;
}

var setIntervalCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      __appServiceSDK__.traceCoreDotting('app_error', {
        info: err.message + err.stack,
        isError: true
      })
      var app = __appServiceEngine__.getApp()
      app && app.onError && app.onError(err.message + err.stack)
    }
  } else {
    console.error("[setIntervalCallback]: setInterval fn is not a fn " + funcId);
  }
}

var clearInterval = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearIntervalNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

/**
 * 全局变量
 */
var globalThis = (function() {
  return this
})();

// 谷歌渠道,jscore改成webview,因此window上会存在全局变量,会去访问document变量
globalThis && globalThis.MutationObserver && (MutationObserver = null)
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)
if (globalThis) {
  globalThis.onunhandledrejection = function(params) {
    __appServiceSDK__.dd && __appServiceSDK__.dd.emitUnhandledRejection && __appServiceSDK__.dd.emitUnhandledRejection(params)
    var app = __appServiceEngine__.getApp()
    app && app.onUnhandledRejection && app.onUnhandledRejection(params)
  }
  globalThis.onunhandledrejectionForNative = function(promise, reason) {
    globalThis.onunhandledrejection && globalThis.onunhandledrejection({ promise, reason })
    __appServiceSDK__.reportNative('pub_native_unhandlereject_bt', {
      reason: '' + reason
    })
  }
}
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)

var __ddLibrary = {
  envType: 'Service',
  contextType: '',
  fileName: 'WAService.js',
  execStart: Date.now()
};
var __libVersionInfo__ = {}
/** wcc config start */
var window = {};
window.__wcc_version_info__ = {
  customComponents: true,
  fixZeroRpx: true,
  propValueDeepCopy: false
};
/** wcc config end */

var __ddAppData = __ddAppData || {};
var __ddRoute = __ddRoute || '';
var __ddRouteBegin = __ddRouteBegin || "";
var __ddAppCurrentFile__ = __ddAppCurrentFile__ || "";
var __define__;
var __routePackages__;
var global = global || {};
var __ddConfigWindow__ = {};
var Reporter = {};
var __vd_version_info__ = {
  delayedGwx: true
};
var __ddConfig = {
  envVersion: 'release',
  platform: '',
  isIsolateContext: false     // 是否是游戏，游戏为true，不是游戏，字段缺省或者为false
};
var __MAIN_PKG_DIR__ = 'app';
var __APP_RESOURCES_SUB_DIR__ = 'res';
var currentStackId = -1;
var tabBarTapList = []

var isDevTools = typeof acquireLocalBridge === 'function'
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}

if (isDevTools) {
  // ide 环境重写对象
  console = __console__;
  setTimeout = __setTimeout__;
  clearTimeout = __clearTimeout__;
  setInterval = __setInterval__;
  clearInterval = __clearInterval__;
}


/**
 * 基础库的 service 的代码
 */
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}
var Foundation=function(){"use strict";function t(n){return(t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(n)}function n(){return(n=Object.assign||function(t){for(var n=1;n<arguments.length;n++){var e=arguments[n];for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r])}return t}).apply(this,arguments)}
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var e in n)Object.prototype.hasOwnProperty.call(n,e)&&(t[e]=n[e])})(t,n)};var r="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function o(t,n,e){return t(e={path:n,exports:{},require:function(t,n){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==n&&e.path)}},e.exports),e.exports}var i,c,u=function(t){return t&&t.Math==Math&&t},a=u("object"==typeof globalThis&&globalThis)||u("object"==typeof window&&window)||u("object"==typeof self&&self)||u("object"==typeof r&&r)||function(){return this}()||Function("return this")(),f=function(t,n,e){if(function(t){if("function"!=typeof t)throw TypeError(String(t)+" is not a function")}(t),void 0===n)return t;switch(e){case 0:return function(){return t.call(n)};case 1:return function(e){return t.call(n,e)};case 2:return function(e,r){return t.call(n,e,r)};case 3:return function(e,r,o){return t.call(n,e,r,o)}}return function(){return t.apply(n,arguments)}},s=function(t){try{return!!t()}catch(t){return!0}},l={}.toString,p=function(t){return l.call(t).slice(8,-1)},y="".split,d=s((function(){return!Object("z").propertyIsEnumerable(0)}))?function(t){return"String"==p(t)?y.call(t,""):Object(t)}:Object,g=function(t){if(null==t)throw TypeError("Can't call method on "+t);return t},h=function(t){return Object(g(t))},v=Math.ceil,b=Math.floor,m=function(t){return isNaN(t=+t)?0:(t>0?b:v)(t)},x=Math.min,S=function(t){return t>0?x(m(t),9007199254740991):0},_=function(t){return"object"==typeof t?null!==t:"function"==typeof t},w=Array.isArray||function(t){return"Array"==p(t)},O=function(t,n){try{Object.defineProperty(a,t,{value:n,configurable:!0,writable:!0})}catch(e){a[t]=n}return n},E="__core-js_shared__",T=a[E]||O(E,{}),C=o((function(t){(t.exports=function(t,n){return T[t]||(T[t]=void 0!==n?n:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),R={}.hasOwnProperty,A=Object.hasOwn||function(t,n){return R.call(h(t),n)},I=0,j=Math.random(),L=function(t){return"Symbol("+String(void 0===t?"":t)+")_"+(++I+j).toString(36)},P=function(t){return"function"==typeof t?t:void 0},D=function(t,n){return arguments.length<2?P(a[t]):a[t]&&a[t][n]},k=D("navigator","userAgent")||"",M=a.process,F=a.Deno,N=M&&M.versions||F&&F.version,V=N&&N.v8;V?c=(i=V.split("."))[0]<4?1:i[0]+i[1]:k&&(!(i=k.match(/Edge\/(\d+)/))||i[1]>=74)&&(i=k.match(/Chrome\/(\d+)/))&&(c=i[1]);var G=c&&+c,W=!!Object.getOwnPropertySymbols&&!s((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&G&&G<41})),B=W&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,Y=C("wks"),U=a.Symbol,K=B?U:U&&U.withoutSetter||L,q=function(t){return A(Y,t)&&(W||"string"==typeof Y[t])||(W&&A(U,t)?Y[t]=U[t]:Y[t]=K("Symbol."+t)),Y[t]},z=q("species"),H=function(t,n){return new(function(t){var n;return w(t)&&("function"!=typeof(n=t.constructor)||n!==Array&&!w(n.prototype)?_(n)&&null===(n=n[z])&&(n=void 0):n=void 0),void 0===n?Array:n}(t))(0===n?0:n)},J=[].push,$=function(t){var n=1==t,e=2==t,r=3==t,o=4==t,i=6==t,c=7==t,u=5==t||i;return function(a,s,l,p){for(var y,g,v=h(a),b=d(v),m=f(s,l,3),x=S(b.length),_=0,w=p||H,O=n?w(a,x):e||c?w(a,0):void 0;x>_;_++)if((u||_ in b)&&(g=m(y=b[_],_,v),t))if(n)O[_]=g;else if(g)switch(t){case 3:return!0;case 5:return y;case 6:return _;case 2:J.call(O,y)}else switch(t){case 4:return!1;case 7:J.call(O,y)}return i?-1:r||o?o:O}},X={forEach:$(0),map:$(1),filter:$(2),some:$(3),every:$(4),find:$(5),findIndex:$(6),filterReject:$(7)},Q=function(t,n){var e=[][t];return!!e&&s((function(){e.call(null,n||function(){throw 1},1)}))},Z=X.forEach,tt=Q("forEach")?[].forEach:function(t){return Z(this,t,arguments.length>1?arguments[1]:void 0)},nt=!s((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),et=a.document,rt=_(et)&&_(et.createElement),ot=function(t){return rt?et.createElement(t):{}},it=!nt&&!s((function(){return 7!=Object.defineProperty(ot("div"),"a",{get:function(){return 7}}).a})),ct=function(t){if(!_(t))throw TypeError(String(t)+" is not an object");return t},ut=B?function(t){return"symbol"==typeof t}:function(t){var n=D("Symbol");return"function"==typeof n&&Object(t)instanceof n},at=q("toPrimitive"),ft=function(t,n){if(!_(t)||ut(t))return t;var e,r=t[at];if(void 0!==r){if(void 0===n&&(n="default"),e=r.call(t,n),!_(e)||ut(e))return e;throw TypeError("Can't convert object to primitive value")}return void 0===n&&(n="number"),function(t,n){var e,r;if("string"===n&&"function"==typeof(e=t.toString)&&!_(r=e.call(t)))return r;if("function"==typeof(e=t.valueOf)&&!_(r=e.call(t)))return r;if("string"!==n&&"function"==typeof(e=t.toString)&&!_(r=e.call(t)))return r;throw TypeError("Can't convert object to primitive value")}(t,n)},st=function(t){var n=ft(t,"string");return ut(n)?n:String(n)},lt=Object.defineProperty,pt={f:nt?lt:function(t,n,e){if(ct(t),n=st(n),ct(e),it)try{return lt(t,n,e)}catch(t){}if("get"in e||"set"in e)throw TypeError("Accessors not supported");return"value"in e&&(t[n]=e.value),t}},yt=function(t,n){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:n}},dt=nt?function(t,n,e){return pt.f(t,n,yt(1,e))}:function(t,n,e){return t[n]=e,t};for(var gt in{CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}){var ht=a[gt],vt=ht&&ht.prototype;if(vt&&vt.forEach!==tt)try{dt(vt,"forEach",tt)}catch(t){vt.forEach=tt}}var bt={}.propertyIsEnumerable,mt=Object.getOwnPropertyDescriptor,xt={f:mt&&!bt.call({1:2},1)?function(t){var n=mt(this,t);return!!n&&n.enumerable}:bt},St=function(t){return d(g(t))},_t=Object.getOwnPropertyDescriptor,wt={f:nt?_t:function(t,n){if(t=St(t),n=st(n),it)try{return _t(t,n)}catch(t){}if(A(t,n))return yt(!xt.f.call(t,n),t[n])}},Ot=Function.toString;"function"!=typeof T.inspectSource&&(T.inspectSource=function(t){return Ot.call(t)});var Et,Tt,Ct,Rt=T.inspectSource,At=a.WeakMap,It="function"==typeof At&&/native code/.test(Rt(At)),jt=C("keys"),Lt=function(t){return jt[t]||(jt[t]=L(t))},Pt={},Dt="Object already initialized",kt=a.WeakMap;if(It||T.state){var Mt=T.state||(T.state=new kt),Ft=Mt.get,Nt=Mt.has,Vt=Mt.set;Et=function(t,n){if(Nt.call(Mt,t))throw new TypeError(Dt);return n.facade=t,Vt.call(Mt,t,n),n},Tt=function(t){return Ft.call(Mt,t)||{}},Ct=function(t){return Nt.call(Mt,t)}}else{var Gt=Lt("state");Pt[Gt]=!0,Et=function(t,n){if(A(t,Gt))throw new TypeError(Dt);return n.facade=t,dt(t,Gt,n),n},Tt=function(t){return A(t,Gt)?t[Gt]:{}},Ct=function(t){return A(t,Gt)}}var Wt,Bt={set:Et,get:Tt,has:Ct,enforce:function(t){return Ct(t)?Tt(t):Et(t,{})},getterFor:function(t){return function(n){var e;if(!_(n)||(e=Tt(n)).type!==t)throw TypeError("Incompatible receiver, "+t+" required");return e}}},Yt=o((function(t){var n=Bt.get,e=Bt.enforce,r=String(String).split("String");(t.exports=function(t,n,o,i){var c,u=!!i&&!!i.unsafe,f=!!i&&!!i.enumerable,s=!!i&&!!i.noTargetGet;"function"==typeof o&&("string"!=typeof n||A(o,"name")||dt(o,"name",n),(c=e(o)).source||(c.source=r.join("string"==typeof n?n:""))),t!==a?(u?!s&&t[n]&&(f=!0):delete t[n],f?t[n]=o:dt(t,n,o)):f?t[n]=o:O(n,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&n(this).source||Rt(this)}))})),Ut=Math.max,Kt=Math.min,qt=function(t){return function(n,e,r){var o,i=St(n),c=S(i.length),u=function(t,n){var e=m(t);return e<0?Ut(e+n,0):Kt(e,n)}(r,c);if(t&&e!=e){for(;c>u;)if((o=i[u++])!=o)return!0}else for(;c>u;u++)if((t||u in i)&&i[u]===e)return t||u||0;return!t&&-1}},zt={includes:qt(!0),indexOf:qt(!1)},Ht=zt.indexOf,Jt=function(t,n){var e,r=St(t),o=0,i=[];for(e in r)!A(Pt,e)&&A(r,e)&&i.push(e);for(;n.length>o;)A(r,e=n[o++])&&(~Ht(i,e)||i.push(e));return i},$t=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Xt=$t.concat("length","prototype"),Qt={f:Object.getOwnPropertyNames||function(t){return Jt(t,Xt)}},Zt={f:Object.getOwnPropertySymbols},tn=D("Reflect","ownKeys")||function(t){var n=Qt.f(ct(t)),e=Zt.f;return e?n.concat(e(t)):n},nn=function(t,n){for(var e=tn(n),r=pt.f,o=wt.f,i=0;i<e.length;i++){var c=e[i];A(t,c)||r(t,c,o(n,c))}},en=/#|\.prototype\./,rn=function(t,n){var e=cn[on(t)];return e==an||e!=un&&("function"==typeof n?s(n):!!n)},on=rn.normalize=function(t){return String(t).replace(en,".").toLowerCase()},cn=rn.data={},un=rn.NATIVE="N",an=rn.POLYFILL="P",fn=rn,sn=wt.f,ln=function(t,n){var e,r,o,i,c,u=t.target,f=t.global,s=t.stat;if(e=f?a:s?a[u]||O(u,{}):(a[u]||{}).prototype)for(r in n){if(i=n[r],o=t.noTargetGet?(c=sn(e,r))&&c.value:e[r],!fn(f?r:u+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof i==typeof o)continue;nn(i,o)}(t.sham||o&&o.sham)&&dt(i,"sham",!0),Yt(e,r,i,t)}},pn=q("species"),yn=X.filter;ln({target:"Array",proto:!0,forced:!(Wt="filter",G>=51||!s((function(){var t=[];return(t.constructor={})[pn]=function(){return{foo:1}},1!==t[Wt](Boolean).foo})))},{filter:function(t){return yn(this,t,arguments.length>1?arguments[1]:void 0)}});var dn=function(){function t(){this.listeners={}}return t.prototype.emit=function(t,n){if(this.listeners[t]&&this.listeners[t].length>0){var e=!1;return this.listeners[t].forEach((function(t){0!==t.count&&t.cb(n),t.count>0&&t.count--,0===t.count&&(e=!0)})),e&&(this.listeners[t]=this.listeners[t].filter((function(t){return 0!==t.count}))),!0}return!1},t.prototype.many=function(t,n,e){if(!n)return this;var r={count:e,cb:n};return this.listeners[t]?this.listeners[t].push(r):this.listeners[t]=[r],this},t.prototype.on=function(t,n){this.many(t,n,-1)},t.prototype.off=function(t,n){for(var e=0;e<this.listeners[t].length;e++){var r=this.listeners[t][e];if(r.cb===n)return void(r.count=0)}},t.prototype.once=function(t,n){this.many(t,n,1)},t}(),gn=Object.setPrototypeOf||("__proto__"in{}?function(){var t,n=!1,e={};try{(t=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(e,[]),n=e instanceof Array}catch(t){}return function(e,r){return ct(e),function(t){if(!_(t)&&null!==t)throw TypeError("Can't set "+String(t)+" as a prototype")}(r),n?t.call(e,r):e.__proto__=r,e}}():void 0),hn=q("match"),vn=function(t){if(ut(t))throw TypeError("Cannot convert a Symbol value to a string");return String(t)},bn=function(){var t=ct(this),n="";return t.global&&(n+="g"),t.ignoreCase&&(n+="i"),t.multiline&&(n+="m"),t.dotAll&&(n+="s"),t.unicode&&(n+="u"),t.sticky&&(n+="y"),n},mn=a.RegExp,xn={UNSUPPORTED_Y:s((function(){var t=mn("a","y");return t.lastIndex=2,null!=t.exec("abcd")})),BROKEN_CARET:s((function(){var t=mn("^r","gy");return t.lastIndex=2,null!=t.exec("str")}))},Sn=q("species"),_n=a.RegExp,wn=s((function(){var t=_n(".","s");return!(t.dotAll&&t.exec("\n")&&"s"===t.flags)})),On=a.RegExp,En=s((function(){var t=On("(?<a>b)","g");return"b"!==t.exec("b").groups.a||"bc"!=="b".replace(t,"$<a>c")})),Tn=pt.f,Cn=Qt.f,Rn=Bt.enforce,An=q("match"),In=a.RegExp,jn=In.prototype,Ln=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Pn=/a/g,Dn=/a/g,kn=new In(Pn)!==Pn,Mn=xn.UNSUPPORTED_Y,Fn=nt&&(!kn||Mn||wn||En||s((function(){return Dn[An]=!1,In(Pn)!=Pn||In(Dn)==Dn||"/a/i"!=In(Pn,"i")})));if(fn("RegExp",Fn)){for(var Nn=function(t,n){var e,r,o,i,c,u,a,f,s,l,y,d,g,h=this instanceof Nn,v=_(e=t)&&(void 0!==(r=e[hn])?!!r:"RegExp"==p(e)),b=void 0===n,m=[],x=t;if(!h&&v&&b&&t.constructor===Nn)return t;if((v||t instanceof Nn)&&(t=t.source,b&&(n="flags"in x?x.flags:bn.call(x))),t=void 0===t?"":vn(t),n=void 0===n?"":vn(n),x=t,wn&&"dotAll"in Pn&&(i=!!n&&n.indexOf("s")>-1)&&(n=n.replace(/s/g,"")),o=n,Mn&&"sticky"in Pn&&(c=!!n&&n.indexOf("y")>-1)&&(n=n.replace(/y/g,"")),En&&(t=(u=function(t){for(var n,e=t.length,r=0,o="",i=[],c={},u=!1,a=!1,f=0,s="";r<=e;r++){if("\\"===(n=t.charAt(r)))n+=t.charAt(++r);else if("]"===n)u=!1;else if(!u)switch(!0){case"["===n:u=!0;break;case"("===n:Ln.test(t.slice(r+1))&&(r+=2,a=!0),o+=n,f++;continue;case">"===n&&a:if(""===s||A(c,s))throw new SyntaxError("Invalid capture group name");c[s]=!0,i.push([s,f]),a=!1,s="";continue}a?s+=n:o+=n}return[o,i]}(t))[0],m=u[1]),s=In(t,n),l=h?this:jn,y=Nn,gn&&"function"==typeof(d=l.constructor)&&d!==y&&_(g=d.prototype)&&g!==y.prototype&&gn(s,g),a=s,(i||c||m.length)&&(f=Rn(a),i&&(f.dotAll=!0,f.raw=Nn(function(t){for(var n,e=t.length,r=0,o="",i=!1;r<=e;r++)"\\"!==(n=t.charAt(r))?i||"."!==n?("["===n?i=!0:"]"===n&&(i=!1),o+=n):o+="[\\s\\S]":o+=n+t.charAt(++r);return o}(t),o)),c&&(f.sticky=!0),m.length&&(f.groups=m)),t!==x)try{dt(a,"source",""===x?"(?:)":x)}catch(t){}return a},Vn=function(t){t in Nn||Tn(Nn,t,{configurable:!0,get:function(){return In[t]},set:function(n){In[t]=n}})},Gn=Cn(In),Wn=0;Gn.length>Wn;)Vn(Gn[Wn++]);jn.constructor=Nn,Nn.prototype=jn,Yt(a,"RegExp",Nn)}!function(t){var n=D(t),e=pt.f;nt&&n&&!n[Sn]&&e(n,Sn,{configurable:!0,get:function(){return this}})}("RegExp");var Bn,Yn=Object.keys||function(t){return Jt(t,$t)},Un=nt?Object.defineProperties:function(t,n){ct(t);for(var e,r=Yn(n),o=r.length,i=0;o>i;)pt.f(t,e=r[i++],n[e]);return t},Kn=D("document","documentElement"),qn=Lt("IE_PROTO"),zn=function(){},Hn=function(t){return"<script>"+t+"</"+"script>"},Jn=function(t){t.write(Hn("")),t.close();var n=t.parentWindow.Object;return t=null,n},$n=function(){try{Bn=new ActiveXObject("htmlfile")}catch(t){}var t,n;$n="undefined"!=typeof document?document.domain&&Bn?Jn(Bn):((n=ot("iframe")).style.display="none",Kn.appendChild(n),n.src=String("javascript:"),(t=n.contentWindow.document).open(),t.write(Hn("document.F=Object")),t.close(),t.F):Jn(Bn);for(var e=$t.length;e--;)delete $n.prototype[$t[e]];return $n()};Pt[qn]=!0;var Xn=Object.create||function(t,n){var e;return null!==t?(zn.prototype=ct(t),e=new zn,zn.prototype=null,e[qn]=t):e=$n(),void 0===n?e:Un(e,n)},Qn=Bt.get,Zn=RegExp.prototype.exec,te=C("native-string-replace",String.prototype.replace),ne=Zn,ee=function(){var t=/a/,n=/b*/g;return Zn.call(t,"a"),Zn.call(n,"a"),0!==t.lastIndex||0!==n.lastIndex}(),re=xn.UNSUPPORTED_Y||xn.BROKEN_CARET,oe=void 0!==/()??/.exec("")[1];(ee||oe||re||wn||En)&&(ne=function(t){var n,e,r,o,i,c,u,a=this,f=Qn(a),s=vn(t),l=f.raw;if(l)return l.lastIndex=a.lastIndex,n=ne.call(l,s),a.lastIndex=l.lastIndex,n;var p=f.groups,y=re&&a.sticky,d=bn.call(a),g=a.source,h=0,v=s;if(y&&(-1===(d=d.replace("y","")).indexOf("g")&&(d+="g"),v=s.slice(a.lastIndex),a.lastIndex>0&&(!a.multiline||a.multiline&&"\n"!==s.charAt(a.lastIndex-1))&&(g="(?: "+g+")",v=" "+v,h++),e=new RegExp("^(?:"+g+")",d)),oe&&(e=new RegExp("^"+g+"$(?!\\s)",d)),ee&&(r=a.lastIndex),o=Zn.call(y?e:a,v),y?o?(o.input=o.input.slice(h),o[0]=o[0].slice(h),o.index=a.lastIndex,a.lastIndex+=o[0].length):a.lastIndex=0:ee&&o&&(a.lastIndex=a.global?o.index+o[0].length:r),oe&&o&&o.length>1&&te.call(o[0],e,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=c=Xn(null),i=0;i<p.length;i++)c[(u=p[i])[0]]=o[u[1]];return o});var ie=ne;ln({target:"RegExp",proto:!0,forced:/./.exec!==ie},{exec:ie});var ce="toString",ue=RegExp.prototype,ae=ue.toString,fe=s((function(){return"/a/b"!=ae.call({source:"a",flags:"b"})})),se=ae.name!=ce;(fe||se)&&Yt(RegExp.prototype,ce,(function(){var t=ct(this),n=vn(t.source),e=t.flags;return"/"+n+"/"+vn(void 0===e&&t instanceof RegExp&&!("flags"in ue)?bn.call(t):e)}),{unsafe:!0});var le=zt.indexOf,pe=[].indexOf,ye=!!pe&&1/[1].indexOf(1,-0)<0,de=Q("indexOf");ln({target:"Array",proto:!0,forced:ye||!de},{indexOf:function(t){return ye?pe.apply(this,arguments)||0:le(this,t,arguments.length>1?arguments[1]:void 0)}});var ge=q("species"),he=RegExp.prototype,ve=function(t){return function(n,e){var r,o,i=vn(g(n)),c=m(e),u=i.length;return c<0||c>=u?t?"":void 0:(r=i.charCodeAt(c))<55296||r>56319||c+1===u||(o=i.charCodeAt(c+1))<56320||o>57343?t?i.charAt(c):r:t?i.slice(c,c+2):o-56320+(r-55296<<10)+65536}},be={codeAt:ve(!1),charAt:ve(!0)}.charAt,me=function(t,n,e){return n+(e?be(t,n).length:1)},xe=function(t,n){var e=t.exec;if("function"==typeof e){var r=e.call(t,n);if("object"!=typeof r)throw TypeError("RegExp exec method returned something other than an Object or null");return r}if("RegExp"!==p(t))throw TypeError("RegExp#exec called on incompatible receiver");return ie.call(t,n)};!function(t,n,e,r){var o=q(t),i=!s((function(){var n={};return n[o]=function(){return 7},7!=""[t](n)})),c=i&&!s((function(){var n=!1,e=/a/;return"split"===t&&((e={}).constructor={},e.constructor[ge]=function(){return e},e.flags="",e[o]=/./[o]),e.exec=function(){return n=!0,null},e[o](""),!n}));if(!i||!c||e){var u=/./[o],a=n(o,""[t],(function(t,n,e,r,o){var c=n.exec;return c===ie||c===he.exec?i&&!o?{done:!0,value:u.call(n,e,r)}:{done:!0,value:t.call(e,n,r)}:{done:!1}}));Yt(String.prototype,t,a[0]),Yt(he,o,a[1])}r&&dt(he[o],"sham",!0)}("match",(function(t,n,e){return[function(n){var e=g(this),r=null==n?void 0:n[t];return void 0!==r?r.call(n,e):new RegExp(n)[t](vn(e))},function(t){var r=ct(this),o=vn(t),i=e(n,r,o);if(i.done)return i.value;if(!r.global)return xe(r,o);var c=r.unicode;r.lastIndex=0;for(var u,a=[],f=0;null!==(u=xe(r,o));){var s=vn(u[0]);a[f]=s,""===s&&(r.lastIndex=me(o,S(r.lastIndex),c)),f++}return 0===f?null:a}]}));var Se="((?:(?:[0-9]|(?:[1-9](?:[0-9]*))).){2}(?:[0-9]|(?:[1-9](?:[0-9]*))))",_e=new RegExp("native_sdk/"+Se),we=new RegExp("native_app_version/"+Se);var Oe=new dn,Ee={},Te=function(){var n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":t(window))&&(n=window)}return n}();function Ce(t,n){t in Ee?n&&n(Ee[t]):Oe.once("lifeCycle:"+t,n)}function Re(t,n){t in Ee||(Ee[t]=n,Oe.emit("lifeCycle:"+t,n))}var Ae=function(t){function r(){var n=t.call(this)||this;return n._STATIC_CONFIG_READY="configReady",n._STATIC_LIB_READY="libraryReady",n.init(),n}return function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Class extends value "+String(n)+" is not a constructor or null");function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}(r,t),r.prototype.init=function(){this.env=function(t){var n=t.__ddLibrary,e=t.__ddConfig,r=n.envType,o=n.contextType,i="Service"===r,c="WebView"===r,u="Worker"===r,a="Widget"===r,f=c||i&&0===o.indexOf("App:"),s=i&&0===o.indexOf("Game:"),l=u&&"function"==typeof t.workerInvokeJsApi,p=!!e.isIsolateContext,y=i&&(p&&0<=o.indexOf("Uncertain")||0<=o.indexOf("MainContext")),d=i&&0<=o.indexOf("SubContext"),g=y||d,h=c||y,v=e.platform,b=e.SDKVersion,m=e.version;if(c){var x=window.navigator.userAgent.toLowerCase();!v&&c&&0<=x.indexOf("devtools")?v="devtools":0<=x.indexOf("miniprogramenv/windows")?v="windows":0<=x.indexOf("miniprogramenv/mac")?v="mac":0<=x.indexOf("iphone")||0<=x.indexOf("ipad")?v="ios":0<=x.indexOf("android")&&(v="android");var S=x.match(_e),_=x.match(we);S&&(b=S[1]||""),_&&(m=_[1]||"")}return{platform:(v||"unknown").toLowerCase(),jssdkVersion:"undefined"==typeof __libVersionInfo__||"develop"===__libVersionInfo__.version?"9.9.9":__libVersionInfo__.version,SDKVersion:b,version:m,isIsolateContext:g,isGame:s,isApp:f,isMainContext:y,isSubContext:d,isSafeEnv:h,isService:i,isWebView:c,isWorker:u,isWidget:a,isSupportWorkerAPI:l,typeStr:r}}(Te),this.global=Te,this.EventEmitter=dn,this.exportConfig={}},r.prototype.emitConfigReady=function(t){Re(this._STATIC_CONFIG_READY,t)},r.prototype.onConfigReady=function(t){Ce(this._STATIC_CONFIG_READY,t)},Object.defineProperty(r.prototype,"isConfigReady",{get:function(){return this._STATIC_CONFIG_READY in Ee},enumerable:!1,configurable:!0}),r.prototype.onLibraryReady=function(t){Ce(this._STATIC_LIB_READY,t)},r.prototype.emitLibraryReady=function(t){Re(this._STATIC_LIB_READY,t)},Object.defineProperty(r.prototype,"isLibraryReady",{get:function(){return this._STATIC_LIB_READY in Ee},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"isBridgeReady",{get:function(){return!1},enumerable:!1,configurable:!0}),r.prototype.onBridgeReady=function(t){Te.WeixinJSBridge?"function"==typeof t&&t():"undefined"!=typeof document&&"function"==typeof t&&document.addEventListener("WeixinJSBridgeReady",t,!1)},r.prototype.refreshDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t),n(this.exportConfig,t)},r.prototype.getExportConfig=function(){return this.exportConfig},r.prototype.setExportConfig=function(t){void 0===t&&(t={}),this.exportConfig=t},r.prototype.setDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t)},r}(dn);void 0!==Te.__Function__&&(Te.Function=function(){},Te.Function.prototype=Te.__Function__.prototype);var Ie=new Ae;return Te.__ddLibrary&&(Te.__ddLibrary.onEnd=function(){Ie.emitLibraryReady({})}),Ie}();


var didiJsBridge=function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(t,r,n){return t(n={path:r,exports:{},require:function(t,r){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==r&&n.path)}},n.exports),n.exports}var n,e,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),u=function(t){try{return!!t()}catch(t){return!0}},c=!u((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),a={}.propertyIsEnumerable,f=Object.getOwnPropertyDescriptor,s={f:f&&!a.call({1:2},1)?function(t){var r=f(this,t);return!!r&&r.enumerable}:a},l=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},p={}.toString,v=function(t){return p.call(t).slice(8,-1)},g="".split,y=u((function(){return!Object("z").propertyIsEnumerable(0)}))?function(t){return"String"==v(t)?g.call(t,""):Object(t)}:Object,d=function(t){if(null==t)throw TypeError("Can't call method on "+t);return t},h=function(t){return y(d(t))},b=function(t){return"object"==typeof t?null!==t:"function"==typeof t},m=function(t){return"function"==typeof t?t:void 0},S=function(t,r){return arguments.length<2?m(i[t]):i[t]&&i[t][r]},w=S("navigator","userAgent")||"",_=i.process,E=i.Deno,O=_&&_.versions||E&&E.version,j=O&&O.v8;j?e=(n=j.split("."))[0]<4?1:n[0]+n[1]:w&&(!(n=w.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=w.match(/Chrome\/(\d+)/))&&(e=n[1]);var T=e&&+e,k=!!Object.getOwnPropertySymbols&&!u((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&T&&T<41})),A=k&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,I=A?function(t){return"symbol"==typeof t}:function(t){var r=S("Symbol");return"function"==typeof r&&Object(t)instanceof r},N=function(t,r){try{Object.defineProperty(i,t,{value:r,configurable:!0,writable:!0})}catch(n){i[t]=r}return r},B="__core-js_shared__",x=i[B]||N(B,{}),C=r((function(t){(t.exports=function(t,r){return x[t]||(x[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),P=function(t){return Object(d(t))},M={}.hasOwnProperty,D=Object.hasOwn||function(t,r){return M.call(P(t),r)},F=0,R=Math.random(),L=function(t){return"Symbol("+String(void 0===t?"":t)+")_"+(++F+R).toString(36)},z=C("wks"),H=i.Symbol,U=A?H:H&&H.withoutSetter||L,V=function(t){return D(z,t)&&(k||"string"==typeof z[t])||(k&&D(H,t)?z[t]=H[t]:z[t]=U("Symbol."+t)),z[t]},W=V("toPrimitive"),G=function(t,r){if(!b(t)||I(t))return t;var n,e=t[W];if(void 0!==e){if(void 0===r&&(r="default"),n=e.call(t,r),!b(n)||I(n))return n;throw TypeError("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var n,e;if("string"===r&&"function"==typeof(n=t.toString)&&!b(e=n.call(t)))return e;if("function"==typeof(n=t.valueOf)&&!b(e=n.call(t)))return e;if("string"!==r&&"function"==typeof(n=t.toString)&&!b(e=n.call(t)))return e;throw TypeError("Can't convert object to primitive value")}(t,r)},q=function(t){var r=G(t,"string");return I(r)?r:String(r)},J=i.document,K=b(J)&&b(J.createElement),X=function(t){return K?J.createElement(t):{}},Y=!c&&!u((function(){return 7!=Object.defineProperty(X("div"),"a",{get:function(){return 7}}).a})),Z=Object.getOwnPropertyDescriptor,Q={f:c?Z:function(t,r){if(t=h(t),r=q(r),Y)try{return Z(t,r)}catch(t){}if(D(t,r))return l(!s.f.call(t,r),t[r])}},$=function(t){if(!b(t))throw TypeError(String(t)+" is not an object");return t},tt=Object.defineProperty,rt={f:c?tt:function(t,r,n){if($(t),r=q(r),$(n),Y)try{return tt(t,r,n)}catch(t){}if("get"in n||"set"in n)throw TypeError("Accessors not supported");return"value"in n&&(t[r]=n.value),t}},nt=c?function(t,r,n){return rt.f(t,r,l(1,n))}:function(t,r,n){return t[r]=n,t},et=Function.toString;"function"!=typeof x.inspectSource&&(x.inspectSource=function(t){return et.call(t)});var ot,it,ut,ct=x.inspectSource,at=i.WeakMap,ft="function"==typeof at&&/native code/.test(ct(at)),st=C("keys"),lt=function(t){return st[t]||(st[t]=L(t))},pt={},vt="Object already initialized",gt=i.WeakMap;if(ft||x.state){var yt=x.state||(x.state=new gt),dt=yt.get,ht=yt.has,bt=yt.set;ot=function(t,r){if(ht.call(yt,t))throw new TypeError(vt);return r.facade=t,bt.call(yt,t,r),r},it=function(t){return dt.call(yt,t)||{}},ut=function(t){return ht.call(yt,t)}}else{var mt=lt("state");pt[mt]=!0,ot=function(t,r){if(D(t,mt))throw new TypeError(vt);return r.facade=t,nt(t,mt,r),r},it=function(t){return D(t,mt)?t[mt]:{}},ut=function(t){return D(t,mt)}}var St,wt={set:ot,get:it,has:ut,enforce:function(t){return ut(t)?it(t):ot(t,{})},getterFor:function(t){return function(r){var n;if(!b(r)||(n=it(r)).type!==t)throw TypeError("Incompatible receiver, "+t+" required");return n}}},_t=r((function(t){var r=wt.get,n=wt.enforce,e=String(String).split("String");(t.exports=function(t,r,o,u){var c,a=!!u&&!!u.unsafe,f=!!u&&!!u.enumerable,s=!!u&&!!u.noTargetGet;"function"==typeof o&&("string"!=typeof r||D(o,"name")||nt(o,"name",r),(c=n(o)).source||(c.source=e.join("string"==typeof r?r:""))),t!==i?(a?!s&&t[r]&&(f=!0):delete t[r],f?t[r]=o:nt(t,r,o)):f?t[r]=o:N(r,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&r(this).source||ct(this)}))})),Et=Math.ceil,Ot=Math.floor,jt=function(t){return isNaN(t=+t)?0:(t>0?Ot:Et)(t)},Tt=Math.min,kt=function(t){return t>0?Tt(jt(t),9007199254740991):0},At=Math.max,It=Math.min,Nt=function(t,r){var n=jt(t);return n<0?At(n+r,0):It(n,r)},Bt=function(t){return function(r,n,e){var o,i=h(r),u=kt(i.length),c=Nt(e,u);if(t&&n!=n){for(;u>c;)if((o=i[c++])!=o)return!0}else for(;u>c;c++)if((t||c in i)&&i[c]===n)return t||c||0;return!t&&-1}},xt={includes:Bt(!0),indexOf:Bt(!1)}.indexOf,Ct=function(t,r){var n,e=h(t),o=0,i=[];for(n in e)!D(pt,n)&&D(e,n)&&i.push(n);for(;r.length>o;)D(e,n=r[o++])&&(~xt(i,n)||i.push(n));return i},Pt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Mt=Pt.concat("length","prototype"),Dt={f:Object.getOwnPropertyNames||function(t){return Ct(t,Mt)}},Ft={f:Object.getOwnPropertySymbols},Rt=S("Reflect","ownKeys")||function(t){var r=Dt.f($(t)),n=Ft.f;return n?r.concat(n(t)):r},Lt=function(t,r){for(var n=Rt(r),e=rt.f,o=Q.f,i=0;i<n.length;i++){var u=n[i];D(t,u)||e(t,u,o(r,u))}},zt=/#|\.prototype\./,Ht=function(t,r){var n=Vt[Ut(t)];return n==Gt||n!=Wt&&("function"==typeof r?u(r):!!r)},Ut=Ht.normalize=function(t){return String(t).replace(zt,".").toLowerCase()},Vt=Ht.data={},Wt=Ht.NATIVE="N",Gt=Ht.POLYFILL="P",qt=Ht,Jt=Q.f,Kt=Array.isArray||function(t){return"Array"==v(t)},Xt=V("species"),Yt=function(t,r){return new(function(t){var r;return Kt(t)&&("function"!=typeof(r=t.constructor)||r!==Array&&!Kt(r.prototype)?b(r)&&null===(r=r[Xt])&&(r=void 0):r=void 0),void 0===r?Array:r}(t))(0===r?0:r)},Zt=function(t,r,n){var e=q(r);e in t?rt.f(t,e,l(0,n)):t[e]=n},Qt=V("species"),$t=(St="splice",T>=51||!u((function(){var t=[];return(t.constructor={})[Qt]=function(){return{foo:1}},1!==t[St](Boolean).foo}))),tr=Math.max,rr=Math.min,nr=9007199254740991,er="Maximum allowed length exceeded";!function(t,r){var n,e,o,u,c,a=t.target,f=t.global,s=t.stat;if(n=f?i:s?i[a]||N(a,{}):(i[a]||{}).prototype)for(e in r){if(u=r[e],o=t.noTargetGet?(c=Jt(n,e))&&c.value:n[e],!qt(f?e:a+(s?".":"#")+e,t.forced)&&void 0!==o){if(typeof u==typeof o)continue;Lt(u,o)}(t.sham||o&&o.sham)&&nt(u,"sham",!0),_t(n,e,u,t)}}({target:"Array",proto:!0,forced:!$t},{splice:function(t,r){var n,e,o,i,u,c,a=P(this),f=kt(a.length),s=Nt(t,f),l=arguments.length;if(0===l?n=e=0:1===l?(n=0,e=f-s):(n=l-2,e=rr(tr(jt(r),0),f-s)),f+n-e>nr)throw TypeError(er);for(o=Yt(a,e),i=0;i<e;i++)(u=s+i)in a&&Zt(o,i,a[u]);if(o.length=e,n<e){for(i=s;i<f-e;i++)c=i+n,(u=i+e)in a?a[c]=a[u]:delete a[c];for(i=f;i>f-e+n;i--)delete a[i-1]}else if(n>e)for(i=f-e;i>s;i--)c=i+n-1,(u=i+e-1)in a?a[c]=a[u]:delete a[c];for(i=0;i<n;i++)a[i+s]=arguments[i+2];return a.length=f-e+n,o}});var or={};or[V("toStringTag")]="z";var ir="[object z]"===String(or),ur=V("toStringTag"),cr="Arguments"==v(function(){return arguments}()),ar=ir?v:function(t){var r,n,e;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=function(t,r){try{return t[r]}catch(t){}}(r=Object(t),ur))?n:cr?v(r):"Object"==(e=v(r))&&"function"==typeof r.callee?"Arguments":e},fr=ir?{}.toString:function(){return"[object "+ar(this)+"]"};ir||_t(Object.prototype,"toString",fr,{unsafe:!0});var sr=function(t){if(I(t))throw TypeError("Cannot convert a Symbol value to a string");return String(t)},lr=function(){var t=$(this),r="";return t.global&&(r+="g"),t.ignoreCase&&(r+="i"),t.multiline&&(r+="m"),t.dotAll&&(r+="s"),t.unicode&&(r+="u"),t.sticky&&(r+="y"),r},pr="toString",vr=RegExp.prototype,gr=vr.toString,yr=u((function(){return"/a/b"!=gr.call({source:"a",flags:"b"})})),dr=gr.name!=pr;(yr||dr)&&_t(RegExp.prototype,pr,(function(){var t=$(this),r=sr(t.source),n=t.flags;return"/"+r+"/"+sr(void 0===n&&t instanceof RegExp&&!("flags"in vr)?lr.call(t):n)}),{unsafe:!0});var hr,br=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,n={};try{(t=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(n,[]),r=n instanceof Array}catch(t){}return function(n,e){return $(n),function(t){if(!b(t)&&null!==t)throw TypeError("Can't set "+String(t)+" as a prototype")}(e),r?t.call(n,e):n.__proto__=e,n}}():void 0),mr=function(t,r,n){var e,o;return br&&"function"==typeof(e=r.constructor)&&e!==n&&b(o=e.prototype)&&o!==n.prototype&&br(t,o),t},Sr=Object.keys||function(t){return Ct(t,Pt)},wr=c?Object.defineProperties:function(t,r){$(t);for(var n,e=Sr(r),o=e.length,i=0;o>i;)rt.f(t,n=e[i++],r[n]);return t},_r=S("document","documentElement"),Er=lt("IE_PROTO"),Or=function(){},jr=function(t){return"<script>"+t+"</"+"script>"},Tr=function(t){t.write(jr("")),t.close();var r=t.parentWindow.Object;return t=null,r},kr=function(){try{hr=new ActiveXObject("htmlfile")}catch(t){}var t,r;kr="undefined"!=typeof document?document.domain&&hr?Tr(hr):((r=X("iframe")).style.display="none",_r.appendChild(r),r.src=String("javascript:"),(t=r.contentWindow.document).open(),t.write(jr("document.F=Object")),t.close(),t.F):Tr(hr);for(var n=Pt.length;n--;)delete kr.prototype[Pt[n]];return kr()};pt[Er]=!0;var Ar=Object.create||function(t,r){var n;return null!==t?(Or.prototype=$(t),n=new Or,Or.prototype=null,n[Er]=t):n=kr(),void 0===r?n:wr(n,r)},Ir="[\t\n\v\f\r                　\u2028\u2029\ufeff]",Nr=RegExp("^"+Ir+Ir+"*"),Br=RegExp(Ir+Ir+"*$"),xr=function(t){return function(r){var n=sr(d(r));return 1&t&&(n=n.replace(Nr,"")),2&t&&(n=n.replace(Br,"")),n}},Cr={start:xr(1),end:xr(2),trim:xr(3)},Pr=Dt.f,Mr=Q.f,Dr=rt.f,Fr=Cr.trim,Rr="Number",Lr=i.Number,zr=Lr.prototype,Hr=v(Ar(zr))==Rr,Ur=function(t){if(I(t))throw TypeError("Cannot convert a Symbol value to a number");var r,n,e,o,i,u,c,a,f=G(t,"number");if("string"==typeof f&&f.length>2)if(43===(r=(f=Fr(f)).charCodeAt(0))||45===r){if(88===(n=f.charCodeAt(2))||120===n)return NaN}else if(48===r){switch(f.charCodeAt(1)){case 66:case 98:e=2,o=49;break;case 79:case 111:e=8,o=55;break;default:return+f}for(u=(i=f.slice(2)).length,c=0;c<u;c++)if((a=i.charCodeAt(c))<48||a>o)return NaN;return parseInt(i,e)}return+f};if(qt(Rr,!Lr(" 0o1")||!Lr("0b1")||Lr("+0x1"))){for(var Vr,Wr=function(t){var r=arguments.length<1?0:t,n=this;return n instanceof Wr&&(Hr?u((function(){zr.valueOf.call(n)})):v(n)!=Rr)?mr(new Lr(Ur(r)),n,Wr):Ur(r)},Gr=c?Pr(Lr):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),qr=0;Gr.length>qr;qr++)D(Lr,Vr=Gr[qr])&&!D(Wr,Vr)&&Dr(Wr,Vr,Mr(Lr,Vr));Wr.prototype=zr,zr.constructor=Wr,_t(i,Rr,Wr)}var Jr=r((function(t){!function(){var r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",n={rotl:function(t,r){return t<<r|t>>>32-r},rotr:function(t,r){return t<<32-r|t>>>r},endian:function(t){if(t.constructor==Number)return 16711935&n.rotl(t,8)|4278255360&n.rotl(t,24);for(var r=0;r<t.length;r++)t[r]=n.endian(t[r]);return t},randomBytes:function(t){for(var r=[];t>0;t--)r.push(Math.floor(256*Math.random()));return r},bytesToWords:function(t){for(var r=[],n=0,e=0;n<t.length;n++,e+=8)r[e>>>5]|=t[n]<<24-e%32;return r},wordsToBytes:function(t){for(var r=[],n=0;n<32*t.length;n+=8)r.push(t[n>>>5]>>>24-n%32&255);return r},bytesToHex:function(t){for(var r=[],n=0;n<t.length;n++)r.push((t[n]>>>4).toString(16)),r.push((15&t[n]).toString(16));return r.join("")},hexToBytes:function(t){for(var r=[],n=0;n<t.length;n+=2)r.push(parseInt(t.substr(n,2),16));return r},bytesToBase64:function(t){for(var n=[],e=0;e<t.length;e+=3)for(var o=t[e]<<16|t[e+1]<<8|t[e+2],i=0;i<4;i++)8*e+6*i<=8*t.length?n.push(r.charAt(o>>>6*(3-i)&63)):n.push("=");return n.join("")},base64ToBytes:function(t){t=t.replace(/[^A-Z0-9+\/]/gi,"");for(var n=[],e=0,o=0;e<t.length;o=++e%4)0!=o&&n.push((r.indexOf(t.charAt(e-1))&Math.pow(2,-2*o+8)-1)<<2*o|r.indexOf(t.charAt(e))>>>6-2*o);return n}};t.exports=n}()})),Kr={utf8:{stringToBytes:function(t){return Kr.bin.stringToBytes(unescape(encodeURIComponent(t)))},bytesToString:function(t){return decodeURIComponent(escape(Kr.bin.bytesToString(t)))}},bin:{stringToBytes:function(t){for(var r=[],n=0;n<t.length;n++)r.push(255&t.charCodeAt(n));return r},bytesToString:function(t){for(var r=[],n=0;n<t.length;n++)r.push(String.fromCharCode(t[n]));return r.join("")}}},Xr=Kr,Yr=function(t){return null!=t&&(Zr(t)||function(t){return"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&Zr(t.slice(0,0))}(t)||!!t._isBuffer)};function Zr(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}r((function(t){!function(){var r=Jr,n=Xr.utf8,e=Yr,o=Xr.bin,i=function(t,u){t.constructor==String?t=u&&"binary"===u.encoding?o.stringToBytes(t):n.stringToBytes(t):e(t)?t=Array.prototype.slice.call(t,0):Array.isArray(t)||t.constructor===Uint8Array||(t=t.toString());for(var c=r.bytesToWords(t),a=8*t.length,f=1732584193,s=-271733879,l=-1732584194,p=271733878,v=0;v<c.length;v++)c[v]=16711935&(c[v]<<8|c[v]>>>24)|4278255360&(c[v]<<24|c[v]>>>8);c[a>>>5]|=128<<a%32,c[14+(a+64>>>9<<4)]=a;var g=i._ff,y=i._gg,d=i._hh,h=i._ii;for(v=0;v<c.length;v+=16){var b=f,m=s,S=l,w=p;f=g(f,s,l,p,c[v+0],7,-680876936),p=g(p,f,s,l,c[v+1],12,-389564586),l=g(l,p,f,s,c[v+2],17,606105819),s=g(s,l,p,f,c[v+3],22,-1044525330),f=g(f,s,l,p,c[v+4],7,-176418897),p=g(p,f,s,l,c[v+5],12,1200080426),l=g(l,p,f,s,c[v+6],17,-1473231341),s=g(s,l,p,f,c[v+7],22,-45705983),f=g(f,s,l,p,c[v+8],7,1770035416),p=g(p,f,s,l,c[v+9],12,-1958414417),l=g(l,p,f,s,c[v+10],17,-42063),s=g(s,l,p,f,c[v+11],22,-1990404162),f=g(f,s,l,p,c[v+12],7,1804603682),p=g(p,f,s,l,c[v+13],12,-40341101),l=g(l,p,f,s,c[v+14],17,-1502002290),f=y(f,s=g(s,l,p,f,c[v+15],22,1236535329),l,p,c[v+1],5,-165796510),p=y(p,f,s,l,c[v+6],9,-1069501632),l=y(l,p,f,s,c[v+11],14,643717713),s=y(s,l,p,f,c[v+0],20,-373897302),f=y(f,s,l,p,c[v+5],5,-701558691),p=y(p,f,s,l,c[v+10],9,38016083),l=y(l,p,f,s,c[v+15],14,-660478335),s=y(s,l,p,f,c[v+4],20,-405537848),f=y(f,s,l,p,c[v+9],5,568446438),p=y(p,f,s,l,c[v+14],9,-1019803690),l=y(l,p,f,s,c[v+3],14,-187363961),s=y(s,l,p,f,c[v+8],20,1163531501),f=y(f,s,l,p,c[v+13],5,-1444681467),p=y(p,f,s,l,c[v+2],9,-51403784),l=y(l,p,f,s,c[v+7],14,1735328473),f=d(f,s=y(s,l,p,f,c[v+12],20,-1926607734),l,p,c[v+5],4,-378558),p=d(p,f,s,l,c[v+8],11,-2022574463),l=d(l,p,f,s,c[v+11],16,1839030562),s=d(s,l,p,f,c[v+14],23,-35309556),f=d(f,s,l,p,c[v+1],4,-1530992060),p=d(p,f,s,l,c[v+4],11,1272893353),l=d(l,p,f,s,c[v+7],16,-155497632),s=d(s,l,p,f,c[v+10],23,-1094730640),f=d(f,s,l,p,c[v+13],4,681279174),p=d(p,f,s,l,c[v+0],11,-358537222),l=d(l,p,f,s,c[v+3],16,-722521979),s=d(s,l,p,f,c[v+6],23,76029189),f=d(f,s,l,p,c[v+9],4,-640364487),p=d(p,f,s,l,c[v+12],11,-421815835),l=d(l,p,f,s,c[v+15],16,530742520),f=h(f,s=d(s,l,p,f,c[v+2],23,-995338651),l,p,c[v+0],6,-198630844),p=h(p,f,s,l,c[v+7],10,1126891415),l=h(l,p,f,s,c[v+14],15,-1416354905),s=h(s,l,p,f,c[v+5],21,-57434055),f=h(f,s,l,p,c[v+12],6,1700485571),p=h(p,f,s,l,c[v+3],10,-1894986606),l=h(l,p,f,s,c[v+10],15,-1051523),s=h(s,l,p,f,c[v+1],21,-2054922799),f=h(f,s,l,p,c[v+8],6,1873313359),p=h(p,f,s,l,c[v+15],10,-30611744),l=h(l,p,f,s,c[v+6],15,-1560198380),s=h(s,l,p,f,c[v+13],21,1309151649),f=h(f,s,l,p,c[v+4],6,-145523070),p=h(p,f,s,l,c[v+11],10,-1120210379),l=h(l,p,f,s,c[v+2],15,718787259),s=h(s,l,p,f,c[v+9],21,-343485551),f=f+b>>>0,s=s+m>>>0,l=l+S>>>0,p=p+w>>>0}return r.endian([f,s,l,p])};i._ff=function(t,r,n,e,o,i,u){var c=t+(r&n|~r&e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._gg=function(t,r,n,e,o,i,u){var c=t+(r&e|n&~e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._hh=function(t,r,n,e,o,i,u){var c=t+(r^n^e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._ii=function(t,r,n,e,o,i,u){var c=t+(n^(r|~e))+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._blocksize=16,i._digestsize=16,t.exports=function(t,n){if(null==t)throw new Error("Illegal argument "+t);var e=r.wordsToBytes(i(t,n));return n&&n.asBytes?e:n&&n.asString?o.bytesToString(e):r.bytesToHex(e)}}()}));function Qr(t){return"function"==typeof t}var $r={},tn={},rn={};function nn(t){var r=t.invokeId,n=t.event,e=t.payload;if(r||n){e=r?{data:e}:e;for(var o=(r?rn[r]:tn[n])||[],i=0;i<o.length;i++){var u=o[i];try{u.callback(e)}catch(t){var c=__appServiceEngine__&&__appServiceEngine__.getApp();__appServiceSDK__.traceCoreDotting("app_error",{info:t.message+t.stack,isError:!0}),c&&c.onError&&c.onError(t.message+" "+t.stack)}}}}function en(t){if("string"==typeof t)try{t=JSON.parse(t)}catch(t){}for(var r=t.payload,n=t.event,e=$r[n]||[],o=0;o<e.length;o++){var i=e[o];i.isSustain||(e.splice(o,1),o--);try{i.callback(r)}catch(t){var u=__appServiceEngine__&&__appServiceEngine__.getApp();__appServiceSDK__.traceCoreDotting("app_error",{info:t.message+t.stack,isError:!0}),u&&u.onError&&u.onError(t.message+" "+t.stack)}}}var on=function(t){var r=t.isSustain,n=void 0===r||r,e=t.method,o=t.callback,i=t.invokeId;if(o){var u={method:e,callback:o,isSustain:n};rn[i]?rn[i].push(u):rn[i]=[u]}},un=DiminaServiceBridge&&Qr(DiminaServiceBridge.invoke),cn=DiminaServiceBridge&&Qr(DiminaServiceBridge.publish),an={invoke:function(t){var r=t.method,n=t.module,e=void 0===n?"":n,o=t.data,i=t.invokeId,u=t.isSustain,c=void 0!==u&&u,a=t.callback;if(r){if(a&&(i||(i=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36)),on({invokeId:i,method:r,isSustain:c,callback:a})),un)return DiminaServiceBridge.invoke(r,o,i,e);throw new Error("Service bridge invoke failed.")}},publish:function(t){var r=t.event,n=t.webViewId,e=t.data;if(r){if(!cn)throw new Error("Service bridge publish failed.");var o={data:e};DiminaServiceBridge.publish(JSON.stringify({event:r,payload:o}),n)}},on:function(t,r){var n=t.isSustain,e=void 0===n||n,o=t.method,i=t.callback,u=t.event;if(i=i||r){var c={method:o,callback:i,isSustain:e};tn[u]?tn[u].push(c):tn[u]=[c]}},onBridgeCb:on,off:function(t){var r=t.event,n=t.callback;if(r){if(n&&!Qr(n))throw new Error("Error in off: callback should be function");if(n)for(var e=tn[r]||[],o=0;o<e.length;++o){(e[o]||{}).callback===n&&(e.splice(o,1),o--)}else tn[r]=[]}},subscribe:function(t,r){var n=t.event,e=t.isSustain,o=void 0===e||e,i=t.callback;if(i=i||r){var u={event:n,callback:i,isSustain:o};$r[u.event]?$r[u.event].push(u):$r[u.event]=[u]}},clearAll:function(){$r={},rn={},tn={}},invokeCallbackHandler:nn,subscribeHandler:en};return DiminaServiceBridge&&(DiminaServiceBridge.invokeCallbackHandler=nn,DiminaServiceBridge.subscribeHandler=en),an}();


// ide 在全局注入的 变量
if (isDevTools) {
  didiJsBridge = new acquireLocalBridge({ from: 'AppService' })
}

var Reporter=function(){"use strict";function t(e){return(t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(e)}function e(){return(e=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var r=arguments[e];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(t[n]=r[n])}return t}).apply(this,arguments)}var r=function(t){try{return!!t()}catch(t){return!0}},n=!r((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),o="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function i(t,e,r){return t(r={path:e,exports:{},require:function(t,e){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==e&&r.path)}},r.exports),r.exports}var a,c,u=function(t){return t&&t.Math==Math&&t},f=u("object"==typeof globalThis&&globalThis)||u("object"==typeof window&&window)||u("object"==typeof self&&self)||u("object"==typeof o&&o)||function(){return this}()||Function("return this")(),p=/#|\.prototype\./,s=function(t,e){var n=m[l(t)];return n==v||n!=y&&("function"==typeof e?r(e):!!e)},l=s.normalize=function(t){return String(t).replace(p,".").toLowerCase()},m=s.data={},y=s.NATIVE="N",v=s.POLYFILL="P",d=s,g=function(t){return"object"==typeof t?null!==t:"function"==typeof t},b=f.document,h=g(b)&&g(b.createElement),_=function(t){return h?b.createElement(t):{}},S=!n&&!r((function(){return 7!=Object.defineProperty(_("div"),"a",{get:function(){return 7}}).a})),w=function(t){if(!g(t))throw TypeError(String(t)+" is not an object");return t},O=function(t){return"function"==typeof t?t:void 0},j=function(t,e){return arguments.length<2?O(f[t]):f[t]&&f[t][e]},N=j("navigator","userAgent")||"",E=f.process,P=f.Deno,T=E&&E.versions||P&&P.version,I=T&&T.v8;I?c=(a=I.split("."))[0]<4?1:a[0]+a[1]:N&&(!(a=N.match(/Edge\/(\d+)/))||a[1]>=74)&&(a=N.match(/Chrome\/(\d+)/))&&(c=a[1]);var R,k=c&&+c,L=!!Object.getOwnPropertySymbols&&!r((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&k&&k<41})),M=L&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,A=M?function(t){return"symbol"==typeof t}:function(t){var e=j("Symbol");return"function"==typeof e&&Object(t)instanceof e},C=function(t,e){try{Object.defineProperty(f,t,{value:e,configurable:!0,writable:!0})}catch(r){f[t]=e}return e},F="__core-js_shared__",D=f[F]||C(F,{}),x=i((function(t){(t.exports=function(t,e){return D[t]||(D[t]=void 0!==e?e:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),B=function(t){if(null==t)throw TypeError("Can't call method on "+t);return t},J={}.hasOwnProperty,V=Object.hasOwn||function(t,e){return J.call(Object(B(t)),e)},z=0,G=Math.random(),W=function(t){return"Symbol("+String(void 0===t?"":t)+")_"+(++z+G).toString(36)},q=x("wks"),X=f.Symbol,Y=M?X:X&&X.withoutSetter||W,U=(V(q,R="toPrimitive")&&(L||"string"==typeof q[R])||(L&&V(X,R)?q[R]=X[R]:q[R]=Y("Symbol."+R)),q[R]),$=function(t,e){if(!g(t)||A(t))return t;var r,n=t[U];if(void 0!==n){if(void 0===e&&(e="default"),r=n.call(t,e),!g(r)||A(r))return r;throw TypeError("Can't convert object to primitive value")}return void 0===e&&(e="number"),function(t,e){var r,n;if("string"===e&&"function"==typeof(r=t.toString)&&!g(n=r.call(t)))return n;if("function"==typeof(r=t.valueOf)&&!g(n=r.call(t)))return n;if("string"!==e&&"function"==typeof(r=t.toString)&&!g(n=r.call(t)))return n;throw TypeError("Can't convert object to primitive value")}(t,e)},H=function(t){var e=$(t,"string");return A(e)?e:String(e)},K=Object.defineProperty,Q={f:n?K:function(t,e,r){if(w(t),e=H(e),w(r),S)try{return K(t,e,r)}catch(t){}if("get"in r||"set"in r)throw TypeError("Accessors not supported");return"value"in r&&(t[e]=r.value),t}},Z=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}},tt=n?function(t,e,r){return Q.f(t,e,Z(1,r))}:function(t,e,r){return t[e]=r,t},et=Function.toString;"function"!=typeof D.inspectSource&&(D.inspectSource=function(t){return et.call(t)});var rt,nt,ot,it=D.inspectSource,at=f.WeakMap,ct="function"==typeof at&&/native code/.test(it(at)),ut=x("keys"),ft=function(t){return ut[t]||(ut[t]=W(t))},pt={},st="Object already initialized",lt=f.WeakMap;if(ct||D.state){var mt=D.state||(D.state=new lt),yt=mt.get,vt=mt.has,dt=mt.set;rt=function(t,e){if(vt.call(mt,t))throw new TypeError(st);return e.facade=t,dt.call(mt,t,e),e},nt=function(t){return yt.call(mt,t)||{}},ot=function(t){return vt.call(mt,t)}}else{var gt=ft("state");pt[gt]=!0,rt=function(t,e){if(V(t,gt))throw new TypeError(st);return e.facade=t,tt(t,gt,e),e},nt=function(t){return V(t,gt)?t[gt]:{}},ot=function(t){return V(t,gt)}}var bt,ht={set:rt,get:nt,has:ot,enforce:function(t){return ot(t)?nt(t):rt(t,{})},getterFor:function(t){return function(e){var r;if(!g(e)||(r=nt(e)).type!==t)throw TypeError("Incompatible receiver, "+t+" required");return r}}},_t=i((function(t){var e=ht.get,r=ht.enforce,n=String(String).split("String");(t.exports=function(t,e,o,i){var a,c=!!i&&!!i.unsafe,u=!!i&&!!i.enumerable,p=!!i&&!!i.noTargetGet;"function"==typeof o&&("string"!=typeof e||V(o,"name")||tt(o,"name",e),(a=r(o)).source||(a.source=n.join("string"==typeof e?e:""))),t!==f?(c?!p&&t[e]&&(u=!0):delete t[e],u?t[e]=o:tt(t,e,o)):u?t[e]=o:C(e,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&e(this).source||it(this)}))})),St={}.toString,wt=function(t){return St.call(t).slice(8,-1)},Ot=Object.setPrototypeOf||("__proto__"in{}?function(){var t,e=!1,r={};try{(t=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(r,[]),e=r instanceof Array}catch(t){}return function(r,n){return w(r),function(t){if(!g(t)&&null!==t)throw TypeError("Can't set "+String(t)+" as a prototype")}(n),e?t.call(r,n):r.__proto__=n,r}}():void 0),jt=function(t,e,r){var n,o;return Ot&&"function"==typeof(n=e.constructor)&&n!==r&&g(o=n.prototype)&&o!==r.prototype&&Ot(t,o),t},Nt="".split,Et=r((function(){return!Object("z").propertyIsEnumerable(0)}))?function(t){return"String"==wt(t)?Nt.call(t,""):Object(t)}:Object,Pt=function(t){return Et(B(t))},Tt=Math.ceil,It=Math.floor,Rt=function(t){return isNaN(t=+t)?0:(t>0?It:Tt)(t)},kt=Math.min,Lt=Math.max,Mt=Math.min,At=function(t){return function(e,r,n){var o,i,a=Pt(e),c=(o=a.length)>0?kt(Rt(o),9007199254740991):0,u=function(t,e){var r=Rt(t);return r<0?Lt(r+e,0):Mt(r,e)}(n,c);if(t&&r!=r){for(;c>u;)if((i=a[u++])!=i)return!0}else for(;c>u;u++)if((t||u in a)&&a[u]===r)return t||u||0;return!t&&-1}},Ct={includes:At(!0),indexOf:At(!1)}.indexOf,Ft=function(t,e){var r,n=Pt(t),o=0,i=[];for(r in n)!V(pt,r)&&V(n,r)&&i.push(r);for(;e.length>o;)V(n,r=e[o++])&&(~Ct(i,r)||i.push(r));return i},Dt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],xt=Object.keys||function(t){return Ft(t,Dt)},Bt=n?Object.defineProperties:function(t,e){w(t);for(var r,n=xt(e),o=n.length,i=0;o>i;)Q.f(t,r=n[i++],e[r]);return t},Jt=j("document","documentElement"),Vt=ft("IE_PROTO"),zt=function(){},Gt=function(t){return"<script>"+t+"</"+"script>"},Wt=function(t){t.write(Gt("")),t.close();var e=t.parentWindow.Object;return t=null,e},qt=function(){try{bt=new ActiveXObject("htmlfile")}catch(t){}var t,e;qt="undefined"!=typeof document?document.domain&&bt?Wt(bt):((e=_("iframe")).style.display="none",Jt.appendChild(e),e.src=String("javascript:"),(t=e.contentWindow.document).open(),t.write(Gt("document.F=Object")),t.close(),t.F):Wt(bt);for(var r=Dt.length;r--;)delete qt.prototype[Dt[r]];return qt()};pt[Vt]=!0;var Xt=Object.create||function(t,e){var r;return null!==t?(zt.prototype=w(t),r=new zt,zt.prototype=null,r[Vt]=t):r=qt(),void 0===e?r:Bt(r,e)},Yt=Dt.concat("length","prototype"),Ut={f:Object.getOwnPropertyNames||function(t){return Ft(t,Yt)}},$t={}.propertyIsEnumerable,Ht=Object.getOwnPropertyDescriptor,Kt={f:Ht&&!$t.call({1:2},1)?function(t){var e=Ht(this,t);return!!e&&e.enumerable}:$t},Qt=Object.getOwnPropertyDescriptor,Zt={f:n?Qt:function(t,e){if(t=Pt(t),e=H(e),S)try{return Qt(t,e)}catch(t){}if(V(t,e))return Z(!Kt.f.call(t,e),t[e])}},te="[\t\n\v\f\r                　\u2028\u2029\ufeff]",ee=RegExp("^"+te+te+"*"),re=RegExp(te+te+"*$"),ne=function(t){return function(e){var r=function(t){if(A(t))throw TypeError("Cannot convert a Symbol value to a string");return String(t)}(B(e));return 1&t&&(r=r.replace(ee,"")),2&t&&(r=r.replace(re,"")),r}},oe={start:ne(1),end:ne(2),trim:ne(3)},ie=Ut.f,ae=Zt.f,ce=Q.f,ue=oe.trim,fe="Number",pe=f.Number,se=pe.prototype,le=wt(Xt(se))==fe,me=function(t){if(A(t))throw TypeError("Cannot convert a Symbol value to a number");var e,r,n,o,i,a,c,u,f=$(t,"number");if("string"==typeof f&&f.length>2)if(43===(e=(f=ue(f)).charCodeAt(0))||45===e){if(88===(r=f.charCodeAt(2))||120===r)return NaN}else if(48===e){switch(f.charCodeAt(1)){case 66:case 98:n=2,o=49;break;case 79:case 111:n=8,o=55;break;default:return+f}for(a=(i=f.slice(2)).length,c=0;c<a;c++)if((u=i.charCodeAt(c))<48||u>o)return NaN;return parseInt(i,n)}return+f};if(d(fe,!pe(" 0o1")||!pe("0b1")||pe("+0x1"))){for(var ye,ve=function(t){var e=arguments.length<1?0:t,n=this;return n instanceof ve&&(le?r((function(){se.valueOf.call(n)})):wt(n)!=fe)?jt(new pe(me(e)),n,ve):me(e)},de=n?ie(pe):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),ge=0;de.length>ge;ge++)V(pe,ye=de[ge])&&!V(ve,ye)&&ce(ve,ye,ae(pe,ye));ve.prototype=se,se.constructor=ve,_t(f,fe,ve)}
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */var be,he=function(){return(he=Object.assign||function(t){for(var e,r=1,n=arguments.length;r<n;r++)for(var o in e=arguments[r])Object.prototype.hasOwnProperty.call(e,o)&&(t[o]=e[o]);return t}).apply(this,arguments)},_e=[],Se=0,we=(new Date).getTime();!function(t){t.pageLoad="pub_saga_page_load_bt",t.errorMessage="pub_saga_error_message_bt"}(be||(be={}));var Oe=!1,je={};return function(){function r(){}return r.ddBridge=function(t,e){t&&t.event&&didiJsBridge.invoke({method:t.event,module:"DMServiceBridgeModule",data:t.data||{},isSustain:t.isSustain||!1,callback:e||function(e){(e=e.data).success?t.success&&t.success(e.data):t.fail&&t.fail({errMsg:e.errMsg}),t.complete&&t.complete()}})},r.reportNative=function(e,n){var o={};if(e){if(n)for(var i in n){var a=n[i];void 0===a||!a&&void 0!==a&&0!==a||(o[i]=n[i]),"object"===t(a)&&(o[i]=JSON.stringify(n[i]))}Oe?(o=r.formatReportParmas(je,n),r.reportAnalytics(e,o)):r.ddBridge({event:"getSystemInfo",data:{},success:function(i){for(var a in i){var c=i[a];void 0===c||!c&&void 0!==c&&0!==c||(je[a.toLowerCase()]=c),"object"===t(c)&&(je[a.toLowerCase()]=JSON.stringify(c))}o=r.formatReportParmas(je,n),r.reportAnalytics(e,o),Oe=!0}})}},r.reportAnalytics=function(t,n){r.ddBridge({event:"reportAnalytics",data:{eventName:t,data:e(he({},n),je)}})},r.traceBeginEvent=function(t,e){if(t&&e)try{var r={category:t,name:e,timeStamp:(new Date).getTime()};if(_e.length>=1){var n=_e.length-1;Se=(new Date).getTime()-_e[n].timeStamp}_e.push(r)}catch(t){}},r.traceEndEvent=function(){if(_e&&_e.length)try{var t=_e.pop(),e=(new Date).getTime(),n=e-t.timeStamp,o={category:"",name:"",timeStamp:e};_e&&_e.length&&(o=_e[_e.length-1]),r.reportNative(("pub_saga_"+t.category+"_"+t.name+"_bt").toLowerCase(),{reportId:we,start_time:t.timeStamp,end_time:e,take_up_time:n,take_begin_time:Se,take_before_name:o.name,take_before_category:o.category})}catch(t){}},r.reportAppLaunchTime=function(t){void 0===t&&(t={app_launch_time:"",saga_launch:""}),t.app_launch_time&&(r.appLaunchTime=Number(t.app_launch_time)),t.saga_launch&&(r.sagaLaunchTime=Number(t.saga_launch))},r.pageLoadReport=function(t,e){var n=(new Date).getTime();r.reportNative(""+be.pageLoad,{timetigger:n,path:t,webviewid:e,app_launch_time:n-(r.appLaunchTime||n),saga_launch_time:n-(r.sagaLaunchTime||n)})},r.errorReport=function(t){r.reportNative(""+be.errorMessage,{key:t.key,type:t.type,error:t.error})},r.ravenReport=function(e,n,o){var i={};e&&(Oe?(i=r.formatReportParmas(je,n),r.reportRavenNative(e,i,n,o)):r.ddBridge({event:"getSystemInfo",data:{},success:function(a){for(var c in a){var u=a[c];void 0===u||!u&&void 0!==u&&0!==u||(je[c.toLowerCase()]=u),"object"===t(u)&&(je[c.toLowerCase()]=JSON.stringify(u))}i=r.formatReportParmas(je,n),r.reportRavenNative(e,i,n,o),Oe=!0}}))},r.formatReportParmas=function(n,o){var i={};if(o)for(var a in o){var c=o[a];void 0===c||!c&&void 0!==c&&0!==c||"fail"===a||(i[a]=o[a]),"object"===t(c)&&"fail"!==a&&(i[a]=JSON.stringify(o[a]))}return r.publicReportParams.jssdk_version=n.jssdkversion,r.publicReportParams.platform=n.platform,r.publicReportParams.brand=n.brand,r.publicReportParams.app_version=n.sdkversion,r.publicReportParams.applets_version=n.appversion,r.publicReportParams.app_id=n.appid,i=e(he({},i),r.publicReportParams)},r.reportRavenNative=function(t,e,r,n){didiJsBridge.invoke({method:"traceRaven",data:{eventName:t,data:e||{}},callback:n||function(t){(t=t.data).success?r.success&&r.success(t.data):r.fail&&r.fail({errMsg:t.errMsg}),r.complete&&r.complete()}})},r.appLaunchTime=0,r.sagaLaunchTime=0,r.publicReportParams={jssdk_version:"",app_id:"",app_version:"",applets_version:"",platform:"",brand:"",user_info:""},r}()}();


!function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function n(t,n,e){return t(e={path:n,exports:{},require:function(t,n){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==n&&e.path)}},e.exports),e.exports}var e,r,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),c={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},a=function(t){if("function"!=typeof t)throw TypeError(String(t)+" is not a function");return t},u=function(t,n,e){if(a(t),void 0===n)return t;switch(e){case 0:return function(){return t.call(n)};case 1:return function(e){return t.call(n,e)};case 2:return function(e,r){return t.call(n,e,r)};case 3:return function(e,r,o){return t.call(n,e,r,o)}}return function(){return t.apply(n,arguments)}},f=function(t){try{return!!t()}catch(t){return!0}},s={}.toString,l=function(t){return s.call(t).slice(8,-1)},p="".split,d=f((function(){return!Object("z").propertyIsEnumerable(0)}))?function(t){return"String"==l(t)?p.call(t,""):Object(t)}:Object,v=function(t){if(null==t)throw TypeError("Can't call method on "+t);return t},h=function(t){return Object(v(t))},y=Math.ceil,g=Math.floor,m=function(t){return isNaN(t=+t)?0:(t>0?g:y)(t)},b=Math.min,_=function(t){return t>0?b(m(t),9007199254740991):0},w=function(t){return"object"==typeof t?null!==t:"function"==typeof t},S=Array.isArray||function(t){return"Array"==l(t)},C=function(t,n){try{Object.defineProperty(i,t,{value:n,configurable:!0,writable:!0})}catch(e){i[t]=n}return n},j="__core-js_shared__",O=i[j]||C(j,{}),T=n((function(t){(t.exports=function(t,n){return O[t]||(O[t]=void 0!==n?n:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),x={}.hasOwnProperty,E=Object.hasOwn||function(t,n){return x.call(h(t),n)},P=0,A=Math.random(),R=function(t){return"Symbol("+String(void 0===t?"":t)+")_"+(++P+A).toString(36)},I=function(t){return"function"==typeof t?t:void 0},k=function(t,n){return arguments.length<2?I(i[t]):i[t]&&i[t][n]},L=k("navigator","userAgent")||"",M=i.process,D=i.Deno,F=M&&M.versions||D&&D.version,V=F&&F.v8;V?r=(e=V.split("."))[0]<4?1:e[0]+e[1]:L&&(!(e=L.match(/Edge\/(\d+)/))||e[1]>=74)&&(e=L.match(/Chrome\/(\d+)/))&&(r=e[1]);var N=r&&+r,G=!!Object.getOwnPropertySymbols&&!f((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&N&&N<41})),W=G&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,B=T("wks"),U=i.Symbol,H=W?U:U&&U.withoutSetter||R,q=function(t){return E(B,t)&&(G||"string"==typeof B[t])||(G&&E(U,t)?B[t]=U[t]:B[t]=H("Symbol."+t)),B[t]},z=q("species"),K=function(t,n){return new(function(t){var n;return S(t)&&("function"!=typeof(n=t.constructor)||n!==Array&&!S(n.prototype)?w(n)&&null===(n=n[z])&&(n=void 0):n=void 0),void 0===n?Array:n}(t))(0===n?0:n)},Y=[].push,J=function(t){var n=1==t,e=2==t,r=3==t,o=4==t,i=6==t,c=7==t,a=5==t||i;return function(f,s,l,p){for(var v,y,g=h(f),m=d(g),b=u(s,l,3),w=_(m.length),S=0,C=p||K,j=n?C(f,w):e||c?C(f,0):void 0;w>S;S++)if((a||S in m)&&(y=b(v=m[S],S,g),t))if(n)j[S]=y;else if(y)switch(t){case 3:return!0;case 5:return v;case 6:return S;case 2:Y.call(j,v)}else switch(t){case 4:return!1;case 7:Y.call(j,v)}return i?-1:r||o?o:j}},X={forEach:J(0),map:J(1),filter:J(2),some:J(3),every:J(4),find:J(5),findIndex:J(6),filterReject:J(7)}.forEach,Q=function(t,n){var e=[][t];return!!e&&f((function(){e.call(null,n||function(){throw 1},1)}))}("forEach")?[].forEach:function(t){return X(this,t,arguments.length>1?arguments[1]:void 0)},Z=!f((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),$=i.document,tt=w($)&&w($.createElement),nt=function(t){return tt?$.createElement(t):{}},et=!Z&&!f((function(){return 7!=Object.defineProperty(nt("div"),"a",{get:function(){return 7}}).a})),rt=function(t){if(!w(t))throw TypeError(String(t)+" is not an object");return t},ot=W?function(t){return"symbol"==typeof t}:function(t){var n=k("Symbol");return"function"==typeof n&&Object(t)instanceof n},it=q("toPrimitive"),ct=function(t,n){if(!w(t)||ot(t))return t;var e,r=t[it];if(void 0!==r){if(void 0===n&&(n="default"),e=r.call(t,n),!w(e)||ot(e))return e;throw TypeError("Can't convert object to primitive value")}return void 0===n&&(n="number"),function(t,n){var e,r;if("string"===n&&"function"==typeof(e=t.toString)&&!w(r=e.call(t)))return r;if("function"==typeof(e=t.valueOf)&&!w(r=e.call(t)))return r;if("string"!==n&&"function"==typeof(e=t.toString)&&!w(r=e.call(t)))return r;throw TypeError("Can't convert object to primitive value")}(t,n)},at=function(t){var n=ct(t,"string");return ot(n)?n:String(n)},ut=Object.defineProperty,ft={f:Z?ut:function(t,n,e){if(rt(t),n=at(n),rt(e),et)try{return ut(t,n,e)}catch(t){}if("get"in e||"set"in e)throw TypeError("Accessors not supported");return"value"in e&&(t[n]=e.value),t}},st=function(t,n){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:n}},lt=Z?function(t,n,e){return ft.f(t,n,st(1,e))}:function(t,n,e){return t[n]=e,t};for(var pt in c){var dt=i[pt],vt=dt&&dt.prototype;if(vt&&vt.forEach!==Q)try{lt(vt,"forEach",Q)}catch(t){vt.forEach=Q}}var ht,yt=function(t){return d(v(t))},gt=Math.max,mt=Math.min,bt=function(t){return function(n,e,r){var o,i=yt(n),c=_(i.length),a=function(t,n){var e=m(t);return e<0?gt(e+n,0):mt(e,n)}(r,c);if(t&&e!=e){for(;c>a;)if((o=i[a++])!=o)return!0}else for(;c>a;a++)if((t||a in i)&&i[a]===e)return t||a||0;return!t&&-1}},_t={includes:bt(!0),indexOf:bt(!1)},wt={},St=_t.indexOf,Ct=function(t,n){var e,r=yt(t),o=0,i=[];for(e in r)!E(wt,e)&&E(r,e)&&i.push(e);for(;n.length>o;)E(r,e=n[o++])&&(~St(i,e)||i.push(e));return i},jt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ot=Object.keys||function(t){return Ct(t,jt)},Tt=Z?Object.defineProperties:function(t,n){rt(t);for(var e,r=Ot(n),o=r.length,i=0;o>i;)ft.f(t,e=r[i++],n[e]);return t},xt=k("document","documentElement"),Et=T("keys"),Pt=function(t){return Et[t]||(Et[t]=R(t))},At=Pt("IE_PROTO"),Rt=function(){},It=function(t){return"<script>"+t+"</"+"script>"},kt=function(t){t.write(It("")),t.close();var n=t.parentWindow.Object;return t=null,n},Lt=function(){try{ht=new ActiveXObject("htmlfile")}catch(t){}var t,n;Lt="undefined"!=typeof document?document.domain&&ht?kt(ht):((n=nt("iframe")).style.display="none",xt.appendChild(n),n.src=String("javascript:"),(t=n.contentWindow.document).open(),t.write(It("document.F=Object")),t.close(),t.F):kt(ht);for(var e=jt.length;e--;)delete Lt.prototype[jt[e]];return Lt()};wt[At]=!0;var Mt=Object.create||function(t,n){var e;return null!==t?(Rt.prototype=rt(t),e=new Rt,Rt.prototype=null,e[At]=t):e=Lt(),void 0===n?e:Tt(e,n)},Dt=q("unscopables"),Ft=Array.prototype;null==Ft[Dt]&&ft.f(Ft,Dt,{configurable:!0,value:Mt(null)});var Vt=function(t){Ft[Dt][t]=!0},Nt={},Gt=Function.toString;"function"!=typeof O.inspectSource&&(O.inspectSource=function(t){return Gt.call(t)});var Wt,Bt,Ut,Ht=O.inspectSource,qt=i.WeakMap,zt="function"==typeof qt&&/native code/.test(Ht(qt)),Kt="Object already initialized",Yt=i.WeakMap;if(zt||O.state){var Jt=O.state||(O.state=new Yt),Xt=Jt.get,Qt=Jt.has,Zt=Jt.set;Wt=function(t,n){if(Qt.call(Jt,t))throw new TypeError(Kt);return n.facade=t,Zt.call(Jt,t,n),n},Bt=function(t){return Xt.call(Jt,t)||{}},Ut=function(t){return Qt.call(Jt,t)}}else{var $t=Pt("state");wt[$t]=!0,Wt=function(t,n){if(E(t,$t))throw new TypeError(Kt);return n.facade=t,lt(t,$t,n),n},Bt=function(t){return E(t,$t)?t[$t]:{}},Ut=function(t){return E(t,$t)}}var tn,nn,en,rn={set:Wt,get:Bt,has:Ut,enforce:function(t){return Ut(t)?Bt(t):Wt(t,{})},getterFor:function(t){return function(n){var e;if(!w(n)||(e=Bt(n)).type!==t)throw TypeError("Incompatible receiver, "+t+" required");return e}}},on={}.propertyIsEnumerable,cn=Object.getOwnPropertyDescriptor,an={f:cn&&!on.call({1:2},1)?function(t){var n=cn(this,t);return!!n&&n.enumerable}:on},un=Object.getOwnPropertyDescriptor,fn={f:Z?un:function(t,n){if(t=yt(t),n=at(n),et)try{return un(t,n)}catch(t){}if(E(t,n))return st(!an.f.call(t,n),t[n])}},sn=n((function(t){var n=rn.get,e=rn.enforce,r=String(String).split("String");(t.exports=function(t,n,o,c){var a,u=!!c&&!!c.unsafe,f=!!c&&!!c.enumerable,s=!!c&&!!c.noTargetGet;"function"==typeof o&&("string"!=typeof n||E(o,"name")||lt(o,"name",n),(a=e(o)).source||(a.source=r.join("string"==typeof n?n:""))),t!==i?(u?!s&&t[n]&&(f=!0):delete t[n],f?t[n]=o:lt(t,n,o)):f?t[n]=o:C(n,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&n(this).source||Ht(this)}))})),ln=jt.concat("length","prototype"),pn={f:Object.getOwnPropertyNames||function(t){return Ct(t,ln)}},dn={f:Object.getOwnPropertySymbols},vn=k("Reflect","ownKeys")||function(t){var n=pn.f(rt(t)),e=dn.f;return e?n.concat(e(t)):n},hn=function(t,n){for(var e=vn(n),r=ft.f,o=fn.f,i=0;i<e.length;i++){var c=e[i];E(t,c)||r(t,c,o(n,c))}},yn=/#|\.prototype\./,gn=function(t,n){var e=bn[mn(t)];return e==wn||e!=_n&&("function"==typeof n?f(n):!!n)},mn=gn.normalize=function(t){return String(t).replace(yn,".").toLowerCase()},bn=gn.data={},_n=gn.NATIVE="N",wn=gn.POLYFILL="P",Sn=gn,Cn=fn.f,jn=function(t,n){var e,r,o,c,a,u=t.target,f=t.global,s=t.stat;if(e=f?i:s?i[u]||C(u,{}):(i[u]||{}).prototype)for(r in n){if(c=n[r],o=t.noTargetGet?(a=Cn(e,r))&&a.value:e[r],!Sn(f?r:u+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof c==typeof o)continue;hn(c,o)}(t.sham||o&&o.sham)&&lt(c,"sham",!0),sn(e,r,c,t)}},On=!f((function(){function t(){}return t.prototype.constructor=null,Object.getPrototypeOf(new t)!==t.prototype})),Tn=Pt("IE_PROTO"),xn=Object.prototype,En=On?Object.getPrototypeOf:function(t){return t=h(t),E(t,Tn)?t[Tn]:"function"==typeof t.constructor&&t instanceof t.constructor?t.constructor.prototype:t instanceof Object?xn:null},Pn=q("iterator"),An=!1;[].keys&&("next"in(en=[].keys())?(nn=En(En(en)))!==Object.prototype&&(tn=nn):An=!0),(null==tn||f((function(){var t={};return tn[Pn].call(t)!==t})))&&(tn={}),E(tn,Pn)||lt(tn,Pn,(function(){return this}));var Rn={IteratorPrototype:tn,BUGGY_SAFARI_ITERATORS:An},In=ft.f,kn=q("toStringTag"),Ln=function(t,n,e){t&&!E(t=e?t:t.prototype,kn)&&In(t,kn,{configurable:!0,value:n})},Mn=Rn.IteratorPrototype,Dn=function(){return this},Fn=Object.setPrototypeOf||("__proto__"in{}?function(){var t,n=!1,e={};try{(t=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(e,[]),n=e instanceof Array}catch(t){}return function(e,r){return rt(e),function(t){if(!w(t)&&null!==t)throw TypeError("Can't set "+String(t)+" as a prototype")}(r),n?t.call(e,r):e.__proto__=r,e}}():void 0),Vn=Rn.IteratorPrototype,Nn=Rn.BUGGY_SAFARI_ITERATORS,Gn=q("iterator"),Wn="keys",Bn="values",Un="entries",Hn=function(){return this},qn=function(t,n,e,r,o,i,c){!function(t,n,e){var r=n+" Iterator";t.prototype=Mt(Mn,{next:st(1,e)}),Ln(t,r,!1),Nt[r]=Dn}(e,n,r);var a,u,f,s=function(t){if(t===o&&h)return h;if(!Nn&&t in d)return d[t];switch(t){case Wn:case Bn:case Un:return function(){return new e(this,t)}}return function(){return new e(this)}},l=n+" Iterator",p=!1,d=t.prototype,v=d[Gn]||d["@@iterator"]||o&&d[o],h=!Nn&&v||s(o),y="Array"==n&&d.entries||v;if(y&&(a=En(y.call(new t)),Vn!==Object.prototype&&a.next&&(En(a)!==Vn&&(Fn?Fn(a,Vn):"function"!=typeof a[Gn]&&lt(a,Gn,Hn)),Ln(a,l,!0))),o==Bn&&v&&v.name!==Bn&&(p=!0,h=function(){return v.call(this)}),d[Gn]!==h&&lt(d,Gn,h),Nt[n]=h,o)if(u={values:s(Bn),keys:i?h:s(Wn),entries:s(Un)},c)for(f in u)(Nn||p||!(f in d))&&sn(d,f,u[f]);else jn({target:n,proto:!0,forced:Nn||p},u);return u},zn="Array Iterator",Kn=rn.set,Yn=rn.getterFor(zn),Jn=qn(Array,"Array",(function(t,n){Kn(this,{type:zn,target:yt(t),index:0,kind:n})}),(function(){var t=Yn(this),n=t.target,e=t.kind,r=t.index++;return!n||r>=n.length?(t.target=void 0,{value:void 0,done:!0}):"keys"==e?{value:r,done:!1}:"values"==e?{value:n[r],done:!1}:{value:[r,n[r]],done:!1}}),"values");Nt.Arguments=Nt.Array,Vt("keys"),Vt("values"),Vt("entries");var Xn={};Xn[q("toStringTag")]="z";var Qn="[object z]"===String(Xn),Zn=q("toStringTag"),$n="Arguments"==l(function(){return arguments}()),te=Qn?l:function(t){var n,e,r;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,n){try{return t[n]}catch(t){}}(n=Object(t),Zn))?e:$n?l(n):"Object"==(r=l(n))&&"function"==typeof n.callee?"Arguments":r},ne=Qn?{}.toString:function(){return"[object "+te(this)+"]"};Qn||sn(Object.prototype,"toString",ne,{unsafe:!0});var ee=i.Promise,re=q("species"),oe=q("iterator"),ie=Array.prototype,ce=q("iterator"),ae=function(t){var n=t.return;if(void 0!==n)return rt(n.call(t)).value},ue=function(t,n){this.stopped=t,this.result=n},fe=function(t,n,e){var r,o,i,c,a,f,s,l,p=e&&e.that,d=!(!e||!e.AS_ENTRIES),v=!(!e||!e.IS_ITERATOR),h=!(!e||!e.INTERRUPTED),y=u(n,p,1+d+h),g=function(t){return r&&ae(r),new ue(!0,t)},m=function(t){return d?(rt(t),h?y(t[0],t[1],g):y(t[0],t[1])):h?y(t,g):y(t)};if(v)r=t;else{if("function"!=typeof(o=function(t){if(null!=t)return t[ce]||t["@@iterator"]||Nt[te(t)]}(t)))throw TypeError("Target is not iterable");if(void 0!==(l=o)&&(Nt.Array===l||ie[oe]===l)){for(i=0,c=_(t.length);c>i;i++)if((a=m(t[i]))&&a instanceof ue)return a;return new ue(!1)}r=o.call(t)}for(f=r.next;!(s=f.call(r)).done;){try{a=m(s.value)}catch(t){throw ae(r),t}if("object"==typeof a&&a&&a instanceof ue)return a}return new ue(!1)},se=q("iterator"),le=!1;try{var pe=0,de={next:function(){return{done:!!pe++}},return:function(){le=!0}};de[se]=function(){return this},Array.from(de,(function(){throw 2}))}catch(t){}var ve,he,ye,ge,me=q("species"),be=/(?:ipad|iphone|ipod).*applewebkit/i.test(L),_e="process"==l(i.process),we=i.setImmediate,Se=i.clearImmediate,Ce=i.process,je=i.MessageChannel,Oe=i.Dispatch,Te=0,xe={},Ee="onreadystatechange";try{ve=i.location}catch(t){}var Pe=function(t){if(xe.hasOwnProperty(t)){var n=xe[t];delete xe[t],n()}},Ae=function(t){return function(){Pe(t)}},Re=function(t){Pe(t.data)},Ie=function(t){i.postMessage(String(t),ve.protocol+"//"+ve.host)};we&&Se||(we=function(t){for(var n=[],e=arguments.length,r=1;e>r;)n.push(arguments[r++]);return xe[++Te]=function(){("function"==typeof t?t:Function(t)).apply(void 0,n)},he(Te),Te},Se=function(t){delete xe[t]},_e?he=function(t){Ce.nextTick(Ae(t))}:Oe&&Oe.now?he=function(t){Oe.now(Ae(t))}:je&&!be?(ge=(ye=new je).port2,ye.port1.onmessage=Re,he=u(ge.postMessage,ge,1)):i.addEventListener&&"function"==typeof postMessage&&!i.importScripts&&ve&&"file:"!==ve.protocol&&!f(Ie)?(he=Ie,i.addEventListener("message",Re,!1)):he=Ee in nt("script")?function(t){xt.appendChild(nt("script")).onreadystatechange=function(){xt.removeChild(this),Pe(t)}}:function(t){setTimeout(Ae(t),0)});var ke,Le,Me,De,Fe,Ve,Ne,Ge,We={set:we,clear:Se},Be=/ipad|iphone|ipod/i.test(L)&&void 0!==i.Pebble,Ue=/web0s(?!.*chrome)/i.test(L),He=fn.f,qe=We.set,ze=i.MutationObserver||i.WebKitMutationObserver,Ke=i.document,Ye=i.process,Je=i.Promise,Xe=He(i,"queueMicrotask"),Qe=Xe&&Xe.value;Qe||(ke=function(){var t,n;for(_e&&(t=Ye.domain)&&t.exit();Le;){n=Le.fn,Le=Le.next;try{n()}catch(t){throw Le?De():Me=void 0,t}}Me=void 0,t&&t.enter()},be||_e||Ue||!ze||!Ke?!Be&&Je&&Je.resolve?((Ne=Je.resolve(void 0)).constructor=Je,Ge=Ne.then,De=function(){Ge.call(Ne,ke)}):De=_e?function(){Ye.nextTick(ke)}:function(){qe.call(i,ke)}:(Fe=!0,Ve=Ke.createTextNode(""),new ze(ke).observe(Ve,{characterData:!0}),De=function(){Ve.data=Fe=!Fe}));var Ze,$e,tr,nr,er=Qe||function(t){var n={fn:t,next:void 0};Me&&(Me.next=n),Le||(Le=n,De()),Me=n},rr=function(t){var n,e;this.promise=new t((function(t,r){if(void 0!==n||void 0!==e)throw TypeError("Bad Promise constructor");n=t,e=r})),this.resolve=a(n),this.reject=a(e)},or={f:function(t){return new rr(t)}},ir=function(t){try{return{error:!1,value:t()}}catch(t){return{error:!0,value:t}}},cr="object"==typeof window,ar=We.set,ur=q("species"),fr="Promise",sr=rn.get,lr=rn.set,pr=rn.getterFor(fr),dr=ee&&ee.prototype,vr=ee,hr=dr,yr=i.TypeError,gr=i.document,mr=i.process,br=or.f,_r=br,wr=!!(gr&&gr.createEvent&&i.dispatchEvent),Sr="function"==typeof PromiseRejectionEvent,Cr="unhandledrejection",jr=!1,Or=Sn(fr,(function(){var t=Ht(vr),n=t!==String(vr);if(!n&&66===N)return!0;if(N>=51&&/native code/.test(t))return!1;var e=new vr((function(t){t(1)})),r=function(t){t((function(){}),(function(){}))};return(e.constructor={})[ur]=r,!(jr=e.then((function(){}))instanceof r)||!n&&cr&&!Sr})),Tr=Or||!function(t,n){if(!n&&!le)return!1;var e=!1;try{var r={};r[se]=function(){return{next:function(){return{done:e=!0}}}},t(r)}catch(t){}return e}((function(t){vr.all(t).catch((function(){}))})),xr=function(t){var n;return!(!w(t)||"function"!=typeof(n=t.then))&&n},Er=function(t,n){if(!t.notified){t.notified=!0;var e=t.reactions;er((function(){for(var r=t.value,o=1==t.state,i=0;e.length>i;){var c,a,u,f=e[i++],s=o?f.ok:f.fail,l=f.resolve,p=f.reject,d=f.domain;try{s?(o||(2===t.rejection&&Ir(t),t.rejection=1),!0===s?c=r:(d&&d.enter(),c=s(r),d&&(d.exit(),u=!0)),c===f.promise?p(yr("Promise-chain cycle")):(a=xr(c))?a.call(c,l,p):l(c)):p(r)}catch(t){d&&!u&&d.exit(),p(t)}}t.reactions=[],t.notified=!1,n&&!t.rejection&&Ar(t)}))}},Pr=function(t,n,e){var r,o;wr?((r=gr.createEvent("Event")).promise=n,r.reason=e,r.initEvent(t,!1,!0),i.dispatchEvent(r)):r={promise:n,reason:e},!Sr&&(o=i["on"+t])?o(r):t===Cr&&function(t,n){var e=i.console;e&&e.error&&(1===arguments.length?e.error(t):e.error(t,n))}("Unhandled promise rejection",e)},Ar=function(t){ar.call(i,(function(){var n,e=t.facade,r=t.value;if(Rr(t)&&(n=ir((function(){_e?mr.emit("unhandledRejection",r,e):Pr(Cr,e,r)})),t.rejection=_e||Rr(t)?2:1,n.error))throw n.value}))},Rr=function(t){return 1!==t.rejection&&!t.parent},Ir=function(t){ar.call(i,(function(){var n=t.facade;_e?mr.emit("rejectionHandled",n):Pr("rejectionhandled",n,t.value)}))},kr=function(t,n,e){return function(r){t(n,r,e)}},Lr=function(t,n,e){t.done||(t.done=!0,e&&(t=e),t.value=n,t.state=2,Er(t,!0))},Mr=function(t,n,e){if(!t.done){t.done=!0,e&&(t=e);try{if(t.facade===n)throw yr("Promise can't be resolved itself");var r=xr(n);r?er((function(){var e={done:!1};try{r.call(n,kr(Mr,e,t),kr(Lr,e,t))}catch(n){Lr(e,n,t)}})):(t.value=n,t.state=1,Er(t,!1))}catch(n){Lr({done:!1},n,t)}}};if(Or&&(hr=(vr=function(t){!function(t,n,e){if(!(t instanceof n))throw TypeError("Incorrect "+(e?e+" ":"")+"invocation")}(this,vr,fr),a(t),Ze.call(this);var n=sr(this);try{t(kr(Mr,n),kr(Lr,n))}catch(t){Lr(n,t)}}).prototype,(Ze=function(t){lr(this,{type:fr,done:!1,notified:!1,parent:!1,reactions:[],rejection:!1,state:0,value:void 0})}).prototype=function(t,n,e){for(var r in n)sn(t,r,n[r],e);return t}(hr,{then:function(t,n){var e,r,o,i=pr(this),c=br((e=vr,void 0===(o=rt(this).constructor)||null==(r=rt(o)[me])?e:a(r)));return c.ok="function"!=typeof t||t,c.fail="function"==typeof n&&n,c.domain=_e?mr.domain:void 0,i.parent=!0,i.reactions.push(c),0!=i.state&&Er(i,!1),c.promise},catch:function(t){return this.then(void 0,t)}}),$e=function(){var t=new Ze,n=sr(t);this.promise=t,this.resolve=kr(Mr,n),this.reject=kr(Lr,n)},or.f=br=function(t){return t===vr||t===tr?new $e(t):_r(t)},"function"==typeof ee&&dr!==Object.prototype)){nr=dr.then,jr||(sn(dr,"then",(function(t,n){var e=this;return new vr((function(t,n){nr.call(e,t,n)})).then(t,n)}),{unsafe:!0}),sn(dr,"catch",hr.catch,{unsafe:!0}));try{delete dr.constructor}catch(t){}Fn&&Fn(dr,hr)}jn({global:!0,wrap:!0,forced:Or},{Promise:vr}),Ln(vr,fr,!1),function(t){var n=k(t),e=ft.f;Z&&n&&!n[re]&&e(n,re,{configurable:!0,get:function(){return this}})}(fr),tr=k(fr),jn({target:fr,stat:!0,forced:Or},{reject:function(t){var n=br(this);return n.reject.call(void 0,t),n.promise}}),jn({target:fr,stat:!0,forced:Or},{resolve:function(t){return function(t,n){if(rt(t),w(n)&&n.constructor===t)return n;var e=or.f(t);return(0,e.resolve)(n),e.promise}(this,t)}}),jn({target:fr,stat:!0,forced:Tr},{all:function(t){var n=this,e=br(n),r=e.resolve,o=e.reject,i=ir((function(){var e=a(n.resolve),i=[],c=0,u=1;fe(t,(function(t){var a=c++,f=!1;i.push(void 0),u++,e.call(n,t).then((function(t){f||(f=!0,i[a]=t,--u||r(i))}),o)})),--u||r(i)}));return i.error&&o(i.value),e.promise},race:function(t){var n=this,e=br(n),r=e.reject,o=ir((function(){var o=a(n.resolve);fe(t,(function(t){o.call(n,t).then(e.resolve,r)}))}));return o.error&&r(o.value),e.promise}});var Dr=function(t){if(ot(t))throw TypeError("Cannot convert a Symbol value to a string");return String(t)},Fr=function(t){return function(n,e){var r,o,i=Dr(v(n)),c=m(e),a=i.length;return c<0||c>=a?t?"":void 0:(r=i.charCodeAt(c))<55296||r>56319||c+1===a||(o=i.charCodeAt(c+1))<56320||o>57343?t?i.charAt(c):r:t?i.slice(c,c+2):o-56320+(r-55296<<10)+65536}},Vr={codeAt:Fr(!1),charAt:Fr(!0)}.charAt,Nr="String Iterator",Gr=rn.set,Wr=rn.getterFor(Nr);qn(String,"String",(function(t){Gr(this,{type:Nr,string:Dr(t),index:0})}),(function(){var t,n=Wr(this),e=n.string,r=n.index;return r>=e.length?{value:void 0,done:!0}:(t=Vr(e,r),n.index+=t.length,{value:t,done:!1})}));var Br=q("iterator"),Ur=q("toStringTag"),Hr=Jn.values;for(var qr in c){var zr=i[qr],Kr=zr&&zr.prototype;if(Kr){if(Kr[Br]!==Hr)try{lt(Kr,Br,Hr)}catch(t){Kr[Br]=Hr}if(Kr[Ur]||lt(Kr,Ur,qr),c[qr])for(var Yr in Jn)if(Kr[Yr]!==Jn[Yr])try{lt(Kr,Yr,Jn[Yr])}catch(t){Kr[Yr]=Jn[Yr]}}}var Jr=Foundation.env.isSubContext,Xr=Foundation.env.isSafeEnv,Qr=["env","appLaunchInfo","ext","wxAppInfo","debug","entryPagePath","envVersion","tabBar","pages","page","accountInfo","global","platform","system","appType","networkTimeout","navigateToMiniProgramAppIdList","plugins","extAppid","host","prerender"],Zr={};function $r(t,n,e,r){Object.defineProperty(t,e,{configurable:!0,enumerable:!0,get:function(){if(e in n)return n[e];try{return"function"!=typeof r?r:r()}catch(t){return}},set:function(t){n[e]=t}})}var to=!0===__ddConfig.preload,no=!1,eo=[],ro=[],oo=Foundation.env.typeStr;function io(t,n){try{Date.now(),t(n),Date.now()}catch(t){}}function co(t){ro.push(t)}function ao(t){no?void 0!==__ddConfig&&io(t,__ddConfig):"function"==typeof t&&eo.push(t)}function uo(t){t.tabBar&&t.tabBar.list&&t.tabBar.list.forEach((function(t){delete t.iconData,delete t.selectedIconData})),delete t.permission;var n=t.subPackages||t.subpackages;return n&&0<n.length&&(n.forEach((function(t){delete t.pages})),t.subPackages=t.subpackages=n),no&&(__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Jr||(__ddConfig._preloadRule=__ddConfig.preloadRule||{},__ddConfig._page=__ddConfig.page||{},delete __ddConfig.preloadRule,delete __ddConfig.page),__ddConfig.updatePage=function(t,n){var e;__ddConfig.page=__ddConfig.page||{},__ddConfig.page[t]=__ddConfig.page[t+".html"]=n,Zr[t+".html"]=(e=n,JSON.parse(JSON.stringify(e)))},__ddConfig.updatePreloadRule=function(t,n){__ddConfig.preloadRule=__ddConfig.preloadRule||{},__ddConfig.preloadRule[t]=n}),__ddConfig.page=__ddConfig.page||{}),t}function fo(t){return t.onReady=ao,t.beforeReady=co,Jr||(t.preload=to),t.isReady=no,t.isSubContext=Jr,t.envTag=oo,t.isSafeContext=Xr,t.sdkVersion=t.SDKVersion=Foundation.env.SDKVersion,t.twoPhaseInject=!0,t.platform=Foundation.env.platform,t.brand||"ios"!==t.platform||(t.brand="iPhone"),"number"==typeof t.pixelRatio?t.devicePixelRatio=t.pixelRatio:"number"==typeof t.devicePixelRatio&&(t.pixelRatio=t.devicePixelRatio),t}function so(){if(__ddConfig.onReadyStart=Date.now(),eo.forEach((function(t){io(t,__ddConfig)})),__ddConfig.onReadyEnd=Date.now(),eo=[],!Xr){var t=__ddConfig,n={},e={};Zr=t.page||{},__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Zr={});try{$r(e,n,"deprecated",!0),Qr.forEach((function(r){if(r in t){var o=t[r];switch(r){case"page":$r(e,n,r,Zr);break;case"env":$r(e,n,r,(function(){return{USER_DATA_PATH:o.USER_DATA_PATH}}));break;case"accountInfo":$r(e,n,r,{appId:o.appId,icon:o.icon,nickname:o.nickname});break;case"appLaunchInfo":$r(e,n,r,(function(){return wx&&"function"==typeof wx.getLaunchOptionsSync?wx.getLaunchOptionsSync():{}}));break;case"wxAppInfo":$r(e,n,r,{maxRequestConcurrent:o.maxRequestConcurrent,maxUploadConcurrent:o.maxUploadConcurrent,maxDownloadConcurrent:o.maxDownloadConcurrent,maxWorkerConcurrent:o.maxWorkerConcurrent,maxWebsocketConnect:o.maxWebsocketConnect});break;default:$r(e,n,r,o)}}})),Foundation.setExportConfig(e)}catch(n){Foundation.setExportConfig(t)}}}function lo(){void 0===__ddConfig||no||(no=!0,__ddConfig=fo(__ddConfig),__ddConfig=uo(__ddConfig),function(t){if(!ro.length)return t();var n=!1;setTimeout((function(){n||(n=!0,t())}),3e3),Promise.all(ro).catch((function(t){})).then((function(){n||(n=!0,t())})),ro=[]}(so))}function po(){Foundation.emitConfigReady(__ddConfig)}Foundation.env.isSubContext&&(oo="SubContext"),__ddConfig=fo(__ddConfig),__ddConfig=uo(__ddConfig),Foundation.onConfigReady((function(){lo()})),Jr?__ddConfig.__readyHandler=po:Foundation.onLibraryReady(po)}();

var __appServiceSDK__=function(){"use strict";var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function t(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var n,r,i=function(e){return e&&e.Math==Math&&e},o=i("object"==typeof globalThis&&globalThis)||i("object"==typeof window&&window)||i("object"==typeof self&&self)||i("object"==typeof e&&e)||function(){return this}()||Function("return this")(),a=function(e){try{return!!e()}catch(e){return!0}},s=!a((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),c={}.propertyIsEnumerable,u=Object.getOwnPropertyDescriptor,f={f:u&&!c.call({1:2},1)?function(e){var t=u(this,e);return!!t&&t.enumerable}:c},l=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},d={}.toString,p=function(e){return d.call(e).slice(8,-1)},h="".split,y=a((function(){return!Object("z").propertyIsEnumerable(0)}))?function(e){return"String"==p(e)?h.call(e,""):Object(e)}:Object,v=function(e){if(null==e)throw TypeError("Can't call method on "+e);return e},g=function(e){return y(v(e))},m=function(e){return"object"==typeof e?null!==e:"function"==typeof e},b=function(e){return"function"==typeof e?e:void 0},S=function(e,t){return arguments.length<2?b(o[e]):o[e]&&o[e][t]},w=S("navigator","userAgent")||"",_=o.process,T=o.Deno,k=_&&_.versions||T&&T.version,M=k&&k.v8;M?r=(n=M.split("."))[0]<4?1:n[0]+n[1]:w&&(!(n=w.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=w.match(/Chrome\/(\d+)/))&&(r=n[1]);var N=r&&+r,x=!!Object.getOwnPropertySymbols&&!a((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&N&&N<41})),I=x&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,O=I?function(e){return"symbol"==typeof e}:function(e){var t=S("Symbol");return"function"==typeof t&&Object(e)instanceof t},P=function(e,t){try{Object.defineProperty(o,e,{value:t,configurable:!0,writable:!0})}catch(n){o[e]=t}return t},L="__core-js_shared__",C=o[L]||P(L,{}),E=t((function(e){(e.exports=function(e,t){return C[e]||(C[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),A=function(e){return Object(v(e))},V={}.hasOwnProperty,j=Object.hasOwn||function(e,t){return V.call(A(e),t)},B=0,R=Math.random(),z=function(e){return"Symbol("+String(void 0===e?"":e)+")_"+(++B+R).toString(36)},F=E("wks"),D=o.Symbol,W=I?D:D&&D.withoutSetter||z,U=function(e){return j(F,e)&&(x||"string"==typeof F[e])||(x&&j(D,e)?F[e]=D[e]:F[e]=W("Symbol."+e)),F[e]},q=U("toPrimitive"),J=function(e,t){if(!m(e)||O(e))return e;var n,r=e[q];if(void 0!==r){if(void 0===t&&(t="default"),n=r.call(e,t),!m(n)||O(n))return n;throw TypeError("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&"function"==typeof(n=e.toString)&&!m(r=n.call(e)))return r;if("function"==typeof(n=e.valueOf)&&!m(r=n.call(e)))return r;if("string"!==t&&"function"==typeof(n=e.toString)&&!m(r=n.call(e)))return r;throw TypeError("Can't convert object to primitive value")}(e,t)},G=function(e){var t=J(e,"string");return O(t)?t:String(t)},H=o.document,Q=m(H)&&m(H.createElement),$=function(e){return Q?H.createElement(e):{}},X=!s&&!a((function(){return 7!=Object.defineProperty($("div"),"a",{get:function(){return 7}}).a})),K=Object.getOwnPropertyDescriptor,Y={f:s?K:function(e,t){if(e=g(e),t=G(t),X)try{return K(e,t)}catch(e){}if(j(e,t))return l(!f.f.call(e,t),e[t])}},Z=function(e){if(!m(e))throw TypeError(String(e)+" is not an object");return e},ee=Object.defineProperty,te={f:s?ee:function(e,t,n){if(Z(e),t=G(t),Z(n),X)try{return ee(e,t,n)}catch(e){}if("get"in n||"set"in n)throw TypeError("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},ne=s?function(e,t,n){return te.f(e,t,l(1,n))}:function(e,t,n){return e[t]=n,e},re=Function.toString;"function"!=typeof C.inspectSource&&(C.inspectSource=function(e){return re.call(e)});var ie,oe,ae,se=C.inspectSource,ce=o.WeakMap,ue="function"==typeof ce&&/native code/.test(se(ce)),fe=E("keys"),le=function(e){return fe[e]||(fe[e]=z(e))},de={},pe="Object already initialized",he=o.WeakMap;if(ue||C.state){var ye=C.state||(C.state=new he),ve=ye.get,ge=ye.has,me=ye.set;ie=function(e,t){if(ge.call(ye,e))throw new TypeError(pe);return t.facade=e,me.call(ye,e,t),t},oe=function(e){return ve.call(ye,e)||{}},ae=function(e){return ge.call(ye,e)}}else{var be=le("state");de[be]=!0,ie=function(e,t){if(j(e,be))throw new TypeError(pe);return t.facade=e,ne(e,be,t),t},oe=function(e){return j(e,be)?e[be]:{}},ae=function(e){return j(e,be)}}var Se={set:ie,get:oe,has:ae,enforce:function(e){return ae(e)?oe(e):ie(e,{})},getterFor:function(e){return function(t){var n;if(!m(t)||(n=oe(t)).type!==e)throw TypeError("Incompatible receiver, "+e+" required");return n}}},we=t((function(e){var t=Se.get,n=Se.enforce,r=String(String).split("String");(e.exports=function(e,t,i,a){var s,c=!!a&&!!a.unsafe,u=!!a&&!!a.enumerable,f=!!a&&!!a.noTargetGet;"function"==typeof i&&("string"!=typeof t||j(i,"name")||ne(i,"name",t),(s=n(i)).source||(s.source=r.join("string"==typeof t?t:""))),e!==o?(c?!f&&e[t]&&(u=!0):delete e[t],u?e[t]=i:ne(e,t,i)):u?e[t]=i:P(t,i)})(Function.prototype,"toString",(function(){return"function"==typeof this&&t(this).source||se(this)}))})),_e=Math.ceil,Te=Math.floor,ke=function(e){return isNaN(e=+e)?0:(e>0?Te:_e)(e)},Me=Math.min,Ne=function(e){return e>0?Me(ke(e),9007199254740991):0},xe=Math.max,Ie=Math.min,Oe=function(e,t){var n=ke(e);return n<0?xe(n+t,0):Ie(n,t)},Pe=function(e){return function(t,n,r){var i,o=g(t),a=Ne(o.length),s=Oe(r,a);if(e&&n!=n){for(;a>s;)if((i=o[s++])!=i)return!0}else for(;a>s;s++)if((e||s in o)&&o[s]===n)return e||s||0;return!e&&-1}},Le={includes:Pe(!0),indexOf:Pe(!1)},Ce=Le.indexOf,Ee=function(e,t){var n,r=g(e),i=0,o=[];for(n in r)!j(de,n)&&j(r,n)&&o.push(n);for(;t.length>i;)j(r,n=t[i++])&&(~Ce(o,n)||o.push(n));return o},Ae=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ve=Ae.concat("length","prototype"),je={f:Object.getOwnPropertyNames||function(e){return Ee(e,Ve)}},Be={f:Object.getOwnPropertySymbols},Re=S("Reflect","ownKeys")||function(e){var t=je.f(Z(e)),n=Be.f;return n?t.concat(n(e)):t},ze=function(e,t){for(var n=Re(t),r=te.f,i=Y.f,o=0;o<n.length;o++){var a=n[o];j(e,a)||r(e,a,i(t,a))}},Fe=/#|\.prototype\./,De=function(e,t){var n=Ue[We(e)];return n==Je||n!=qe&&("function"==typeof t?a(t):!!t)},We=De.normalize=function(e){return String(e).replace(Fe,".").toLowerCase()},Ue=De.data={},qe=De.NATIVE="N",Je=De.POLYFILL="P",Ge=De,He=Y.f,Qe=function(e,t){var n,r,i,a,s,c=e.target,u=e.global,f=e.stat;if(n=u?o:f?o[c]||P(c,{}):(o[c]||{}).prototype)for(r in t){if(a=t[r],i=e.noTargetGet?(s=He(n,r))&&s.value:n[r],!Ge(u?r:c+(f?".":"#")+r,e.forced)&&void 0!==i){if(typeof a==typeof i)continue;ze(a,i)}(e.sham||i&&i.sham)&&ne(a,"sham",!0),we(n,r,a,e)}},$e=function(e,t){var n=[][e];return!!n&&a((function(){n.call(null,t||function(){throw 1},1)}))},Xe=Le.indexOf,Ke=[].indexOf,Ye=!!Ke&&1/[1].indexOf(1,-0)<0,Ze=$e("indexOf");function et(e){return(et="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function tt(){return(tt=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}Qe({target:"Array",proto:!0,forced:Ye||!Ze},{indexOf:function(e){return Ye?Ke.apply(this,arguments)||0:Xe(this,e,arguments.length>1?arguments[1]:void 0)}});var nt={};nt[U("toStringTag")]="z";var rt="[object z]"===String(nt),it=U("toStringTag"),ot="Arguments"==p(function(){return arguments}()),at=rt?p:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Object(e),it))?n:ot?p(t):"Object"==(r=p(t))&&"function"==typeof t.callee?"Arguments":r},st=rt?{}.toString:function(){return"[object "+at(this)+"]"};rt||we(Object.prototype,"toString",st,{unsafe:!0});var ct=o.Promise,ut=function(e,t,n){for(var r in t)we(e,r,t[r],n);return e},ft=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return Z(n),function(e){if(!m(e)&&null!==e)throw TypeError("Can't set "+String(e)+" as a prototype")}(r),t?e.call(n,r):n.__proto__=r,n}}():void 0),lt=te.f,dt=U("toStringTag"),pt=function(e,t,n){e&&!j(e=n?e:e.prototype,dt)&&lt(e,dt,{configurable:!0,value:t})},ht=U("species"),yt=function(e){var t=S(e),n=te.f;s&&t&&!t[ht]&&n(t,ht,{configurable:!0,get:function(){return this}})},vt=function(e){if("function"!=typeof e)throw TypeError(String(e)+" is not a function");return e},gt=function(e,t,n){if(!(e instanceof t))throw TypeError("Incorrect "+(n?n+" ":"")+"invocation");return e},mt={},bt=U("iterator"),St=Array.prototype,wt=function(e,t,n){if(vt(e),void 0===t)return e;switch(n){case 0:return function(){return e.call(t)};case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,i){return e.call(t,n,r,i)}}return function(){return e.apply(t,arguments)}},_t=U("iterator"),Tt=function(e){var t=e.return;if(void 0!==t)return Z(t.call(e)).value},kt=function(e,t){this.stopped=e,this.result=t},Mt=function(e,t,n){var r,i,o,a,s,c,u,f,l=n&&n.that,d=!(!n||!n.AS_ENTRIES),p=!(!n||!n.IS_ITERATOR),h=!(!n||!n.INTERRUPTED),y=wt(t,l,1+d+h),v=function(e){return r&&Tt(r),new kt(!0,e)},g=function(e){return d?(Z(e),h?y(e[0],e[1],v):y(e[0],e[1])):h?y(e,v):y(e)};if(p)r=e;else{if("function"!=typeof(i=function(e){if(null!=e)return e[_t]||e["@@iterator"]||mt[at(e)]}(e)))throw TypeError("Target is not iterable");if(void 0!==(f=i)&&(mt.Array===f||St[bt]===f)){for(o=0,a=Ne(e.length);a>o;o++)if((s=g(e[o]))&&s instanceof kt)return s;return new kt(!1)}r=i.call(e)}for(c=r.next;!(u=c.call(r)).done;){try{s=g(u.value)}catch(e){throw Tt(r),e}if("object"==typeof s&&s&&s instanceof kt)return s}return new kt(!1)},Nt=U("iterator"),xt=!1;try{var It=0,Ot={next:function(){return{done:!!It++}},return:function(){xt=!0}};Ot[Nt]=function(){return this},Array.from(Ot,(function(){throw 2}))}catch(e){}var Pt,Lt,Ct,Et,At=function(e,t){if(!t&&!xt)return!1;var n=!1;try{var r={};r[Nt]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Vt=U("species"),jt=function(e,t){var n,r=Z(e).constructor;return void 0===r||null==(n=Z(r)[Vt])?t:vt(n)},Bt=S("document","documentElement"),Rt=/(?:ipad|iphone|ipod).*applewebkit/i.test(w),zt="process"==p(o.process),Ft=o.setImmediate,Dt=o.clearImmediate,Wt=o.process,Ut=o.MessageChannel,qt=o.Dispatch,Jt=0,Gt={},Ht="onreadystatechange";try{Pt=o.location}catch(e){}var Qt=function(e){if(Gt.hasOwnProperty(e)){var t=Gt[e];delete Gt[e],t()}},$t=function(e){return function(){Qt(e)}},Xt=function(e){Qt(e.data)},Kt=function(e){o.postMessage(String(e),Pt.protocol+"//"+Pt.host)};Ft&&Dt||(Ft=function(e){for(var t=[],n=arguments.length,r=1;n>r;)t.push(arguments[r++]);return Gt[++Jt]=function(){("function"==typeof e?e:Function(e)).apply(void 0,t)},Lt(Jt),Jt},Dt=function(e){delete Gt[e]},zt?Lt=function(e){Wt.nextTick($t(e))}:qt&&qt.now?Lt=function(e){qt.now($t(e))}:Ut&&!Rt?(Et=(Ct=new Ut).port2,Ct.port1.onmessage=Xt,Lt=wt(Et.postMessage,Et,1)):o.addEventListener&&"function"==typeof postMessage&&!o.importScripts&&Pt&&"file:"!==Pt.protocol&&!a(Kt)?(Lt=Kt,o.addEventListener("message",Xt,!1)):Lt=Ht in $("script")?function(e){Bt.appendChild($("script")).onreadystatechange=function(){Bt.removeChild(this),Qt(e)}}:function(e){setTimeout($t(e),0)});var Yt,Zt,en,tn,nn,rn,on,an,sn={set:Ft,clear:Dt},cn=/ipad|iphone|ipod/i.test(w)&&void 0!==o.Pebble,un=/web0s(?!.*chrome)/i.test(w),fn=Y.f,ln=sn.set,dn=o.MutationObserver||o.WebKitMutationObserver,pn=o.document,hn=o.process,yn=o.Promise,vn=fn(o,"queueMicrotask"),gn=vn&&vn.value;gn||(Yt=function(){var e,t;for(zt&&(e=hn.domain)&&e.exit();Zt;){t=Zt.fn,Zt=Zt.next;try{t()}catch(e){throw Zt?tn():en=void 0,e}}en=void 0,e&&e.enter()},Rt||zt||un||!dn||!pn?!cn&&yn&&yn.resolve?((on=yn.resolve(void 0)).constructor=yn,an=on.then,tn=function(){an.call(on,Yt)}):tn=zt?function(){hn.nextTick(Yt)}:function(){ln.call(o,Yt)}:(nn=!0,rn=pn.createTextNode(""),new dn(Yt).observe(rn,{characterData:!0}),tn=function(){rn.data=nn=!nn}));var mn,bn,Sn,wn,_n=gn||function(e){var t={fn:e,next:void 0};en&&(en.next=t),Zt||(Zt=t,tn()),en=t},Tn=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=vt(t),this.reject=vt(n)},kn={f:function(e){return new Tn(e)}},Mn=function(e,t){if(Z(e),m(t)&&t.constructor===e)return t;var n=kn.f(e);return(0,n.resolve)(t),n.promise},Nn=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},xn="object"==typeof window,In=sn.set,On=U("species"),Pn="Promise",Ln=Se.get,Cn=Se.set,En=Se.getterFor(Pn),An=ct&&ct.prototype,Vn=ct,jn=An,Bn=o.TypeError,Rn=o.document,zn=o.process,Fn=kn.f,Dn=Fn,Wn=!!(Rn&&Rn.createEvent&&o.dispatchEvent),Un="function"==typeof PromiseRejectionEvent,qn="unhandledrejection",Jn=!1,Gn=Ge(Pn,(function(){var e=se(Vn),t=e!==String(Vn);if(!t&&66===N)return!0;if(N>=51&&/native code/.test(e))return!1;var n=new Vn((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};return(n.constructor={})[On]=r,!(Jn=n.then((function(){}))instanceof r)||!t&&xn&&!Un})),Hn=Gn||!At((function(e){Vn.all(e).catch((function(){}))})),Qn=function(e){var t;return!(!m(e)||"function"!=typeof(t=e.then))&&t},$n=function(e,t){if(!e.notified){e.notified=!0;var n=e.reactions;_n((function(){for(var r=e.value,i=1==e.state,o=0;n.length>o;){var a,s,c,u=n[o++],f=i?u.ok:u.fail,l=u.resolve,d=u.reject,p=u.domain;try{f?(i||(2===e.rejection&&Zn(e),e.rejection=1),!0===f?a=r:(p&&p.enter(),a=f(r),p&&(p.exit(),c=!0)),a===u.promise?d(Bn("Promise-chain cycle")):(s=Qn(a))?s.call(a,l,d):l(a)):d(r)}catch(e){p&&!c&&p.exit(),d(e)}}e.reactions=[],e.notified=!1,t&&!e.rejection&&Kn(e)}))}},Xn=function(e,t,n){var r,i;Wn?((r=Rn.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),o.dispatchEvent(r)):r={promise:t,reason:n},!Un&&(i=o["on"+e])?i(r):e===qn&&function(e,t){var n=o.console;n&&n.error&&(1===arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},Kn=function(e){In.call(o,(function(){var t,n=e.facade,r=e.value;if(Yn(e)&&(t=Nn((function(){zt?zn.emit("unhandledRejection",r,n):Xn(qn,n,r)})),e.rejection=zt||Yn(e)?2:1,t.error))throw t.value}))},Yn=function(e){return 1!==e.rejection&&!e.parent},Zn=function(e){In.call(o,(function(){var t=e.facade;zt?zn.emit("rejectionHandled",t):Xn("rejectionhandled",t,e.value)}))},er=function(e,t,n){return function(r){e(t,r,n)}},tr=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,$n(e,!0))},nr=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw Bn("Promise can't be resolved itself");var r=Qn(t);r?_n((function(){var n={done:!1};try{r.call(t,er(nr,n,e),er(tr,n,e))}catch(t){tr(n,t,e)}})):(e.value=t,e.state=1,$n(e,!1))}catch(t){tr({done:!1},t,e)}}};if(Gn&&(jn=(Vn=function(e){gt(this,Vn,Pn),vt(e),mn.call(this);var t=Ln(this);try{e(er(nr,t),er(tr,t))}catch(e){tr(t,e)}}).prototype,(mn=function(e){Cn(this,{type:Pn,done:!1,notified:!1,parent:!1,reactions:[],rejection:!1,state:0,value:void 0})}).prototype=ut(jn,{then:function(e,t){var n=En(this),r=Fn(jt(this,Vn));return r.ok="function"!=typeof e||e,r.fail="function"==typeof t&&t,r.domain=zt?zn.domain:void 0,n.parent=!0,n.reactions.push(r),0!=n.state&&$n(n,!1),r.promise},catch:function(e){return this.then(void 0,e)}}),bn=function(){var e=new mn,t=Ln(e);this.promise=e,this.resolve=er(nr,t),this.reject=er(tr,t)},kn.f=Fn=function(e){return e===Vn||e===Sn?new bn(e):Dn(e)},"function"==typeof ct&&An!==Object.prototype)){wn=An.then,Jn||(we(An,"then",(function(e,t){var n=this;return new Vn((function(e,t){wn.call(n,e,t)})).then(e,t)}),{unsafe:!0}),we(An,"catch",jn.catch,{unsafe:!0}));try{delete An.constructor}catch(e){}ft&&ft(An,jn)}Qe({global:!0,wrap:!0,forced:Gn},{Promise:Vn}),pt(Vn,Pn,!1),yt(Pn),Sn=S(Pn),Qe({target:Pn,stat:!0,forced:Gn},{reject:function(e){var t=Fn(this);return t.reject.call(void 0,e),t.promise}}),Qe({target:Pn,stat:!0,forced:Gn},{resolve:function(e){return Mn(this,e)}}),Qe({target:Pn,stat:!0,forced:Hn},{all:function(e){var t=this,n=Fn(t),r=n.resolve,i=n.reject,o=Nn((function(){var n=vt(t.resolve),o=[],a=0,s=1;Mt(e,(function(e){var c=a++,u=!1;o.push(void 0),s++,n.call(t,e).then((function(e){u||(u=!0,o[c]=e,--s||r(o))}),i)})),--s||r(o)}));return o.error&&i(o.value),n.promise},race:function(e){var t=this,n=Fn(t),r=n.reject,i=Nn((function(){var i=vt(t.resolve);Mt(e,(function(e){i.call(t,e).then(n.resolve,r)}))}));return i.error&&r(i.value),n.promise}});
/*! *****************************************************************************
	Copyright (c) Microsoft Corporation.

	Permission to use, copy, modify, and/or distribute this software for any
	purpose with or without fee is hereby granted.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
	REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
	INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
	LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
	OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
	PERFORMANCE OF THIS SOFTWARE.
	***************************************************************************** */
var rr=function(){return(rr=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function ir(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{c(r.next(e))}catch(e){o(e)}}function s(e){try{c(r.throw(e))}catch(e){o(e)}}function c(e){e.done?i(e.value):function(e){return e instanceof n?e:new n((function(t){t(e)}))}(e.value).then(a,s)}c((r=r.apply(e,t||[])).next())}))}function or(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}var ar={customShare:{type:"async",event:"customShare",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},image:{type:["String"],ifMustNeed:!1,default:void 0,desc:"分享图片"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},showShareEntrance:{type:"async",event:"showShareEntrance",argsSize:1,agrs0Type:"Object",params:{buttons:{type:["Array"],ifMustNeed:!0,default:"",desc:"转发按钮名称列表"}}},hideShareEntrance:{type:"async",event:"hideShareEntrance",argsSize:0,agrs0Type:"any",params:null},shareWeixinTimeline:{type:"async",event:"shareWeixinTimeline",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"}}},shareWeixinAppmsg:{type:"async",event:"shareWeixinAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQqAppmsg:{type:"async",event:"shareQqAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQzone:{type:"async",event:"shareQzone",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayFriend:{type:"async",event:"shareAlipayFriend",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayLife:{type:"async",event:"shareAlipayLife",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareMessage:{type:"async",event:"shareMessage",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareSinaWeibo:{type:"async",event:"shareSinaWeibo",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}}},sr=rr(rr(rr(rr(rr(rr(rr(rr(rr(rr(rr(rr(rr(rr({},{getStorageSync:{type:"sync",event:"getStorageSync",argsSize:1,agrs0Type:"String",needReturn:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},setStorageSync:{type:"sync",event:"setStorageSync",argsSize:2,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},removeStorageSync:{type:"sync",event:"removeStorageSync",argsSize:1,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},removeStorage:{type:"async",event:"removeStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},getStorageInfo:{type:"async",event:"getStorageInfo",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setStorage:{type:"async",event:"setStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},getStorage:{type:"async",event:"getStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},clearStorage:{type:"async",event:"clearStorage",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setBackgroundFetchToken:{type:"async",event:"setBackgroundFetchToken",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{token:{type:["String"],ifMustNeed:!0,default:"",desc:"传给端上获取预加载数据的token"}}},getBackgroundFetchData:{type:"async",event:"getBackgroundFetchData",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{fetchType:{type:["String"],ifMustNeed:!0,defult:"",desc:"获取端上预加载的数据"}}}}),{getSystemInfo:{type:"async",event:"getSystemInfo",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getSystemInfoSync:{type:"sync",event:"getSystemInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getAccountInfoSync:{type:"sync",event:"getAccountInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getLaunchOptionsSync:{type:"sync",event:"getLaunchOptionsSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getNetworkType:{type:"async",event:"getNetworkType",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},authorize:{type:"async",event:"authorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"}}},businessAuthorize:{type:"async",event:"businessAuthorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 title"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 icon 仅支持difile格式"},subTitle:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 subTitle"},desc:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 desc"},showType:{type:["String"],ifMustNeed:!1,default:"bottom",desc:'需要获取权限的 showType ["bottom","center"]'}}},openSetting:{type:"async",event:"openSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},getSetting:{type:"async",event:"getSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},vibrateShort:{type:"async",event:"vibrateShort",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},vibrateLong:{type:"async",event:"vibrateLong",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},makePhoneCall:{type:"async",event:"makePhoneCall",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{phoneNumber:{type:["String"],ifMustNeed:!0,default:"",desc:"需要拨打的电话号码"}}},getClipboardData:{type:"async",event:"makePgetClipboardDatahoneCall",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},setClipboardData:{type:"async",event:"setClipboardData",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{data:{type:["String"],ifMustNeed:!0,default:"",desc:"剪贴板的内容"}}},getLocation:{type:"async",event:"getLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!1,default:"wgs84",desc:"wgs84 返回 gps 坐标，gcj02 返回可用于 wx.openLocation 的坐标"},altitude:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"传入 true 会返回高度信息，由于获取高度需要较高精确度，会减慢接口返回速度"},isHighAccuracy:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"开启高精度定位"},highAccuracyExpireTime:{type:["Number"],ifMustNeed:!1,default:3e3,desc:"高精度定位超时时间(ms)，指定时间内返回最高精度，该值3000ms以上高精度定位才有效果"}}},openLocation:{type:"async",event:"openLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"纬度，范围为-90~90，负数表示南纬。使用 gcj02 国测局坐标系"},longitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"经度，范围为-180~180，负数表示西经。使用 gcj02 国测局坐标系"},scale:{type:["Number"],ifMustNeed:!1,default:18,desc:"缩放比例，范围5~18"},name:{type:["String"],ifMustNeed:!1,default:"",desc:"位置名"},address:{type:["String"],ifMustNeed:!1,default:"",desc:"地址的详细说明"}}},choosePoi:{type:"async",event:"choosePoi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},chooseLocation:{type:"async",event:"chooseLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地纬度"},longitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地经度"}}},request:{type:"async",event:"request",agrs0Type:"Object",argsSize:1,params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器接口地址"},data:{type:["String","Object","ArrayBuffer"],ifMustNeed:!1,default:"",desc:"请求的参数"},header:{type:["Object"],ifMustNeed:!1,default:{"content-type":"application/json"},desc:"设置请求的 header，header 中不能设置 Referer。content-type 默认为 application/json"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},method:{type:["String"],ifMustNeed:!1,default:"GET",desc:"HTTP 请求方法"},dataType:{type:["String"],ifMustNeed:!1,default:"json",desc:"返回的数据格式"},responseType:{type:["String"],ifMustNeed:!1,default:"text",desc:"响应的数据类型"}}},startRecord:{type:"async",event:"startRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopRecord:{type:"async",event:"stopRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},startWifi:{type:"async",event:"startWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopWifi:{type:"async",event:"stopWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getWifiList:{type:"async",event:"getWifiList",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getConnectedWifi:{type:"async",event:"getConnectedWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},closeDimina:{type:"async",event:"closeDimina",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},showActionSheet:{type:"async",event:"showActionSheet",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{alertText:{type:["String"],ifMustNeed:!1,default:"",desc:"警示文案"},itemList:{type:["Array"],ifMustNeed:!0,default:"",desc:"按钮的文字数组，数组长度最大为 6"},itemColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"按钮的文字颜色"}}},enableAlertBeforeUnload:{type:"async",event:"enableAlertBeforeUnload",agrs0Type:"Object",argsSize:1,params:{message:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},disableAlertBeforeUnload:{type:"async",event:"disableAlertBeforeUnload",agrs0Type:"any",argsSize:0,params:null},onMemoryWarning:{type:"monitor",event:"onMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},offMemoryWarning:{type:"offMonitor",event:"offMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},onNetworkStatusChange:{type:"monitor",event:"onNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},offNetworkStatusChange:{type:"offMonitor",event:"offNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},onGetWifiList:{type:"monitor",event:"onGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},offGetWifiList:{type:"offMonitor",event:"offGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},onWifiConnected:{type:"monitor",event:"onWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},offWifiConnected:{type:"offMonitor",event:"offWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},onLoginStatusChanged:{type:"monitor",event:"onLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},offLoginStatusChanged:{type:"offMonitor",event:"offLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},onUserCaptureScreen:{type:"monitor",event:"onUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},offUserCaptureScreen:{type:"offMonitor",event:"offUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},showTabBar:{type:"async",event:"showTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}},hideTabBar:{type:"async",event:"hideTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}}}),{showLoading:{type:"async",event:"showLoading",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideLoading:{type:"async",event:"hideLoading",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showToast:{type:"async",event:"showToast",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},icon:{type:["String"],ifMustNeed:!1,default:"success",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"自定义图标的本地路径，image 的优先级高于 icon"},duration:{type:["Number"],ifMustNeed:!1,default:1500,desc:"提示的延迟时间"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideToast:{type:"async",event:"hideToast",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showModal:{type:"async",event:"showModal",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的内容"},showCancel:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否显示取消按钮"},cancelText:{type:["String"],ifMustNeed:!1,default:"取消",desc:"取消按钮的文字，最多 4 个字符"},cancelColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"取消按钮的文字颜色，必须是 16 进制格式的颜色字符串"},confirmText:{type:["String"],ifMustNeed:!1,default:"确定",desc:"确认按钮的文字，最多 4 个字符"},confirmColor:{type:["String"],ifMustNeed:!1,default:"#576B95",desc:"确认按钮的文字颜色，必须是 16 进制格式的颜色字符串"}}},setNavigationBarTitle:{type:"async",event:"setNavigationBarTitle",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"页面标题"}}},setNavigationBarColor:{type:"async",event:"setNavigationBarColor",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{frontColor:{type:["String"],ifMustNeed:!0,default:"",desc:"前景颜色值，包括按钮、标题、状态栏的颜色，仅支持 #ffffff 和 #000000"},backgroundColor:{type:["String"],ifMustNeed:!0,default:"",desc:"背景颜色值，有效值为十六进制颜色"},animation:{type:["Object"],ifMustNeed:!1,default:{},desc:"动画效果"}}},getMenuButtonBoundingClientRect:{type:"sync",event:"getMenuButtonBoundingClientRect",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},setTabBarBadge:{type:"async",event:"setTabBarBadge",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{index:{type:["Number"],ifMustNeed:!0,default:0,desc:"tabBar 的哪一项，从左边算起"},text:{type:["String"],ifMustNeed:!0,default:"",desc:"显示的文本，超过 4 个字符则显示成 ..."}}},showCapsuleButton:{type:"async",event:"showCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},hideCapsuleButton:{type:"async",event:"hideCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{getImageInfo:{type:"async",event:"getImageInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片的路径，支持网络路径、本地路径、代码包路径"}}},saveImageToPhotosAlbum:{type:"async",event:"saveImageToPhotosAlbum",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"图片文件路径，可以是临时文件路径或永久文件路径 (本地路径) ，不支持网络路径"}}},chooseImage:{type:"async",event:"chooseImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的图片张数"},sizeType:{type:["Array"],ifMustNeed:!1,default:["original"],desc:"所选的图片的尺寸"},sourceType:{type:["Array"],ifMustNeed:!1,default:["album"],desc:"选择图片的来源"}}},scanCode:{type:"async",event:"scanCode",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{onlyFromCamera:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否只能从相机扫码，不允许从相册选择图片"},scanType:{type:["Array"],ifMustNeed:!1,default:["barCode","qrCode"],desc:"扫码类型"}}},previewImage:{type:"async",event:"previewImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{urls:{type:["Array"],ifMustNeed:!0,default:"",desc:"需要预览的图片链接列表"},current:{type:["String"],ifMustNeed:!1,default:"",desc:"当前显示图片的链接"}}},compressImage:{type:"async",event:"compressImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片路径，图片的路径，支持本地路径、代码包路径"},quality:{type:["Number"],ifMustNeed:!1,default:80,desc:"压缩质量，范围0～100，数值越小，质量越低，压缩率越高（仅对jpg有效）。"}}}}),{getSavedFileInfo:{type:"async",event:"getSavedFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"文件路径 (本地路径)"}}},getFileInfo:{type:"async",event:"getFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"本地文件路径 (本地路径)"},digestAlgorithm:{type:["String"],ifMustNeed:!1,default:"md5",desc:"计算文件摘要的算法"}}},saveFile:{type:"async",event:"saveFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{tempFilePath:{type:["String"],ifMustNeed:!0,default:!1,desc:"需要保存的文件的临时路径 (本地路径)"}}},removeSavedFile:{type:"async",event:"removeSavedFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"需要删除的文件路径 (本地路径)"}}}}),{startPullDownRefresh:{type:"async",event:"startPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},stopPullDownRefresh:{type:"async",event:"stopPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},enablePullDownRefresh:{type:"async",event:"enablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},disablePullDownRefresh:{type:"async",event:"disablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),ar),{login:{type:"async",event:"login",argsSize:1,agrs0Type:"Object",params:{needLoginPage:{type:["Boolean"],ifMustNeed:!0,default:!1,desc:"needLoginPage"}}},passportLogin:{type:"async",event:"passportLogin",argsSize:0,agrs0Type:"any",params:null},getUserInfo:{type:"async",event:"getUserInfo",argsSize:0,agrs0Type:"any",params:null},logout:{type:"async",event:"logout",argsSize:0,agrs0Type:"any",params:null}}),{openBluetoothAdapter:{type:"async",event:"openBluetoothAdapter",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getBluetoothAdapterState:{type:"async",event:"getBluetoothAdapterState",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},onBluetoothDeviceFound:{type:"async",event:"onBluetoothDeviceFound",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},startBluetoothDevicesDiscovery:{type:"async",event:"startBluetoothDevicesDiscovery",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!1,default:"",desc:"要搜索的蓝牙设备主 service 的 uuid 列表"},allowDuplicatesKey:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否允许重复上报同一设备"},interval:{type:["Number"],ifMustNeed:!1,default:0,desc:"上报设备的间隔"}}},onBluetoothAdapterStateChange:{type:"async",event:"onBluetoothAdapterStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},stopBluetoothDevicesDiscovery:{type:"async",event:"stopBluetoothDevicesDiscovery",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},createBLEConnection:{type:"async",event:"createBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"用于区分设备的 id"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位ms，不填表示不会超时"}}},onBLEConnectionStateChange:{type:"async",event:"onBLEConnectionStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},getBLEDeviceServices:{type:"async",event:"getBLEDeviceServices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getBLEDeviceCharacteristics:{type:"async",event:"getBLEDeviceCharacteristics",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙服务 uuid，需要使用 getBLEDeviceServices 获取"}}},notifyBLECharacteristicValueChange:{type:"async",event:"notifyBLECharacteristicValueChange",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},state:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否启用 notify"}}},writeBLECharacteristicValue:{type:"async",event:"writeBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},value:{type:["ArrayBuffer"],ifMustNeed:!0,default:"",desc:"蓝牙设备特征值对应的二进制值"}}},onBLECharacteristicValueChange:{type:"async",event:"onBLECharacteristicValueChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},closeBluetoothAdapter:{type:"async",event:"closeBluetoothAdapter",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},closeBLEConnection:{type:"async",event:"closeBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getConnectedBluetoothDevices:{type:"async",event:"getConnectedBluetoothDevices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!0,default:"",desc:"蓝牙设备主 service 的 uuid 列表"}}},getBluetoothDevices:{type:"async",event:"getBluetoothDevices",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},readBLECharacteristicValue:{type:"async",event:"readBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"}}}}),{hideKeyboard:{type:"async",event:"hideKeyboard",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{setScreenBrightness:{type:"async",event:"setScreenBrightness",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{value:{type:["Number"],ifMustNeed:!0,default:"",desc:"屏幕亮度值，范围 0 ~ 1。0 最暗，1 最亮"}}},setKeepScreenOn:{type:"async",event:"setKeepScreenOn",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{keepScreenOn:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否保持屏幕常亮"}}},getScreenBrightness:{type:"async",event:"getScreenBrightness",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{chooseContact:{type:"async",event:"chooseContact",agrs0Type:"any",argsSize:0,params:null},addPhoneContact:{type:"async",event:"addPhoneContact",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{firstName:{type:["String"],ifMustNeed:!0,default:"",desc:"名字"},photoFilePath:{type:["String"],ifMustNeed:!1,default:"",desc:"头像本地文件路径"},nickName:{type:["String"],ifMustNeed:!1,default:"",desc:"昵称"},lastName:{type:["String"],ifMustNeed:!1,default:"",desc:"姓氏"},middleName:{type:["String"],ifMustNeed:!1,default:"",desc:"中间名"},remark:{type:["String"],ifMustNeed:!1,default:"",desc:"备注"},mobilePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"手机号"},weChatNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"微信号"},addressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址国家"},addressState:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址省份"},addressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址城市"},addressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址街道"},addressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址邮政编码"},organization:{type:["String"],ifMustNeed:!1,default:"",desc:"公司"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"职位"},workFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作传真"},workPhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作电话"},hostNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"公司电话"},email:{type:["String"],ifMustNeed:!1,default:"",desc:"电子邮件"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"网站"},workAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址国家"},workAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址省份"},workAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址城市"},workAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址街道"},workAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址邮政编码"},homeFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅传真"},homePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅电话"},homeAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址国家"},homeAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址省份"},homeAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址城市"},homeAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址街道"},homeAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址邮政编码"}}}}),{chooseVideo:{type:"async",event:"chooseVideo",agrs0Type:"Object",argsSize:1,params:{compressed:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否压缩所选择的视频文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:60,desc:"拍摄视频最长拍摄时间，单位秒"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"视频选择的来源"}}},getVideoInfo:{type:"async",event:"getVideoInfo",agrs0Type:"any",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"}}},saveVideoToPhotosAlbum:{type:"async",event:"saveVideoToPhotosAlbum",agrs0Type:"Object",argsSize:1,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径 (本地路径)"}}},chooseMedia:{type:"async",event:"chooseMedia",agrs0Type:"Object",argsSize:1,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的文件个数"},mediaType:{type:["Array"],ifMustNeed:!1,default:[],desc:"文件类型"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"图片和视频选择的来源"},sizeType:{type:["Array"],ifMustNeed:!1,default:[],desc:"仅对mediaType为 image 时有效，是否压缩所选文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:10,desc:"拍摄视频最长拍摄时间，单位秒。时间范围为 3s 至 60s 之间。不限制相册。"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"}}},compressVideo:{type:"async",event:"compressVideo",agrs0Type:"Object",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"},quality:{type:["String"],ifMustNeed:!0,default:"",desc:"压缩质量"},bitrate:{type:["Number"],ifMustNeed:!0,default:0,desc:"码率，单位 kbps"},fps:{type:["Number"],ifMustNeed:!0,default:0,desc:"帧率"},resolution:{type:["Number"],ifMustNeed:!0,default:0,desc:"相对于原视频的分辨率比例，取值范围(0, 1]"}}}}),{registerLocalNotify:{type:"async",event:"registerLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"},title:{type:["String"],ifMustNeed:!0,default:"",desc:"标题"},subtitle:{type:["String"],ifMustNeed:!1,default:"",desc:"副标题"},body:{type:["String"],ifMustNeed:!1,default:"",desc:"body"},badge:{type:["Number"],ifMustNeed:!1,default:"",desc:"badge"},year:{type:["Number"],ifMustNeed:!1,default:"",desc:"year"},month:{type:["Number"],ifMustNeed:!1,default:"",desc:"month"},day:{type:["Number"],ifMustNeed:!1,default:"",desc:"day"},hour:{type:["Number"],ifMustNeed:!1,default:"",desc:"hour"},minute:{type:["Number"],ifMustNeed:!1,default:"",desc:"minute"},second:{type:["Number"],ifMustNeed:!1,default:"",desc:"second"},repeats:{type:["Boolean"],ifMustNeed:!1,default:"",desc:"second"},attachmenturl:{type:["String"],ifMustNeed:!1,default:"",desc:"attachmenturl"}}},checkLocalNotify:{type:"async",event:"checkLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:null},removeLocalNotify:{type:"async",event:"removeLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"}}}}),cr=Array.isArray||function(e){return"Array"==p(e)},ur=function(e,t,n){var r=G(t);r in e?te.f(e,r,l(0,n)):e[r]=n},fr=U("species"),lr=function(e){return N>=51||!a((function(){var t=[];return(t.constructor={})[fr]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},dr=lr("slice"),pr=U("species"),hr=[].slice,yr=Math.max;Qe({target:"Array",proto:!0,forced:!dr},{slice:function(e,t){var n,r,i,o=g(this),a=Ne(o.length),s=Oe(e,a),c=Oe(void 0===t?a:t,a);if(cr(o)&&("function"!=typeof(n=o.constructor)||n!==Array&&!cr(n.prototype)?m(n)&&null===(n=n[pr])&&(n=void 0):n=void 0,n===Array||void 0===n))return hr.call(o,s,c);for(r=new(void 0===n?Array:n)(yr(c-s,0)),i=0;s<c;s++,i++)s in o&&ur(r,i,o[s]);return r.length=i,r}});var vr,gr=function(e,t,n){var r,i;return ft&&"function"==typeof(r=t.constructor)&&r!==n&&m(i=r.prototype)&&i!==n.prototype&&ft(e,i),e},mr=Object.keys||function(e){return Ee(e,Ae)},br=s?Object.defineProperties:function(e,t){Z(e);for(var n,r=mr(t),i=r.length,o=0;i>o;)te.f(e,n=r[o++],t[n]);return e},Sr=le("IE_PROTO"),wr=function(){},_r=function(e){return"<script>"+e+"</"+"script>"},Tr=function(e){e.write(_r("")),e.close();var t=e.parentWindow.Object;return e=null,t},kr=function(){try{vr=new ActiveXObject("htmlfile")}catch(e){}var e,t;kr="undefined"!=typeof document?document.domain&&vr?Tr(vr):((t=$("iframe")).style.display="none",Bt.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(_r("document.F=Object")),e.close(),e.F):Tr(vr);for(var n=Ae.length;n--;)delete kr.prototype[Ae[n]];return kr()};de[Sr]=!0;var Mr=Object.create||function(e,t){var n;return null!==e?(wr.prototype=Z(e),n=new wr,wr.prototype=null,n[Sr]=e):n=kr(),void 0===t?n:br(n,t)},Nr=function(e){if(O(e))throw TypeError("Cannot convert a Symbol value to a string");return String(e)},xr="\t\n\v\f\r                　\u2028\u2029\ufeff",Ir="["+xr+"]",Or=RegExp("^"+Ir+Ir+"*"),Pr=RegExp(Ir+Ir+"*$"),Lr=function(e){return function(t){var n=Nr(v(t));return 1&e&&(n=n.replace(Or,"")),2&e&&(n=n.replace(Pr,"")),n}},Cr={start:Lr(1),end:Lr(2),trim:Lr(3)},Er=je.f,Ar=Y.f,Vr=te.f,jr=Cr.trim,Br="Number",Rr=o.Number,zr=Rr.prototype,Fr=p(Mr(zr))==Br,Dr=function(e){if(O(e))throw TypeError("Cannot convert a Symbol value to a number");var t,n,r,i,o,a,s,c,u=J(e,"number");if("string"==typeof u&&u.length>2)if(43===(t=(u=jr(u)).charCodeAt(0))||45===t){if(88===(n=u.charCodeAt(2))||120===n)return NaN}else if(48===t){switch(u.charCodeAt(1)){case 66:case 98:r=2,i=49;break;case 79:case 111:r=8,i=55;break;default:return+u}for(a=(o=u.slice(2)).length,s=0;s<a;s++)if((c=o.charCodeAt(s))<48||c>i)return NaN;return parseInt(o,r)}return+u};if(Ge(Br,!Rr(" 0o1")||!Rr("0b1")||Rr("+0x1"))){for(var Wr,Ur=function(e){var t=arguments.length<1?0:e,n=this;return n instanceof Ur&&(Fr?a((function(){zr.valueOf.call(n)})):p(n)!=Br)?gr(new Rr(Dr(t)),n,Ur):Dr(t)},qr=s?Er(Rr):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),Jr=0;qr.length>Jr;Jr++)j(Rr,Wr=qr[Jr])&&!j(Ur,Wr)&&Vr(Ur,Wr,Ar(Rr,Wr));Ur.prototype=zr,zr.constructor=Ur,we(o,Br,Ur)}var Gr="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,Hr=function(e){if(void 0===e)return 0;var t=ke(e),n=Ne(t);if(t!==n)throw RangeError("Wrong length or index");return n},Qr=Math.abs,$r=Math.pow,Xr=Math.floor,Kr=Math.log,Yr=Math.LN2,Zr=function(e,t,n){var r,i,o,a=new Array(n),s=8*n-t-1,c=(1<<s)-1,u=c>>1,f=23===t?$r(2,-24)-$r(2,-77):0,l=e<0||0===e&&1/e<0?1:0,d=0;for((e=Qr(e))!=e||e===1/0?(i=e!=e?1:0,r=c):(r=Xr(Kr(e)/Yr),e*(o=$r(2,-r))<1&&(r--,o*=2),(e+=r+u>=1?f/o:f*$r(2,1-u))*o>=2&&(r++,o/=2),r+u>=c?(i=0,r=c):r+u>=1?(i=(e*o-1)*$r(2,t),r+=u):(i=e*$r(2,u-1)*$r(2,t),r=0));t>=8;a[d++]=255&i,i/=256,t-=8);for(r=r<<t|i,s+=t;s>0;a[d++]=255&r,r/=256,s-=8);return a[--d]|=128*l,a},ei=function(e,t){var n,r=e.length,i=8*r-t-1,o=(1<<i)-1,a=o>>1,s=i-7,c=r-1,u=e[c--],f=127&u;for(u>>=7;s>0;f=256*f+e[c],c--,s-=8);for(n=f&(1<<-s)-1,f>>=-s,s+=t;s>0;n=256*n+e[c],c--,s-=8);if(0===f)f=1-a;else{if(f===o)return n?NaN:u?-1/0:1/0;n+=$r(2,t),f-=a}return(u?-1:1)*n*$r(2,f-t)},ti=!a((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),ni=le("IE_PROTO"),ri=Object.prototype,ii=ti?Object.getPrototypeOf:function(e){return e=A(e),j(e,ni)?e[ni]:"function"==typeof e.constructor&&e instanceof e.constructor?e.constructor.prototype:e instanceof Object?ri:null},oi=function(e){for(var t=A(this),n=Ne(t.length),r=arguments.length,i=Oe(r>1?arguments[1]:void 0,n),o=r>2?arguments[2]:void 0,a=void 0===o?n:Oe(o,n);a>i;)t[i++]=e;return t},ai=je.f,si=te.f,ci=Se.get,ui=Se.set,fi="ArrayBuffer",li="DataView",di="Wrong index",pi=o.ArrayBuffer,hi=pi,yi=o.DataView,vi=yi&&yi.prototype,gi=Object.prototype,mi=o.RangeError,bi=Zr,Si=ei,wi=function(e){return[255&e]},_i=function(e){return[255&e,e>>8&255]},Ti=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},ki=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},Mi=function(e){return bi(e,23,4)},Ni=function(e){return bi(e,52,8)},xi=function(e,t){si(e.prototype,t,{get:function(){return ci(this)[t]}})},Ii=function(e,t,n,r){var i=Hr(n),o=ci(e);if(i+t>o.byteLength)throw mi(di);var a=ci(o.buffer).bytes,s=i+o.byteOffset,c=a.slice(s,s+t);return r?c:c.reverse()},Oi=function(e,t,n,r,i,o){var a=Hr(n),s=ci(e);if(a+t>s.byteLength)throw mi(di);for(var c=ci(s.buffer).bytes,u=a+s.byteOffset,f=r(+i),l=0;l<t;l++)c[u+l]=f[o?l:t-l-1]};if(Gr){if(!a((function(){pi(1)}))||!a((function(){new pi(-1)}))||a((function(){return new pi,new pi(1.5),new pi(NaN),pi.name!=fi}))){for(var Pi,Li=(hi=function(e){return gt(this,hi),new pi(Hr(e))}).prototype=pi.prototype,Ci=ai(pi),Ei=0;Ci.length>Ei;)(Pi=Ci[Ei++])in hi||ne(hi,Pi,pi[Pi]);Li.constructor=hi}ft&&ii(vi)!==gi&&ft(vi,gi);var Ai=new yi(new hi(2)),Vi=vi.setInt8;Ai.setInt8(0,2147483648),Ai.setInt8(1,2147483649),!Ai.getInt8(0)&&Ai.getInt8(1)||ut(vi,{setInt8:function(e,t){Vi.call(this,e,t<<24>>24)},setUint8:function(e,t){Vi.call(this,e,t<<24>>24)}},{unsafe:!0})}else hi=function(e){gt(this,hi,fi);var t=Hr(e);ui(this,{bytes:oi.call(new Array(t),0),byteLength:t}),s||(this.byteLength=t)},yi=function(e,t,n){gt(this,yi,li),gt(e,hi,li);var r=ci(e).byteLength,i=ke(t);if(i<0||i>r)throw mi("Wrong offset");if(i+(n=void 0===n?r-i:Ne(n))>r)throw mi("Wrong length");ui(this,{buffer:e,byteLength:n,byteOffset:i}),s||(this.buffer=e,this.byteLength=n,this.byteOffset=i)},s&&(xi(hi,"byteLength"),xi(yi,"buffer"),xi(yi,"byteLength"),xi(yi,"byteOffset")),ut(yi.prototype,{getInt8:function(e){return Ii(this,1,e)[0]<<24>>24},getUint8:function(e){return Ii(this,1,e)[0]},getInt16:function(e){var t=Ii(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=Ii(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return ki(Ii(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return ki(Ii(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return Si(Ii(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return Si(Ii(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){Oi(this,1,e,wi,t)},setUint8:function(e,t){Oi(this,1,e,wi,t)},setInt16:function(e,t){Oi(this,2,e,_i,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){Oi(this,2,e,_i,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){Oi(this,4,e,Ti,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){Oi(this,4,e,Ti,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){Oi(this,4,e,Mi,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){Oi(this,8,e,Ni,t,arguments.length>2?arguments[2]:void 0)}});pt(hi,fi),pt(yi,li);var ji={ArrayBuffer:hi,DataView:yi},Bi="ArrayBuffer",Ri=ji.ArrayBuffer,zi=o.ArrayBuffer;Qe({global:!0,forced:zi!==Ri},{ArrayBuffer:Ri}),yt(Bi);var Fi=ji.ArrayBuffer,Di=ji.DataView,Wi=Fi.prototype.slice,Ui=a((function(){return!new Fi(2).slice(1,void 0).byteLength}));Qe({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:Ui},{slice:function(e,t){if(void 0!==Wi&&void 0===t)return Wi.call(Z(this),e);for(var n=Z(this).byteLength,r=Oe(e,n),i=Oe(void 0===t?n:t,n),o=new(jt(this,Fi))(Ne(i-r)),a=new Di(this),s=new Di(o),c=0;r<i;)s.setUint8(c++,a.getUint8(r++));return o}});var qi={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},Ji=U("species"),Gi=function(e,t){return new(function(e){var t;return cr(e)&&("function"!=typeof(t=e.constructor)||t!==Array&&!cr(t.prototype)?m(t)&&null===(t=t[Ji])&&(t=void 0):t=void 0),void 0===t?Array:t}(e))(0===t?0:t)},Hi=[].push,Qi=function(e){var t=1==e,n=2==e,r=3==e,i=4==e,o=6==e,a=7==e,s=5==e||o;return function(c,u,f,l){for(var d,p,h=A(c),v=y(h),g=wt(u,f,3),m=Ne(v.length),b=0,S=l||Gi,w=t?S(c,m):n||a?S(c,0):void 0;m>b;b++)if((s||b in v)&&(p=g(d=v[b],b,h),e))if(t)w[b]=p;else if(p)switch(e){case 3:return!0;case 5:return d;case 6:return b;case 2:Hi.call(w,d)}else switch(e){case 4:return!1;case 7:Hi.call(w,d)}return o?-1:r||i?i:w}},$i={forEach:Qi(0),map:Qi(1),filter:Qi(2),some:Qi(3),every:Qi(4),find:Qi(5),findIndex:Qi(6),filterReject:Qi(7)},Xi=$i.forEach,Ki=$e("forEach")?[].forEach:function(e){return Xi(this,e,arguments.length>1?arguments[1]:void 0)};for(var Yi in qi){var Zi=o[Yi],eo=Zi&&Zi.prototype;if(eo&&eo.forEach!==Ki)try{ne(eo,"forEach",Ki)}catch(e){eo.forEach=Ki}}var to=a((function(){mr(1)}));Qe({target:"Object",stat:!0,forced:to},{keys:function(e){return mr(A(e))}});try{globalThis||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":et(window))&&window}var no=Object.prototype.toString;function ro(e){return no.call(e).slice(8,-1)}function io(e){return"Number"===ro(e)}function oo(e){return"function"==typeof e}function ao(e,t){var n=e.params,r=ro(t[0]),i=e.argsSize,o=(e.agrs0Type,e.event,{});if(i>1||1===i&&"Object"!==r)for(var a=Object.keys(n),s=0;s<i;s++)o[a[s]]=t[s];else 1===i&&"Object"===r&&(o=t[0]);return e.params&&Object.keys(n).forEach((function(e){n[e].ifMustNeed;var t=ro(o[e]);e in o&&"any"!==n[e].type&&n[e].type.indexOf(t)})),o}function so(e,t){var n={};return e&&Object.keys(e).forEach((function(r){"boolean"==typeof t[r]?n[r]=t[r]:n[r]=t[r]||e[r].default})),n}var co=U("unscopables"),uo=Array.prototype;null==uo[co]&&te.f(uo,co,{configurable:!0,value:Mr(null)});var fo,lo,po,ho=function(e){uo[co][e]=!0},yo=U("iterator"),vo=!1;[].keys&&("next"in(po=[].keys())?(lo=ii(ii(po)))!==Object.prototype&&(fo=lo):vo=!0),(null==fo||a((function(){var e={};return fo[yo].call(e)!==e})))&&(fo={}),j(fo,yo)||ne(fo,yo,(function(){return this}));var go={IteratorPrototype:fo,BUGGY_SAFARI_ITERATORS:vo},mo=go.IteratorPrototype,bo=function(){return this},So=go.IteratorPrototype,wo=go.BUGGY_SAFARI_ITERATORS,_o=U("iterator"),To="keys",ko="values",Mo="entries",No=function(){return this},xo=function(e,t,n,r,i,o,a){!function(e,t,n){var r=t+" Iterator";e.prototype=Mr(mo,{next:l(1,n)}),pt(e,r,!1),mt[r]=bo}(n,t,r);var s,c,u,f=function(e){if(e===i&&v)return v;if(!wo&&e in h)return h[e];switch(e){case To:case ko:case Mo:return function(){return new n(this,e)}}return function(){return new n(this)}},d=t+" Iterator",p=!1,h=e.prototype,y=h[_o]||h["@@iterator"]||i&&h[i],v=!wo&&y||f(i),g="Array"==t&&h.entries||y;if(g&&(s=ii(g.call(new e)),So!==Object.prototype&&s.next&&(ii(s)!==So&&(ft?ft(s,So):"function"!=typeof s[_o]&&ne(s,_o,No)),pt(s,d,!0))),i==ko&&y&&y.name!==ko&&(p=!0,v=function(){return y.call(this)}),h[_o]!==v&&ne(h,_o,v),mt[t]=v,i)if(c={values:f(ko),keys:o?v:f(To),entries:f(Mo)},a)for(u in c)(wo||p||!(u in h))&&we(h,u,c[u]);else Qe({target:t,proto:!0,forced:wo||p},c);return c},Io="Array Iterator",Oo=Se.set,Po=Se.getterFor(Io),Lo=xo(Array,"Array",(function(e,t){Oo(this,{type:Io,target:g(e),index:0,kind:t})}),(function(){var e=Po(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values");mt.Arguments=mt.Array,ho("keys"),ho("values"),ho("entries");var Co=function(e){return function(t,n){var r,i,o=Nr(v(t)),a=ke(n),s=o.length;return a<0||a>=s?e?"":void 0:(r=o.charCodeAt(a))<55296||r>56319||a+1===s||(i=o.charCodeAt(a+1))<56320||i>57343?e?o.charAt(a):r:e?o.slice(a,a+2):i-56320+(r-55296<<10)+65536}},Eo={codeAt:Co(!1),charAt:Co(!0)},Ao=Eo.charAt,Vo="String Iterator",jo=Se.set,Bo=Se.getterFor(Vo);xo(String,"String",(function(e){jo(this,{type:Vo,string:Nr(e),index:0})}),(function(){var e,t=Bo(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=Ao(n,r),t.index+=e.length,{value:e,done:!1})}));var Ro=je.f,zo={}.toString,Fo="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Do={f:function(e){return Fo&&"[object Window]"==zo.call(e)?function(e){try{return Ro(e)}catch(e){return Fo.slice()}}(e):Ro(g(e))}},Wo=!a((function(){return Object.isExtensible(Object.preventExtensions({}))})),Uo=t((function(e){var t=te.f,n=!1,r=z("meta"),i=0,o=Object.isExtensible||function(){return!0},a=function(e){t(e,r,{value:{objectID:"O"+i++,weakData:{}}})},s=e.exports={enable:function(){s.enable=function(){},n=!0;var e=je.f,t=[].splice,i={};i[r]=1,e(i).length&&(je.f=function(n){for(var i=e(n),o=0,a=i.length;o<a;o++)if(i[o]===r){t.call(i,o,1);break}return i},Qe({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Do.f}))},fastKey:function(e,t){if(!m(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!j(e,r)){if(!o(e))return"F";if(!t)return"E";a(e)}return e[r].objectID},getWeakData:function(e,t){if(!j(e,r)){if(!o(e))return!0;if(!t)return!1;a(e)}return e[r].weakData},onFreeze:function(e){return Wo&&n&&o(e)&&!j(e,r)&&a(e),e}};de[r]=!0})),qo=function(e,t,n){var r=-1!==e.indexOf("Map"),i=-1!==e.indexOf("Weak"),s=r?"set":"add",c=o[e],u=c&&c.prototype,f=c,l={},d=function(e){var t=u[e];we(u,e,"add"==e?function(e){return t.call(this,0===e?0:e),this}:"delete"==e?function(e){return!(i&&!m(e))&&t.call(this,0===e?0:e)}:"get"==e?function(e){return i&&!m(e)?void 0:t.call(this,0===e?0:e)}:"has"==e?function(e){return!(i&&!m(e))&&t.call(this,0===e?0:e)}:function(e,n){return t.call(this,0===e?0:e,n),this})};if(Ge(e,"function"!=typeof c||!(i||u.forEach&&!a((function(){(new c).entries().next()})))))f=n.getConstructor(t,e,r,s),Uo.enable();else if(Ge(e,!0)){var p=new f,h=p[s](i?{}:-0,1)!=p,y=a((function(){p.has(1)})),v=At((function(e){new c(e)})),g=!i&&a((function(){for(var e=new c,t=5;t--;)e[s](t,t);return!e.has(-0)}));v||((f=t((function(t,n){gt(t,f,e);var i=gr(new c,t,f);return null!=n&&Mt(n,i[s],{that:i,AS_ENTRIES:r}),i}))).prototype=u,u.constructor=f),(y||g)&&(d("delete"),d("has"),r&&d("get")),(g||h)&&d(s),i&&u.clear&&delete u.clear}return l[e]=f,Qe({global:!0,forced:f!=c},l),pt(f,e),i||n.setStrong(f,e,r),f},Jo=Uo.getWeakData,Go=Se.set,Ho=Se.getterFor,Qo=$i.find,$o=$i.findIndex,Xo=0,Ko=function(e){return e.frozen||(e.frozen=new Yo)},Yo=function(){this.entries=[]},Zo=function(e,t){return Qo(e.entries,(function(e){return e[0]===t}))};Yo.prototype={get:function(e){var t=Zo(this,e);if(t)return t[1]},has:function(e){return!!Zo(this,e)},set:function(e,t){var n=Zo(this,e);n?n[1]=t:this.entries.push([e,t])},delete:function(e){var t=$o(this.entries,(function(t){return t[0]===e}));return~t&&this.entries.splice(t,1),!!~t}};var ea={getConstructor:function(e,t,n,r){var i=e((function(e,o){gt(e,i,t),Go(e,{type:t,id:Xo++,frozen:void 0}),null!=o&&Mt(o,e[r],{that:e,AS_ENTRIES:n})})),o=Ho(t),a=function(e,t,n){var r=o(e),i=Jo(Z(t),!0);return!0===i?Ko(r).set(t,n):i[r.id]=n,e};return ut(i.prototype,{delete:function(e){var t=o(this);if(!m(e))return!1;var n=Jo(e);return!0===n?Ko(t).delete(e):n&&j(n,t.id)&&delete n[t.id]},has:function(e){var t=o(this);if(!m(e))return!1;var n=Jo(e);return!0===n?Ko(t).has(e):n&&j(n,t.id)}}),ut(i.prototype,n?{get:function(e){var t=o(this);if(m(e)){var n=Jo(e);return!0===n?Ko(t).get(e):n?n[t.id]:void 0}},set:function(e,t){return a(this,e,t)}}:{add:function(e){return a(this,e,!0)}}),i}},ta=(t((function(e){var t,n=Se.enforce,r=!o.ActiveXObject&&"ActiveXObject"in o,i=Object.isExtensible,a=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},s=e.exports=qo("WeakMap",a,ea);if(ue&&r){t=ea.getConstructor(a,"WeakMap",!0),Uo.enable();var c=s.prototype,u=c.delete,f=c.has,l=c.get,d=c.set;ut(c,{delete:function(e){if(m(e)&&!i(e)){var r=n(this);return r.frozen||(r.frozen=new t),u.call(this,e)||r.frozen.delete(e)}return u.call(this,e)},has:function(e){if(m(e)&&!i(e)){var r=n(this);return r.frozen||(r.frozen=new t),f.call(this,e)||r.frozen.has(e)}return f.call(this,e)},get:function(e){if(m(e)&&!i(e)){var r=n(this);return r.frozen||(r.frozen=new t),f.call(this,e)?l.call(this,e):r.frozen.get(e)}return l.call(this,e)},set:function(e,r){if(m(e)&&!i(e)){var o=n(this);o.frozen||(o.frozen=new t),f.call(this,e)?d.call(this,e,r):o.frozen.set(e,r)}else d.call(this,e,r);return this}})}})),U("iterator")),na=U("toStringTag"),ra=Lo.values;for(var ia in qi){var oa=o[ia],aa=oa&&oa.prototype;if(aa){if(aa[ta]!==ra)try{ne(aa,ta,ra)}catch(e){aa[ta]=ra}if(aa[na]||ne(aa,na,ia),qi[ia])for(var sa in Lo)if(aa[sa]!==Lo[sa])try{ne(aa,sa,Lo[sa])}catch(e){aa[sa]=Lo[sa]}}}var ca=U("isConcatSpreadable"),ua=9007199254740991,fa="Maximum allowed index exceeded",la=N>=51||!a((function(){var e=[];return e[ca]=!1,e.concat()[0]!==e})),da=lr("concat"),pa=function(e){if(!m(e))return!1;var t=e[ca];return void 0!==t?!!t:cr(e)};Qe({target:"Array",proto:!0,forced:!la||!da},{concat:function(e){var t,n,r,i,o,a=A(this),s=Gi(a,0),c=0;for(t=-1,r=arguments.length;t<r;t++)if(pa(o=-1===t?a:arguments[t])){if(c+(i=Ne(o.length))>ua)throw TypeError(fa);for(n=0;n<i;n++,c++)n in o&&ur(s,c,o[n])}else{if(c>=ua)throw TypeError(fa);ur(s,c++,o)}return s.length=c,s}});var ha=t((function(e,t){!function(t){var n=Object.hasOwnProperty,r=Array.isArray?Array.isArray:function(e){return"[object Array]"===Object.prototype.toString.call(e)},i="object"==typeof process&&"function"==typeof process.nextTick,o="function"==typeof Symbol,a="object"==typeof Reflect,s="function"==typeof setImmediate?setImmediate:setTimeout,c=o?a&&"function"==typeof Reflect.ownKeys?Reflect.ownKeys:function(e){var t=Object.getOwnPropertyNames(e);return t.push.apply(t,Object.getOwnPropertySymbols(e)),t}:Object.keys;function u(){this._events={},this._conf&&f.call(this,this._conf)}function f(e){e&&(this._conf=e,e.delimiter&&(this.delimiter=e.delimiter),e.maxListeners!==t&&(this._maxListeners=e.maxListeners),e.wildcard&&(this.wildcard=e.wildcard),e.newListener&&(this._newListener=e.newListener),e.removeListener&&(this._removeListener=e.removeListener),e.verboseMemoryLeak&&(this.verboseMemoryLeak=e.verboseMemoryLeak),e.ignoreErrors&&(this.ignoreErrors=e.ignoreErrors),this.wildcard&&(this.listenerTree={}))}function l(e,t){var n="(node) warning: possible EventEmitter memory leak detected. "+e+" listeners added. Use emitter.setMaxListeners() to increase limit.";if(this.verboseMemoryLeak&&(n+=" Event name: "+t+"."),"undefined"!=typeof process&&process.emitWarning){var r=new Error(n);r.name="MaxListenersExceededWarning",r.emitter=this,r.count=e,process.emitWarning(r)}else console.trace}var d=function(e,t,n){var r=arguments.length;switch(r){case 0:return[];case 1:return[e];case 2:return[e,t];case 3:return[e,t,n];default:for(var i=new Array(r);r--;)i[r]=arguments[r];return i}};function p(e,n){for(var r={},i=e.length,o=n?value.length:0,a=0;a<i;a++)r[e[a]]=a<o?n[a]:t;return r}function h(e,t,n){var r,i;if(this._emitter=e,this._target=t,this._listeners={},this._listenersCount=0,(n.on||n.off)&&(r=n.on,i=n.off),t.addEventListener?(r=t.addEventListener,i=t.removeEventListener):t.addListener?(r=t.addListener,i=t.removeListener):t.on&&(r=t.on,i=t.off),!r&&!i)throw Error("target does not implement any known event API");if("function"!=typeof r)throw TypeError("on method must be a function");if("function"!=typeof i)throw TypeError("off method must be a function");this._on=r,this._off=i;var o=e._observers;o?o.push(this):e._observers=[this]}function y(e,r,i,o){var a=Object.assign({},r);if(!e)return a;if("object"!=typeof e)throw TypeError("options must be an object");var s,c,u,f=Object.keys(e),l=f.length;function d(e){throw Error('Invalid "'+s+'" option value'+(e?". Reason: "+e:""))}for(var p=0;p<l;p++){if(s=f[p],!o&&!n.call(r,s))throw Error('Unknown "'+s+'" option');(c=e[s])!==t&&(u=i[s],a[s]=u?u(c,d):c)}return a}function v(e,t){return"function"==typeof e&&e.hasOwnProperty("prototype")||t("value must be a constructor"),e}function g(e){var t="value must be type of "+e.join("|"),n=e.length,r=e[0],i=e[1];return 1===n?function(e,n){if(typeof e===r)return e;n(t)}:2===n?function(e,n){var o=typeof e;if(o===r||o===i)return e;n(t)}:function(r,i){for(var o=typeof r,a=n;a-- >0;)if(o===e[a])return r;i(t)}}Object.assign(h.prototype,{subscribe:function(e,t,n){var r=this,i=this._target,o=this._emitter,a=this._listeners,s=function(){var r=d.apply(null,arguments),a={data:r,name:t,original:e};if(n){var s=n.call(i,a);!1!==s&&o.emit.apply(o,[a.name].concat(r))}else o.emit.apply(o,[t].concat(r))};if(a[e])throw Error("Event '"+e+"' is already listening");this._listenersCount++,o._newListener&&o._removeListener&&!r._onNewListener?(this._onNewListener=function(n){n===t&&null===a[e]&&(a[e]=s,r._on.call(i,e,s))},o.on("newListener",this._onNewListener),this._onRemoveListener=function(n){n===t&&!o.hasListeners(n)&&a[e]&&(a[e]=null,r._off.call(i,e,s))},a[e]=null,o.on("removeListener",this._onRemoveListener)):(a[e]=s,r._on.call(i,e,s))},unsubscribe:function(e){var t,n,r,i=this,o=this._listeners,a=this._emitter,s=this._off,u=this._target;if(e&&"string"!=typeof e)throw TypeError("event must be a string");function f(){i._onNewListener&&(a.off("newListener",i._onNewListener),a.off("removeListener",i._onRemoveListener),i._onNewListener=null,i._onRemoveListener=null);var e=w.call(a,i);a._observers.splice(e,1)}if(e){if(!(t=o[e]))return;s.call(u,e,t),delete o[e],--this._listenersCount||f()}else{for(r=(n=c(o)).length;r-- >0;)e=n[r],s.call(u,e,o[e]);this._listeners={},this._listenersCount=0,f()}}});var m=g(["function"]),b=g(["object","function"]);function S(e,t,n){var r,i,o,a=0,s=new e((function(c,u,f){function l(){i&&(i=null),a&&(clearTimeout(a),a=0)}n=y(n,{timeout:0,overload:!1},{timeout:function(e,t){return("number"!=typeof(e*=1)||e<0||!Number.isFinite(e))&&t("timeout must be a positive number"),e}}),r=!n.overload&&"function"==typeof e.prototype.cancel&&"function"==typeof f;var d=function(e){l(),c(e)},p=function(e){l(),u(e)};r?t(d,p,f):(i=[function(e){p(e||Error("canceled"))}],t(d,p,(function(e){if(o)throw Error("Unable to subscribe on cancel event asynchronously");if("function"!=typeof e)throw TypeError("onCancel callback must be a function");i.push(e)})),o=!0),n.timeout>0&&(a=setTimeout((function(){var e=Error("timeout");e.code="ETIMEDOUT",a=0,s.cancel(e),u(e)}),n.timeout))}));return r||(s.cancel=function(e){if(i){for(var t=i.length,n=1;n<t;n++)i[n](e);i[0](e),i=null}}),s}function w(e){var t=this._observers;if(!t)return-1;for(var n=t.length,r=0;r<n;r++)if(t[r]._target===e)return r;return-1}function _(e,t,n,r,i){if(!n)return null;if(0===r){var o=typeof t;if("string"===o){var a,s,u=0,f=0,l=this.delimiter,d=l.length;if(-1!==(s=t.indexOf(l))){a=new Array(5);do{a[u++]=t.slice(f,s),f=s+d}while(-1!==(s=t.indexOf(l,f)));a[u++]=t.slice(f),t=a,i=u}else t=[t],i=1}else"object"===o?i=t.length:(t=[t],i=1)}var p,h,y,v,g,m,b,S=null,w=t[r],T=t[r+1];if(r===i&&n._listeners)return"function"==typeof n._listeners?(e&&e.push(n._listeners),[n]):(e&&e.push.apply(e,n._listeners),[n]);if("*"===w){for(s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&(b=_(e,t,n[p],r+1,i))&&(S?S.push.apply(S,b):S=b);return S}if("**"===w){for((g=r+1===i||r+2===i&&"*"===T)&&n._listeners&&(S=_(e,t,n,i,i)),s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&("*"===p||"**"===p?(n[p]._listeners&&!g&&(b=_(e,t,n[p],i,i))&&(S?S.push.apply(S,b):S=b),b=_(e,t,n[p],r,i)):b=_(e,t,n[p],p===T?r+2:r,i),b&&(S?S.push.apply(S,b):S=b));return S}if(n[w]&&(S=_(e,t,n[w],r+1,i)),(h=n["*"])&&_(e,t,h,r+1,i),y=n["**"])if(r<i)for(y._listeners&&_(e,t,y,i,i),s=(m=c(y)).length;s-- >0;)"_listeners"!==(p=m[s])&&(p===T?_(e,t,y[p],r+2,i):p===w?_(e,t,y[p],r+1,i):((v={})[p]=y[p],_(e,t,{"**":v},r+1,i)));else y._listeners?_(e,t,y,i,i):y["*"]&&y["*"]._listeners&&_(e,t,y["*"],i,i);return S}function T(e,t,n){var r,i,o=0,a=0,s=this.delimiter,c=s.length;if("string"==typeof e)if(-1!==(r=e.indexOf(s))){i=new Array(5);do{i[o++]=e.slice(a,r),a=r+c}while(-1!==(r=e.indexOf(s,a)));i[o++]=e.slice(a)}else i=[e],o=1;else i=e,o=e.length;if(o>1)for(r=0;r+1<o;r++)if("**"===i[r]&&"**"===i[r+1])return;var u,f=this.listenerTree;for(r=0;r<o;r++)if(f=f[u=i[r]]||(f[u]={}),r===o-1)return f._listeners?("function"==typeof f._listeners&&(f._listeners=[f._listeners]),n?f._listeners.unshift(t):f._listeners.push(t),!f._listeners.warned&&this._maxListeners>0&&f._listeners.length>this._maxListeners&&(f._listeners.warned=!0,l.call(this,f._listeners.length,u))):f._listeners=t,!0;return!0}function k(e,t,n,r){for(var i,o,a,s,u=c(e),f=u.length,l=e._listeners;f-- >0;)i=e[o=u[f]],a="_listeners"===o?n:n?n.concat(o):[o],s=r||"symbol"==typeof o,l&&t.push(s?a:a.join(this.delimiter)),"object"==typeof i&&k.call(this,i,t,a,s);return t}function M(e){for(var t,n,r,i=c(e),o=i.length;o-- >0;)(t=e[n=i[o]])&&(r=!0,"_listeners"===n||M(t)||delete e[n]);return r}function N(e,t,n){this.emitter=e,this.event=t,this.listener=n}function x(e,n,r){if(!0===r)a=!0;else if(!1===r)o=!0;else{if(!r||"object"!=typeof r)throw TypeError("options should be an object or true");var o=r.async,a=r.promisify,c=r.nextTick,u=r.objectify}if(o||c||a){var f=n,l=n._origin||n;if(c&&!i)throw Error("process.nextTick is not supported");a===t&&(a="AsyncFunction"===n.constructor.name),(n=function(){var e=arguments,t=this,n=this.event;return a?c?Promise.resolve():new Promise((function(e){s(e)})).then((function(){return t.event=n,f.apply(t,e)})):(c?process.nextTick:s)((function(){t.event=n,f.apply(t,e)}))})._async=!0,n._origin=l}return[n,u?new N(this,e,n):this]}function I(e){this._events={},this._newListener=!1,this._removeListener=!1,this.verboseMemoryLeak=!1,f.call(this,e)}N.prototype.off=function(){return this.emitter.off(this.event,this.listener),this},I.EventEmitter2=I,I.prototype.listenTo=function(e,n,i){if("object"!=typeof e)throw TypeError("target musts be an object");var o=this;function a(t){if("object"!=typeof t)throw TypeError("events must be an object");var n,r=i.reducers,a=w.call(o,e);n=-1===a?new h(o,e,i):o._observers[a];for(var s,u=c(t),f=u.length,l="function"==typeof r,d=0;d<f;d++)s=u[d],n.subscribe(s,t[s]||s,l?r:r&&r[s])}return i=y(i,{on:t,off:t,reducers:t},{on:m,off:m,reducers:b}),r(n)?a(p(n)):a("string"==typeof n?p(n.split(/\s+/)):n),this},I.prototype.stopListeningTo=function(e,t){var n=this._observers;if(!n)return!1;var r,i=n.length,o=!1;if(e&&"object"!=typeof e)throw TypeError("target should be an object");for(;i-- >0;)r=n[i],e&&r._target!==e||(r.unsubscribe(t),o=!0);return o},I.prototype.delimiter=".",I.prototype.setMaxListeners=function(e){e!==t&&(this._maxListeners=e,this._conf||(this._conf={}),this._conf.maxListeners=e)},I.prototype.getMaxListeners=function(){return this._maxListeners},I.prototype.event="",I.prototype.once=function(e,t,n){return this._once(e,t,!1,n)},I.prototype.prependOnceListener=function(e,t,n){return this._once(e,t,!0,n)},I.prototype._once=function(e,t,n,r){return this._many(e,1,t,n,r)},I.prototype.many=function(e,t,n,r){return this._many(e,t,n,!1,r)},I.prototype.prependMany=function(e,t,n,r){return this._many(e,t,n,!0,r)},I.prototype._many=function(e,t,n,r,i){var o=this;if("function"!=typeof n)throw new Error("many only accepts instances of Function");function a(){return 0==--t&&o.off(e,a),n.apply(this,arguments)}return a._origin=n,this._on(e,a,r,i)},I.prototype.emit=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return!1;if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(n=s.length,o)for(r=0;r<n;r++)if("symbol"==typeof s[r]){a=!0;break}a||(s=s.join(this.delimiter))}var f,l=arguments.length;if(this._all&&this._all.length)for(r=0,n=(f=this._all.slice()).length;r<n;r++)switch(this.event=s,l){case 1:f[r].call(this,s);break;case 2:f[r].call(this,s,arguments[1]);break;case 3:f[r].call(this,s,arguments[1],arguments[2]);break;default:f[r].apply(this,arguments)}if(c)f=[],_.call(this,f,e,this.listenerTree,0,n);else{if("function"==typeof(f=this._events[s])){switch(this.event=s,l){case 1:f.call(this);break;case 2:f.call(this,arguments[1]);break;case 3:f.call(this,arguments[1],arguments[2]);break;default:for(t=new Array(l-1),i=1;i<l;i++)t[i-1]=arguments[i];f.apply(this,t)}return!0}f&&(f=f.slice())}if(f&&f.length){if(l>3)for(t=new Array(l-1),i=1;i<l;i++)t[i-1]=arguments[i];for(r=0,n=f.length;r<n;r++)switch(this.event=s,l){case 1:f[r].call(this);break;case 2:f[r].call(this,arguments[1]);break;case 3:f[r].call(this,arguments[1],arguments[2]);break;default:f[r].apply(this,t)}return!0}if(!this.ignoreErrors&&!this._all&&"error"===s)throw arguments[1]instanceof Error?arguments[1]:new Error("Uncaught, unspecified 'error' event.");return!!this._all},I.prototype.emitAsync=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return Promise.resolve([!1]);if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(r=s.length,o)for(i=0;i<r;i++)if("symbol"==typeof s[i]){t=!0;break}t||(s=s.join(this.delimiter))}var f,l=[],d=arguments.length;if(this._all)for(i=0,r=this._all.length;i<r;i++)switch(this.event=s,d){case 1:l.push(this._all[i].call(this,s));break;case 2:l.push(this._all[i].call(this,s,arguments[1]));break;case 3:l.push(this._all[i].call(this,s,arguments[1],arguments[2]));break;default:l.push(this._all[i].apply(this,arguments))}if(c?(f=[],_.call(this,f,e,this.listenerTree,0)):f=this._events[s],"function"==typeof f)switch(this.event=s,d){case 1:l.push(f.call(this));break;case 2:l.push(f.call(this,arguments[1]));break;case 3:l.push(f.call(this,arguments[1],arguments[2]));break;default:for(n=new Array(d-1),a=1;a<d;a++)n[a-1]=arguments[a];l.push(f.apply(this,n))}else if(f&&f.length){if(f=f.slice(),d>3)for(n=new Array(d-1),a=1;a<d;a++)n[a-1]=arguments[a];for(i=0,r=f.length;i<r;i++)switch(this.event=s,d){case 1:l.push(f[i].call(this));break;case 2:l.push(f[i].call(this,arguments[1]));break;case 3:l.push(f[i].call(this,arguments[1],arguments[2]));break;default:l.push(f[i].apply(this,n))}}else if(!this.ignoreErrors&&!this._all&&"error"===s)return arguments[1]instanceof Error?Promise.reject(arguments[1]):Promise.reject("Uncaught, unspecified 'error' event.");return Promise.all(l)},I.prototype.on=function(e,t,n){return this._on(e,t,!1,n)},I.prototype.prependListener=function(e,t,n){return this._on(e,t,!0,n)},I.prototype.onAny=function(e){return this._onAny(e,!1)},I.prototype.prependAny=function(e){return this._onAny(e,!0)},I.prototype.addListener=I.prototype.on,I.prototype._onAny=function(e,t){if("function"!=typeof e)throw new Error("onAny only accepts instances of Function");return this._all||(this._all=[]),t?this._all.unshift(e):this._all.push(e),this},I.prototype._on=function(e,n,r,i){if("function"==typeof e)return this._onAny(e,n),this;if("function"!=typeof n)throw new Error("on only accepts instances of Function");this._events||u.call(this);var o,a=this;return i!==t&&(n=(o=x.call(this,e,n,i))[0],a=o[1]),this._newListener&&this.emit("newListener",e,n),this.wildcard?(T.call(this,e,n,r),a):(this._events[e]?("function"==typeof this._events[e]&&(this._events[e]=[this._events[e]]),r?this._events[e].unshift(n):this._events[e].push(n),!this._events[e].warned&&this._maxListeners>0&&this._events[e].length>this._maxListeners&&(this._events[e].warned=!0,l.call(this,this._events[e].length,e))):this._events[e]=n,a)},I.prototype.off=function(e,t){if("function"!=typeof t)throw new Error("removeListener only takes instances of Function");var n,i=[];if(this.wildcard){var o="string"==typeof e?e.split(this.delimiter):e.slice();if(!(i=_.call(this,null,o,this.listenerTree,0)))return this}else{if(!this._events[e])return this;n=this._events[e],i.push({_listeners:n})}for(var a=0;a<i.length;a++){var s=i[a];if(n=s._listeners,r(n)){for(var c=-1,u=0,f=n.length;u<f;u++)if(n[u]===t||n[u].listener&&n[u].listener===t||n[u]._origin&&n[u]._origin===t){c=u;break}if(c<0)continue;return this.wildcard?s._listeners.splice(c,1):this._events[e].splice(c,1),0===n.length&&(this.wildcard?delete s._listeners:delete this._events[e]),this._removeListener&&this.emit("removeListener",e,t),this}(n===t||n.listener&&n.listener===t||n._origin&&n._origin===t)&&(this.wildcard?delete s._listeners:delete this._events[e],this._removeListener&&this.emit("removeListener",e,t))}return this.listenerTree&&M(this.listenerTree),this},I.prototype.offAny=function(e){var t,n=0,r=0;if(e&&this._all&&this._all.length>0){for(n=0,r=(t=this._all).length;n<r;n++)if(e===t[n])return t.splice(n,1),this._removeListener&&this.emit("removeListenerAny",e),this}else{if(t=this._all,this._removeListener)for(n=0,r=t.length;n<r;n++)this.emit("removeListenerAny",t[n]);this._all=[]}return this},I.prototype.removeListener=I.prototype.off,I.prototype.removeAllListeners=function(e){if(e===t)return!this._events||u.call(this),this;if(this.wildcard){var n,r=_.call(this,null,e,this.listenerTree,0);if(!r)return this;for(n=0;n<r.length;n++)r[n]._listeners=null;this.listenerTree&&M(this.listenerTree)}else this._events&&(this._events[e]=null);return this},I.prototype.listeners=function(e){var n,r,i,o,a,s=this._events;if(e===t){if(this.wildcard)throw Error("event name required for wildcard emitter");if(!s)return[];for(o=(n=c(s)).length,i=[];o-- >0;)"function"==typeof(r=s[n[o]])?i.push(r):i.push.apply(i,r);return i}if(this.wildcard){if(!(a=this.listenerTree))return[];var u=[],f="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,u,f,a,0),u}return s&&(r=s[e])?"function"==typeof r?[r]:r:[]},I.prototype.eventNames=function(e){var t=this._events;return this.wildcard?k.call(this,this.listenerTree,[],null,e):t?c(t):[]},I.prototype.listenerCount=function(e){return this.listeners(e).length},I.prototype.hasListeners=function(e){if(this.wildcard){var n=[],r="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,n,r,this.listenerTree,0),n.length>0}var i=this._events,o=this._all;return!!(o&&o.length||i&&(e===t?c(i).length:i[e]))},I.prototype.listenersAny=function(){return this._all?this._all:[]},I.prototype.waitFor=function(e,n){var r=this,i=typeof n;return"number"===i?n={timeout:n}:"function"===i&&(n={filter:n}),S((n=y(n,{timeout:0,filter:t,handleError:!1,Promise:Promise,overload:!1},{filter:m,Promise:v})).Promise,(function(t,i,o){function a(){var o=n.filter;if(!o||o.apply(r,arguments))if(r.off(e,a),n.handleError){var s=arguments[0];s?i(s):t(d.apply(null,arguments).slice(1))}else t(d.apply(null,arguments))}o((function(){r.off(e,a)})),r._on(e,a,!1)}),{timeout:n.timeout,overload:n.overload})};var O=I.prototype;Object.defineProperties(I,{defaultMaxListeners:{get:function(){return O._maxListeners},set:function(e){if("number"!=typeof e||e<0||Number.isNaN(e))throw TypeError("n must be a non-negative number");O._maxListeners=e},enumerable:!0},once:{value:function(e,t,n){return S((n=y(n,{Promise:Promise,timeout:0,overload:!1},{Promise:v})).Promise,(function(n,r,i){var o;if("function"==typeof e.addEventListener)return o=function(){n(d.apply(null,arguments))},i((function(){e.removeEventListener(t,o)})),void e.addEventListener(t,o,{once:!0});var a,s=function(){a&&e.removeListener("error",a),n(d.apply(null,arguments))};"error"!==t&&(a=function(n){e.removeListener(t,s),r(n)},e.once("error",a)),i((function(){a&&e.removeListener("error",a),e.removeListener(t,s)})),e.once(t,s)}),{timeout:n.timeout,overload:n.overload})},writable:!0,configurable:!0}}),Object.defineProperties(O,{_maxListeners:{value:10,writable:!0,configurable:!0},_observers:{value:null,writable:!0,configurable:!0}}),e.exports=I}()})),ya={f:U},va=o,ga=te.f,ma=function(e){var t=va.Symbol||(va.Symbol={});j(t,e)||ga(t,e,{value:ya.f(e)})},ba=$i.forEach,Sa=le("hidden"),wa="Symbol",_a=U("toPrimitive"),Ta=Se.set,ka=Se.getterFor(wa),Ma=Object.prototype,Na=o.Symbol,xa=S("JSON","stringify"),Ia=Y.f,Oa=te.f,Pa=Do.f,La=f.f,Ca=E("symbols"),Ea=E("op-symbols"),Aa=E("string-to-symbol-registry"),Va=E("symbol-to-string-registry"),ja=E("wks"),Ba=o.QObject,Ra=!Ba||!Ba.prototype||!Ba.prototype.findChild,za=s&&a((function(){return 7!=Mr(Oa({},"a",{get:function(){return Oa(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Ia(Ma,t);r&&delete Ma[t],Oa(e,t,n),r&&e!==Ma&&Oa(Ma,t,r)}:Oa,Fa=function(e,t){var n=Ca[e]=Mr(Na.prototype);return Ta(n,{type:wa,tag:e,description:t}),s||(n.description=t),n},Da=function(e,t,n){e===Ma&&Da(Ea,t,n),Z(e);var r=G(t);return Z(n),j(Ca,r)?(n.enumerable?(j(e,Sa)&&e[Sa][r]&&(e[Sa][r]=!1),n=Mr(n,{enumerable:l(0,!1)})):(j(e,Sa)||Oa(e,Sa,l(1,{})),e[Sa][r]=!0),za(e,r,n)):Oa(e,r,n)},Wa=function(e,t){Z(e);var n=g(t),r=mr(n).concat(Ga(n));return ba(r,(function(t){s&&!Ua.call(n,t)||Da(e,t,n[t])})),e},Ua=function(e){var t=G(e),n=La.call(this,t);return!(this===Ma&&j(Ca,t)&&!j(Ea,t))&&(!(n||!j(this,t)||!j(Ca,t)||j(this,Sa)&&this[Sa][t])||n)},qa=function(e,t){var n=g(e),r=G(t);if(n!==Ma||!j(Ca,r)||j(Ea,r)){var i=Ia(n,r);return!i||!j(Ca,r)||j(n,Sa)&&n[Sa][r]||(i.enumerable=!0),i}},Ja=function(e){var t=Pa(g(e)),n=[];return ba(t,(function(e){j(Ca,e)||j(de,e)||n.push(e)})),n},Ga=function(e){var t=e===Ma,n=Pa(t?Ea:g(e)),r=[];return ba(n,(function(e){!j(Ca,e)||t&&!j(Ma,e)||r.push(Ca[e])})),r};if(x||(we((Na=function(){if(this instanceof Na)throw TypeError("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Nr(arguments[0]):void 0,t=z(e),n=function(e){this===Ma&&n.call(Ea,e),j(this,Sa)&&j(this[Sa],t)&&(this[Sa][t]=!1),za(this,t,l(1,e))};return s&&Ra&&za(Ma,t,{configurable:!0,set:n}),Fa(t,e)}).prototype,"toString",(function(){return ka(this).tag})),we(Na,"withoutSetter",(function(e){return Fa(z(e),e)})),f.f=Ua,te.f=Da,Y.f=qa,je.f=Do.f=Ja,Be.f=Ga,ya.f=function(e){return Fa(U(e),e)},s&&(Oa(Na.prototype,"description",{configurable:!0,get:function(){return ka(this).description}}),we(Ma,"propertyIsEnumerable",Ua,{unsafe:!0}))),Qe({global:!0,wrap:!0,forced:!x,sham:!x},{Symbol:Na}),ba(mr(ja),(function(e){ma(e)})),Qe({target:wa,stat:!0,forced:!x},{for:function(e){var t=Nr(e);if(j(Aa,t))return Aa[t];var n=Na(t);return Aa[t]=n,Va[n]=t,n},keyFor:function(e){if(!O(e))throw TypeError(e+" is not a symbol");if(j(Va,e))return Va[e]},useSetter:function(){Ra=!0},useSimple:function(){Ra=!1}}),Qe({target:"Object",stat:!0,forced:!x,sham:!s},{create:function(e,t){return void 0===t?Mr(e):Wa(Mr(e),t)},defineProperty:Da,defineProperties:Wa,getOwnPropertyDescriptor:qa}),Qe({target:"Object",stat:!0,forced:!x},{getOwnPropertyNames:Ja,getOwnPropertySymbols:Ga}),Qe({target:"Object",stat:!0,forced:a((function(){Be.f(1)}))},{getOwnPropertySymbols:function(e){return Be.f(A(e))}}),xa){var Ha=!x||a((function(){var e=Na();return"[null]"!=xa([e])||"{}"!=xa({a:e})||"{}"!=xa(Object(e))}));Qe({target:"JSON",stat:!0,forced:Ha},{stringify:function(e,t,n){for(var r,i=[e],o=1;arguments.length>o;)i.push(arguments[o++]);if(r=t,(m(t)||void 0!==e)&&!O(e))return cr(t)||(t=function(e,t){if("function"==typeof r&&(t=r.call(this,e,t)),!O(t))return t}),i[1]=t,xa.apply(null,i)}})}Na.prototype[_a]||ne(Na.prototype,_a,Na.prototype.valueOf),pt(Na,wa),de[Sa]=!0;var Qa=te.f,$a=o.Symbol;if(s&&"function"==typeof $a&&(!("description"in $a.prototype)||void 0!==$a().description)){var Xa={},Ka=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:String(arguments[0]),t=this instanceof Ka?new $a(e):void 0===e?$a():$a(e);return""===e&&(Xa[t]=!0),t};ze(Ka,$a);var Ya=Ka.prototype=$a.prototype;Ya.constructor=Ka;var Za=Ya.toString,es="Symbol(test)"==String($a("test")),ts=/^Symbol\((.*)\)[^)]+$/;Qa(Ya,"description",{configurable:!0,get:function(){var e=m(this)?this.valueOf():this,t=Za.call(e);if(j(Xa,e))return"";var n=es?t.slice(7,-1):t.replace(ts,"$1");return""===n?void 0:n}}),Qe({global:!0,forced:!0},{Symbol:Ka})}ma("iterator");var ns={},rs=new ha.EventEmitter2({maxListeners:20,newListener:!1}),is=new ha.EventEmitter2({maxListeners:20,newListener:!1});function os(e){var t=new WeakMap;return e=e[0].toUpperCase()+e.slice(1),ns[e]||(ns[e]={getGlobalListeners:function(){return rs.listeners(e)},getInternalListeners:function(){return is.listeners(e)},emit:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];is.emit.apply(is,[e].concat(t)),rs.emit.apply(rs,[e].concat(t))},emitGlobal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];rs.emit.apply(rs,[e].concat(t))},emitInternal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];is.emit.apply(is,[e].concat(t))},internalOnMethod:function(t,n){void 0===n&&(n={}),oo(t)&&(n.prepend?n.once?is.prependOnceListener(e,t):is.prependListener(e,t):n.once?is.once(e,t):is.on(e,t))},internalOffMethod:function(t){oo(t)&&is.off(e,t)},onMethod:function(n){var r;(r=oo(n)?n:null)&&(t.set(n,r),rs.on(e,r))},offMethod:function(n){if(!n||oo(n))if(n){var r=void 0;t.has(n)&&(r=t.get(n),t.delete(n)),rs.off(e,r)}else t=new WeakMap,rs.removeAllListeners(e)}}),ns[e]}function as(e){return!!ns[e]}var ss=new Proxy({},{get:function(e,t){if(t in Gf)return Gf[t];if(t in sr){var n=sr[t];return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];var i=ao(n,e),o=so(n.params,i),a=n.isSustain;if("async"===n.type){var s=e[0],c=s||{},u=c.success,f=c.fail,l=c.complete;if(n.usePromise&&!(oo(u)||oo(f)||oo(l)))return new Promise((function(e,n){fs({isSustain:a,event:t,data:o,success:e,fail:n})}));"function"==typeof s?fs({isSustain:a,event:t,data:o},s):fs({isSustain:a,event:t,data:o,success:s&&s.success,fail:s&&s.fail,complete:s&&s.complete})}if("sync"===n.type){var d=ls({isSustain:a,event:t,data:o});if(n.needReturn)return d}"monitor"===n.type&&cs(rr(rr({},n),o)),"offMonitor"===n.type&&us(rr(rr({},n),o))}}if(t in e)return e[t];throw new Error(t+" method 暂未实现")}}),cs=function(e){as(e.eventManagerName)||didiJsBridge.on({event:e.nativeEvent},(function(t){os(e.eventManagerName).emit(t.data)})),os(e.eventManagerName).onMethod(e.callBack)},us=function(e){as(e.eventManagerName)&&os(e.eventManagerName).offMethod(e.callBack)},fs=function(e,t){if(e&&e.event){didiJsBridge.invoke({method:e.event,data:e.data||{},isSustain:e.isSustain||!1,callback:(t?function(e){try{(e=e.data).success?t&&t(e.data):t&&t(e.message)}catch(e){throw e}}:"")||function(t){t=t.data;try{t.success?(t.data&&"object"===et(t.data)&&(t.data.errMsg=e.event+":ok"),e.success&&e.success(t.data)):e.fail&&e.fail({errMsg:t.errMsg})}catch(e){throw e}finally{e.complete&&e.complete()}}})}},ls=function(e){if(e&&e.event)return didiJsBridge.invoke({method:e.event,data:e.data||{}})};didiJsBridge.on({event:"onCloseMiniProgram",isSustain:!0},(function(e){void 0===e&&(e={data:{}});var t=e.data;os("onCloseMiniProgram").emit(t)}));var ds=Le.includes;Qe({target:"Array",proto:!0},{includes:function(e){return ds(this,e,arguments.length>1?arguments[1]:void 0)}}),ho("includes");var ps,hs,ys=function(){var e=Z(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},vs=o.RegExp,gs={UNSUPPORTED_Y:a((function(){var e=vs("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),BROKEN_CARET:a((function(){var e=vs("^r","gy");return e.lastIndex=2,null!=e.exec("str")}))},ms=o.RegExp,bs=a((function(){var e=ms(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),Ss=o.RegExp,ws=a((function(){var e=Ss("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),_s=Se.get,Ts=RegExp.prototype.exec,ks=E("native-string-replace",String.prototype.replace),Ms=Ts,Ns=(ps=/a/,hs=/b*/g,Ts.call(ps,"a"),Ts.call(hs,"a"),0!==ps.lastIndex||0!==hs.lastIndex),xs=gs.UNSUPPORTED_Y||gs.BROKEN_CARET,Is=void 0!==/()??/.exec("")[1];(Ns||Is||xs||bs||ws)&&(Ms=function(e){var t,n,r,i,o,a,s,c=this,u=_s(c),f=Nr(e),l=u.raw;if(l)return l.lastIndex=c.lastIndex,t=Ms.call(l,f),c.lastIndex=l.lastIndex,t;var d=u.groups,p=xs&&c.sticky,h=ys.call(c),y=c.source,v=0,g=f;if(p&&(-1===(h=h.replace("y","")).indexOf("g")&&(h+="g"),g=f.slice(c.lastIndex),c.lastIndex>0&&(!c.multiline||c.multiline&&"\n"!==f.charAt(c.lastIndex-1))&&(y="(?: "+y+")",g=" "+g,v++),n=new RegExp("^(?:"+y+")",h)),Is&&(n=new RegExp("^"+y+"$(?!\\s)",h)),Ns&&(r=c.lastIndex),i=Ts.call(p?n:c,g),p?i?(i.input=i.input.slice(v),i[0]=i[0].slice(v),i.index=c.lastIndex,c.lastIndex+=i[0].length):c.lastIndex=0:Ns&&i&&(c.lastIndex=c.global?i.index+i[0].length:r),Is&&i&&i.length>1&&ks.call(i[0],n,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&d)for(i.groups=a=Mr(null),o=0;o<d.length;o++)a[(s=d[o])[0]]=i[s[1]];return i});var Os=Ms;Qe({target:"RegExp",proto:!0,forced:/./.exec!==Os},{exec:Os});var Ps=U("species"),Ls=RegExp.prototype,Cs=function(e,t,n,r){var i=U(e),o=!a((function(){var t={};return t[i]=function(){return 7},7!=""[e](t)})),s=o&&!a((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[Ps]=function(){return n},n.flags="",n[i]=/./[i]),n.exec=function(){return t=!0,null},n[i](""),!t}));if(!o||!s||n){var c=/./[i],u=t(i,""[e],(function(e,t,n,r,i){var a=t.exec;return a===Os||a===Ls.exec?o&&!i?{done:!0,value:c.call(t,n,r)}:{done:!0,value:e.call(n,t,r)}:{done:!1}}));we(String.prototype,e,u[0]),we(Ls,i,u[1])}r&&ne(Ls[i],"sham",!0)},Es=U("match"),As=function(e){var t;return m(e)&&(void 0!==(t=e[Es])?!!t:"RegExp"==p(e))},Vs=Eo.charAt,js=function(e,t,n){return t+(n?Vs(e,t).length:1)},Bs=function(e,t){var n=e.exec;if("function"==typeof n){var r=n.call(e,t);if("object"!=typeof r)throw TypeError("RegExp exec method returned something other than an Object or null");return r}if("RegExp"!==p(e))throw TypeError("RegExp#exec called on incompatible receiver");return Os.call(e,t)},Rs=gs.UNSUPPORTED_Y,zs=[].push,Fs=Math.min,Ds=4294967295;Cs("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=Nr(v(this)),i=void 0===n?Ds:n>>>0;if(0===i)return[];if(void 0===e)return[r];if(!As(e))return t.call(r,e,i);for(var o,a,s,c=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),f=0,l=new RegExp(e.source,u+"g");(o=Os.call(l,r))&&!((a=l.lastIndex)>f&&(c.push(r.slice(f,o.index)),o.length>1&&o.index<r.length&&zs.apply(c,o.slice(1)),s=o[0].length,f=a,c.length>=i));)l.lastIndex===o.index&&l.lastIndex++;return f===r.length?!s&&l.test("")||c.push(""):c.push(r.slice(f)),c.length>i?c.slice(0,i):c}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:t.call(this,e,n)}:t,[function(t,n){var i=v(this),o=null==t?void 0:t[e];return void 0!==o?o.call(t,i,n):r.call(Nr(i),t,n)},function(e,i){var o=Z(this),a=Nr(e),s=n(r,o,a,i,r!==t);if(s.done)return s.value;var c=jt(o,RegExp),u=o.unicode,f=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(Rs?"g":"y"),l=new c(Rs?"^(?:"+o.source+")":o,f),d=void 0===i?Ds:i>>>0;if(0===d)return[];if(0===a.length)return null===Bs(l,a)?[a]:[];for(var p=0,h=0,y=[];h<a.length;){l.lastIndex=Rs?0:h;var v,g=Bs(l,Rs?a.slice(h):a);if(null===g||(v=Fs(Ne(l.lastIndex+(Rs?h:0)),a.length))===p)h=js(a,h,u);else{if(y.push(a.slice(p,h)),y.length===d)return y;for(var m=1;m<=g.length-1;m++)if(y.push(g[m]),y.length===d)return y;h=p=v}}return y.push(a.slice(p)),y}]}),!!a((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]})),Rs);var Ws=lr("splice"),Us=Math.max,qs=Math.min,Js=9007199254740991,Gs="Maximum allowed length exceeded";Qe({target:"Array",proto:!0,forced:!Ws},{splice:function(e,t){var n,r,i,o,a,s,c=A(this),u=Ne(c.length),f=Oe(e,u),l=arguments.length;if(0===l?n=r=0:1===l?(n=0,r=u-f):(n=l-2,r=qs(Us(ke(t),0),u-f)),u+n-r>Js)throw TypeError(Gs);for(i=Gi(c,r),o=0;o<r;o++)(a=f+o)in c&&ur(i,o,c[a]);if(i.length=r,n<r){for(o=f;o<u-r;o++)s=o+n,(a=o+r)in c?c[s]=c[a]:delete c[s];for(o=u;o>u-r+n;o--)delete c[o-1]}else if(n>r)for(o=u-r;o>f;o--)s=o+n-1,(a=o+r-1)in c?c[s]=c[a]:delete c[s];for(o=0;o<n;o++)c[o+f]=arguments[o+2];return c.length=u-r+n,i}});var Hs=te.f,Qs=Uo.fastKey,$s=Se.set,Xs=Se.getterFor,Ks={getConstructor:function(e,t,n,r){var i=e((function(e,o){gt(e,i,t),$s(e,{type:t,index:Mr(null),first:void 0,last:void 0,size:0}),s||(e.size=0),null!=o&&Mt(o,e[r],{that:e,AS_ENTRIES:n})})),o=Xs(t),a=function(e,t,n){var r,i,a=o(e),u=c(e,t);return u?u.value=n:(a.last=u={index:i=Qs(t,!0),key:t,value:n,previous:r=a.last,next:void 0,removed:!1},a.first||(a.first=u),r&&(r.next=u),s?a.size++:e.size++,"F"!==i&&(a.index[i]=u)),e},c=function(e,t){var n,r=o(e),i=Qs(t);if("F"!==i)return r.index[i];for(n=r.first;n;n=n.next)if(n.key==t)return n};return ut(i.prototype,{clear:function(){for(var e=o(this),t=e.index,n=e.first;n;)n.removed=!0,n.previous&&(n.previous=n.previous.next=void 0),delete t[n.index],n=n.next;e.first=e.last=void 0,s?e.size=0:this.size=0},delete:function(e){var t=this,n=o(t),r=c(t,e);if(r){var i=r.next,a=r.previous;delete n.index[r.index],r.removed=!0,a&&(a.next=i),i&&(i.previous=a),n.first==r&&(n.first=i),n.last==r&&(n.last=a),s?n.size--:t.size--}return!!r},forEach:function(e){for(var t,n=o(this),r=wt(e,arguments.length>1?arguments[1]:void 0,3);t=t?t.next:n.first;)for(r(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!c(this,e)}}),ut(i.prototype,n?{get:function(e){var t=c(this,e);return t&&t.value},set:function(e,t){return a(this,0===e?0:e,t)}}:{add:function(e){return a(this,e=0===e?0:e,e)}}),s&&Hs(i.prototype,"size",{get:function(){return o(this).size}}),i},setStrong:function(e,t,n){var r=t+" Iterator",i=Xs(t),o=Xs(r);xo(e,t,(function(e,t){$s(this,{type:r,target:e,state:i(e),kind:t,last:void 0})}),(function(){for(var e=o(this),t=e.kind,n=e.last;n&&n.removed;)n=n.previous;return e.target&&(e.last=n=n?n.next:e.state.first)?"keys"==t?{value:n.key,done:!1}:"values"==t?{value:n.value,done:!1}:{value:[n.key,n.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),n?"entries":"values",!n,!0),yt(t)}},Ys=(qo("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Ks),$i.map),Zs=lr("map");Qe({target:"Array",proto:!0,forced:!Zs},{map:function(e){return Ys(this,e,arguments.length>1?arguments[1]:void 0)}});var ec=!!ct&&a((function(){ct.prototype.finally.call({then:function(){}},(function(){}))}));if(Qe({target:"Promise",proto:!0,real:!0,forced:ec},{finally:function(e){var t=jt(this,S("Promise")),n="function"==typeof e;return this.then(n?function(n){return Mn(t,e()).then((function(){return n}))}:e,n?function(n){return Mn(t,e()).then((function(){throw n}))}:e)}}),"function"==typeof ct){var tc=S("Promise").prototype.finally;ct.prototype.finally!==tc&&we(ct.prototype,"finally",tc,{unsafe:!0})}var nc=function(){function e(t){this._promise=t,this.taskIds=[],null!==e.currentTask&&(e.currentTask.destroy(),e.currentTask=null),e.setCurrentTask(this),this.status=2,this.event=exparser.EventBus.create("App Route Callback")}return e.setCurrentTask=function(t){e.currentTask=t},e.getCurrentTask=function(){return e.currentTask},e.prototype.addTask=function(e){var t=this.event.add(e);this.taskIds.push(t)},e.prototype.clearTask=function(){for(var e=0,t=this.taskIds;e<t.length;e++){var n=t[e];this.event.remove(n)}this.taskIds.length=0},e.prototype.resolve=function(){this.status=0,this.event.call(void 0,[])},e.prototype.reject=function(){this.status=1},e.prototype.destroy=function(){var t=this;e.currentTask===this&&(e.currentTask=null),this.clearTask(),this.event=null,"Promise"===ro(this._promise)?Promise.race([Promise.resolve(),this._promise]).catch((function(e){})).finally((function(){return t._promise=null})):this._promise=null},Object.defineProperty(e.prototype,"resolved",{get:function(){return 0===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"rejected",{get:function(){return 1===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"pending",{get:function(){return 2===this.status},enumerable:!1,configurable:!0}),e.currentTask=null,e}(),rc=!1,ic="custom-tab-bar/index";function oc(e,t,n){if(void 0===n&&(n=!1),n&&(t=function(e){if("string"!=typeof e)return e;var t=e.split("?"),n=t[0],r=t[1];return n+=".wxml",void 0!==r?n+"?"+r:n}(t)),0===t.indexOf("/"))return t.substr(1);if(0===t.indexOf("./"))return oc(e,t.substr(2));for(var r=t.split("/"),i=r.length,o=0;o<i&&".."===r[o];)o+=1;r.splice(0,o);var a=0<e.length?e.split("/"):[];return o>a.length-1?r.join("/"):(a.splice(a.length-o-1,o+1),a.concat(r).join("/"))}function ac(e){if(__routePackages__){if(Object.prototype.hasOwnProperty.call(__routePackages__,e))return __routePackages__[e];throw new Error("getPackageNameByRoute 未找到对应路由: "+e)}throw new Error("__routePackages__ not define.")}var sc=new Set;function cc(e){return sc.has(e)}function uc(e,t){t?sc.add(e):sc.has(e)&&sc.delete(e)}var fc=function(e,t){return ir(this,void 0,void 0,(function(){var n;return or(this,(function(r){switch(r.label){case 0:return!1!==cc(e)?[3,2]:[4,new Promise((function(t,n){didiJsBridge.invoke({method:"loadJSFileToDataThread",data:{package:e},callback:function(r){r&&r.data&&r.data.success?(uc(e,!0),t()):n(r.data.errMsg||"loadJSFileToDataThread failed ("+e+").")}})}))];case 1:r.sent(),r.label=2;case 2:return __define__(e),(n=new Set).add(t),lc(t,n),function(e){if(!__ddConfig.tabBar||!0!==__ddConfig.tabBar.custom)return;!rc&&function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;if(t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0)return!0;return!1}(e)&&(__ddRoute=ic,__ddRouteBegin=!0,__ddAppCurrentFile__=ic+".js",require(ic+".js"),rc=!0)}(t),globalThis._=void 0,[2,e]}}))}))};var lc=function e(t,n){var r=__ddAppCode__[t+".json"],i=__ddConfig.isLazyLoad;if("object"===et(r)&&r.usingComponents){var o=r.usingComponents,a=r.componentPlaceholder||[];Object.keys(o).forEach((function(r){if(!i||i&&!a[r]){var s=oc(t,o[r]);n.has(s)||(n.add(s),e(s,n))}}))}__ddRoute=t,__ddRouteBegin=!0,__ddAppCurrentFile__=t+".js",require(t+".js")};var dc=!1;function pc(e,t,n){if(void 0===n&&(n=!1),n||!dc||globalThis.isBrowser){var r=oc(__appServiceEngine__.getCurrentRoute(),e.split("?")[0]),i=ac(r);dc=!0,function(e){return new Promise((function(t,n){didiJsBridge.invoke({method:"loadSubPackage",data:{package:e},callback:function(e){isDevTools&&"devtools"===__ddConfig.platform&&e&&t(),e&&e.data&&e.data.success?t():n(e.data.errMsg)}})}))}(i).then((function(){var e=new nc;t(i),fc(i,r).then((function(){return e.resolve()})).catch((function(t){e.reject(),Reporter.errorReport({key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t,fail:function(e){}})})).finally((function(){e.clearTask(),dc=!1}))})).catch((function(e){dc=!1,Reporter.errorReport({key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e,fail:function(e){}})}))}}var hc=function(e){var t=e||{},n=t.delta,r=void 0===n?1:n,i=t.success,o=t.fail,a=t.complete;if(window.isBrowser)return window.parent.postMessage({event:"navigateBack",delta:r,openType:"navigateBack"},"*"),void os("AppRoute").emit({openType:"navigateBack",webViewId:1});didiJsBridge.invoke({method:"navigateBack",data:{delta:r,openType:"navigateBack",stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?i&&i():o&&o(),a&&a();var t=+(e.data&&e.data.webViewId);os("AppRoute").emit({openType:"navigateBack",webViewId:t})}})};function yc(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getLaunchOptionsSync",data:{}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}function vc(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getEnterOptionsSync",data:{stackId:currentStackId}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}didiJsBridge.on({event:"navigateBackNative"},(function(e){var t=+e.webViewId;os("AppRoute").emit({openType:"navigateBack",webViewId:t})}));var gc=Math.floor,mc="".replace,bc=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,Sc=/\$([$&'`]|\d{1,2})/g,wc=function(e,t,n,r,i,o){var a=n+e.length,s=r.length,c=Sc;return void 0!==i&&(i=A(i),c=bc),mc.call(o,c,(function(o,c){var u;switch(c.charAt(0)){case"$":return"$";case"&":return e;case"`":return t.slice(0,n);case"'":return t.slice(a);case"<":u=i[c.slice(1,-1)];break;default:var f=+c;if(0===f)return o;if(f>s){var l=gc(f/10);return 0===l?o:l<=s?void 0===r[l-1]?c.charAt(1):r[l-1]+c.charAt(1):o}u=r[f-1]}return void 0===u?"":u}))},_c=U("replace"),Tc=Math.max,kc=Math.min,Mc="$0"==="a".replace(/./,"$0"),Nc=!!/./[_c]&&""===/./[_c]("a","$0");Cs("replace",(function(e,t,n){var r=Nc?"$":"$0";return[function(e,n){var r=v(this),i=null==e?void 0:e[_c];return void 0!==i?i.call(e,r,n):t.call(Nr(r),e,n)},function(e,i){var o=Z(this),a=Nr(e);if("string"==typeof i&&-1===i.indexOf(r)&&-1===i.indexOf("$<")){var s=n(t,o,a,i);if(s.done)return s.value}var c="function"==typeof i;c||(i=Nr(i));var u=o.global;if(u){var f=o.unicode;o.lastIndex=0}for(var l=[];;){var d=Bs(o,a);if(null===d)break;if(l.push(d),!u)break;""===Nr(d[0])&&(o.lastIndex=js(a,Ne(o.lastIndex),f))}for(var p,h="",y=0,v=0;v<l.length;v++){d=l[v];for(var g=Nr(d[0]),m=Tc(kc(ke(d.index),a.length),0),b=[],S=1;S<d.length;S++)b.push(void 0===(p=d[S])?p:String(p));var w=d.groups;if(c){var _=[g].concat(b,m,a);void 0!==w&&_.push(w);var T=Nr(i.apply(void 0,_))}else T=wc(g,a,m,b,w,i);m>=y&&(h+=a.slice(y,m)+T,y=m+g.length)}return h+a.slice(y)}]}),!!a((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Mc||Nc);var xc={lastRoute:"",lastOpenType:"",query:{},runningStatus:"active",navigatorLock:!1,openUrlLock:!1,possessingBackgroundAudioPlayer:!1,webviewEventCallback:null,hanged:!1,appStatus:0,navigationBarTitleMap:{},currentWebviewId:void 0,lastRawQuery:null},Ic=function(e,t){var n=e.data;void 0===t&&(t=0),Lc.handleRewriteRoute(n)&&("appLaunch"!==n.openType&&"autoReLaunch"!==n.openType&&(n.path=function(e){return"string"==typeof e?-1!==e.indexOf("?")?e.replace(/\.html\?/,"?"):e.replace(/\.html$/,""):e}(n.path),n.webViewId=void 0!==n.webViewId?n.webViewId:t,xc.lastRoute=n.path||"",xc.lastRawQuery=n.query&&JSON.parse(JSON.stringify(n.query))||{},xc.lastOpenType=n.openType),xc.query=n.query,xc.currentWebviewId=n.webViewId,didiJsBridge.publish({event:"onAppRoute",data:{},webViewId:n.webViewId}),os("AppRoute").emit(n))},Oc=os("AppRoute").internalOnMethod,Pc=os("AppRoute").internalOffMethod;didiJsBridge.on({event:"switchTabNotification"},(function(e){void 0===e&&(e={data:{toRoute:"",toWebViewId:"",query:{}}});var t=e.data,n=t.toRoute;0===n.indexOf("plugin://imPlugin")&&(n="__dimina__/empty/empty");var r=t.toIndex;t.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[r]&&tabBarTapList.push({index:r,pagePath:(__ddConfig.tabBar.list[r].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[r].text}),Ic({data:{openType:"switchTab",path:n,webViewId:t.toWebViewId,query:t.query}})}));var Lc={launch:function(e,t){pc(e.url,(function(n){!function(e,t){didiJsBridge.invoke({method:"launch",data:{url:e.url,openType:e.openType,query:e.query,package:e.package,stackId:t}})}(rr(rr({},e),{package:n}),t)}),!0)},reLaunch:function(e){pc(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;window.isBrowser?window.parent.postMessage({event:"reLaunch",route:t,openType:"reLaunch"},"*"):didiJsBridge.invoke({method:"reLaunch",data:{url:oc(__appServiceEngine__.getCurrentRoute(),t),openType:"reLaunch",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(rr(rr({},e),{package:t}))}))},navigateTo:function(e){pc(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;globalThis.isBrowser?window.parent.postMessage({event:"navigateTo",route:t,openType:"navigateTo"},"*"):didiJsBridge.invoke({method:"navigateTo",data:{url:oc(__appServiceEngine__.getCurrentRoute(),t),openType:"navigateTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(rr(rr({},e),{package:t}))}))},redirectTo:function(e){pc(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;window.isBrowser?window.parent.postMessage({event:"redirectTo",route:oc(__appServiceEngine__.getCurrentRoute(),t),openType:"redirectTo"},"*"):didiJsBridge.invoke({method:"redirectTo",data:{url:oc(__appServiceEngine__.getCurrentRoute(),t),openType:"redirectTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(rr(rr({},e),{package:t}))}))},handleRewriteRoute:function(e){if(["dismissPip","navigateBack"].includes(e.openType))return!1;if(!e.notFound)return!0;if(/^[-_+a-z]+:\/\//i.test(e.rawPath))try{return didiJsBridge.invoke({method:"rewriteRoute",data:{},webViewId:"",invokeId:""}),!0}catch(e){return!1}return!1},navigateBack:hc,switchTab:function(e){pc(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail;if(window.isBrowser){var i=t.split("?"),o=i[0];return 2===i.length&&(o=o+"&"+i[1]),void window.parent.postMessage({event:"switchTab",route:oc(__appServiceEngine__.getCurrentRoute(),o),openType:"switchTab"},"*")}didiJsBridge.invoke({method:"switchTab",data:{url:t,openType:"switchTab",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r()}})}(rr(rr({},e),{package:t}))}))},navigateToMiniProgram:function(e){if(!e.appId)return e.fail&&e.fail("缺少appId"),void(e.complete&&e.complete());fs({event:"navigateToMiniProgram",data:{appId:e.appId,path:e.path,extraData:e.extraData,envVersion:e.envVersion||"release"},success:e.success,fail:e.fail,complete:e.complete})}};didiJsBridge.subscribe({event:"H5navigateTo"},(function(e){!e||e.data,Lc.navigateTo(e.data.params)})),didiJsBridge.subscribe({event:"H5navigateBack"},(function(e){!e||e.data,Lc.navigateBack(e.data.params)})),didiJsBridge.subscribe({event:"H5redirectTo"},(function(e){!e||e.data,Lc.redirectTo(e.data.params)})),didiJsBridge.subscribe({event:"H5switchTab"},(function(e){!e||e.data,Lc.switchTab(e.data.params)})),didiJsBridge.subscribe({event:"H5reLaunch"},(function(e){!e||e.data,Lc.reLaunch(e.data.params)})),didiJsBridge.subscribe({event:"H5goSuperAppTab"},(function(){Cc()})),didiJsBridge.subscribe({event:"H5openLocation"},(function(e){var t;void 0===(t=e.data)&&(t={latitude:0,longitude:0}),fs({event:"openLocation",data:{latitude:t.latitude,longitude:t.longitude,scale:t.scale||18,name:t.name,address:t.address},success:t.success,fail:t.fail,complete:t.complete})}));var Cc=function(){var e,t,n,r=(vc().query||{}).fromDidiTabbar||!1;"string"==typeof r&&(r="true"===r),r?(void 0===n&&(n={}),fs({event:"closeDimina",data:{},success:n.success,fail:n.fail,complete:n.complete})):(e=!1,(t=__appServiceEngine__.getCurrentPagesByDomain(""))&&t.length&&t[0].route.indexOf("pages/index/index")>-1&&(e=!0),hc(e?{delta:10}:{delta:10,success:function(){Lc.redirectTo({url:"/pages/index/index"})}}))},Ec=Cr.trim,Ac=o.parseInt,Vc=/^[+-]?0[Xx]/,jc=8!==Ac(xr+"08")||22!==Ac(xr+"0x16")?function(e,t){var n=Ec(Nr(e));return Ac(n,t>>>0||(Vc.test(n)?16:10))}:Ac;Qe({global:!0,forced:parseInt!=jc},{parseInt:jc});var Bc="toString",Rc=RegExp.prototype,zc=Rc.toString,Fc=a((function(){return"/a/b"!=zc.call({source:"a",flags:"b"})})),Dc=zc.name!=Bc;(Fc||Dc)&&we(RegExp.prototype,Bc,(function(){var e=Z(this),t=Nr(e.source),n=e.flags;return"/"+t+"/"+Nr(void 0===n&&e instanceof RegExp&&!("flags"in Rc)?ys.call(e):n)}),{unsafe:!0});var Wc=Cr.trim,Uc=o.parseFloat,qc=1/Uc(xr+"-0")!=-1/0?function(e){var t=Wc(Nr(e)),n=Uc(t);return 0===n&&"-"==t.charAt(0)?-0:n}:Uc;Qe({global:!0,forced:parseFloat!=qc},{parseFloat:qc});var Jc,Gc=function(e){if(As(e))throw TypeError("The method doesn't accept regular expressions");return e},Hc=U("match"),Qc=Y.f,$c="".endsWith,Xc=Math.min,Kc=function(e){var t=/./;try{"/./"[e](t)}catch(n){try{return t[Hc]=!1,"/./"[e](t)}catch(e){}}return!1}("endsWith"),Yc=!(Kc||(Jc=Qc(String.prototype,"endsWith"),!Jc||Jc.writable));Qe({target:"String",proto:!0,forced:!Yc&&!Kc},{endsWith:function(e){var t=Nr(v(this));Gc(e);var n=arguments.length>1?arguments[1]:void 0,r=Ne(t.length),i=void 0===n?r:Xc(Ne(n),r),o=Nr(e);return $c?$c.call(t,o,i):t.slice(i-o.length,i)===o}});var Zc,eu={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgrey:"#a9a9a9",darkgreen:"#006400",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",grey:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgrey:"#d3d3d3",lightgreen:"#90ee90",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32",transparent:"#00000000"};function tu(e,t,n,r){void 0===n&&(n=""),void 0===r&&(r="");var i="canvas_"+e+"_"+t+"_"+n+"_";return r&&r!==__virtualDOM__.getRootNodeId(e)&&(i+=r),i}function nu(e,t,n,r){var i;void 0===n&&(n={}),void 0===r&&(r=!1);var o=ls({event:t+"Canvas",data:rr({canvasId:e},n)});return r?null==o?void 0:o.data:null===(i=null==o?void 0:o.data)||void 0===i?void 0:i[t]}function ru(e){return parseInt(e,16)}function iu(e){var t=Number(Math.min(Zc.MAX_COLOR_VALUE,Math.max(Math.round(parseFloat(e)),Zc.MIN_COLOR_VALUE))).toString(16);return 1===t.length&&(t="0"+t),t}function ou(e){return Math.min(Zc.MAX_COLOR_VALUE,Math.max(parseFloat(e),Zc.MIN_COLOR_VALUE))}function au(e){var t=e.slice(0,3).map((function(e){return""+Math.round(e)}));if(4===e.length){var n=e[3].toFixed(3).replace(/0+$/g,"");n.endsWith(".")&&(n="0"),t.push(n)}return t}!function(e){e[e.MAX_COLOR_VALUE=255]="MAX_COLOR_VALUE",e[e.MIN_COLOR_VALUE=0]="MIN_COLOR_VALUE"}(Zc||(Zc={}));var su={};os("skiaCanvasLoadFontFace");function cu(e,t){t?su[e]&&delete su[e].nodeId:delete su[e]}var uu={},fu=1;didiJsBridge.subscribe({event:"pageScrollDone"},(function(e){var t=e.data,n=void 0===t?{}:t;if(n.callBackId>0&&uu[n.callBackId]){var r=uu[n.callBackId];delete uu[n.callBackId],n.success?"function"==typeof r.success&&r.success():"function"==typeof r.fail&&r.fail(),"function"==typeof r.complete&&r.complete()}}));var lu,du=$i.filter,pu=lr("filter");Qe({target:"Array",proto:!0,forced:!pu},{filter:function(e){return du(this,e,arguments.length>1?arguments[1]:void 0)}});var hu=function(){function e(){this.entryList=new vu}return e.prototype.createObserver=function(e){var t=this,n=new yu(e);return didiJsBridge.on({event:"performanceEntries",isSustain:!0},(function(e){var r;if(e){var i=JSON.parse(null===(r=null==e?void 0:e.data)||void 0===r?void 0:r.entryList);i&&(t.entryList.push(i),n.notify(i))}})),n},e.prototype.getEntries=function(){return this.entryList.getEntries()},e.prototype.getEntriesByName=function(e,t){return this.entryList.getEntriesByName(e,t)},e.prototype.getEntriesByType=function(e){return this.entryList.getEntriesByType(e)},e.prototype.setBufferSize=function(){},e}(),yu=function(){function e(e){this.entryTypes=[],this.callback=e}return e.prototype.observe=function(e){this.connected=!0,this.entryTypes=e.entryTypes},e.prototype.notify=function(e){var t=this;if(this.connected){var n=new vu;n.push(e.filter((function(e){var n=!1;return t.entryTypes&&t.entryTypes.length>0&&t.entryTypes.forEach((function(t){e.entryType===t&&(n=!0)})),n}))),this.callback(n)}},e.prototype.disconnect=function(){this.connected=!1},e}(),vu=function(){function e(){this._list=[]}return e.prototype.push=function(e){this._list=this._list.concat(e)},e.prototype.getEntriesByName=function(e,t){return this._entryFilter(e,t)},e.prototype.getEntriesByType=function(e){return this._entryFilter(null,e)},e.prototype._entryFilter=function(e,t){return this._list.filter((function(n){return(!e||e===n.name)&&(!t||t===n.entryType)}))},e.prototype.getEntries=function(){return this._list},e}(),gu=function(e,t){var n={};if(e){if(t)for(var r in t){var i=t[r];void 0===i||!i&&void 0!==i&&0!==i||(n[r]=t[r]),"object"===et(i)&&(n[r]=JSON.stringify(t[r]))}fs({event:"reportAnalytics",data:{eventName:""+e,data:rr({},n)},success:t&&t.success,fail:t&&t.fail,complete:t&&t.complete})}},mu=[],bu=0;function Su(e,t){for(var n=e.split("."),r=t.split("."),i=Math.max(n.length,r.length);n.length<i;)n.push("0");for(;r.length<i;)r.push("0");for(var o=0;o<i;o++){var a=parseInt(n[o]),s=parseInt(r[o]);if(a>s)return 1;if(a<s)return-1}return 0}var wu,_u,Tu={"image.webp":{version:"1.4.0",dmVersion:"1.0.0"},view:{version:"1.0.0",dmVersion:"1.0.0"},text:{version:"1.0.0",dmVersion:"1.0.0"},image:{version:"1.0.0",dmVersion:"1.0.0"},label:{version:"1.0.0",dmVersion:"1.0.0"},input:{version:"1.0.0",dmVersion:"1.0.0"},textarea:{version:"1.0.0",dmVersion:"1.0.0"},form:{version:"1.0.0",dmVersion:"1.0.0"},button:{version:"1.0.0",dmVersion:"1.0.0"},"rich-text":{version:"1.0.0",dmVersion:"1.0.0"},swiper:{version:"1.0.0",dmVersion:"1.0.0"},picker:{version:"1.0.0",dmVersion:"1.0.0"},"swiper-item":{version:"1.0.0",dmVersion:"1.0.0"},navigator:{version:"1.0.0",dmVersion:"1.0.0"},radio:{version:"1.0.0",dmVersion:"1.0.0"},"radio-group":{version:"1.0.0",dmVersion:"1.0.0"},switch:{version:"1.0.0",dmVersion:"1.0.0"},slider:{version:"1.0.0",dmVersion:"1.0.0"},"scroll-view":{version:"1.0.0",dmVersion:"1.0.0"},map:{version:"1.0.0",dmVersion:"1.0.0"},"functional-map":{version:"1.0.0",dmVersion:"1.0.0"},"cover-view":{version:"1.0.0",dmVersion:"1.0.0"},checkbox:{version:"1.0.0",dmVersion:"1.0.0"},"checkbox-group":{version:"1.0.0",dmVersion:"1.0.0"},"web-view":{version:"1.0.0",dmVersion:"1.0.0"},"movable-area":{version:"1.0.0",dmVersion:"1.0.0"},"movable-view":{version:"1.0.0",dmVersion:"1.0.0"},nextTick:{version:"1.0.0",dmVersion:"1.0.0"},createAnimation:{version:"1.0.0",dmVersion:"1.0.0"},createSelectorQuery:{version:"1.0.0",dmVersion:"1.0.0"},createIntersectionObserver:{version:"1.0.0",dmVersion:"1.0.0"},createMediaQueryObserver:{version:"1.0.0",dmVersion:"1.0.0"},onAppHide:{version:"1.0.0",dmVersion:"1.0.0"},startPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},stopPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},enablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},disablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},navigateTo:{version:"1.0.0",dmVersion:"1.0.0"},redirectTo:{version:"1.0.0",dmVersion:"1.0.0"},navigateBack:{version:"1.0.0",dmVersion:"1.0.0"},switchTab:{version:"1.0.0",dmVersion:"1.0.0"},reLaunch:{version:"1.0.0",dmVersion:"1.0.0"},launch:{version:"1.0.0",dmVersion:"1.0.0"},getRealRoute:{version:"1.0.0",dmVersion:"1.0.0"},getLocalFilePath:{version:"1.0.0",dmVersion:"1.0.0"},getStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},setStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorage:{version:"1.0.0",dmVersion:"1.0.0"},getStorageInfo:{version:"1.0.0",dmVersion:"1.0.0"},setStorage:{version:"1.0.0",dmVersion:"1.0.0"},clearStorage:{version:"1.0.0",dmVersion:"1.0.0"},setBackgroundFetchToken:{version:"1.12.0",dmVersion:"1.3.0"},getBackgroundFetchData:{version:"1.12.0",dmVersion:"1.3.0"},showLoading:{version:"1.0.0",dmVersion:"1.0.0"},hideLoading:{version:"1.0.0",dmVersion:"1.0.0"},showToast:{version:"1.0.0",dmVersion:"1.0.0"},showModal:{version:"1.0.0",dmVersion:"1.0.0"},getImageInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfoSync:{version:"1.0.0",dmVersion:"1.0.0"},setNavigationBarTitle:{version:"1.0.0",dmVersion:"1.0.0"},saveImageToPhotosAlbum:{version:"1.0.0",dmVersion:"1.0.0"},request:{version:"1.0.0",dmVersion:"1.0.0"},RequestTask:{version:"2.9.0",dmVersion:"1.7.6"},getLocation:{version:"1.0.0",dmVersion:"1.0.0"},getLaunchOptionsSync:{version:"1.0.0",dmVersion:"1.0.0"},chooseImage:{version:"1.0.0",dmVersion:"1.0.0"},scanCode:{version:"1.0.0",dmVersion:"1.0.0"},makePhoneCall:{version:"1.0.0",dmVersion:"1.0.0"},getSavedFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},downloadFile:{version:"1.0.0",dmVersion:"1.0.0"},DownloadTask:{version:"2.11.0",dmVersion:"1.7.6"},getFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},saveFile:{version:"1.0.0",dmVersion:"1.0.0"},removeSavedFile:{version:"1.0.0",dmVersion:"1.0.0"},uploadFile:{version:"1.0.0",dmVersion:"1.0.0"},UploadTask:{version:"2.9.0",dmVersion:"1.7.6"},setClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getFileSystemManager:{version:"1.0.0",dmVersion:"1.0.0"},onAppRoute:{version:"1.0.0",dmVersion:"1.0.0"},canIUse:{version:"1.0.0",dmVersion:"1.0.0"},getUpdateManager:{version:"1.0.0",dmVersion:"1.0.0"},reportEvent:{version:"11.0.0",dmVersion:"11.0.0"},reportAnalytics:{version:"1.0.0",dmVersion:"1.0.0"},navigateToMiniProgram:{version:"1.0.0",dmVersion:"1.0.0"},authorize:{version:"1.14.0",dmVersion:"1.3.0"},openSetting:{version:"1.0.0",dmVersion:"1.0.0"},getSetting:{version:"1.0.0",dmVersion:"1.0.0"},setNavigationBarColor:{version:"1.0.0",dmVersion:"1.0.0"},customShare:{version:"1.0.0",dmVersion:"1.0.0"},showShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},hideShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinAppmsg:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinTimeline:{version:"1.0.0",dmVersion:"1.0.0"},shareMessage:{version:"1.0.0",dmVersion:"1.0.0"},getMenuButtonBoundingClientRect:{version:"1.0.0",dmVersion:"1.0.0"},pageScrollTo:{version:"1.0.0",dmVersion:"1.0.0"},previewImage:{version:"1.0.0",dmVersion:"1.0.0"},requestPayment:{version:"1.0.0",dmVersion:"1.0.0"},extBridge:{version:"1.0.0",dmVersion:"1.0.0"},setTabBarBadge:{version:"1.0.0",dmVersion:"1.0.0"},openLocation:{version:"1.0.0",dmVersion:"1.0.0"},showCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},hideCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},triggerGC:{version:"1.0.0",dmVersion:"1.0.0"},vibrateShort:{version:"1.0.0",dmVersion:"1.0.0"},vibrateLong:{version:"2.8.0",dmVersion:"1.7.0"},onMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},offMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},closeDimina:{version:"1.0.0",dmVersion:"1.0.0"},getNetworkType:{version:"1.0.0",dmVersion:"1.0.0"},onNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},offNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},loginNotifition:{version:"1.0.0",dmVersion:"1.0.0"},logout:{version:"1.0.0",dmVersion:"1.0.0"},login:{version:"1.0.0",dmVersion:"1.0.0"},passportLogin:{version:"1.0.0",dmVersion:"1.0.0"},businessAuthorize:{version:"2.1.0",dmVersion:"1.4.0"},onUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},offUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},setScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},setKeepScreenOn:{version:"2.8.0",dmVersion:"1.7.0"},onUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},offUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},getScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},startRecord:{version:"2.8.0",dmVersion:"1.7.0"},stopRecord:{version:"2.8.0",dmVersion:"1.7.0"},startWifi:{version:"2.8.0",dmVersion:"1.7.0"},stopWifi:{version:"2.8.0",dmVersion:"1.7.0"},getWifiList:{version:"2.8.0",dmVersion:"1.7.0"},onGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},offGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},getConnectedWifi:{version:"2.8.0",dmVersion:"1.7.0"},onWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},offWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},showActionSheet:{version:"2.8.0",dmVersion:"1.7.0"},enableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},disableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},getAccountInfoSync:{version:"2.6.0",dmVersion:"1.6.0"},chooseContact:{version:"2.11.0",dmVersion:"1.8.0"},addPhoneContact:{version:"2.11.0",dmVersion:"1.8.0"},chooseVideo:{version:"2.13.0",dmVersion:"1.9.0"},getVideoInfo:{version:"2.13.0",dmVersion:"1.9.0"},saveVideoToPhotosAlbum:{version:"2.13.0",dmVersion:"1.9.0"},chooseMedia:{version:"2.13.0",dmVersion:"1.9.0"},compressVideo:{version:"2.13.0",dmVersion:"1.9.0"},showTabBar:{version:"2.8.0",dmVersion:"1.6.2"},hideTabBar:{version:"2.8.0",dmVersion:"1.6.2"},setTabBarStyle:{version:"10000.0.0",dmVersion:"10000.0.0"},getPerformance:{version:"2.11.0",dmVersion:"1.8.0"},choosePoi:{version:"3.0.0",dmVersion:"1.8.0"},chooseLocation:{version:"3.0.0",dmVersion:"1.8.0"},shareQqAppmsg:{version:"10000.0.0",dmVersion:"10000.0.0"},shareQzone:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayFriend:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayLife:{version:"10000.0.0",dmVersion:"10000.0.0"},shareSinaWeibo:{version:"10000.0.0",dmVersion:"10000.0.0"},requestSubscribeMessage:{version:"10000.0.0",dmVersion:"10000.0.0"},getRealtimeLogManager:{version:"10000.0.0",dmVersion:"10000.0.0"},openBusinessView:{version:"10000.0.0",dmVersion:"10000.0.0"},registerLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},checkLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},removeLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"}},ku=null,Mu=[],Nu=null;function xu(){var e=Mu;Mu=[],Nu=null;for(var t=0;t<e.length;t++)e[t]()}var Iu=function(e){return function(t,n,r,i){vt(n);var o=A(t),a=y(o),s=Ne(o.length),c=e?s-1:0,u=e?-1:1;if(r<2)for(;;){if(c in a){i=a[c],c+=u;break}if(c+=u,e?c<0:s<=c)throw TypeError("Reduce of empty array with no initial value")}for(;e?c>=0:s>c;c+=u)c in a&&(i=n(i,a[c],c,o));return i}},Ou={left:Iu(!1),right:Iu(!0)}.left,Pu=$e("reduce");Qe({target:"Array",proto:!0,forced:!Pu||!zt&&N>79&&N<83},{reduce:function(e){return Ou(this,e,arguments.length,arguments.length>1?arguments[1]:void 0)}});var Lu=function(){function e(e){void 0===e&&(e={}),this.actions=[],this.currentTransform={},this.currentStepAnimates=[],this.option={transition:{duration:void 0!==e.duration?e.duration:400,timingFunction:void 0!==e.timingFunction?e.timingFunction:"linear",delay:void 0!==e.delay?e.delay:0},transformOrigin:e.transformOrigin||"50% 50% 0"}}return e.prototype.export=function(){var e=this.actions;return this.actions=[],{actions:e}},e.prototype.step=function(e){void 0===e&&(e={});for(var t=this,n=0,r=this.currentStepAnimates;n<r.length;n++){var i=r[n];"style"===i.type?this.currentTransform[i.type+"."+i.args[0]]=i:this.currentTransform[i.type]=i}return this.actions.push({animates:Object.keys(this.currentTransform).reduce((function(e,n){return[].concat.apply([],function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}(e,[[t.currentTransform[n]]]))}),[]),option:{transformOrigin:void 0!==e.transformOrigin?e.transformOrigin:this.option.transformOrigin,transition:{duration:void 0!==e.duration?e.duration:this.option.transition.duration,timingFunction:void 0!==e.timingFunction?e.timingFunction:this.option.transition.timingFunction,delay:void 0!==e.delay?e.delay:this.option.transition.delay}}}),this.currentStepAnimates=[],this},e.prototype.matrix=function(e,t,n,r,i,o){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=1),void 0===i&&(i=1),void 0===o&&(o=1),this.currentStepAnimates.push({type:"matrix",args:[e,t,n,r,i,o]}),this},e.prototype.matrix3d=function(e,t,n,r,i,o,a,s,c,u,f,l,d,p,h,y){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),void 0===i&&(i=0),void 0===o&&(o=1),void 0===a&&(a=0),void 0===s&&(s=0),void 0===c&&(c=0),void 0===u&&(u=0),void 0===f&&(f=1),void 0===l&&(l=0),void 0===d&&(d=0),void 0===p&&(p=0),void 0===h&&(h=0),void 0===y&&(y=1),this.currentStepAnimates.push({type:"matrix3d",args:[e,t,n,r,i,o,a,s,c,u,f,l,d,p,h,y]}),this},e.prototype.rotate=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotate",args:[e]}),this},e.prototype.rotate3d=function(e,t,n,r){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),this.currentStepAnimates.push({type:"rotate3d",args:[e,t,n,r]}),this},e.prototype.rotateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateX",args:[e]}),this},e.prototype.rotateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateY",args:[e]}),this},e.prototype.rotateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateZ",args:[e]}),this},e.prototype.scale=function(e,t){return void 0===e&&(e=1),void 0===t&&(t=1),this.currentStepAnimates.push({type:"scale",args:[e,t]}),this},e.prototype.scale3d=function(e,t,n){return void 0===e&&(e=1),void 0===t&&(t=1),void 0===n&&(n=1),this.currentStepAnimates.push({type:"scale3d",args:[e,t,n]}),this},e.prototype.scaleX=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleX",args:[e]}),this},e.prototype.scaleY=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleY",args:[e]}),this},e.prototype.scaleZ=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleZ",args:[e]}),this},e.prototype.skew=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"skew",args:[e,t]}),this},e.prototype.skewX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewX",args:[e]}),this},e.prototype.skewY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewY",args:[e]}),this},e.prototype.translate=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"translate",args:[e,t]}),this},e.prototype.translate3d=function(e,t,n){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),this.currentStepAnimates.push({type:"translate3d",args:[e,t,n]}),this},e.prototype.translateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateX",args:[e]}),this},e.prototype.translateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateY",args:[e]}),this},e.prototype.translateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateZ",args:[e]}),this},e.prototype.opacity=function(e){return this.currentStepAnimates.push({type:"style",args:["opacity",e]}),this},e.prototype.backgroundColor=function(e){return this.currentStepAnimates.push({type:"style",args:["background-color",e]}),this},e.prototype.width=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["width",e]}),this},e.prototype.height=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["height",e]}),this},e.prototype.left=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["left",e]}),this},e.prototype.right=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["right",e]}),this},e.prototype.top=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["top",e]}),this},e.prototype.bottom=function(e){return io(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["bottom",e]}),this},e}();var Cu=function(){function e(e,t,n,r){this._selectorQuery=e,this._component=t,this._selector=n,this._single=r}return e.prototype.fields=function(e,t){return this._selectorQuery._push(this._selector,this._component,this._single,e,t),this._selectorQuery},e.prototype.boundingClientRect=function(e){return this.fields({id:!0,dataset:!0,rect:!0,size:!0},e)},e.prototype.scrollOffset=function(e){return this.fields({id:!0,dataset:!0,scrollOffset:!0},e)},e.prototype.context=function(e){return this.fields({context:!0},e)},e.prototype.node=function(e){return this.fields({node:!0},e)},e}(),Eu=function(){function e(){this.width=0,this.height=0,this.src="",this.path=null,this.onload=void 0,this.onerror=void 0,this._onload=void 0,this._onerror=void 0,this._complete=!1,this._status=null,this._sendTime=null,Object.defineProperty(this,"onload",{set:function(e){e&&"function"==typeof e?(this._onload=e,this._complete&&this._status&&(this._complete=!1,e())):this._onload=void 0},get:function(){return this._onload}}),Object.defineProperty(this,"onerror",{set:function(e){e&&"function"==typeof e?(this._onerror=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onerror=void 0},get:function(){return this._onerror}}),Object.defineProperty(this,"src",{set:function(e){this._src=e,this.checkImageValid(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.checkImageValid=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,fs({event:"getImageInfo",data:{src:e}},(function(e){n._sendTime===t&&(n._complete=!0,n.dealCheckResult(e))}))},e.prototype.dealCheckResult=function(e){var t=e.width,n=e.height,r=e.path,i=!!t&&!!n&&!!r;this._status=i,this.width=t||0,this.height=n||0,this.path=r||null,i&&this._onload?this._onload():!i&&this._onerror&&this._onerror()},e}(),Au=["shadowBlur","shadowOffsetX","shadowOffsetY","lineCap","lineJoin","lineWidth","miterLimit","font","textAlign","textBaseline","direction"],Vu=["fillStyle","strokeStyle","shadowColor"],ju=[{key:"clearRect",params:["x","y","width","height"],extParams:[]},{key:"fillRect",params:["x","y","width","height"],extParams:[]},{key:"strokeRect",params:["x","y","width","height"],extParams:[]},{key:"fillText",params:["text","x","y"],extParams:["maxWidth"]},{key:"strokeText",params:["text","x","y"],extParams:["maxWidth"]},{key:"measureText",params:["text"],extParams:[]},{key:"beginPath",params:[],extParams:[]},{key:"closePath",params:[],extParams:[]},{key:"moveTo",params:["x","y"],extParams:[]},{key:"lineTo",params:["x","y"],extParams:[]},{key:"bezierCurveTo",params:["cp1x","cp1y","cp2x","cp2y","x","y"],extParams:[]},{key:"quadraticCurveTo",params:["cpx","cpy","x","y"],extParams:[]},{key:"arc",params:["x","y","radius","startAngle","endAngle"],extParams:["anticlockwise"]},{key:"rect",params:["x","y","width","height"],extParams:[]},{key:"fill",params:[],extParams:[]},{key:"stroke",params:[],extParams:[]},{key:"clip",params:[],extParams:[]},{key:"rotate",params:["angle"],extParams:[]},{key:"scale",params:["x","y"],extParams:[]},{key:"translate",params:["x","y"],extParams:[]},{key:"transform",params:["a","b","c","d","e","f"],extParams:[]},{key:"setTransform",params:["a","b","c","d","e","f"],extParams:[]},{key:"save",params:[],extParams:[]},{key:"restore",params:[],extParams:[]}],Bu=function(){function e(e){var t=this;this.viewId=e,Au.forEach((function(e){Object.defineProperty(t,e,{set:function(n){var r;nu(t.viewId,e,((r={})[e]=n,r))},get:function(){return nu(t.viewId,e)}})})),Vu.forEach((function(e){Object.defineProperty(t,"_"+e,{value:"#000000",writable:!0}),Object.defineProperty(t,e,{set:function(n){var r,i=function(e){if("string"==typeof e){if(e=e.toLowerCase().replace(/\s+/g,""),/^#([0-9|a-f]{6})$/.test(e))return e;if(/^#([0-9|a-f]{8})$/.test(e))return"ff"===e.slice(7)?e.slice(0,7):au([ru(e.slice(1,3)),ru(e.slice(3,5)),ru(e.slice(5,7)),ru(e.slice(7))/Zc.MAX_COLOR_VALUE]);if(/^#([0-9|a-f]{3,4})$/.test(e)){var t=e.slice(1,2),n=e.slice(2,3),r=e.slice(3,4),i=void 0;return 4===e.length||"f"===(i=e.slice(4))?"#"+t+t+n+n+r+r:au([ru(t+t),ru(n+n),ru(r+r),ru(i+i)/Zc.MAX_COLOR_VALUE])}if(/^rgb[a]?\(((-|\+?)\d+(\.\d+)?,){2,3}(-|\+?)\d+(\.\d+)?\)$/.test(e)){var o=e.split(",");return t=o[0].split("(")[1],n=o[1],r=o[2],"rgba"===e.slice(0,4)&&o[3]&&(i=ou(o[3].split(")")[0]))<1?au([ou(t),ou(n),ou(r),i]):"#"+iu(t)+iu(n)+iu(r)}if(eu[e])return eu[e]}return null}(n);i&&(Array.isArray(i)?(t["_"+e]="rgba("+i.join(", ")+")",i="#"+iu(""+parseFloat(i[3])*Zc.MAX_COLOR_VALUE)+iu(i[0])+iu(i[1])+iu(i[2])):t["_"+e]=i,nu(t.viewId,e,((r={})[e]=i,r)))},get:function(){return t["_"+e]}})})),ju.forEach((function(e){var n=e.key,r=e.params,i=e.extParams;t[n]=function(){for(var e=[],o=0;o<arguments.length;o++)e[o]=arguments[o];var a={},s=e.length,c=r.length;if(s<c)throw new TypeError("Failed to execute '"+n+"' on 'CanvasRenderingContext2D': "+r.length+" arguments required, but only "+e.length+" present.");for(var u=i.length,f=0;f<c;f++)a[r[f]]=e[f];if(s>c)for(f=0;f<u;f++)a[i[f]]=e[f+c];return nu(t.viewId,n,a)}}))}return e.prototype.drawImage=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(!(e instanceof Eu))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': image must be created by canvas.");if(![2,4,8].includes(t.length))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': Overload resolution failed.");if(e.path){var r={src:e.path},i=void 0,o=void 0,a=void 0,s=void 0;2===t.length||4===t.length?(i=t[0],o=t[1],a=t[2]||null,s=t[3]||null):(r.sx=t[0],r.sy=t[1],r.sWidth=t[2],r.sHeight=t[3],i=t[4],o=t[5],a=t[6],s=t[7]),r.dx=i,r.dy=o,a&&(r.dWidth=a,r.dHeight=s),nu(this.viewId,"drawImage",r)}},e}(),Ru=function(){function e(e,t){var n=this;this._width=300,this._height=150,this._webViewId=e,this._nodeId=t,this.canvasRef=null,Object.defineProperty(this,"width",{get:function(){return n._width},set:function(e){e=zu(e),n._width=e,nu(n._nodeId,"width",{width:e})}}),Object.defineProperty(this,"height",{get:function(){return n._height},set:function(e){e=zu(e),n._height=e,nu(n._nodeId,"height",{height:e})}})}return e.prototype.getContext=function(e){if(!this.canvasRef&&"2d"===e){var t=nu(this._nodeId,"getContext",{type:"2d"},!0);if(!(null==t?void 0:t.canvasId))return null;this.canvasRef=new Bu(this._nodeId)}return this.canvasRef},e.prototype.createImage=function(){return new Eu},e.prototype.createImageData=function(){},e.prototype.createPath2D=function(){},e.prototype.requestAnimationFrame=function(){},e.prototype.cancelAnimationFrame=function(){},e}();function zu(e){try{var t=Math.abs(parseInt(e));return isNaN(t)?0:t}catch(e){return 0}}qo("Map",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Ks);var Fu=function(){function e(e){this.lottieId="",this.src="",this._onDataReady=void 0,this._onDataFailed=void 0,this._complete=!1,this._status=null,this._sendTime=null,this.onCompletionCallbackLottie=null,this.lottieId=e,Object.defineProperty(this,"src",{set:function(e){this._src=e,this.srcLottie(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.onDataReady=function(e){e&&"function"==typeof e?(this._onDataReady=e,this._complete&&this._status&&(this._complete=!1,e())):this._onDataReady=void 0},e.prototype.onDataFailed=function(e){e&&"function"==typeof e?(this._onDataFailed=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onDataFailed=void 0},e.prototype.srcLottie=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,fs({event:"srcLottie",data:{src:e,lottieId:this.lottieId},success:function(){n._sendTime===t&&(n._complete=!0,n._status=!0,n._onDataReady&&n._onDataReady())},fail:function(e){n._sendTime===t&&(n._complete=!0,n._status=!1,n._onDataFailed&&n._onDataFailed(e.data))}})},e.prototype.setLoopLottie=function(e){fs({event:"setLoopLottie",data:{isLoop:e,lottieId:this.lottieId}})},e.prototype.playAnimationLottie=function(){fs({event:"playAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.cancelAnimationLottie=function(){fs({event:"cancelAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.setOnCompletionCallbackLottie=function(e){var t=this;this.onCompletionCallbackLottie&&didiJsBridge.off({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}),"function"==typeof e&&(this.onCompletionCallbackLottie=function(n){var r;(null===(r=n.data)||void 0===r?void 0:r.lottieId)===t.lottieId&&e()},didiJsBridge.on({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}))},e}(),Du=new Map;function Wu(e,t,n,r){if(e)if(Array.isArray(e))e.forEach((function(e){return Wu(e,t,n)}));else{var i=e.nodeIs;if(i){var o=e.nodeId;"dd-canvas"===i&&o?e.node=function(e,t){if("2d"===t){var n=function(e,t){var n,r=tu(e,t);return(null===(n=su[e])||void 0===n?void 0:n[r])||null}(xc.currentWebviewId,e);return n||(n=new Ru(xc.currentWebviewId,e),function(e,t,n){var r=tu(e,t);su[e]?su[e][r]=n:su[e]={id:n}}(xc.currentWebviewId,e,n),n)}}(o,e.nodeCanvasType):"dd-lottie"===i&&o&&(e.node=(a=o,Du.has(a)||Du.set(a,new Fu(a)),Du.get(a))),delete e.nodeIs,delete e.nodeId,delete e.nodeCanvasType,e.node&&"function"==typeof e.node._onReady&&n.push(new Promise((function(t){return e.node._onReady(t)})))}}var a}var Uu={},qu={};function Ju(e,t){return Uu[t]||(Uu[t]=function(e){return function(){function t(e){if(e&&e.page)this._component=this._defaultComponent=e.page,this._webViewId=this._defaultComponent.__ddWebViewId__;else{var t=__appServiceEngine__.getCurrentPagesByDomain("");this._defaultComponent=t[t.length-1],this._component=null,this._webViewId=null}this._queue=[],this._queueCb=[]}return t.prototype.in=function(e){return null===this._webViewId?(this._webViewId=e.__ddWebViewId__,this._component=e):this._webViewId!==e.__ddWebViewId__||(this._component=e),this},t.prototype.select=function(e){return new Cu(this,this._component,e,!0)},t.prototype.selectAll=function(e){return new Cu(this,this._component,e,!1)},t.prototype.selectViewport=function(){return new Cu(this,0,"",!0)},t.prototype._push=function(t,n,r,i,o){null===this._webViewId&&(this._webViewId=this._defaultComponent?this._defaultComponent.__ddWebViewId__:void 0);var a=e?"":__virtualDOM__.getRootNodeId(this._webViewId),s=null!=n?0===n?0:n.__ddExparserNodeId__:a;this._queue.push({component:s,selector:t,single:r,fields:i}),this._queueCb.push(o||null)},t.prototype.exec=function(t){var n=this,r=this,i=this._webViewId,o={pluginId:e,queue:this._queue},a=function(e){return ir(n,void 0,void 0,(function(){var n,i,o,a=this;return or(this,(function(s){switch(s.label){case 0:return n=this._queueCb,i=[],o=[],e.forEach((function(e,t){Wu(e,a._component,o),oo(n[t])&&i.push((function(){n[t].call(r,e)}))})),oo(t)&&i.push((function(){t.call(r,e)})),o.length?[4,Promise.all(o)]:[3,2];case 1:s.sent(),s.label=2;case 2:return i.forEach((function(e){return e()})),[2]}}))}))};if(null!=i)var s=__virtualDOM__.requestViewInfo("selectorQuery",o,i,(function(e){a&&(__virtualDOM__.endViewInfoCallback(i,s),a&&a(e))}))},t}()}(t)),new Uu[t](e)}function Gu(e,t,n){return qu[n]||(qu[n]=function(e){return function(){function t(e,t){if(this._component=e,this._options=t,this._relativeInfo=[],this._observerId=null,this._disconnected=!1,this._component)this._webViewId=this._component.__ddWebViewId__;else{var n=__appServiceEngine__.getCurrentPagesByDomain("");n.length&&(this._webViewId=n[n.length-1].__ddWebViewId__)}}return t.requestViewInfo=function(e,t,n){var r=__virtualDOM__.requestViewInfo("intersection",t,e,(function(t){t.reqEnd&&__virtualDOM__.endViewInfoCallback(e,r),n&&!t.reqEnd&&n(t)}))},t.prototype.relativeTo=function(e,t){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:e,margins:t}),this},t.prototype.relativeToViewport=function(e){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:null,margins:e}),this},t.prototype.observe=function(n,r){var i=this;if(null!==this._observerId)throw new Error('"observe" call can be only called once in IntersectionObserver');this._observerId="";var o=this._component;t.requestViewInfo(this._webViewId,{type:"addIntersectionObserver",pluginId:e,nodeId:o?o.__ddExparserNodeId__:__virtualDOM__.getRootNodeId(this._webViewId),targetSelector:n,relativeInfo:this._relativeInfo,options:this._options},(function(e){i._disconnected||(e.observerId&&(i._observerId=e.observerId),e.info&&r.call(i,e.info))}))},t.prototype.disconnect=function(){t.requestViewInfo(this._webViewId,{type:"removeIntersectionObserver",observerId:this._observerId}),this._disconnected=!0},t}()}(n)),new qu[n](e,t)}var Hu=os("AppHide").internalOnMethod;os("AppHide").internalOffMethod;function Qu(e,t,n){var r={event:e,data:t,webViewId:n};didiJsBridge.publish(r)}function $u(e,t){didiJsBridge.subscribe({event:e},(function(e){var n=e.data,r=void 0===n?{}:n,i=e.webViewId;oo(t)&&t(r,i)}))}var Xu=!1;var Ku=new ha.EventEmitter2;didiJsBridge.on({event:"onUpdateStatusChange"},(function(e){var t=e&&e.data&&e.data.event||"";Ku.emit(t,e)}));var Yu,Zu=null,ef=[];function tf(){ef.forEach((function(e){"function"==typeof e&&e(Yu)})),ef.length=0}Ku.on("updating",(function(){Yu={hasUpdate:!0},tf()})),Ku.on("noupdate",(function(){Yu={hasUpdate:!1},tf()}));var nf,rf=[],of=!1;Ku.on("updateready",(function(){of=!0,rf.forEach((function(e){"function"==typeof e&&e()})),rf.length=0}));var af=[];Ku.on("updatefail",(function(){nf={},af.forEach((function(e){"function"==typeof e&&e(nf)})),af.length=0}));var sf,cf={src:"",startTime:0,paused:!0,currentTime:0,duration:0,obeyMuteSwitch:!0,volume:1,autoplay:!1,loop:!1,buffered:0,referrerPolicy:""},uf=new Map,ff=function(){function e(e){this.src=e.src,this.startTime=e.startTime,this.paused=e.paused,this.currentTime=e.currentTime,this.duration=e.duration,this.obeyMuteSwitch=e.obeyMuteSwitch,this.volume=e.volume,this.autoplay=e.autoplay,this.loop=e.loop,this.buffered=e.buffered,this.referrerPolicy=e.referrerPolicy}return e.prototype.play=function(){fs({event:"audioInstancePlay",data:{audioId:sf,src:this.src,paused:!1,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.stop=function(){fs({event:"audioInstanceStop",data:{audioId:sf,src:this.src,paused:this.paused,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.destroy=function(){uf.clear()},e.prototype.onPlay=function(e){this.onPlayFuncs=e},e.prototype.onStop=function(e){this.onStopFuncs=e},e.prototype.onEnded=function(e){this.onEndedFuncs=e},e}();didiJsBridge.on({event:"audioInstanceStateChanged"},(function(e){var t=e.data,n=t.audioId,r=t.emitFunctionName,i=uf.get(n);i&&i[r+"Funcs"]()}));var lf=function(){function e(e,t){this.mapId=e,this.that=t}return e.prototype.setCenterOffset=function(e){void 0===e&&(e={}),e.mapId=this.mapId,fs({event:"setCenterOffset",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.includePoints=function(e){void 0===e&&(e={}),e.mapId=this.mapId,fs({event:"includePoints",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.getCenterLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,fs({event:"getCenterLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.moveToLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,fs({event:"moveToLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.getScale=function(e){void 0===e&&(e={}),e.mapId=this.mapId,fs({event:"getScale",data:e,success:e.success,fail:e.fail,complete:e.complete})},e}();var df=function(){function e(){}return e.prototype.takePhoto=function(e){var t=e.quality,n=void 0===t?"normal":t,r=e.success,i=e.fail,o=e.complete;fs({event:"takePhotoCamera",data:{quality:n},success:r,fail:i,complete:o})},e.prototype.setZoom=function(e){var t=e.zoom,n=e.success,r=e.fail,i=e.complete;if("number"!=typeof t)throw new Error("CameraContext.setZoom:fail parameter error: parameter.zoom should be Number instead of "+et(t)+";");fs({event:"setZoomCamera",data:{zoom:t},success:n,fail:r,complete:i})},e.prototype.startRecord=function(e){var t=e.success,n=e.fail,r=e.complete;fs({event:"startRecordCamera",success:t,fail:n,complete:r})},e.prototype.stopRecord=function(e){var t=e.compressed,n=void 0!==t&&t,r=e.success,i=e.fail,o=e.complete;fs({event:"stopRecordCamera",data:{compressed:n},success:r,fail:i,complete:o})},e}();var pf="";function hf(e){return e||null}function yf(e,t,n,r){var i=["then","catch","always"].reduce((function(e,t){return e[t]=function(n){return e[t]=n,e},e}),{}),o=new XMLHttpRequest,a=function(e,t,n){if("get"!==n.toLowerCase()||!t)return e;var r=function(e){return gf(e)?mf(e):e}(t),i=e.indexOf("?")>-1?"&":"?";return e+i+r}(t,n,e);return o.open(e,a,!0),o.withCredentials=r.hasOwnProperty("withCredentials"),function(e,t,n){(function(e){return Object.keys(e).some((function(e){return"content-type"===e.toLowerCase()}))})(t=t||{})||(t["Content-Type"]=gf(n)?"application/json":"application/x-www-form-urlencoded");if("application/x-www-form-urlencoded"===t["Content-Type"]||"application/x-www-form-urlencoded"===t["content-type"]){if(gf(n)){for(var r in n)pf=pf+r+"="+n[r]+"&";pf=pf.substr(0,pf.length-1)}}else pf=gf(n)?JSON.stringify(n):n;Object.keys(t).forEach((function(n){t[n]&&e.setRequestHeader(n,t[n])}))}(o,r.headers,n),o.addEventListener("readystatechange",function(e,t){return function n(){t.readyState===t.DONE&&(t.removeEventListener("readystatechange",n,!1),e.always.apply(e,vf(t)),t.status>=200&&t.status<300?e.then.apply(e,vf(t)):e.catch.apply(e,vf(t)))}}(i,o),!1),o.send(pf),i.abort=function(){return o.abort()},i}function vf(e){var t;try{t=JSON.parse(e.responseText)}catch(n){t=e.responseText}return[t,e]}function gf(e){return"[object Object]"===Object.prototype.toString.call(e)}function mf(e,t){return Object.keys(e).map((function(n){if(e.hasOwnProperty(n)&&void 0!==e[n]){var r=e[n];return n=t?t+"["+n+"]":n,null!==r&&"object"===et(r)?mf(r,n):bf(n)+"="+bf(r)}})).filter(Boolean).join("&")}function bf(e){return encodeURIComponent(e)}function Sf(e,t){this.eventMap=new Map,this.callbackMap=new WeakMap,this.originalCallbackMap=new WeakMap,this.type=e,this.surround=t,this.on=function(e,t){var n,r;oo(t)&&(n=t,this.surround&&(r=t,"at"+this.type+e+"callback function",n=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];try{return r.apply(void 0,e)}catch(e){return}},this.callbackMap.set(t,n),this.originalCallbackMap.set(n,t),this.eventMap.has(e)?this.eventMap.get(e).add(n):this.eventMap.set(e,new Set([n]))))},this.off=function(e,t){var n,r=this,i=this.eventMap.get(e);i&&("function"!=typeof t?(i.forEach((function(e){var t=r.originalCallbackMap.get(e);r.callbackMap.delete(t),r.originalCallbackMap.delete(e)})),i.clear()):this.surround?(n=this.callbackMap.get(t),i.delete(n),this.callbackMap.delete(t),this.originalCallbackMap.delete(n)):i.delete(t))},this.emit=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];this.eventMap.has(e)&&new Set(this.eventMap.get(e)).forEach((function(e){return e.apply(void 0,t)}))},this.removeAllListeners=function(e){this.off(e)}}var wf="pending",_f="then",Tf="catch",kf=function(){function e(e){if(this._status=wf,this._return=void 0,this._processors=[],"function"!=typeof e)throw new TypeError("Promise resolver is not a function");var t=this;try{e((function(e){t._status===wf&&(t._status=_f,t._return=e,t._consume())}),(function(e){t._status===wf&&(t._status=Tf,t._return=e,t._consume())}))}catch(e){}}return e.prototype._consume=function(){if(this._status!==wf){for(var e=this._processors.shift();e&&e.type!==this._status;)e=this._processors.shift();if(e)try{this._return=e.func(this._return),this._status=_f}catch(e){this._return=e,this._status=Tf}finally{this._consume()}}},e.prototype.then=function(e){return this._processors.push({func:e,type:_f}),this._consume(),this},e.prototype.catch=function(e){return this._processors.push({func:e,type:Tf}),this._consume(),this},e.prototype.resolve=function(t){return new e((function(e){return e(t)}))},e.prototype.reject=function(t){return new e((function(){throw t}))},e}(),Mf={currentTaskCount:0,maxTaskCount:10,taskQueue:[],functionName:"",taskIdMap:{}},Nf={};function xf(e,t){var n=Nf[e]?Nf[e]:Mf;didiJsBridge.on({event:"on"+e+"TaskStateChange"},(function(t){!function(e,t){var n=e.taskId,r=e.state,i=e.data;Cf.emit(""+t+n+r,i),("success"===r||"fail"===r)&&(Cf.emit(""+t+n+"complete",i),--Nf[t].currentTaskCount,Nf[t].taskQueue.length>0&&Nf[t].taskQueue.shift().item.createTask(),delete Nf[t].taskIdMap[""+t+n])}(t&&t.data,e)})),Nf[e]=tt(n,t)}xf("Request",{maxTaskCount:10,functionName:"request"}),xf("Download",{maxTaskCount:10,functionName:"downloadFile"}),xf("Upload",{maxTaskCount:10,functionName:"uploadFile"});var If=new WeakMap,Of=new WeakMap,Pf=new WeakMap,Lf=0,Cf=new Sf("netWork",!0),Ef=function(){function e(e){var t=this,n=e.taskType;++Lf,Nf[n].taskIdMap[""+n+Lf]=this,Of.set(this,n),Pf.set(this,e),this.promise=new kf((function(e,n){t.resolve=e,t.reject=n})),Nf[n].currentTaskCount>=Nf[n].maxTaskCount?Nf[n].taskQueue.push({id:""+n+Lf,item:this}):this.createTask()}return e.prototype.createTask=function(){var e=this,t=Pf.get(this),n=Of.get(this),r={url:t.url,data:t.data,header:t.header,dataType:t.dataType,responseType:t.responseType,method:t.method,timeout:t.timeout,filePath:t.filePath,formData:t.formData,name:t.name};"Request"===n&&(r.dataType||(r.dataType="json"),r.responseType||(r.responseType="text"),r.method||(r.method="GET"));var i=""+n+Lf;fs({event:"create"+n+"Task",data:{taskId:i,options:r},success:function(){If.set(e,""+i),Nf[n].taskIdMap[i].resolve()},fail:function(e){Nf[n].taskIdMap[i].reject(e)}}),this.promise.then((function(){e.createTaskSuccess()})).catch((function(t){e.createTaskFail(t)}))},e.prototype.createTaskSuccess=function(){var e=Of.get(this),t=If.get(this),n=Pf.get(this);Cf.on(""+e+t+"success",(function(e){n&&n.success&&"function"==typeof n.success&&n.success(e)})),Cf.on(""+e+t+"fail",(function(e){n&&n.fail&&"function"==typeof n.fail&&n.fail(e)})),Cf.on(""+e+t+"complete",(function(e){n&&n.complete&&"function"==typeof n.complete&&n.complete(e)}))},e.prototype.createTaskFail=function(e){var t=Pf.get(this);t&&t.fail&&"function"==typeof t.fail&&t.fail(e),t&&t.complete&&"function"==typeof t.complete&&t.complete(e)},e.prototype.abort=function(){var e=this;this.promise.then((function(){var t=Of.get(e);fs({event:"operate"+t+"Task",data:{operationType:"abort",taskId:If.get(e),extra:{}},success:function(){},fail:function(e){}})}))},e.prototype.onProgressUpdate=function(e){var t=this;If.get(this)?Cf.on(""+Of.get(this)+If.get(this)+"progressUpdate",e):this.promise.then((function(){Cf.on(""+Of.get(t)+If.get(t)+"progressUpdate",e)}))},e.prototype.offProgressUpdate=function(e){Cf.off(""+Of.get(this)+If.get(this)+"progressUpdate",e)},e}();var Af,Vf={type:"async",event:"downloadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"下载资源的url"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求的 Header，Header 中不能设置 Referer"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},filePath:{type:["String"],ifMustNeed:!1,default:"",desc:"指定文件下载后存储的路径 (本地路径)"}}},jf={type:"async",event:"uploadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器地址"},filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"要上传文件资源的路径 (本地路径)"},name:{type:["String"],ifMustNeed:!0,default:"",desc:"文件对应的 key，开发者在服务端可以通过这个 key 获取文件的二进制内容"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求 Header，Header 中不能设置 Referer"},formData:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求中其他额外的 form data"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"}}},Bf=function(e){var t;(void 0===e&&(e={url:""}),window.isBrowser)?(t={method:e.method||"GET",data:e.data,url:e.url,headers:e.header,timeout:e.timeout,dataType:e.dataType||"json",responseType:e.responseType||"text"},pf="",(t=t||{}).baseUrl=t.baseUrl||"",t.method&&t.url?yf(t.method,t.baseUrl+t.url,hf(t.data),t):["get","post","put","delete"].reduce((function(e,n){return e[n]=function(e,r){return yf(n,t.baseUrl+e,hf(r),t)},e}),{})).then((function(t){e.success({data:t})})):fs({event:"request",data:{url:e.url,data:e.data,header:e.header,timeout:e.timeout,method:e.method||"GET",dataType:e.dataType||"json",responseType:e.responseType||"text"},success:e.success,fail:e.fail,complete:e.complete})},Rf="2.11.0",zf=new Sf("socket-task",!0),Ff=0,Df=new WeakMap,Wf={};didiJsBridge.on({event:"onSocketStateChange"},(function(e){var t=e.data,n=t.state,r=t.taskId,i=t.data;"open"===n&&(qf.currentTaskCount++,Wf[r].readyState=1),zf.emit(""+r+n,i),"close"===n&&(qf.currentTaskCount--,Wf[r].readyState=3,zf.removeAllListeners(r+"open"),zf.removeAllListeners(r+"close"),zf.removeAllListeners(r+"message"),zf.removeAllListeners(r+"error"))}));var Uf=new WeakMap,qf=function(){function e(){}return e.connectSocket=function(t){if(t&&t.url&&(r=t.url,/^(ws|wss):\/\/.*/i.test(r))){t.header&&"[Object object]"===Object.prototype.toString.call(t.header)||delete t.header,0===t.timeout&&delete t.timeout;try{var n=new Jf(t);return n&&3!==n.readyState&&Uf.set(e.currentTask,n),n}catch(e){}}var r},e.closeSocket=function(){var t=Uf.get(e.currentTask);t&&3!==t.readyState&&t.close()},e.sendSocketMessage=function(t){Uf.get(e.currentTask).send(t)},e.onSocketOpen=function(t){t||(t=function(){});var n=Uf.get(e.currentTask);zf.on(n.taskId+"open",t)},e.onSocketClose=function(t){t||(t=function(){});var n=Uf.get(e.currentTask);zf.on(n.taskId+"close",t)},e.onSocketMessage=function(t){t||(t=function(){});var n=Uf.get(e.currentTask);zf.on(n.taskId+"message",t)},e.onSocketError=function(t){t||(t=function(){});var n=Uf.get(e.currentTask);zf.on(n.taskId+"error",t)},e.currentTask={},e.currentTaskCount=0,e}(),Jf=function(){function e(e){this.readyState=0;var t="web-socket"+Ff++;Df.set(this,t),Wf[t]=this,qf.currentTaskCount>=2?e.fail({errMsg:"exceed max task count"}):fs({event:"createSocketTask",data:{taskId:t,options:{url:e.url,header:e.header,protocols:e.protocols,tcpNoDelay:e.tcpNoDelay,perMessageDeflate:e.perMessageDeflate,timeout:e.timeout}},success:function(n){n.errMsg=n.errMsg.replace("createSocketTask","connectSocket"),n.socketTaskId=t,e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})}return e.prototype.close=function(e){var t=this;this.readyState>1||(e.code&&(1e3!==e.code||e.code>=3e3&&e.code<=4999)?e&&e.fail&&e.fail({errMsg:"closeSocket:fail Failed to execute 'close' on 'WebSocket': The code must be either 1000, or between 3000 and 4999. "+e.code+" is neither."}):(this.readyState=2,fs({event:"operateSocketTask",data:{operationType:"close",taskId:Df.get(this),extra:{code:e.code||1e3,reason:e.reason}},success:function(n){qf.currentTaskCount--,t.readyState=3,n.errMsg=n.errMsg.replace("operateSocketTask","closeSocket"),e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})))},e.prototype.send=function(e){if(1===this.readyState)fs({event:"operateSocketTask",data:{operationType:"send",taskId:Df.get(this),extra:{data:e.data||""}},success:function(t){t.errMsg=t.errMsg.replace("operateSocketTask","sendSocketMessage"),e.success&&e.success(t)},fail:function(t){e.fail&&e.fail(t)}});else{if(!e.fail)throw new Error("SocketTask.send:fail SocketTask.readyState is not OPEN");e.fail({errMsg:"SocketTask.send:fail SocketTask.readyState is not OPEN"})}},e.prototype.onClose=function(e){var t=this;e||(e=function(){});var n=Df.get(this);zf.on(n+"close",(function(){t.readyState=3,e()}))},e.prototype.onError=function(e){e||(e=function(){});var t=Df.get(this);zf.on(t+"error",e)},e.prototype.onMessage=function(e){e||(e=function(){});var t=Df.get(this);zf.on(t+"message",e)},e.prototype.onOpen=function(e){e||(e=function(){});var t=Df.get(this);zf.on(t+"open",e)},e}();var Gf={downloadFile:function(e){void 0===e&&(e={url:""});var t=ao(Vf,[e]);if(Su((null==(Af=Af||dd.getSystemInfoSync())?void 0:Af.SDKVersion)||"10.0.0",Rf)>=0)return new Ef(rr({taskType:"Download"},t));!function(e){fs({event:"downloadFile",data:{url:e.url,header:e.header,timeout:e.timeout,filePath:e.filePath},success:e.success,fail:e.fail,complete:e.complete})}(t)},request:function(e){if(void 0===e&&(e={url:""}),Su((null==(Af=Af||dd.getSystemInfoSync())?void 0:Af.SDKVersion)||"10.0.0",Rf)>=0)return new Ef(rr({taskType:"Request"},e));Bf(e)},uploadFile:function(e){var t=ao(jf,[e]);if(Su((null==(Af=Af||dd.getSystemInfoSync())?void 0:Af.SDKVersion)||"10.0.0",Rf)>=0)return new Ef(rr({taskType:"Upload"},t));!function(e){fs({event:"uploadFile",data:{url:e.url,filePath:e.filePath,name:e.name,header:e.header,formData:e.formData,timeout:e.timeout},success:e.success,fail:e.fail,complete:e.complete})}(t)},connectSocket:function(e){return qf.connectSocket(e)},onSocketOpen:function(e){qf.onSocketOpen(e)},closeSocket:function(){qf.closeSocket()},sendSocketMessage:function(e){qf.sendSocketMessage(e)},onSocketClose:function(e){qf.onSocketClose(e)},onSocketMessage:function(e){qf.onSocketMessage(e)},onSocketError:function(e){qf.onSocketError(e)},nextTick:function(e){oo(e)&&(Mu.push(e),Nu||(Nu=setTimeout(xu,0)))},createAnimation:function(e){return void 0===e&&(e={}),new Lu(e)},createSelectorQuery:function(e){return Ju(e,"")},createIntersectionObserver:function(e,t){return Gu(e,t,"")},createMediaQueryObserver:function(){return null},getLaunchOptionsSync:yc,getEnterOptionsSync:vc,onAppHide:Hu,navigateTo:Lc.navigateTo,redirectTo:Lc.redirectTo,navigateBack:Lc.navigateBack,switchTab:Lc.switchTab,reLaunch:Lc.reLaunch,launch:Lc.launch,getRealRoute:oc,getLocalFilePath:function(e,t){return new Promise((function(n,r){didiJsBridge.invoke({method:"getLocalFilePath",data:{package:e,path:t},callback:function(i){i&&i.data&&i.data.success?n(i.data.data.path):r(i.data.errMsg||"getLocalFilePath failed ("+e+" - "+t+").")}})}))},getFileSystemManager:function(){return{unlink:function(e){void 0===e&&(e={filePath:""}),fs({event:"unlink",data:{filePath:e.filePath},success:e.success,fail:e.fail,complete:e.complete})}}},onAppRoute:Oc,canIUse:function(e){if(!Tu[e])return!1;if(!wu||!_u){var t=dd.getSystemInfoSync();wu=(null==t?void 0:t.SDKVersion)||"10.0.0",_u=(null==t?void 0:t.jssdkVersion)||"10.0.0"}var n=Su(wu,Tu[e].version),r=Su(_u,Tu[e].dmVersion);return n>=0&&r>=0},getUpdateManager:function(){return Zu||(Zu={onCheckForUpdate:function(e){Yu?"function"==typeof e&&e(Yu):ef.push(e)},onUpdateReady:function(e){of?"function"==typeof e&&e():rf.push(e)},onUpdateFailed:function(e){nf?"function"==typeof e&&e(nf):af.push(e)},applyUpdate:function(){of&&fs({event:"applyUpdate"})}})},getRealtimeLogManager:function(){return{info:function(){},warn:function(){},error:function(){},setFilterMsg:function(){},addFilterMsg:function(){},in:function(){}}},openBusinessView:function(){return!1},reportAnalytics:function(e,t){gu(e,t)},navigateToMiniProgram:Lc.navigateToMiniProgram,requestSubscribeMessage:function(e){return e.sucssess&&e.success(),{}},loginNotifition:function(e){didiJsBridge.on({event:"loginNotifition"},(function(t){e&&e(t.data||{})}))},shareQqAppmsg:function(e){fs({event:"shareQqAppmsg",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareQzone:function(e){fs({event:"shareQzone",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayFriend:function(e){fs({event:"shareAlipayFriend",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayLife:function(e){fs({event:"shareAlipayLife",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareSinaWeibo:function(e){fs({event:"shareSinaWeibo",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},getPerformance:function(){return lu||(lu=new hu),lu},pageScrollTo:function(e){var t=__appServiceEngine__.getCurrentPagesByDomain(""),n=t[t.length-1].__ddWebViewId__;e.page&&(e.page.__ddWebViewId__||e.page.__wxWebviewId__)&&(n=e.page.__ddWebViewId__||e.page.__wxWebviewId__);var r={};for(var i in e)"function"==typeof e[i]&&(r[i]=e[i],delete e[i]);e.callBackId=fu,uu[fu]=r,fu++,didiJsBridge.publish({event:"pageScrollTo",data:e,webViewId:n})},requestPayment:function(e){if(!e.isTrip&&!e.outTradeId)return e.fail&&e.fail("缺少outTradeId"),void(e.complete&&e.complete());for(var t={},n=0,r=["isTrip","oid","sid","bid","appId","domain","isOnline","mOfflineURL","outToken","ext_info","bizContent","sign","signType","terminalId","orderId"];n<r.length;n++){var i=r[n];void 0!==e[i]&&(t[i]=e[i])}fs({event:"requestPayment",data:rr({outTradeId:e.outTradeId},t),success:e.success,fail:e.fail,complete:e.complete})},skiaCanvasRemove:cu,extBridge:function(e,t){e&&e.event&&e.module&&didiJsBridge.invoke({module:e.module,method:e.event,data:e.data||{},isSustain:e.isSustain||!1,callback:t||function(t){(t=t.data).success?e.success&&e.success(t.data):e.fail&&e.fail({errMsg:t.errMsg}),e.complete&&e.complete()}})},extOnBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t&&r){var i=n+"_"+t;cs({eventManagerName:i,nativeEvent:i,callBack:r})}},extOffBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t){var i=n+"_"+t;us({eventManagerName:i,nativeEvent:i,callBack:r})}},triggerGC:function(){if(!Xu){Xu=!0;for(var e={},t=0;t<1e5;t++)e[t]=[];e=null,new Promise((function(e){e(!0)})).then((function(){})).catch((function(){})).finally((function(){return Xu&&(Xu=!1)}))}},goSuperAppTab:Cc,onCloseMiniProgram:function(e){os("onCloseMiniProgram").internalOnMethod(e)},exitMiniProgram:function(e){void 0===e&&(e={}),fs({event:"exitMiniProgram",data:{},success:e.success,fail:e.fail,complete:e.complete})},createInnerAudioContext:function(){var e=new ff(cf);sf=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36);var t=new Proxy(e,{get:function(e,t){return e[t]},set:function(e,t,n){var r;return fs({event:"updateAudioInstanceState",data:(r={audioId:sf},r[t]=n,r)}),e[t]=n,!0}});return uf.set(sf,t),t},createMapContext:function(e,t){return new lf(e,t)},createCameraContext:function(){return new df},emitUnhandledRejection:function(e){ku&&ku.emit(e)},onUnhandledRejection:function(e){ku||(ku=os("unhandledRejection")),ku.onMethod(e)},offUnhandledRejection:function(e){ku&&ku.offMethod(e)},reportEvent:function(e){didiJsBridge.invoke({method:"reportEvent",data:rr({},e)})}},Hf={openSetting:function(e){void 0===e&&(e={}),fs({event:"openSetting",data:{},success:e&&e.success,fail:e&&e.fail,complete:e&&e.complete})},showToast:function(e){fs({event:"showToast",data:{title:e.title,icon:e.icon,image:e.image,duration:e.duration||1500,mask:e.mask||!1},success:e.success,fail:e.fail,complete:e.complete})},hideToast:function(e){void 0===e&&(e={}),fs({event:"hideToast",data:{},success:e.success,fail:e.fail,complete:e.complete})},showModal:function(e){window.isBrowser?window.confirm(e.content)?e.success({confirm:!0}):e.fail({confirm:!1}):fs({event:"showModal",data:{title:e.title,content:e.content,showCancel:void 0===e.showCancel||e.showCancel,cancelText:e.cancelText||"取消",cancelColor:e.cancelColor||"#000000",confirmText:e.confirmText||"确定",confirmColor:e.confirmColor||"#576B95"},success:e.success,fail:e.fail,complete:e.complete})},navigateTo:Lc.navigateTo,redirectTo:Lc.redirectTo,navigateBack:Lc.navigateBack,switchTab:Lc.switchTab,reLaunch:Lc.reLaunch};$u("invokeAppServiceMethod",(function(e){e.name in Hf&&Hf[e.name].apply(void 0,e.args)})),$u("skiaCanvasRemove",(function(e){var t=e.viewId;cu(e.webViewId,t)}));var Qf={vdSync:function(e,t){Qu("vdSync",{data:e,webViewId:t},t)},vdSyncBatch:function(e,t){Qu("vdSyncBatch",{data:e,webViewId:t},t)},onVdSync:function(e){$u("vdSync",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))},onVdSyncBatch:function(e){$u("vdSyncBatch",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))}};var $f=os("onAppRouteDone").internalOnMethod,Xf=os("onAppRouteDone").internalOffMethod,Kf=0,Yf=[];Oc((function e(t){var n={};"appLaunch"===t.openType&&(n=yc(),os("onAppShow").emitInternal(n),Pc(e))}));var Zf=os("AppEnterForeground"),el=os("onAppShow");didiJsBridge.on({event:"onAppEnterForeground"},(function(e){el.emit(e)})),didiJsBridge.subscribe({event:"onPageReload"},(function(e){void 0===e&&(e={data:{path:"",webViewId:-1,query:{}}});var t=e.data;os("onPageReload").emit({path:t.path,webViewId:t.webViewId,query:t.query})})),didiJsBridge.on({event:"onPullDownRefresh"},(function(){os("onPullDownRefresh").emit()}));var tl=os("onPullDownRefresh").internalOnMethod,nl=os("onPullDownRefresh").internalOffMethod;return{proxySDK:ss,dd:Gf,_createSelectorQuery:Ju,_createIntersectionObserver:Gu,_virtualDOMTunnel:Qf,_getPackageDirByRoute:ac,getLaunchOptionsSync:yc,getEnterOptionsSync:vc,pluginInfos:{},onAppRouteDone:$f,offAppRouteDone:Xf,invokeWebviewMethod:function(e,t,n,r){void 0===t&&(t={});var i=Kf++;Yf[i]=r,Qu&&Qu("invokeWebviewMethod",{name:e,args:t,callbackId:i},void 0===n?xc.currentWebviewId:n),$u&&$u("callbackWebviewMethod",(function(e){var t=e.callbackId;r=Yf[t],delete Yf[t],r&&r(e.res)}))},onAppRoute:Oc,onAppRouteInit:Ic,offAppRoute:Pc,onAppShow:os("onAppShow").onMethod,onAppEnterForeground:function(){return Zf.internalOnMethod},emitIsloatedAppShow:function(e){!function(e){os("onAppShow").emitGlobal(e)}(e)},onAppHide:Hu,traceEvent:function(e){didiJsBridge.invoke({method:"traceEvent",data:rr({},e)})},onAppEnterBackground:function(){didiJsBridge.on({event:"onAppEnterBackground"},(function(){os("AppHide").emit()}))},onCallMethodFromWxs:function(e){$u("vdCallComponentMethodForWxs",e)},onPageReload:os("onPageReload").internalOnMethod,offPageReload:os("onPageReload").internalOffMethod,onPullDownRefresh:tl,offPullDownRefresh:nl,installPackageByRoute:pc,RouteTask:nc,getPackageLoadStatus:cc,setPackageLoadStatus:uc,requireByRoute:lc,traceBeginEvent:function(e,t){if(e&&t)try{var n={category:e,name:t,timeStamp:(new Date).getTime()};if(mu.length>=1){var r=mu.length-1;bu=(new Date).getTime()-mu[r].timeStamp}mu.push(n)}catch(e){}},traceEndEvent:function(){if(mu&&mu.length)try{var e=mu.pop(),t=(new Date).getTime(),n=t-e.timeStamp,r=mu[mu.length-1];gu(("pub_saga_"+e.category+"_"+e.name+"_bt").toLowerCase(),{start_time:e.timeStamp,end_time:t,take_up_time:n,take_begin_time:bu,take_before_name:r.name,take_before_category:r.category})}catch(e){}},reportNative:gu,traceCoreDotting:function(e,t){e&&fs({event:"traceServiceCoreDotting",data:{eventName:""+e,data:rr({},t)}})}}}();

var dd = __appServiceSDK__.dd;

var exparser=function(){"use strict";var e=function(e){try{return!!e()}catch(e){return!0}},t={}.toString,r=function(e){return t.call(e).slice(8,-1)},n="".split,i=e((function(){return!Object("z").propertyIsEnumerable(0)}))?function(e){return"String"==r(e)?n.call(e,""):Object(e)}:Object,o=function(e){if(null==e)throw TypeError("Can't call method on "+e);return e},a=function(e){return i(o(e))},s="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function l(e,t,r){return e(r={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&r.path)}},r.exports),r.exports}var u,c,d=function(e){return e&&e.Math==Math&&e},f=d("object"==typeof globalThis&&globalThis)||d("object"==typeof window&&window)||d("object"==typeof self&&self)||d("object"==typeof s&&s)||function(){return this}()||Function("return this")(),_=function(e,t){try{Object.defineProperty(f,e,{value:t,configurable:!0,writable:!0})}catch(r){f[e]=t}return t},p="__core-js_shared__",h=f[p]||_(p,{}),v=l((function(e){(e.exports=function(e,t){return h[e]||(h[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),g=function(e){return Object(o(e))},m={}.hasOwnProperty,y=Object.hasOwn||function(e,t){return m.call(g(e),t)},b=0,E=Math.random(),w=function(e){return"Symbol("+String(void 0===e?"":e)+")_"+(++b+E).toString(36)},O=function(e){return"function"==typeof e?e:void 0},A=function(e,t){return arguments.length<2?O(f[e]):f[e]&&f[e][t]},C=A("navigator","userAgent")||"",S=f.process,T=f.Deno,N=S&&S.versions||T&&T.version,x=N&&N.v8;x?c=(u=x.split("."))[0]<4?1:u[0]+u[1]:C&&(!(u=C.match(/Edge\/(\d+)/))||u[1]>=74)&&(u=C.match(/Chrome\/(\d+)/))&&(c=u[1]);var I,R=c&&+c,L=!!Object.getOwnPropertySymbols&&!e((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&R&&R<41})),M=L&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,k=v("wks"),P=f.Symbol,j=M?P:P&&P.withoutSetter||w,D=function(e){return y(k,e)&&(L||"string"==typeof k[e])||(L&&y(P,e)?k[e]=P[e]:k[e]=j("Symbol."+e)),k[e]},B=function(e){return"object"==typeof e?null!==e:"function"==typeof e},F=function(e){if(!B(e))throw TypeError(String(e)+" is not an object");return e},U=!e((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),G=f.document,H=B(G)&&B(G.createElement),V=function(e){return H?G.createElement(e):{}},z=!U&&!e((function(){return 7!=Object.defineProperty(V("div"),"a",{get:function(){return 7}}).a})),$=M?function(e){return"symbol"==typeof e}:function(e){var t=A("Symbol");return"function"==typeof t&&Object(e)instanceof t},Y=D("toPrimitive"),W=function(e,t){if(!B(e)||$(e))return e;var r,n=e[Y];if(void 0!==n){if(void 0===t&&(t="default"),r=n.call(e,t),!B(r)||$(r))return r;throw TypeError("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var r,n;if("string"===t&&"function"==typeof(r=e.toString)&&!B(n=r.call(e)))return n;if("function"==typeof(r=e.valueOf)&&!B(n=r.call(e)))return n;if("string"!==t&&"function"==typeof(r=e.toString)&&!B(n=r.call(e)))return n;throw TypeError("Can't convert object to primitive value")}(e,t)},Z=function(e){var t=W(e,"string");return $(t)?t:String(t)},J=Object.defineProperty,q={f:U?J:function(e,t,r){if(F(e),t=Z(t),F(r),z)try{return J(e,t,r)}catch(e){}if("get"in r||"set"in r)throw TypeError("Accessors not supported");return"value"in r&&(e[t]=r.value),e}},K=Math.ceil,X=Math.floor,Q=function(e){return isNaN(e=+e)?0:(e>0?X:K)(e)},ee=Math.min,te=function(e){return e>0?ee(Q(e),9007199254740991):0},re=Math.max,ne=Math.min,ie=function(e,t){var r=Q(e);return r<0?re(r+t,0):ne(r,t)},oe=function(e){return function(t,r,n){var i,o=a(t),s=te(o.length),l=ie(n,s);if(e&&r!=r){for(;s>l;)if((i=o[l++])!=i)return!0}else for(;s>l;l++)if((e||l in o)&&o[l]===r)return e||l||0;return!e&&-1}},ae={includes:oe(!0),indexOf:oe(!1)},se={},le=ae.indexOf,ue=function(e,t){var r,n=a(e),i=0,o=[];for(r in n)!y(se,r)&&y(n,r)&&o.push(r);for(;t.length>i;)y(n,r=t[i++])&&(~le(o,r)||o.push(r));return o},ce=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],de=Object.keys||function(e){return ue(e,ce)},fe=U?Object.defineProperties:function(e,t){F(e);for(var r,n=de(t),i=n.length,o=0;i>o;)q.f(e,r=n[o++],t[r]);return e},_e=A("document","documentElement"),pe=v("keys"),he=function(e){return pe[e]||(pe[e]=w(e))},ve=he("IE_PROTO"),ge=function(){},me=function(e){return"<script>"+e+"</"+"script>"},ye=function(e){e.write(me("")),e.close();var t=e.parentWindow.Object;return e=null,t},be=function(){try{I=new ActiveXObject("htmlfile")}catch(e){}var e,t;be="undefined"!=typeof document?document.domain&&I?ye(I):((t=V("iframe")).style.display="none",_e.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(me("document.F=Object")),e.close(),e.F):ye(I);for(var r=ce.length;r--;)delete be.prototype[ce[r]];return be()};se[ve]=!0;var Ee=Object.create||function(e,t){var r;return null!==e?(ge.prototype=F(e),r=new ge,ge.prototype=null,r[ve]=e):r=be(),void 0===t?r:fe(r,t)},we=D("unscopables"),Oe=Array.prototype;null==Oe[we]&&q.f(Oe,we,{configurable:!0,value:Ee(null)});var Ae=function(e){Oe[we][e]=!0},Ce={},Se=Function.toString;"function"!=typeof h.inspectSource&&(h.inspectSource=function(e){return Se.call(e)});var Te,Ne,xe,Ie=h.inspectSource,Re=f.WeakMap,Le="function"==typeof Re&&/native code/.test(Ie(Re)),Me=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},ke=U?function(e,t,r){return q.f(e,t,Me(1,r))}:function(e,t,r){return e[t]=r,e},Pe="Object already initialized",je=f.WeakMap;if(Le||h.state){var De=h.state||(h.state=new je),Be=De.get,Fe=De.has,Ue=De.set;Te=function(e,t){if(Fe.call(De,e))throw new TypeError(Pe);return t.facade=e,Ue.call(De,e,t),t},Ne=function(e){return Be.call(De,e)||{}},xe=function(e){return Fe.call(De,e)}}else{var Ge=he("state");se[Ge]=!0,Te=function(e,t){if(y(e,Ge))throw new TypeError(Pe);return t.facade=e,ke(e,Ge,t),t},Ne=function(e){return y(e,Ge)?e[Ge]:{}},xe=function(e){return y(e,Ge)}}var He,Ve,ze,$e={set:Te,get:Ne,has:xe,enforce:function(e){return xe(e)?Ne(e):Te(e,{})},getterFor:function(e){return function(t){var r;if(!B(t)||(r=Ne(t)).type!==e)throw TypeError("Incompatible receiver, "+e+" required");return r}}},Ye={}.propertyIsEnumerable,We=Object.getOwnPropertyDescriptor,Ze={f:We&&!Ye.call({1:2},1)?function(e){var t=We(this,e);return!!t&&t.enumerable}:Ye},Je=Object.getOwnPropertyDescriptor,qe={f:U?Je:function(e,t){if(e=a(e),t=Z(t),z)try{return Je(e,t)}catch(e){}if(y(e,t))return Me(!Ze.f.call(e,t),e[t])}},Ke=l((function(e){var t=$e.get,r=$e.enforce,n=String(String).split("String");(e.exports=function(e,t,i,o){var a,s=!!o&&!!o.unsafe,l=!!o&&!!o.enumerable,u=!!o&&!!o.noTargetGet;"function"==typeof i&&("string"!=typeof t||y(i,"name")||ke(i,"name",t),(a=r(i)).source||(a.source=n.join("string"==typeof t?t:""))),e!==f?(s?!u&&e[t]&&(l=!0):delete e[t],l?e[t]=i:ke(e,t,i)):l?e[t]=i:_(t,i)})(Function.prototype,"toString",(function(){return"function"==typeof this&&t(this).source||Ie(this)}))})),Xe=ce.concat("length","prototype"),Qe={f:Object.getOwnPropertyNames||function(e){return ue(e,Xe)}},et={f:Object.getOwnPropertySymbols},tt=A("Reflect","ownKeys")||function(e){var t=Qe.f(F(e)),r=et.f;return r?t.concat(r(e)):t},rt=function(e,t){for(var r=tt(t),n=q.f,i=qe.f,o=0;o<r.length;o++){var a=r[o];y(e,a)||n(e,a,i(t,a))}},nt=/#|\.prototype\./,it=function(t,r){var n=at[ot(t)];return n==lt||n!=st&&("function"==typeof r?e(r):!!r)},ot=it.normalize=function(e){return String(e).replace(nt,".").toLowerCase()},at=it.data={},st=it.NATIVE="N",lt=it.POLYFILL="P",ut=it,ct=qe.f,dt=function(e,t){var r,n,i,o,a,s=e.target,l=e.global,u=e.stat;if(r=l?f:u?f[s]||_(s,{}):(f[s]||{}).prototype)for(n in t){if(o=t[n],i=e.noTargetGet?(a=ct(r,n))&&a.value:r[n],!ut(l?n:s+(u?".":"#")+n,e.forced)&&void 0!==i){if(typeof o==typeof i)continue;rt(o,i)}(e.sham||i&&i.sham)&&ke(o,"sham",!0),Ke(r,n,o,e)}},ft=!e((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),_t=he("IE_PROTO"),pt=Object.prototype,ht=ft?Object.getPrototypeOf:function(e){return e=g(e),y(e,_t)?e[_t]:"function"==typeof e.constructor&&e instanceof e.constructor?e.constructor.prototype:e instanceof Object?pt:null},vt=D("iterator"),gt=!1;[].keys&&("next"in(ze=[].keys())?(Ve=ht(ht(ze)))!==Object.prototype&&(He=Ve):gt=!0),(null==He||e((function(){var e={};return He[vt].call(e)!==e})))&&(He={}),y(He,vt)||ke(He,vt,(function(){return this}));var mt={IteratorPrototype:He,BUGGY_SAFARI_ITERATORS:gt},yt=q.f,bt=D("toStringTag"),Et=function(e,t,r){e&&!y(e=r?e:e.prototype,bt)&&yt(e,bt,{configurable:!0,value:t})},wt=mt.IteratorPrototype,Ot=function(){return this},At=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,r={};try{(e=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(r,[]),t=r instanceof Array}catch(e){}return function(r,n){return F(r),function(e){if(!B(e)&&null!==e)throw TypeError("Can't set "+String(e)+" as a prototype")}(n),t?e.call(r,n):r.__proto__=n,r}}():void 0),Ct=mt.IteratorPrototype,St=mt.BUGGY_SAFARI_ITERATORS,Tt=D("iterator"),Nt="keys",xt="values",It="entries",Rt=function(){return this},Lt=function(e,t,r,n,i,o,a){!function(e,t,r){var n=t+" Iterator";e.prototype=Ee(wt,{next:Me(1,r)}),Et(e,n,!1),Ce[n]=Ot}(r,t,n);var s,l,u,c=function(e){if(e===i&&h)return h;if(!St&&e in _)return _[e];switch(e){case Nt:case xt:case It:return function(){return new r(this,e)}}return function(){return new r(this)}},d=t+" Iterator",f=!1,_=e.prototype,p=_[Tt]||_["@@iterator"]||i&&_[i],h=!St&&p||c(i),v="Array"==t&&_.entries||p;if(v&&(s=ht(v.call(new e)),Ct!==Object.prototype&&s.next&&(ht(s)!==Ct&&(At?At(s,Ct):"function"!=typeof s[Tt]&&ke(s,Tt,Rt)),Et(s,d,!0))),i==xt&&p&&p.name!==xt&&(f=!0,h=function(){return p.call(this)}),_[Tt]!==h&&ke(_,Tt,h),Ce[t]=h,i)if(l={values:c(xt),keys:o?h:c(Nt),entries:c(It)},a)for(u in l)(St||f||!(u in _))&&Ke(_,u,l[u]);else dt({target:t,proto:!0,forced:St||f},l);return l},Mt="Array Iterator",kt=$e.set,Pt=$e.getterFor(Mt),jt=Lt(Array,"Array",(function(e,t){kt(this,{type:Mt,target:a(e),index:0,kind:t})}),(function(){var e=Pt(this),t=e.target,r=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==r?{value:n,done:!1}:"values"==r?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values");Ce.Arguments=Ce.Array,Ae("keys"),Ae("values"),Ae("entries");var Dt="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,Bt=function(e,t,r){for(var n in t)Ke(e,n,t[n],r);return e},Ft=function(e,t,r){if(!(e instanceof t))throw TypeError("Incorrect "+(r?r+" ":"")+"invocation");return e},Ut=function(e){if(void 0===e)return 0;var t=Q(e),r=te(t);if(t!==r)throw RangeError("Wrong length or index");return r},Gt=Math.abs,Ht=Math.pow,Vt=Math.floor,zt=Math.log,$t=Math.LN2,Yt=function(e,t,r){var n,i,o,a=new Array(r),s=8*r-t-1,l=(1<<s)-1,u=l>>1,c=23===t?Ht(2,-24)-Ht(2,-77):0,d=e<0||0===e&&1/e<0?1:0,f=0;for((e=Gt(e))!=e||e===1/0?(i=e!=e?1:0,n=l):(n=Vt(zt(e)/$t),e*(o=Ht(2,-n))<1&&(n--,o*=2),(e+=n+u>=1?c/o:c*Ht(2,1-u))*o>=2&&(n++,o/=2),n+u>=l?(i=0,n=l):n+u>=1?(i=(e*o-1)*Ht(2,t),n+=u):(i=e*Ht(2,u-1)*Ht(2,t),n=0));t>=8;a[f++]=255&i,i/=256,t-=8);for(n=n<<t|i,s+=t;s>0;a[f++]=255&n,n/=256,s-=8);return a[--f]|=128*d,a},Wt=function(e,t){var r,n=e.length,i=8*n-t-1,o=(1<<i)-1,a=o>>1,s=i-7,l=n-1,u=e[l--],c=127&u;for(u>>=7;s>0;c=256*c+e[l],l--,s-=8);for(r=c&(1<<-s)-1,c>>=-s,s+=t;s>0;r=256*r+e[l],l--,s-=8);if(0===c)c=1-a;else{if(c===o)return r?NaN:u?-1/0:1/0;r+=Ht(2,t),c-=a}return(u?-1:1)*r*Ht(2,c-t)},Zt=function(e){for(var t=g(this),r=te(t.length),n=arguments.length,i=ie(n>1?arguments[1]:void 0,r),o=n>2?arguments[2]:void 0,a=void 0===o?r:ie(o,r);a>i;)t[i++]=e;return t},Jt=Qe.f,qt=q.f,Kt=$e.get,Xt=$e.set,Qt="ArrayBuffer",er="DataView",tr="Wrong index",rr=f.ArrayBuffer,nr=rr,ir=f.DataView,or=ir&&ir.prototype,ar=Object.prototype,sr=f.RangeError,lr=Yt,ur=Wt,cr=function(e){return[255&e]},dr=function(e){return[255&e,e>>8&255]},fr=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},_r=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},pr=function(e){return lr(e,23,4)},hr=function(e){return lr(e,52,8)},vr=function(e,t){qt(e.prototype,t,{get:function(){return Kt(this)[t]}})},gr=function(e,t,r,n){var i=Ut(r),o=Kt(e);if(i+t>o.byteLength)throw sr(tr);var a=Kt(o.buffer).bytes,s=i+o.byteOffset,l=a.slice(s,s+t);return n?l:l.reverse()},mr=function(e,t,r,n,i,o){var a=Ut(r),s=Kt(e);if(a+t>s.byteLength)throw sr(tr);for(var l=Kt(s.buffer).bytes,u=a+s.byteOffset,c=n(+i),d=0;d<t;d++)l[u+d]=c[o?d:t-d-1]};if(Dt){if(!e((function(){rr(1)}))||!e((function(){new rr(-1)}))||e((function(){return new rr,new rr(1.5),new rr(NaN),rr.name!=Qt}))){for(var yr,br=(nr=function(e){return Ft(this,nr),new rr(Ut(e))}).prototype=rr.prototype,Er=Jt(rr),wr=0;Er.length>wr;)(yr=Er[wr++])in nr||ke(nr,yr,rr[yr]);br.constructor=nr}At&&ht(or)!==ar&&At(or,ar);var Or=new ir(new nr(2)),Ar=or.setInt8;Or.setInt8(0,2147483648),Or.setInt8(1,2147483649),!Or.getInt8(0)&&Or.getInt8(1)||Bt(or,{setInt8:function(e,t){Ar.call(this,e,t<<24>>24)},setUint8:function(e,t){Ar.call(this,e,t<<24>>24)}},{unsafe:!0})}else nr=function(e){Ft(this,nr,Qt);var t=Ut(e);Xt(this,{bytes:Zt.call(new Array(t),0),byteLength:t}),U||(this.byteLength=t)},ir=function(e,t,r){Ft(this,ir,er),Ft(e,nr,er);var n=Kt(e).byteLength,i=Q(t);if(i<0||i>n)throw sr("Wrong offset");if(i+(r=void 0===r?n-i:te(r))>n)throw sr("Wrong length");Xt(this,{buffer:e,byteLength:r,byteOffset:i}),U||(this.buffer=e,this.byteLength=r,this.byteOffset=i)},U&&(vr(nr,"byteLength"),vr(ir,"buffer"),vr(ir,"byteLength"),vr(ir,"byteOffset")),Bt(ir.prototype,{getInt8:function(e){return gr(this,1,e)[0]<<24>>24},getUint8:function(e){return gr(this,1,e)[0]},getInt16:function(e){var t=gr(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=gr(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return _r(gr(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return _r(gr(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return ur(gr(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return ur(gr(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){mr(this,1,e,cr,t)},setUint8:function(e,t){mr(this,1,e,cr,t)},setInt16:function(e,t){mr(this,2,e,dr,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){mr(this,2,e,dr,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){mr(this,4,e,fr,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){mr(this,4,e,fr,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){mr(this,4,e,pr,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){mr(this,8,e,hr,t,arguments.length>2?arguments[2]:void 0)}});Et(nr,Qt),Et(ir,er);var Cr={ArrayBuffer:nr,DataView:ir},Sr=function(e){if("function"!=typeof e)throw TypeError(String(e)+" is not a function");return e},Tr=D("species"),Nr=function(e,t){var r,n=F(e).constructor;return void 0===n||null==(r=F(n)[Tr])?t:Sr(r)},xr=Cr.ArrayBuffer,Ir=Cr.DataView,Rr=xr.prototype.slice,Lr=e((function(){return!new xr(2).slice(1,void 0).byteLength}));dt({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:Lr},{slice:function(e,t){if(void 0!==Rr&&void 0===t)return Rr.call(F(this),e);for(var r=F(this).byteLength,n=ie(e,r),i=ie(void 0===t?r:t,r),o=new(Nr(this,xr))(te(i-n)),a=new Ir(this),s=new Ir(o),l=0;n<i;)s.setUint8(l++,a.getUint8(n++));return o}});var Mr={};Mr[D("toStringTag")]="z";var kr="[object z]"===String(Mr),Pr=D("toStringTag"),jr="Arguments"==r(function(){return arguments}()),Dr=kr?r:function(e){var t,n,i;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Object(e),Pr))?n:jr?r(t):"Object"==(i=r(t))&&"function"==typeof t.callee?"Arguments":i},Br=kr?{}.toString:function(){return"[object "+Dr(this)+"]"};kr||Ke(Object.prototype,"toString",Br,{unsafe:!0});var Fr=D("iterator"),Ur=!1;try{var Gr=0,Hr={next:function(){return{done:!!Gr++}},return:function(){Ur=!0}};Hr[Fr]=function(){return this},Array.from(Hr,(function(){throw 2}))}catch(e){}var Vr,zr,$r,Yr=function(e,t){if(!t&&!Ur)return!1;var r=!1;try{var n={};n[Fr]=function(){return{next:function(){return{done:r=!0}}}},e(n)}catch(e){}return r},Wr=q.f,Zr=f.Int8Array,Jr=Zr&&Zr.prototype,qr=f.Uint8ClampedArray,Kr=qr&&qr.prototype,Xr=Zr&&ht(Zr),Qr=Jr&&ht(Jr),en=Object.prototype,tn=en.isPrototypeOf,rn=D("toStringTag"),nn=w("TYPED_ARRAY_TAG"),on=w("TYPED_ARRAY_CONSTRUCTOR"),an=Dt&&!!At&&"Opera"!==Dr(f.opera),sn=!1,ln={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},un={BigInt64Array:8,BigUint64Array:8},cn=function(e){if(!B(e))return!1;var t=Dr(e);return y(ln,t)||y(un,t)};for(Vr in ln)($r=(zr=f[Vr])&&zr.prototype)?ke($r,on,zr):an=!1;for(Vr in un)($r=(zr=f[Vr])&&zr.prototype)&&ke($r,on,zr);if((!an||"function"!=typeof Xr||Xr===Function.prototype)&&(Xr=function(){throw TypeError("Incorrect invocation")},an))for(Vr in ln)f[Vr]&&At(f[Vr],Xr);if((!an||!Qr||Qr===en)&&(Qr=Xr.prototype,an))for(Vr in ln)f[Vr]&&At(f[Vr].prototype,Qr);if(an&&ht(Kr)!==Qr&&At(Kr,Qr),U&&!y(Qr,rn))for(Vr in sn=!0,Wr(Qr,rn,{get:function(){return B(this)?this[nn]:void 0}}),ln)f[Vr]&&ke(f[Vr],nn,Vr);var dn={NATIVE_ARRAY_BUFFER_VIEWS:an,TYPED_ARRAY_CONSTRUCTOR:on,TYPED_ARRAY_TAG:sn&&nn,aTypedArray:function(e){if(cn(e))return e;throw TypeError("Target is not a typed array")},aTypedArrayConstructor:function(e){if(At&&!tn.call(Xr,e))throw TypeError("Target is not a typed array constructor");return e},exportTypedArrayMethod:function(e,t,r){if(U){if(r)for(var n in ln){var i=f[n];if(i&&y(i.prototype,e))try{delete i.prototype[e]}catch(e){}}Qr[e]&&!r||Ke(Qr,e,r?t:an&&Jr[e]||t)}},exportTypedArrayStaticMethod:function(e,t,r){var n,i;if(U){if(At){if(r)for(n in ln)if((i=f[n])&&y(i,e))try{delete i[e]}catch(e){}if(Xr[e]&&!r)return;try{return Ke(Xr,e,r?t:an&&Xr[e]||t)}catch(e){}}for(n in ln)!(i=f[n])||i[e]&&!r||Ke(i,e,t)}},isView:function(e){if(!B(e))return!1;var t=Dr(e);return"DataView"===t||y(ln,t)||y(un,t)},isTypedArray:cn,TypedArray:Xr,TypedArrayPrototype:Qr},fn=dn.NATIVE_ARRAY_BUFFER_VIEWS,_n=f.ArrayBuffer,pn=f.Int8Array,hn=!fn||!e((function(){pn(1)}))||!e((function(){new pn(-1)}))||!Yr((function(e){new pn,new pn(null),new pn(1.5),new pn(e)}),!0)||e((function(){return 1!==new pn(new _n(2),1,void 0).length})),vn=Math.floor,gn=function(e,t){var r=function(e){var t=Q(e);if(t<0)throw RangeError("The argument can't be less than 0");return t}(e);if(r%t)throw RangeError("Wrong offset");return r},mn=D("iterator"),yn=function(e){if(null!=e)return e[mn]||e["@@iterator"]||Ce[Dr(e)]},bn=D("iterator"),En=Array.prototype,wn=function(e){return void 0!==e&&(Ce.Array===e||En[bn]===e)},On=function(e,t,r){if(Sr(e),void 0===t)return e;switch(r){case 0:return function(){return e.call(t)};case 1:return function(r){return e.call(t,r)};case 2:return function(r,n){return e.call(t,r,n)};case 3:return function(r,n,i){return e.call(t,r,n,i)}}return function(){return e.apply(t,arguments)}},An=dn.aTypedArrayConstructor,Cn=function(e){var t,r,n,i,o,a,s=g(e),l=arguments.length,u=l>1?arguments[1]:void 0,c=void 0!==u,d=yn(s);if(null!=d&&!wn(d))for(a=(o=d.call(s)).next,s=[];!(i=a.call(o)).done;)s.push(i.value);for(c&&l>2&&(u=On(u,arguments[2],2)),r=te(s.length),n=new(An(this))(r),t=0;r>t;t++)n[t]=c?u(s[t],t):s[t];return n},Sn=Array.isArray||function(e){return"Array"==r(e)},Tn=D("species"),Nn=function(e,t){return new(function(e){var t;return Sn(e)&&("function"!=typeof(t=e.constructor)||t!==Array&&!Sn(t.prototype)?B(t)&&null===(t=t[Tn])&&(t=void 0):t=void 0),void 0===t?Array:t}(e))(0===t?0:t)},xn=[].push,In=function(e){var t=1==e,r=2==e,n=3==e,o=4==e,a=6==e,s=7==e,l=5==e||a;return function(u,c,d,f){for(var _,p,h=g(u),v=i(h),m=On(c,d,3),y=te(v.length),b=0,E=f||Nn,w=t?E(u,y):r||s?E(u,0):void 0;y>b;b++)if((l||b in v)&&(p=m(_=v[b],b,h),e))if(t)w[b]=p;else if(p)switch(e){case 3:return!0;case 5:return _;case 6:return b;case 2:xn.call(w,_)}else switch(e){case 4:return!1;case 7:xn.call(w,_)}return a?-1:n||o?o:w}},Rn={forEach:In(0),map:In(1),filter:In(2),some:In(3),every:In(4),find:In(5),findIndex:In(6),filterReject:In(7)},Ln=D("species"),Mn=function(e){var t=A(e),r=q.f;U&&t&&!t[Ln]&&r(t,Ln,{configurable:!0,get:function(){return this}})},kn=function(e,t,r){var n,i;return At&&"function"==typeof(n=t.constructor)&&n!==r&&B(i=n.prototype)&&i!==r.prototype&&At(e,i),e},Pn=l((function(e){var t=Qe.f,r=Rn.forEach,n=$e.get,i=$e.set,o=q.f,a=qe.f,s=Math.round,l=f.RangeError,u=Cr.ArrayBuffer,c=Cr.DataView,d=dn.NATIVE_ARRAY_BUFFER_VIEWS,_=dn.TYPED_ARRAY_CONSTRUCTOR,p=dn.TYPED_ARRAY_TAG,h=dn.TypedArray,v=dn.TypedArrayPrototype,g=dn.aTypedArrayConstructor,m=dn.isTypedArray,b="BYTES_PER_ELEMENT",E="Wrong length",w=function(e,t){for(var r=0,n=t.length,i=new(g(e))(n);n>r;)i[r]=t[r++];return i},O=function(e,t){o(e,t,{get:function(){return n(this)[t]}})},A=function(e){var t;return e instanceof u||"ArrayBuffer"==(t=Dr(e))||"SharedArrayBuffer"==t},C=function(e,t){return m(e)&&!$(t)&&t in e&&(!B(r=+t)&&isFinite(r)&&vn(r)===r)&&t>=0;var r},S=function(e,t){return t=Z(t),C(e,t)?Me(2,e[t]):a(e,t)},T=function(e,t,r){return t=Z(t),!(C(e,t)&&B(r)&&y(r,"value"))||y(r,"get")||y(r,"set")||r.configurable||y(r,"writable")&&!r.writable||y(r,"enumerable")&&!r.enumerable?o(e,t,r):(e[t]=r.value,e)};U?(d||(qe.f=S,q.f=T,O(v,"buffer"),O(v,"byteOffset"),O(v,"byteLength"),O(v,"length")),dt({target:"Object",stat:!0,forced:!d},{getOwnPropertyDescriptor:S,defineProperty:T}),e.exports=function(e,a,g){var y=e.match(/\d+$/)[0]/8,O=e+(g?"Clamped":"")+"Array",C="get"+e,S="set"+e,T=f[O],N=T,x=N&&N.prototype,I={},R=function(e,t){o(e,t,{get:function(){return function(e,t){var r=n(e);return r.view[C](t*y+r.byteOffset,!0)}(this,t)},set:function(e){return function(e,t,r){var i=n(e);g&&(r=(r=s(r))<0?0:r>255?255:255&r),i.view[S](t*y+i.byteOffset,r,!0)}(this,t,e)},enumerable:!0})};d?hn&&(N=a((function(e,t,r,n){return Ft(e,N,O),kn(B(t)?A(t)?void 0!==n?new T(t,gn(r,y),n):void 0!==r?new T(t,gn(r,y)):new T(t):m(t)?w(N,t):Cn.call(N,t):new T(Ut(t)),e,N)})),At&&At(N,h),r(t(T),(function(e){e in N||ke(N,e,T[e])})),N.prototype=x):(N=a((function(e,t,r,n){Ft(e,N,O);var o,a,s,d=0,f=0;if(B(t)){if(!A(t))return m(t)?w(N,t):Cn.call(N,t);o=t,f=gn(r,y);var _=t.byteLength;if(void 0===n){if(_%y)throw l(E);if((a=_-f)<0)throw l(E)}else if((a=te(n)*y)+f>_)throw l(E);s=a/y}else s=Ut(t),o=new u(a=s*y);for(i(e,{buffer:o,byteOffset:f,byteLength:a,length:s,view:new c(o)});d<s;)R(e,d++)})),At&&At(N,h),x=N.prototype=Ee(v)),x.constructor!==N&&ke(x,"constructor",N),ke(x,_,N),p&&ke(x,p,O),I[O]=N,dt({global:!0,forced:N!=T,sham:!d},I),b in N||ke(N,b,y),b in x||ke(x,b,y),Mn(O)}):e.exports=function(){}}));Pn("Uint16",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var jn=Math.min,Dn=[].copyWithin||function(e,t){var r=g(this),n=te(r.length),i=ie(e,n),o=ie(t,n),a=arguments.length>2?arguments[2]:void 0,s=jn((void 0===a?n:ie(a,n))-o,n-i),l=1;for(o<i&&i<o+s&&(l=-1,o+=s-1,i+=s-1);s-- >0;)o in r?r[i]=r[o]:delete r[i],i+=l,o+=l;return r},Bn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("copyWithin",(function(e,t){return Dn.call(Bn(this),e,t,arguments.length>2?arguments[2]:void 0)}));var Fn=Rn.every,Un=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("every",(function(e){return Fn(Un(this),e,arguments.length>1?arguments[1]:void 0)}));var Gn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("fill",(function(e){return Zt.apply(Gn(this),arguments)}));var Hn=dn.TYPED_ARRAY_CONSTRUCTOR,Vn=dn.aTypedArrayConstructor,zn=function(e){return Vn(Nr(e,e[Hn]))},$n=function(e,t){return function(e,t){for(var r=0,n=t.length,i=new e(n);n>r;)i[r]=t[r++];return i}(zn(e),t)},Yn=Rn.filter,Wn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("filter",(function(e){var t=Yn(Wn(this),e,arguments.length>1?arguments[1]:void 0);return $n(this,t)}));var Zn=Rn.find,Jn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("find",(function(e){return Zn(Jn(this),e,arguments.length>1?arguments[1]:void 0)}));var qn=Rn.findIndex,Kn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("findIndex",(function(e){return qn(Kn(this),e,arguments.length>1?arguments[1]:void 0)}));var Xn=Rn.forEach,Qn=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("forEach",(function(e){Xn(Qn(this),e,arguments.length>1?arguments[1]:void 0)}));var ei=ae.includes,ti=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("includes",(function(e){return ei(ti(this),e,arguments.length>1?arguments[1]:void 0)}));var ri=ae.indexOf,ni=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("indexOf",(function(e){return ri(ni(this),e,arguments.length>1?arguments[1]:void 0)}));var ii=D("iterator"),oi=f.Uint8Array,ai=jt.values,si=jt.keys,li=jt.entries,ui=dn.aTypedArray,ci=dn.exportTypedArrayMethod,di=oi&&oi.prototype[ii],fi=!!di&&("values"==di.name||null==di.name),_i=function(){return ai.call(ui(this))};ci("entries",(function(){return li.call(ui(this))})),ci("keys",(function(){return si.call(ui(this))})),ci("values",_i,!fi),ci(ii,_i,!fi);var pi=dn.aTypedArray,hi=[].join;(0,dn.exportTypedArrayMethod)("join",(function(e){return hi.apply(pi(this),arguments)}));var vi=function(t,r){var n=[][t];return!!n&&e((function(){n.call(null,r||function(){throw 1},1)}))},gi=Math.min,mi=[].lastIndexOf,yi=!!mi&&1/[1].lastIndexOf(1,-0)<0,bi=vi("lastIndexOf"),Ei=yi||!bi?function(e){if(yi)return mi.apply(this,arguments)||0;var t=a(this),r=te(t.length),n=r-1;for(arguments.length>1&&(n=gi(n,Q(arguments[1]))),n<0&&(n=r+n);n>=0;n--)if(n in t&&t[n]===e)return n||0;return-1}:mi,wi=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("lastIndexOf",(function(e){return Ei.apply(wi(this),arguments)}));var Oi=Rn.map,Ai=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("map",(function(e){return Oi(Ai(this),e,arguments.length>1?arguments[1]:void 0,(function(e,t){return new(zn(e))(t)}))}));var Ci=function(e){return function(t,r,n,o){Sr(r);var a=g(t),s=i(a),l=te(a.length),u=e?l-1:0,c=e?-1:1;if(n<2)for(;;){if(u in s){o=s[u],u+=c;break}if(u+=c,e?u<0:l<=u)throw TypeError("Reduce of empty array with no initial value")}for(;e?u>=0:l>u;u+=c)u in s&&(o=r(o,s[u],u,a));return o}},Si={left:Ci(!1),right:Ci(!0)},Ti=Si.left,Ni=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("reduce",(function(e){return Ti(Ni(this),e,arguments.length,arguments.length>1?arguments[1]:void 0)}));var xi=Si.right,Ii=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("reduceRight",(function(e){return xi(Ii(this),e,arguments.length,arguments.length>1?arguments[1]:void 0)}));var Ri=dn.aTypedArray,Li=dn.exportTypedArrayMethod,Mi=Math.floor;Li("reverse",(function(){for(var e,t=this,r=Ri(t).length,n=Mi(r/2),i=0;i<n;)e=t[i],t[i++]=t[--r],t[r]=e;return t}));var ki=dn.aTypedArray,Pi=[].slice;(0,dn.exportTypedArrayMethod)("slice",(function(e,t){for(var r=Pi.call(ki(this),e,t),n=zn(this),i=0,o=r.length,a=new n(o);o>i;)a[i]=r[i++];return a}),e((function(){new Int8Array(1).slice()})));var ji=Rn.some,Di=dn.aTypedArray;(0,dn.exportTypedArrayMethod)("some",(function(e){return ji(Di(this),e,arguments.length>1?arguments[1]:void 0)}));var Bi=Math.floor,Fi=function(e,t){var r=e.length,n=Bi(r/2);return r<8?Ui(e,t):Gi(Fi(e.slice(0,n),t),Fi(e.slice(n),t),t)},Ui=function(e,t){for(var r,n,i=e.length,o=1;o<i;){for(n=o,r=e[o];n&&t(e[n-1],r)>0;)e[n]=e[--n];n!==o++&&(e[n]=r)}return e},Gi=function(e,t,r){for(var n=e.length,i=t.length,o=0,a=0,s=[];o<n||a<i;)o<n&&a<i?s.push(r(e[o],t[a])<=0?e[o++]:t[a++]):s.push(o<n?e[o++]:t[a++]);return s},Hi=Fi,Vi=C.match(/firefox\/(\d+)/i),zi=!!Vi&&+Vi[1],$i=/MSIE|Trident/.test(C),Yi=C.match(/AppleWebKit\/(\d+)\./),Wi=!!Yi&&+Yi[1],Zi=dn.aTypedArray,Ji=dn.exportTypedArrayMethod,qi=f.Uint16Array,Ki=qi&&qi.prototype.sort,Xi=!!Ki&&!e((function(){var e=new qi(2);e.sort(null),e.sort({})})),Qi=!!Ki&&!e((function(){if(R)return R<74;if(zi)return zi<67;if($i)return!0;if(Wi)return Wi<602;var e,t,r=new qi(516),n=Array(516);for(e=0;e<516;e++)t=e%4,r[e]=515-e,n[e]=e-2*t+3;for(r.sort((function(e,t){return(e/4|0)-(t/4|0)})),e=0;e<516;e++)if(r[e]!==n[e])return!0}));Ji("sort",(function(e){var t=this;if(void 0!==e&&Sr(e),Qi)return Ki.call(t,e);Zi(t);var r,n=te(t.length),i=Array(n);for(r=0;r<n;r++)i[r]=t[r];for(i=Hi(t,function(e){return function(t,r){return void 0!==e?+e(t,r)||0:r!=r?-1:t!=t?1:0===t&&0===r?1/t>0&&1/r<0?1:-1:t>r}}(e)),r=0;r<n;r++)t[r]=i[r];return t}),!Qi||Xi);var eo=f.Int8Array,to=dn.aTypedArray,ro=dn.exportTypedArrayMethod,no=[].toLocaleString,io=[].slice,oo=!!eo&&e((function(){no.call(new eo(1))}));ro("toLocaleString",(function(){return no.apply(oo?io.call(to(this)):to(this),arguments)}),e((function(){return[1,2].toLocaleString()!=new eo([1,2]).toLocaleString()}))||!e((function(){eo.prototype.toLocaleString.call([1,2])})));var ao=dn.exportTypedArrayMethod,so=f.Uint8Array,lo=so&&so.prototype||{},uo=[].toString,co=[].join;e((function(){uo.call({})}))&&(uo=function(){return co.call(this)});var fo=lo.toString!=uo;ao("toString",uo,fo);var _o=function(e,t,r){var n=Z(t);n in e?q.f(e,n,Me(0,r)):e[n]=r},po=D("species"),ho=function(t){return R>=51||!e((function(){var e=[];return(e.constructor={})[po]=function(){return{foo:1}},1!==e[t](Boolean).foo}))},vo=ho("slice"),go=D("species"),mo=[].slice,yo=Math.max;dt({target:"Array",proto:!0,forced:!vo},{slice:function(e,t){var r,n,i,o=a(this),s=te(o.length),l=ie(e,s),u=ie(void 0===t?s:t,s);if(Sn(o)&&("function"!=typeof(r=o.constructor)||r!==Array&&!Sn(r.prototype)?B(r)&&null===(r=r[go])&&(r=void 0):r=void 0,r===Array||void 0===r))return mo.call(o,l,u);for(n=new(void 0===r?Array:r)(yo(u-l,0)),i=0;l<u;l++,i++)l in o&&_o(n,i,o[l]);return n.length=i,n}}),Pn("Int32",(function(e){return function(t,r,n){return e(this,t,r,n)}}));
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */
var bo=function(e,t){return(bo=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])})(e,t)};function Eo(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=e}bo(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}function wo(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),i=0;for(t=0;t<r;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)n[i]=o[a];return n}var Oo="ArrayBuffer",Ao=Cr.ArrayBuffer,Co=f.ArrayBuffer;dt({global:!0,forced:Co!==Ao},{ArrayBuffer:Ao}),Mn(Oo),Pn("Int8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Pn("Uint8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Pn("Int16",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Pn("Uint32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Pn("Float32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Pn("Float64",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var So,To,No,xo,Io,Ro,Lo,Mo,ko,Po,jo=new ArrayBuffer(1114112);function Do(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0;r=(t=e+-8|0)+(e=-8&(i=xo[e+-4>>2]))|0;e:{t:{r:{n:{i:if(!(1&i)){if(!(3&i))break n;if(e=(i=xo[t>>2])+e|0,(0|(t=t-i|0))==xo[262246]){if(3!=(3&xo[r+4>>2]))break i;return xo[262244]=e,xo[r+4>>2]=-2&xo[r+4>>2],xo[t+4>>2]=1|e,xo[e+t>>2]=e,0}256<=i>>>0?Fo(t):(0|(n=xo[t+8>>2]))==(0|(o=xo[t+12>>2]))?(a=1048576,s=xo[262144]&Vo(i>>>3),xo[a>>2]=s):(xo[n+12>>2]=o,xo[o+8>>2]=n)}if(2&(i=xo[r+4>>2]))xo[r+4>>2]=-2&i,xo[t+4>>2]=1|e,xo[e+t>>2]=e;else{i:{if(xo[262247]!=(0|r)){if((0|r)!=xo[262246])break i;return xo[262246]=t,e=xo[262244]+e|0,xo[262244]=e,xo[t+4>>2]=1|e,xo[e+t>>2]=e,0}if(xo[262247]=t,e=xo[262245]+e|0,xo[262245]=e,xo[t+4>>2]=1|e,(0|t)==xo[262246]&&(xo[262244]=0,xo[262246]=0),(r=xo[262254])>>>0>=e>>>0)break n;if(!(e=xo[262247]))break n;o:if(!((i=xo[262245])>>>0<41))for(t=1049e3;;){if((n=xo[t>>2])+xo[t+4>>2]>>>0>e>>>0&&n>>>0<=e>>>0)break o;if(!(t=xo[t+8>>2]))break}if(n=4095,e=xo[262252]){for(t=0;t=t+1|0,e=xo[e+8>>2];);n=4095<t>>>0?t:4095}if(xo[262256]=n,i>>>0<=r>>>0)break n;return xo[262254]=-1,0}if(e=(n=-8&i)+e|0,256<=n>>>0?Fo(r):(0|(n=xo[r+12>>2]))==(0|(r=xo[r+8>>2]))?(a=1048576,s=xo[262144]&Vo(i>>>3),xo[a>>2]=s):(xo[r+12>>2]=n,xo[n+8>>2]=r),xo[t+4>>2]=1|e,xo[e+t>>2]=e,xo[262246]==(0|t)){xo[262244]=e;break n}}if(e>>>0<256)break r;if(Bo(t,e),e=xo[262256]+-1|0,!(xo[262256]=e)){if(e=xo[262252])break t;e=4095;break e}}return}return e=1048584+((r=e>>>3)<<3)|0,i=xo[262144],r=1<<(31&r),n=xo[e+8>>2],i&r||(xo[262144]=r|i,n=e),r=n,xo[e+8>>2]=t,xo[r+12>>2]=t,xo[t+12>>2]=e,xo[t+8>>2]=r,0}for(t=0;t=t+1|0,e=xo[e+8>>2];);e=4095<t>>>0?t:4095}xo[262256]=e}function Bo(e,t){var r=0,n=0,i=0,o=0;xo[e+16>>2]=0,r=xo[(i=e)+20>>2]=0,(n=t>>>8)&&(r=31,16777215<t>>>0||(r=62+((t>>>(6-(n=ko(n))&31)&1)-(n<<1)|0)|0)),i=1048848+((xo[i+28>>2]=r)<<2)|0;e:{t:{r:{n:{if((o=xo[262145])&(n=1<<(31&r))){if(n=xo[i>>2],(-8&xo[n+4>>2])!=(0|t))break n;r=n;break r}xo[262145]=n|o,xo[i>>2]=e,xo[e+24>>2]=i;break e}for(i=t<<(31==(0|r)?0:25-(r>>>1)&31);;){if(!(r=xo[(o=16+((i>>>29&4)+n|0)|0)>>2]))break t;if(i<<=1,(-8&xo[(n=r)+4>>2])==(0|t))break}}return t=xo[r+8>>2],xo[t+12>>2]=e,xo[r+8>>2]=e,xo[e+24>>2]=0,xo[e+12>>2]=r,xo[e+8>>2]=t,0}xo[o>>2]=e,xo[e+24>>2]=n}xo[e+12>>2]=e,xo[e+8>>2]=e}function Fo(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=xo[e+24>>2];e:{t:{if((0|e)==(0|(t=xo[e+12>>2]))){if(n=xo[(t=e+20|0)>>2],r=xo[(n?20:16)+e>>2])break t;t=0;break e}r=xo[e+8>>2],xo[r+12>>2]=t,xo[t+8>>2]=r;break e}for(n=n?t:e+16|0;i=n,(r=xo[(n=(t=r)+20|0)>>2])||(n=t+16|0,r=xo[t+16>>2]),r;);xo[i>>2]=0}e:if(s){r=1048848+(xo[e+28>>2]<<2)|0;t:{if((0|e)==xo[r>>2]){if(xo[r>>2]=t)break t;return o=1048580,a=xo[262145]&Vo(xo[e+28>>2]),xo[o>>2]=a,0}if(!(xo[(xo[s+16>>2]==(0|e)?16:20)+s>>2]=t))break e}xo[t+24>>2]=s,(r=xo[e+16>>2])&&(xo[t+16>>2]=r,xo[r+24>>2]=t),(e=xo[e+20>>2])&&(xo[t+20>>2]=e,xo[e+24>>2]=t)}}function Uo(e,t){return 0|(!(n=function(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0,l=0,u=0,c=0,d=0;e:{t:{r:{if(245<=e>>>0){if(4294901709<=e>>>0)break t;if(i=-8&(e=e+11|0),!(l=xo[262145]))break r;r=0-i|0,s=0,(e>>>=8)&&(s=31,16777215<i>>>0||(s=62+((i>>>(6-(e=ko(e))&31)&1)-(e<<1)|0)|0));n:{i:{if(e=xo[1048848+(s<<2)>>2]){for(o=i<<(31==(0|s)?0:25-(s>>>1)&31);;){if(!((a=-8&xo[e+4>>2])>>>0<i>>>0||(a=a-i|0)>>>0>=r>>>0||(n=e,r=a))){r=0;break i}if(a=xo[e+20>>2],e=xo[16+((o>>>29&4)+e|0)>>2],t=a&&(0|a)!=(0|e)?a:t,o<<=1,!e)break}if(t){e=t;break i}if(n)break n}if(!(e=((n=0)-(e=2<<(31&s))|e)&l))break r;if(!(e=xo[1048848+(Ho(e&0-e)<<2)>>2]))break r}for(;n=(a=(o=(t=-8&xo[e+4>>2])-i|0)>>>0<r>>>0&i>>>0<=t>>>0)?e:n,r=a?o:r,e=(t=xo[e+16>>2])||xo[e+20>>2];);if(!n)break r}if(r>>>0>=(e=xo[262244])-i>>>0&&i>>>0<=e>>>0)break r;Fo(n);n:if(16<=r>>>0){if(xo[n+4>>2]=3|i,xo[4+(t=n+i|0)>>2]=1|r,256<=(xo[t+r>>2]=r)>>>0){Bo(t,r);break n}e=1048584+((r>>>=3)<<3)|0,o=xo[262144],r=1<<(31&r),s=xo[e+8>>2],o&r||(xo[262144]=r|o,s=e),r=s,xo[e+8>>2]=t,xo[r+12>>2]=t,xo[t+12>>2]=e,xo[t+8>>2]=r}else e=r+i|0,xo[n+4>>2]=3|e,xo[4+(e=e+n|0)>>2]=1|xo[e+4>>2];return n+8|0}n:{i:{if(!(3&(e=(t=xo[262144])>>>(n=31&(r=(i=e>>>0<11?16:e+11&-8)>>>3))))){if(i>>>0<=Lo[262244])break r;if(e)break i;if(!(e=xo[262145]))break r;for(t=xo[1048848+(Ho(e&0-e)<<2)>>2],r=(-8&xo[t+4>>2])-i|0,o=t;;){if(!(e=xo[t+16>>2])&&!(e=xo[t+20>>2]))break n;r=(t=(n=(-8&xo[e+4>>2])-i|0)>>>0<r>>>0)?n:r,o=t?e:o,t=e}}r=(e=xo[1048592+(a=(n=r+(1&(-1^e))|0)<<3)>>2])+8|0,(0|(o=xo[e+8>>2]))==(0|(a=a+1048584|0))?(d=Vo(n)&t,xo[(c=1048576)>>2]=d):(xo[o+12>>2]=a,xo[a+8>>2]=o),t=n<<3,xo[e+4>>2]=3|t,xo[4+(e=e+t|0)>>2]=1|xo[e+4>>2];break t}return n=Ho(0-(e=(r=e<<n)&(0-(e=2<<n)|e))&e),e=xo[1048592+(o=n<<3)>>2],(0|(r=xo[e+8>>2]))==(0|(o=o+1048584|0))?(d=Vo(n)&t,xo[(c=1048576)>>2]=d):(xo[r+12>>2]=o,xo[o+8>>2]=r),o=e+8|0,xo[e+4>>2]=3|i,r=(t=n<<3)-i|0,xo[4+(a=e+i|0)>>2]=1|r,xo[e+t>>2]=r,(e=xo[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=xo[262246],i=xo[262144],n=1<<(31&n),s=xo[e+8>>2],i&n||(xo[262144]=n|i,s=e),n=s,xo[e+8>>2]=t,xo[n+12>>2]=t,xo[t+12>>2]=e,xo[t+8>>2]=n),xo[262246]=a,xo[262244]=r,o}return Fo(o),16<=r>>>0?(xo[o+4>>2]=3|i,xo[4+(a=i+o|0)>>2]=1|r,xo[r+a>>2]=r,(e=xo[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=xo[262246],i=xo[262144],n=1<<(31&n),s=xo[e+8>>2],i&n||(xo[262144]=n|i,s=e),n=s,xo[e+8>>2]=t,xo[n+12>>2]=t,xo[t+12>>2]=e,xo[t+8>>2]=n),xo[262246]=a,xo[262244]=r):(e=r+i|0,xo[o+4>>2]=3|e,xo[4+(e=e+o|0)>>2]=1|xo[e+4>>2]),o+8|0}r:{n:{i:{o:{if((t=xo[262244])>>>0<i>>>0){if((e=xo[262245])>>>0>i>>>0)break e;if(-1==((r=0)|(t=zo((e=i+65583|0)>>>16))))break t;if(!(n=t<<16))break t;if(e=(o=-65536&e)+xo[262248]|0,xo[262248]=e,t=xo[262249],xo[262249]=e>>>0<t>>>0?t:e,!(r=xo[262247]))break o;for(e=1049e3;;){if((0|n)==((t=xo[e>>2])+(a=xo[e+4>>2])|0))break i;if(!(e=xo[e+8>>2]))break}break n}return e=xo[262246],(n=t-i|0)>>>0<=15?(xo[262246]=0,xo[262244]=0,xo[e+4>>2]=3|t,i=4+(t=e+t|0)|0,r=1|xo[t+4>>2]):(xo[262244]=n,r=e+i|0,xo[262246]=r,xo[r+4>>2]=1|n,xo[e+t>>2]=n,r=3|i,i=e+4|0),xo[i>>2]=r,e+8|0}for((e=xo[262255])>>>0<=n>>>0&&e||(xo[262255]=n),e=0,xo[262256]=4095,xo[262251]=o,xo[262250]=n,xo[262253]=0;t=e+1048584|0,xo[e+1048592>>2]=t,xo[e+1048596>>2]=t,256!=(0|(e=e+8|0)););xo[262247]=n,e=o+-40|0,xo[262245]=e,xo[n+4>>2]=1|e,xo[4+(e+n|0)>>2]=40,xo[262254]=2097152;break r}if(!(xo[e+12>>2]|n>>>0<=r>>>0|r>>>0<t>>>0)){xo[e+4>>2]=o+a,t=(e=xo[262247])+15&-8,xo[262247]=t+-8,r=8+((n=o+xo[262245]|0)+(e-t|0)|0)|0,xo[262245]=r,xo[t+-4>>2]=1|r,xo[4+(e+n|0)>>2]=40,xo[262254]=2097152;break r}}e=xo[262255],xo[262255]=e>>>0<n>>>0?e:n,t=n+o|0,e=1049e3;n:{for(;(0|t)!=xo[e>>2];)if(!(e=xo[e+8>>2]))break n;if(!xo[e+12>>2]){xo[e>>2]=n,xo[e+4>>2]=o+xo[e+4>>2],xo[n+4>>2]=3|i,o=n+i|0,i=(t-n|0)-i|0;i:{o:{if((0|t)!=xo[262247]){if(xo[262246]==(0|t))break o;if(1==(3&(e=xo[t+4>>2]))&&(256<=(r=-8&e)>>>0?Fo(t):(0|(a=xo[t+12>>2]))==(0|(s=xo[t+8>>2]))?(c=1048576,d=xo[262144]&Vo(e>>>3),xo[c>>2]=d):(xo[s+12>>2]=a,xo[a+8>>2]=s),i=r+i|0,t=t+r|0),xo[t+4>>2]=-2&xo[t+4>>2],xo[o+4>>2]=1|i,256<=(xo[i+o>>2]=i)>>>0){Bo(o,i);break i}e=1048584+((t=i>>>3)<<3)|0,r=xo[262144],t=1<<(31&t),s=xo[e+8>>2],r&t||(xo[262144]=t|r,s=e),r=s,xo[e+8>>2]=o,xo[r+12>>2]=o,xo[o+12>>2]=e,xo[o+8>>2]=r;break i}xo[262247]=o,e=xo[262245]+i|0,xo[262245]=e,xo[o+4>>2]=1|e;break i}xo[262246]=o,e=xo[262244]+i|0,xo[262244]=e,xo[o+4>>2]=1|e,xo[e+o>>2]=e}return n+8|0}}for(e=1049e3;!((t=xo[e>>2])>>>0<=r>>>0&&(a=t+xo[e+4>>2]|0)>>>0>r>>>0);)e=xo[e+8>>2];for(xo[262247]=n,e=o+-40|0,xo[262245]=e,xo[n+4>>2]=1|e,xo[4+(e+n|0)>>2]=40,xo[262254]=2097152,xo[(t=(e=(a+-32&-8)-8|0)>>>0<r+16>>>0?r:e)+4>>2]=27,e=xo[262250],s=xo[262251],u=xo[262253],xo[(l=t+16|0)>>2]=xo[262252],xo[l+4>>2]=u,xo[t+8>>2]=e,xo[t+12>>2]=s,xo[262251]=o,xo[262250]=n,xo[262252]=t+8,e=t+28|(xo[262253]=0);xo[e>>2]=7,a>>>0>(e=e+4|0)>>>0;);(0|t)!=(0|r)&&(xo[t+4>>2]=-2&xo[t+4>>2],e=t-r|0,xo[r+4>>2]=1|e,256<=(xo[t>>2]=e)>>>0?Bo(r,e):(e=1048584+((t=e>>>3)<<3)|0,n=xo[262144],t=1<<(31&t),s=xo[e+8>>2],n&t||(xo[262144]=t|n,s=e),t=s,xo[e+8>>2]=r,xo[t+12>>2]=r,xo[r+12>>2]=e,xo[r+8>>2]=t))}if(r=0,!((e=xo[262245])>>>0<=i>>>0))break e}return r}return t=e-i|0,xo[262245]=t,n=(e=xo[262247])+i|0,xo[262247]=n,xo[n+4>>2]=1|t,xo[e+4>>2]=3|i,e+8|0}(r=Mo(e|=0,t|=0)))|!(3&Io[n+-4|0])||function(e,t){if(t)for(;e=e+1|(No[0|e]=0),t=t+-1|0;);}(n,r),n);var r,n}function Go(){}function Ho(e){return e?31-ko(e+-1^e)|0:32}function Vo(e){var t;return(-1>>>(t=31&e)&-2)<<t|(-1<<(e=0-e&31)&-2)>>>e}function zo(e){e|=0;var t,r,n=0|To.byteLength/65536,i=n+e|0;return n<i&&i<65536&&(t=new ArrayBuffer(Mo(i,65536)),(r=new So.Int8Array(t)).set(No),No=r,No=new So.Int8Array(t),new So.Int16Array(t),xo=new So.Int32Array(t),Io=new So.Uint8Array(t),Ro=new So.Uint16Array(t),Lo=new So.Uint32Array(t),new So.Float32Array(t),new So.Float64Array(t),To=t),n}So={Math:Math,Int8Array:Int8Array,Uint8Array:Uint8Array,Int16Array:Int16Array,Uint16Array:Uint16Array,Int32Array:Int32Array,Uint32Array:Uint32Array,Float32Array:Float32Array,Float64Array:Float64Array,NaN:NaN,Infinity:1/0},To=jo,No=new So.Int8Array(To),new So.Int16Array(To),xo=new So.Int32Array(To),Io=new So.Uint8Array(To),Ro=new So.Uint16Array(To),Lo=new So.Uint32Array(To),new So.Float32Array(To),new So.Float64Array(To),Mo=So.Math.imul,So.Math.fround,So.Math.abs,ko=So.Math.clz32,So.Math.min,So.Math.max,So.Math.floor,So.Math.ceil,So.Math.sqrt,So.NaN,So.Infinity,Po=1048576;var $o={memory:Object.create(Object.prototype,{grow:{value:zo},buffer:{get:function(){return To}}}),rust_calloc:Uo,rust_free:function(e){Do(e|=0)},llparser_create:function(e,t,r){return 0|(n=e|=0,i=t|=0,o=r|=0,Po=a=Po-32|0,xo[28+a>>2]=n,xo[24+a>>2]=i,xo[20+a>>2]=o,i=xo[28+(n=a)>>2]?xo[28+a>>2]:256,xo[n+28>>2]=i,i=xo[24+(n=a)>>2]?xo[24+a>>2]:256,xo[n+24>>2]=i,i=xo[20+(n=a)>>2]?xo[20+a>>2]:256,xo[n+20>>2]=i,l=Uo(((((((Mo(xo[24+(s=a)>>2],140)+52|0)+Mo(xo[20+a>>2],44)|0)+(xo[24+a>>2]<<9)|0)+(xo[24+a>>2]<<9)|0)+Mo(xo[20+a>>2],xo[24+a>>2]<<3)|0)+(xo[28+a>>2]<<1)|0)+(xo[28+a>>2]<<3)|0,1),xo[16+s>>2]=l,xo[xo[16+a>>2]+12>>2]=xo[28+a>>2],xo[xo[16+a>>2]+16>>2]=xo[24+a>>2],xo[xo[16+a>>2]+20>>2]=xo[20+a>>2],xo[xo[16+a>>2]+4>>2]=0,xo[xo[16+a>>2]>>2]=0,xo[xo[16+a>>2]+8>>2]=0,xo[12+a>>2]=xo[16+a>>2]+52,xo[xo[16+a>>2]+24>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+Mo(xo[24+a>>2],140),xo[xo[16+a>>2]+28>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+Mo(xo[20+a>>2],44),xo[xo[16+a>>2]+32>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+(xo[24+a>>2]<<9),xo[xo[16+a>>2]+36>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+(xo[24+a>>2]<<9),xo[xo[16+a>>2]+40>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+Mo(xo[20+a>>2],xo[24+a>>2]<<3),xo[xo[16+a>>2]+44>>2]=xo[12+a>>2],xo[12+a>>2]=xo[12+a>>2]+(xo[28+a>>2]<<1),xo[xo[16+a>>2]+48>>2]=xo[12+a>>2],Po=32+a|0,xo[16+a>>2]);var n,i,o,a,s,l},llparser_destroy:function(e){var t,r;t=e|=0,Po=r=Po-16|0,xo[12+r>>2]=t,Do(xo[12+r>>2]),Po=16+r|0},llparser_create_descriptor:function(e,t){return 0|(r=e|=0,n=t|=0,xo[12+(i=Po-16|0)>>2]=r,xo[8+i>>2]=n,n=xo[xo[12+i>>2]+24>>2],o=xo[12+i>>2],r=xo[o+4>>2],xo[o+4>>2]=r+1,xo[4+i>>2]=n+Mo(r,140),xo[xo[4+i>>2]+4>>2]=xo[8+i>>2]?1:0,xo[4+i>>2]);var r,n,i,o},llparser_descriptor_set_all:function(e){var t;e|=0,xo[12+(t=Po-16|0)>>2]=e,xo[xo[12+t>>2]+4>>2]=-1,No[xo[12+t>>2]+135|0]=1},llparser_descriptor_set_nil:function(e){var t;e|=0,xo[12+(t=Po-16|0)>>2]=e,xo[xo[12+t>>2]+4>>2]=-2,No[xo[12+t>>2]+8|0]=1},llparser_descriptor_add_char:function(e,t){var r,n,i;r=e|=0,n=t|=0,xo[12+(i=Po-16|0)>>2]=r,xo[8+i>>2]=n,No[xo[8+i>>2]+(xo[12+i>>2]+8|0)|0]=1},llparser_descriptor_add_range:function(e,t,r){!function(e,t,r){var n;for(xo[12+(n=Po-16|0)>>2]=e,xo[8+n>>2]=t,xo[4+n>>2]=r,xo[n>>2]=xo[8+n>>2];!(xo[n>>2]>xo[4+n>>2]);)No[xo[n>>2]+(xo[12+n>>2]+8|0)|0]=1,xo[n>>2]=xo[n>>2]+1}(e|=0,t|=0,r|=0)},llparser_descriptor_revert:function(e){!function(e){var t;for(xo[12+(t=Po-16|0)>>2]=e,xo[8+t>>2]=1;!(127<=xo[8+t>>2]);)No[xo[8+t>>2]+(xo[12+t>>2]+8|0)|0]=1&(0!=Io[xo[8+t>>2]+(xo[12+t>>2]+8|0)|0]^-1),xo[8+t>>2]=xo[8+t>>2]+1}(e|=0)},llparser_add_rule:function(e,t,r,n,i,o,a,s,l,u,c,d){return 0|(f=e|=0,_=t|=0,p=r|=0,h=n|=0,v=i|=0,g=o|=0,m=a|=0,y=s|=0,b=l|=0,E=u|=0,w=c|=0,O=d|=0,Po=A=Po+-64|0,xo[60+A>>2]=f,xo[56+A>>2]=_,xo[52+A>>2]=p,xo[48+A>>2]=h,xo[44+A>>2]=v,xo[40+A>>2]=g,xo[36+A>>2]=m,xo[32+A>>2]=y,xo[28+A>>2]=b,xo[24+A>>2]=E,xo[20+A>>2]=w,xo[16+A>>2]=O,_=xo[xo[60+A>>2]+28>>2],p=xo[60+A>>2],f=xo[p>>2],xo[p>>2]=f+1,xo[12+A>>2]=_+Mo(f,44),xo[xo[12+A>>2]>>2]=xo[52+A>>2],xo[xo[12+A>>2]+4>>2]=xo[48+A>>2],0<xo[48+A>>2]&&(xo[xo[12+A>>2]+8>>2]=xo[44+A>>2]),1<xo[48+A>>2]&&(xo[xo[12+A>>2]+12>>2]=xo[40+A>>2]),2<xo[48+A>>2]&&(xo[xo[12+A>>2]+16>>2]=xo[36+A>>2]),3<xo[48+A>>2]&&(xo[xo[12+A>>2]+20>>2]=xo[32+A>>2]),4<xo[48+A>>2]&&(xo[xo[12+A>>2]+24>>2]=xo[28+A>>2]),5<xo[48+A>>2]&&(xo[xo[12+A>>2]+28>>2]=xo[24+A>>2]),6<xo[48+A>>2]&&(xo[xo[12+A>>2]+32>>2]=xo[20+A>>2]),7<xo[48+A>>2]&&(xo[xo[12+A>>2]+36>>2]=xo[16+A>>2]),xo[xo[12+A>>2]+40>>2]=xo[56+A>>2],0<xo[48+A>>2]&&(C=xo[60+A>>2],S=xo[12+A>>2],T=xo[52+A>>2],xo[28+(N=Po-32|0)>>2]=C,xo[24+N>>2]=S,xo[20+N>>2]=T,xo[16+N>>2]=(xo[20+N>>2]-xo[xo[28+N>>2]+24>>2]|0)/140,1==xo[xo[20+N>>2]+4>>2]&&(S=xo[xo[28+N>>2]+40>>2],T=xo[28+N>>2],C=xo[T+8>>2],xo[T+8>>2]=C+1,xo[12+N>>2]=S+(C<<3),xo[xo[12+N>>2]>>2]=xo[24+N>>2],xo[xo[12+N>>2]+4>>2]=xo[xo[20+N>>2]+136>>2],xo[xo[20+N>>2]+136>>2]=xo[12+N>>2])),Po=64+A|0,xo[12+A>>2]);var f,_,p,h,v,g,m,y,b,E,w,O,A,C,S,T,N},llparser_prepare:function(e){!function(e){var t;for(Po=t=Po-32|0,xo[28+t>>2]=e,xo[24+t>>2]=0;!(xo[24+t>>2]>=xo[xo[28+t>>2]+4>>2]);)xo[20+t>>2]=xo[xo[28+t>>2]+24>>2]+Mo(xo[24+t>>2],140),1==xo[xo[20+t>>2]+4>>2]&&function e(t,r,n,i,o){var a;if(Po=a=Po-48|0,xo[44+a>>2]=t,xo[40+a>>2]=r,xo[36+a>>2]=n,xo[32+a>>2]=i,xo[28+a>>2]=o,xo[xo[40+a>>2]>>2]!=xo[36+a>>2])for(xo[xo[40+a>>2]>>2]=xo[36+a>>2],xo[24+a>>2]=xo[xo[40+a>>2]+136>>2],xo[20+a>>2]=1&(0!=xo[28+a>>2]^-1^-1);xo[24+a>>2];){for(xo[20+a>>2]||(xo[28+a>>2]=xo[24+a>>2]),xo[16+a>>2]=xo[xo[xo[24+a>>2]>>2]+8>>2],1==xo[xo[16+a>>2]+4>>2]&&e(xo[44+a>>2],xo[16+a>>2],xo[36+a>>2],xo[32+a>>2],xo[28+a>>2]),xo[12+a>>2]=0;!(128<=xo[12+a>>2]);)Io[xo[12+a>>2]+(xo[16+a>>2]+8|0)|0]&&(Lo[xo[28+a>>2]>>2]>=Lo[xo[32+a>>2]+(xo[12+a>>2]<<2)>>2]&&xo[xo[32+a>>2]+(xo[12+a>>2]<<2)>>2]||(xo[xo[32+a>>2]+(xo[12+a>>2]<<2)>>2]=xo[xo[28+a>>2]>>2])),xo[12+a>>2]=xo[12+a>>2]+1;xo[24+a>>2]=xo[xo[24+a>>2]+4>>2]}Po=48+a|0}(xo[28+t>>2],xo[20+t>>2],xo[20+t>>2],xo[xo[28+t>>2]+32>>2]+(xo[24+t>>2]<<9)|0,0),xo[24+t>>2]=xo[24+t>>2]+1;for(xo[16+t>>2]=0;!(xo[16+t>>2]>=xo[xo[28+t>>2]+4>>2]);)xo[12+t>>2]=xo[xo[28+t>>2]+24>>2]+Mo(xo[16+t>>2],140),1==xo[xo[12+t>>2]+4>>2]&&(xo[xo[12+t>>2]>>2]=0,function(e,t,r,n){var i;for(xo[44+(i=Po-48|0)>>2]=e,xo[40+i>>2]=t,xo[36+i>>2]=r,xo[32+i>>2]=n,xo[28+i>>2]=xo[xo[40+i>>2]+136>>2];xo[28+i>>2];){if(xo[24+i>>2]=xo[xo[xo[28+i>>2]>>2]+8>>2],xo[24+i>>2]==xo[40+i>>2])for(xo[20+i>>2]=xo[xo[xo[28+i>>2]>>2]+12>>2],xo[16+i>>2]=0;!(128<=xo[16+i>>2]);){e:{if(1!=xo[xo[20+i>>2]+4>>2]){if(!Io[xo[16+i>>2]+(xo[20+i>>2]+8|0)|0])break e}else if(xo[12+i>>2]=xo[xo[44+i>>2]+32>>2]+((xo[20+i>>2]-xo[xo[44+i>>2]+24>>2]|0)/140<<9),!xo[xo[12+i>>2]+(xo[16+i>>2]<<2)>>2])break e;Lo[xo[28+i>>2]>>2]>=Lo[xo[32+i>>2]+(xo[16+i>>2]<<2)>>2]&&xo[xo[32+i>>2]+(xo[16+i>>2]<<2)>>2]||(xo[xo[32+i>>2]+(xo[16+i>>2]<<2)>>2]=xo[xo[28+i>>2]>>2])}xo[16+i>>2]=xo[16+i>>2]+1}xo[28+i>>2]=xo[xo[28+i>>2]+4>>2]}}(xo[28+t>>2],xo[12+t>>2],xo[12+t>>2],xo[xo[28+t>>2]+36>>2]+(xo[16+t>>2]<<9)|0)),xo[16+t>>2]=xo[16+t>>2]+1;Po=32+t|0}(e|=0)},llparser_parse:function(e,t){return 0|(r=e|=0,n=t|=0,Po=i=Po-32|0,xo[24+i>>2]=r,xo[20+i>>2]=n,xo[16+i>>2]=0,xo[12+i>>2]=0,a=function e(t,r,n,i,o,a,s){var l,u=0,c=0;Po=l=Po-96|0,xo[88+l>>2]=t,xo[84+l>>2]=r,xo[80+l>>2]=n,xo[76+l>>2]=i,xo[72+l>>2]=o,xo[68+l>>2]=a,xo[64+l>>2]=s,xo[60+l>>2]=Ro[xo[80+l>>2]+(xo[xo[76+l>>2]>>2]<<1)>>1],128<=Lo[60+l>>2]&&(xo[60+l>>2]=1);e:if(xo[xo[72+l>>2]>>2]>(xo[64+l>>2]-4|0))xo[92+l>>2]=-1;else if(1==xo[xo[84+l>>2]+4>>2])if(xo[56+l>>2]=xo[xo[76+l>>2]>>2],xo[52+l>>2]=xo[xo[72+l>>2]>>2],xo[48+l>>2]=0,xo[44+l>>2]=0,xo[40+l>>2]=xo[xo[88+l>>2]+32>>2]+((xo[84+l>>2]-xo[xo[88+l>>2]+24>>2]|0)/140<<9),xo[36+l>>2]=0,!xo[xo[40+l>>2]+(xo[60+l>>2]<<2)>>2]|Lo[60+l>>2]<=0|127<=Lo[60+l>>2]?!xo[60+l>>2]|!xo[xo[40+l>>2]+508>>2]?xo[xo[40+l>>2]>>2]&&(xo[36+l>>2]=xo[xo[40+l>>2]>>2]):xo[36+l>>2]=xo[xo[40+l>>2]+508>>2]:xo[36+l>>2]=xo[xo[40+l>>2]+(xo[60+l>>2]<<2)>>2],xo[36+l>>2]){for(xo[68+l>>2]||xo[xo[36+l>>2]+40>>2]||(xo[48+l>>2]=xo[xo[72+l>>2]>>2],t=xo[72+l>>2],xo[t>>2]=xo[t>>2]+2),xo[32+l>>2]=0;xo[32+l>>2]<xo[xo[36+l>>2]+4>>2];){if(xo[28+l>>2]=xo[68+l>>2],xo[68+l>>2]||!xo[xo[36+l>>2]+40>>2]|xo[xo[36+l>>2]+40>>2]==(xo[32+l>>2]+65536|0)||(xo[28+l>>2]=1),c=e(xo[88+(u=l)>>2],xo[(xo[36+l>>2]+8|0)+(xo[32+l>>2]<<2)>>2],xo[80+l>>2],xo[76+l>>2],xo[72+l>>2],xo[28+l>>2],xo[64+l>>2]),xo[u+24>>2]=c,xo[24+l>>2]<0){xo[92+l>>2]=-1;break e}xo[68+l>>2]|xo[xo[36+l>>2]+40>>2]!=(xo[32+l>>2]+65536|0)||(xo[44+l>>2]=xo[24+l>>2]),xo[32+l>>2]=xo[32+l>>2]+1}for(xo[68+l>>2]||(xo[xo[36+l>>2]+40>>2]?1==xo[xo[36+l>>2]+40>>2]&&(r=xo[56+l>>2],n=xo[xo[88+l>>2]+48>>2],i=xo[72+l>>2],t=xo[i>>2],xo[i>>2]=t+1,xo[n+(t<<2)>>2]=r,xo[44+l>>2]=xo[xo[72+l>>2]>>2],r=xo[xo[76+l>>2]>>2],n=xo[xo[88+l>>2]+48>>2],i=xo[72+l>>2],t=xo[i>>2],xo[i>>2]=t+1,xo[n+(t<<2)>>2]=r):(xo[xo[xo[88+l>>2]+48>>2]+(xo[48+l>>2]<<2)>>2]=0-xo[36+l>>2],xo[xo[xo[88+l>>2]+48>>2]+(xo[48+l>>2]+1<<2)>>2]=xo[xo[36+l>>2]+4>>2],xo[44+l>>2]=xo[48+l>>2]+1));;){if(xo[xo[72+l>>2]>>2]>(xo[64+l>>2]-4|0)){xo[92+l>>2]=-1;break e}if(xo[20+l>>2]=xo[xo[88+l>>2]+36>>2]+((xo[84+l>>2]-xo[xo[88+l>>2]+24>>2]|0)/140<<9),xo[16+l>>2]=0,xo[60+l>>2]=Ro[xo[80+l>>2]+(xo[xo[76+l>>2]>>2]<<1)>>1],128<=Lo[60+l>>2]&&(xo[60+l>>2]=1),!xo[xo[20+l>>2]+(xo[60+l>>2]<<2)>>2]|Lo[60+l>>2]<=0|127<=Lo[60+l>>2]?!xo[60+l>>2]|!xo[xo[20+l>>2]+508>>2]||(xo[16+l>>2]=xo[xo[20+l>>2]+508>>2]):xo[16+l>>2]=xo[xo[20+l>>2]+(xo[60+l>>2]<<2)>>2],!xo[16+l>>2])break;for(xo[68+l>>2]||(xo[xo[16+l>>2]+40>>2]?65536!=xo[xo[16+l>>2]+40>>2]&&(xo[xo[72+l>>2]>>2]=xo[52+l>>2]):(xo[xo[xo[88+l>>2]+48>>2]+(xo[44+l>>2]<<2)>>2]=(0-xo[xo[xo[88+l>>2]+48>>2]+(xo[44+l>>2]<<2)>>2]|0)-1,xo[48+l>>2]=xo[xo[72+l>>2]>>2],t=xo[72+l>>2],xo[t>>2]=xo[t>>2]+2)),xo[12+l>>2]=1;xo[12+l>>2]<xo[xo[16+l>>2]+4>>2];){if(xo[8+l>>2]=xo[68+l>>2],xo[68+l>>2]||!xo[xo[16+l>>2]+40>>2]|xo[xo[16+l>>2]+40>>2]==(xo[12+l>>2]+65536|0)||(xo[8+l>>2]=1),c=e(xo[88+(u=l)>>2],xo[(xo[16+l>>2]+8|0)+(xo[12+l>>2]<<2)>>2],xo[80+l>>2],xo[76+l>>2],xo[72+l>>2],xo[8+l>>2],xo[64+l>>2]),xo[u+4>>2]=c,xo[4+l>>2]<0){xo[92+l>>2]=-1;break e}xo[68+l>>2]|xo[xo[16+l>>2]+40>>2]!=(xo[12+l>>2]+65536|0)||(xo[44+l>>2]=xo[4+l>>2]),xo[12+l>>2]=xo[12+l>>2]+1}xo[68+l>>2]||(xo[xo[16+l>>2]+40>>2]?1==xo[xo[16+l>>2]+40>>2]&&(r=xo[56+l>>2],n=xo[xo[88+l>>2]+48>>2],i=xo[72+l>>2],t=xo[i>>2],xo[i>>2]=t+1,xo[n+(t<<2)>>2]=r,xo[44+l>>2]=xo[xo[72+l>>2]>>2],r=xo[xo[76+l>>2]>>2],n=xo[xo[88+l>>2]+48>>2],i=xo[72+l>>2],t=xo[i>>2],xo[i>>2]=t+1,xo[n+(t<<2)>>2]=r):(xo[xo[xo[88+l>>2]+48>>2]+(xo[48+l>>2]<<2)>>2]=0-xo[16+l>>2],xo[xo[xo[88+l>>2]+48>>2]+(xo[48+l>>2]+1<<2)>>2]=xo[xo[16+l>>2]+4>>2],xo[44+l>>2]=xo[48+l>>2]+1))}xo[92+l>>2]=xo[44+l>>2]}else xo[92+l>>2]=-1;else{if(xo[60+l>>2]&&(-1==xo[xo[84+l>>2]+4>>2]&&(t=xo[76+l>>2],xo[t>>2]=xo[t>>2]+1),!xo[xo[84+l>>2]+4>>2])){if(!Io[xo[60+l>>2]+(xo[84+l>>2]+8|0)|0]){xo[92+l>>2]=-1;break e}t=xo[76+l>>2],xo[t>>2]=xo[t>>2]+1}xo[68+l>>2]||(r=xo[xo[76+l>>2]>>2],n=xo[xo[84+l>>2]+4>>2],i=xo[xo[88+l>>2]+48>>2],o=xo[72+l>>2],t=xo[o>>2],xo[o>>2]=t+1,xo[i+(t<<2)>>2]=r-(-2==(0|n)?0:1),r=xo[xo[76+l>>2]>>2],n=xo[xo[88+l>>2]+48>>2],i=xo[72+l>>2],t=xo[i>>2],xo[i>>2]=t+1,xo[n+(t<<2)>>2]=r),xo[92+l>>2]=xo[xo[72+l>>2]>>2]-1}return Po=96+l|0,xo[92+l>>2]}(xo[24+(o=i)>>2],xo[20+i>>2],xo[xo[24+i>>2]+44>>2],12+i|0,16+i|0,0,xo[xo[24+i>>2]+12>>2]<<1),xo[8+o>>2]=a,r=xo[xo[24+i>>2]+48>>2],n=xo[16+i>>2],xo[16+i>>2]=n+1,xo[r+(n<<2)>>2]=-1,r=xo[xo[24+i>>2]+48>>2],n=xo[16+i>>2],xo[16+i>>2]=n+1,xo[r+(n<<2)>>2]=0,Ro[xo[xo[24+i>>2]+44>>2]+(xo[12+i>>2]<<1)>>1]|xo[8+i>>2]<0?xo[28+i>>2]=xo[12+i>>2]+1:xo[28+i>>2]=0,Po=32+i|0,xo[28+i>>2]);var r,n,i,o,a},llparser_get_input_buffer:function(e){var t;return e|=0,xo[12+(t=Po-16|0)>>2]=e,xo[xo[12+t>>2]+44>>2]},llparser_get_result:function(e){var t;return e|=0,xo[12+(t=Po-16|0)>>2]=e,xo[xo[12+t>>2]+48>>2]},wasm_main:Go,__wbindgen_start:Go},Yo=function(){function e(){}return e.create=function(t,r,n){void 0===n&&(n=16384);var i={},o=new e;o._llp=$o.llparser_create(n,128,128);var a=o._llp,s={ALL:$o.llparser_create_descriptor(a,0),NULL:$o.llparser_create_descriptor(a,0)};for(var l in $o.llparser_descriptor_set_all(s.ALL),$o.llparser_descriptor_set_nil(s.NULL),t){var u=a;s[l]=$o.llparser_create_descriptor(u,1)}for(var l in t)for(var c=t[l],d=s[l],f=0;f<c.length;f++){for(var _=c[f].id,p=c[f].states,h=[],v=0;v<p.length;v++){var g=p[v];s[g]||(s[g]=function(e,t){for(var r=$o.llparser_create_descriptor(e,0),n="^"===t[0],i=+n;i<t.length;i++){var o=t.charCodeAt(i),a=t.charCodeAt(i+2);"-"===t[i+1]&&o<=a?($o.llparser_descriptor_add_range(r,o,a),i+=2):$o.llparser_descriptor_add_char(r,o)}return n&&$o.llparser_descriptor_revert(r),r}(a,g)),h.push(s[g])}var m=0;"_raw"===_?m=1:"_jump"===_?m=65536:"_blank"===_&&(m=65537);var y=$o.llparser_add_rule.apply($o,wo([a,m,d,h.length],h));0===m&&(i[y]=r[_])}return $o.llparser_prepare(a),o._inputPtr=$o.llparser_get_input_buffer(a),o._resultPtr=$o.llparser_get_result(a),o._stateIdMap=s,o._ruleCbMap=i,o._charCountLimit=n,o},e.prototype.parse=function(e,t){var r=Date.now();!function(e,t,r,n){for(var i=n>e.length?e.length:n,o=0;o<i;o++)t[r+o]=e.charCodeAt(o);t[r+i]=0}(t,new Uint16Array($o.memory.buffer),this._inputPtr>>1,this._charCountLimit),Wo.copyIn=Wo.copyIn+Date.now()-r,r=Date.now();var n=$o.llparser_parse(this._llp,this._stateIdMap[e]);if(Wo.parse=Wo.parse+Date.now()-r,r=Date.now(),n)throw new Error("Parsing failed at character position "+(n-1)+' near "'+t.slice(n-20,n)+'"');var i=function(e,t,r,n,i){for(var o=[],a={i:0,r:0,n:!1,cc:-1,c:[]},s=a,l=i.pos,u=!1,c=!1,d=!1;;){var f=t[l],_=t[l+1];if(_<0?(c=!0,_=-_-1):c=!1,f>=0){d=!0;var p=r.slice(f,_);s.c.push(p),u=c}else{if(-1===f&&0===_)break;d=!1;var h={i:s.c.length-(u?1:0),r:-f,n:c,cc:_,c:[]};if(u){var v=s.c.length-1,g=s.c[v];h.c.push(g),s.c[v]=h}else s.c.push(h);o.push(s),s=h,u=!1}if(!d||!u)for(;s.c.length===s.cc;){if(u=s.n,(h=o.pop()).c[s.i]=n[s.r].call(e,s.c),s=h,u)break}l+=2}return a.c[0]}(this,new Int32Array($o.memory.buffer),t,this._ruleCbMap,{pos:this._resultPtr>>2});return Wo.constructOut=Wo.constructOut+Date.now()-r,i},e.stats={all:0,copyIn:0,parse:0,constructOut:0},e}(),Wo=Yo.stats,Zo=ho("splice"),Jo=Math.max,qo=Math.min,Ko=9007199254740991,Xo="Maximum allowed length exceeded";dt({target:"Array",proto:!0,forced:!Zo},{splice:function(e,t){var r,n,i,o,a,s,l=g(this),u=te(l.length),c=ie(e,u),d=arguments.length;if(0===d?r=n=0:1===d?(r=0,n=u-c):(r=d-2,n=qo(Jo(Q(t),0),u-c)),u+r-n>Ko)throw TypeError(Xo);for(i=Nn(l,n),o=0;o<n;o++)(a=c+o)in l&&_o(i,o,l[a]);if(i.length=n,r<n){for(o=c;o<u-n;o++)s=o+r,(a=o+n)in l?l[s]=l[a]:delete l[s];for(o=u;o>u-n+r;o--)delete l[o-1]}else if(r>n)for(o=u-n;o>c;o--)s=o+r-1,(a=o+n-1)in l?l[s]=l[a]:delete l[s];for(o=0;o<r;o++)l[o+c]=arguments[o+2];return l.length=u-n+r,i}});var Qo={renderingMode:"native",lazyRegistration:!1,publicProperties:!1,classPrefix:"",availability:null,domain:"//",writeOnly:!1,allowInWriteOnly:!0,addGlobalClass:!1,templateEngine:null,multipleSlots:!1,reflectToAttributes:!0,writeFieldsToNode:!0,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,listenerChangeLifeTimes:!1,randomizeTagName:!1,virtualHost:!1,throwGlobalError:!1,writeExtraInfoToAttr:!0,documentBackend:"undefined"!=typeof window&&"undefined"!=typeof document?"dom":"none",hasDOMBackend:!("undefined"==typeof window||"undefined"==typeof document)};function ea(e){return(ea="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}var ta=function(e){if($(e))throw TypeError("Cannot convert a Symbol value to a string");return String(e)},ra=function(){var e=F(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},na="toString",ia=RegExp.prototype,oa=ia.toString,aa=e((function(){return"/a/b"!=oa.call({source:"a",flags:"b"})})),sa=oa.name!=na;function la(e){return"[object Object]"===Object.prototype.toString.call(e)}function ua(e){return"[object String]"===Object.prototype.toString.call(e)}function ca(e){return"[object Number]"===Object.prototype.toString.call(e)}function da(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function fa(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}(aa||sa)&&Ke(RegExp.prototype,na,(function(){var e=F(this),t=ta(e.source),r=e.flags;return"/"+t+"/"+ta(void 0===r&&e instanceof RegExp&&!("flags"in ia)?ra.call(e):r)}),{unsafe:!0});var _a={element:null,component:null,freeTemplateEngine:null,textNode:null,nativeNode:null,virtualNode:null},pa=function(e){_a.element=e,pa=null},ha=function(e){_a.component=e,ha=null},va=function(e){_a.freeTemplateEngine=e,va=null},ga=function(e){_a.textNode=e,ga=null},ma=function(e){_a.nativeNode=e,ma=null},ya=function(e){_a.virtualNode=e,ya=null};function ba(){return _a.component}function Ea(e){return e instanceof _a.element}function wa(e){return e instanceof _a.component}function Oa(e){return e instanceof _a.textNode}var Aa=function(){function e(e){this._arr=[],this._index=0,this._type=e}return e.getGlobalErrorInstance=function(){return e.instance||(e.instance=e.create()),e.instance},e.create=function(t){return new e(t)},e.addGlobalErrorListener=function(t){return e.getGlobalErrorInstance().add(t)},e.removeGlobalErrorListener=function(t){return e.getGlobalErrorInstance().remove(t)},e.safeCallback=function(t,r,n,i,o){try{return r.apply(n,i)}catch(c){var a=__appServiceEngine__&&__appServiceEngine__.getApp();__appServiceSDK__&&__appServiceSDK__.traceCoreDotting("app_error",{info:c.message+c.stack,isError:!0}),a&&a.onError&&a.onError(c.message+c.stack);var s=e.getGlobalErrorInstance(),l="[Exparser] [Error] [Component] "+(t||"Error Listener")+" Error @ ";n&&n.is&&(l+=n.is),l+="#"+(r.name||"(anonymous)"),wa(o)&&o.triggerLifeTime("error",[c]);var u={message:l,type:t,element:n,method:r,args:i};if((!u.type||s.call(null,[c,u]))&&Qo.throwGlobalError)throw c}},e.prototype.add=function(e){var t=this._index++;return this._arr.push({id:t,func:e}),t},e.prototype.remove=function(e){for(var t=this._arr,r=da(e),n=0,i=t.length,o=void 0;n<i;n++)if(o=t[n],(r?o.func:o.id)===e)return t.splice(n,1),o.func;return null},e.prototype.call=function(t,r,n){for(var i=!1,o=0,a=this._arr;o<a.length;o++){var s=a[o];!1===e.safeCallback(this._type,s.func,t,r,n)&&(i=!0)}if(i)return!1},e.prototype.destroy=function(){for(var e=0;e<this._arr.length;e++)this._arr[e].func=void 0,this._arr[e]=null;this._arr.length=0},Object.defineProperty(e.prototype,"empty",{get:function(){return 0===this._arr.length},enumerable:!1,configurable:!0}),e}(),Ca=function(e){return function(t,r){var n,i,a=ta(o(t)),s=Q(r),l=a.length;return s<0||s>=l?e?"":void 0:(n=a.charCodeAt(s))<55296||n>56319||s+1===l||(i=a.charCodeAt(s+1))<56320||i>57343?e?a.charAt(s):n:e?a.slice(s,s+2):i-56320+(n-55296<<10)+65536}},Sa={codeAt:Ca(!1),charAt:Ca(!0)},Ta=Sa.charAt,Na="String Iterator",xa=$e.set,Ia=$e.getterFor(Na);Lt(String,"String",(function(e){xa(this,{type:Na,string:ta(e),index:0})}),(function(){var e,t=Ia(this),r=t.string,n=t.index;return n>=r.length?{value:void 0,done:!0}:(e=Ta(r,n),t.index+=e.length,{value:e,done:!1})}));var Ra=Qe.f,La={}.toString,Ma="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],ka={f:function(e){return Ma&&"[object Window]"==La.call(e)?function(e){try{return Ra(e)}catch(e){return Ma.slice()}}(e):Ra(a(e))}},Pa=!e((function(){return Object.isExtensible(Object.preventExtensions({}))})),ja=l((function(e){var t=q.f,r=!1,n=w("meta"),i=0,o=Object.isExtensible||function(){return!0},a=function(e){t(e,n,{value:{objectID:"O"+i++,weakData:{}}})},s=e.exports={enable:function(){s.enable=function(){},r=!0;var e=Qe.f,t=[].splice,i={};i[n]=1,e(i).length&&(Qe.f=function(r){for(var i=e(r),o=0,a=i.length;o<a;o++)if(i[o]===n){t.call(i,o,1);break}return i},dt({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:ka.f}))},fastKey:function(e,t){if(!B(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!y(e,n)){if(!o(e))return"F";if(!t)return"E";a(e)}return e[n].objectID},getWeakData:function(e,t){if(!y(e,n)){if(!o(e))return!0;if(!t)return!1;a(e)}return e[n].weakData},onFreeze:function(e){return Pa&&r&&o(e)&&!y(e,n)&&a(e),e}};se[n]=!0})),Da=function(e){var t=e.return;if(void 0!==t)return F(t.call(e)).value},Ba=function(e,t){this.stopped=e,this.result=t},Fa=function(e,t,r){var n,i,o,a,s,l,u,c=r&&r.that,d=!(!r||!r.AS_ENTRIES),f=!(!r||!r.IS_ITERATOR),_=!(!r||!r.INTERRUPTED),p=On(t,c,1+d+_),h=function(e){return n&&Da(n),new Ba(!0,e)},v=function(e){return d?(F(e),_?p(e[0],e[1],h):p(e[0],e[1])):_?p(e,h):p(e)};if(f)n=e;else{if("function"!=typeof(i=yn(e)))throw TypeError("Target is not iterable");if(wn(i)){for(o=0,a=te(e.length);a>o;o++)if((s=v(e[o]))&&s instanceof Ba)return s;return new Ba(!1)}n=i.call(e)}for(l=n.next;!(u=l.call(n)).done;){try{s=v(u.value)}catch(e){throw Da(n),e}if("object"==typeof s&&s&&s instanceof Ba)return s}return new Ba(!1)},Ua=ja.getWeakData,Ga=$e.set,Ha=$e.getterFor,Va=Rn.find,za=Rn.findIndex,$a=0,Ya=function(e){return e.frozen||(e.frozen=new Wa)},Wa=function(){this.entries=[]},Za=function(e,t){return Va(e.entries,(function(e){return e[0]===t}))};Wa.prototype={get:function(e){var t=Za(this,e);if(t)return t[1]},has:function(e){return!!Za(this,e)},set:function(e,t){var r=Za(this,e);r?r[1]=t:this.entries.push([e,t])},delete:function(e){var t=za(this.entries,(function(t){return t[0]===e}));return~t&&this.entries.splice(t,1),!!~t}};var Ja={getConstructor:function(e,t,r,n){var i=e((function(e,o){Ft(e,i,t),Ga(e,{type:t,id:$a++,frozen:void 0}),null!=o&&Fa(o,e[n],{that:e,AS_ENTRIES:r})})),o=Ha(t),a=function(e,t,r){var n=o(e),i=Ua(F(t),!0);return!0===i?Ya(n).set(t,r):i[n.id]=r,e};return Bt(i.prototype,{delete:function(e){var t=o(this);if(!B(e))return!1;var r=Ua(e);return!0===r?Ya(t).delete(e):r&&y(r,t.id)&&delete r[t.id]},has:function(e){var t=o(this);if(!B(e))return!1;var r=Ua(e);return!0===r?Ya(t).has(e):r&&y(r,t.id)}}),Bt(i.prototype,r?{get:function(e){var t=o(this);if(B(e)){var r=Ua(e);return!0===r?Ya(t).get(e):r?r[t.id]:void 0}},set:function(e,t){return a(this,e,t)}}:{add:function(e){return a(this,e,!0)}}),i}},qa=(l((function(t){var r,n=$e.enforce,i=!f.ActiveXObject&&"ActiveXObject"in f,o=Object.isExtensible,a=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},s=t.exports=function(t,r,n){var i=-1!==t.indexOf("Map"),o=-1!==t.indexOf("Weak"),a=i?"set":"add",s=f[t],l=s&&s.prototype,u=s,c={},d=function(e){var t=l[e];Ke(l,e,"add"==e?function(e){return t.call(this,0===e?0:e),this}:"delete"==e?function(e){return!(o&&!B(e))&&t.call(this,0===e?0:e)}:"get"==e?function(e){return o&&!B(e)?void 0:t.call(this,0===e?0:e)}:"has"==e?function(e){return!(o&&!B(e))&&t.call(this,0===e?0:e)}:function(e,r){return t.call(this,0===e?0:e,r),this})};if(ut(t,"function"!=typeof s||!(o||l.forEach&&!e((function(){(new s).entries().next()})))))u=n.getConstructor(r,t,i,a),ja.enable();else if(ut(t,!0)){var _=new u,p=_[a](o?{}:-0,1)!=_,h=e((function(){_.has(1)})),v=Yr((function(e){new s(e)})),g=!o&&e((function(){for(var e=new s,t=5;t--;)e[a](t,t);return!e.has(-0)}));v||((u=r((function(e,r){Ft(e,u,t);var n=kn(new s,e,u);return null!=r&&Fa(r,n[a],{that:n,AS_ENTRIES:i}),n}))).prototype=l,l.constructor=u),(h||g)&&(d("delete"),d("has"),i&&d("get")),(g||p)&&d(a),o&&l.clear&&delete l.clear}return c[t]=u,dt({global:!0,forced:u!=s},c),Et(u,t),o||n.setStrong(u,t,i),u}("WeakMap",a,Ja);if(Le&&i){r=Ja.getConstructor(a,"WeakMap",!0),ja.enable();var l=s.prototype,u=l.delete,c=l.has,d=l.get,_=l.set;Bt(l,{delete:function(e){if(B(e)&&!o(e)){var t=n(this);return t.frozen||(t.frozen=new r),u.call(this,e)||t.frozen.delete(e)}return u.call(this,e)},has:function(e){if(B(e)&&!o(e)){var t=n(this);return t.frozen||(t.frozen=new r),c.call(this,e)||t.frozen.has(e)}return c.call(this,e)},get:function(e){if(B(e)&&!o(e)){var t=n(this);return t.frozen||(t.frozen=new r),c.call(this,e)?d.call(this,e):t.frozen.get(e)}return d.call(this,e)},set:function(e,t){if(B(e)&&!o(e)){var i=n(this);i.frozen||(i.frozen=new r),c.call(this,e)?_.call(this,e,t):i.frozen.set(e,t)}else _.call(this,e,t);return this}})}})),{CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}),Ka=D("iterator"),Xa=D("toStringTag"),Qa=jt.values;for(var es in qa){var ts=f[es],rs=ts&&ts.prototype;if(rs){if(rs[Ka]!==Qa)try{ke(rs,Ka,Qa)}catch(e){rs[Ka]=Qa}if(rs[Xa]||ke(rs,Xa,es),qa[es])for(var ns in jt)if(rs[ns]!==jt[ns])try{ke(rs,ns,jt[ns])}catch(e){rs[ns]=jt[ns]}}}function is(e,t){if(function(e){return"object"===ea(e)}(e)&&null!==e){var r=t?t.get(e):void 0;if(void 0!==r)return r;if(fa(e)){r=[],t&&t.set(e,r);for(var n=0,i=e.length;n<i;++n)r[n]=is(e[n],t)}else for(var o in r={},t&&t.set(e,r),e)os.call(e,o)&&(r[o]=is(e[o],t));return r}if("symbol"!==ea(e))return e}var os=Object.prototype.hasOwnProperty;function as(e){return is(e,new WeakMap)}var ss=Object.freeze({__proto__:null,hasOwnProperty:os,deepCopy:as}),ls=ae.indexOf,us=[].indexOf,cs=!!us&&1/[1].indexOf(1,-0)<0,ds=vi("indexOf");function fs(e,t,r,n){for(var i=Ea(e)?e.collectMarks():{},o=[],a=[],s=e,l=e;l;){if(s!==l&&(o.push(e),e=l,a.push(i),i=Ea(e)?e.collectMarks():{}),s=l.parentNode,!1===n(l,e,i))return;if(l.__ddHost){if(r)break;e=o.pop()||l.__ddHost,i=a.pop()||(Ea(e)?e.collectMarks():{}),s=l=l.__ddHost}else l=!Ea(l)||r?l.parentNode:l.__ddSlotParent}}dt({target:"Array",proto:!0,forced:cs||!ds},{indexOf:function(e){return cs?us.apply(this,arguments)||0:ls(this,e,arguments.length>1?arguments[1]:void 0)}});var _s=function(){function e(){}return e.setInitTimeStamp=function(t){return void 0===t&&(t=Date.now()),e.initTimeStamp=t},e.getInitTimeStamp=function(){return e.initTimeStamp},e.create=function(t,r,n){void 0===n&&(n={});var i=n.originalEvent,o=n.extraFields,a=void 0===o?{}:o,s=n.bubbles,l=n.composed,u=n.capturePhase,c=Date.now()-e.initTimeStamp,d=new e;for(var f in d.currentTarget=null,d.type=t,d.timeStamp=c,d.mark=null,d.detail=r,d.bubbles=!!s,d.composed=!!l,d.__originalEvent=i,d.__hasCapture=!!u,d.__stopped=!1,d.__dispatched=!1,a)d[f]=a[f];return d},e.dispatchEvent=function(e,t){if(t&&!t.__dispatched){t.__dispatched=!0,e.__ddElement&&e.__ddHost!==e.__ddElement&&Ea((e=e.__ddElement).shadowRoot)&&(e=e.shadowRoot),t.target=Ea(e)?e.__methodCaller:e;var r=t.type,n=!t.composed;if(t.__hasCapture){var i=[];fs(e,0,n,(function(e,t,n){return e.__ddCaptureEvents&&e.__ddCaptureEvents[r]&&i.push([e,t,n]),!0}));for(var o=i.length-1;o>=0;o--){var a=i[o],s=a[0],l=a[1],u=a[2];t.target=Ea(l)?l.__methodCaller:l,t.mark=u;var c=s.__ddCaptureMutated&&s.__ddCaptureMutated[r];if(f(s.__ddCaptureEvents[r],c,s),t.__stopped)break}}if(t.target=Ea(e)?e.__methodCaller:e,!t.__stopped){var d=!t.bubbles;fs(e,0,n,(function(e,n,i){t.target=Ea(n)?n.__methodCaller:n,t.mark=i;var o=e.__ddMutated&&e.__ddMutated[r];return e.__ddEvents&&e.__ddEvents[r]&&f(e.__ddEvents[r],o,e),!d&&!t.__stopped}))}}function f(e,r,n){if(!(r&&r.length&&t.mutatedMarked())){var i=t.currentTarget=Ea(n)?n.__methodCaller:n,o=e.call(i,[t],wa(n)?n:void 0);r&&r.length&&t.mutatedMarked(),!1===o&&(t.__originalEvent&&t.__originalEvent.preventDefault(),t.__stopped=!0)}}},e.triggerEvent=function(t,r,n,i){e.dispatchEvent(t,e.create(r,n,i))},e.addListenerToElement=function(e,t,r,n){var i,o=n&&n.mutated;if(o){var a=r;r=function(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];if(!e.mutatedMarked())return a.apply(this,wo([e],t))}}return n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents||(e.__ddCaptureEvents=Object.create(null)),e.__ddCaptureEvents[t]||(e.__ddCaptureEvents[t]=Aa.create("Event Listener")),i=e.__ddCaptureEvents[t].add(r),o&&(e.__ddCaptureMutated||(e.__ddCaptureMutated=Object.create(null)),e.__ddCaptureMutated[t]||(e.__ddCaptureMutated[t]=[]),e.__ddCaptureMutated[t].push(i))):(e.__ddEvents||(e.__ddEvents=Object.create(null)),e.__ddEvents[t]||(e.__ddEvents[t]=Aa.create("Event Listener")),i=e.__ddEvents[t].add(r),o&&(e.__ddMutated||(e.__ddMutated=Object.create(null)),e.__ddMutated[t]||(e.__ddMutated[t]=[]),e.__ddMutated[t].push(i))),wa(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!0,t,r,n]),i},e.removeListenerFromElement=function(e,t,r,n){var i,o;n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents&&e.__ddCaptureEvents[t]&&(i=e.__ddCaptureEvents[t].remove(r)),e.__ddCaptureMutated&&e.__ddCaptureMutated[t]&&-1!==(o=e.__ddCaptureMutated[t].indexOf(r))&&e.__ddCaptureMutated[t].splice(o,1)):(e.__ddEvents&&e.__ddEvents[t]&&(i=e.__ddEvents[t].remove(r)),e.__ddMutated&&e.__ddMutated[t]&&-1!==(o=e.__ddMutated[t].indexOf(r))&&e.__ddMutated[t].splice(o,1)),i&&wa(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!1,t,i,n])},e.prototype.preventDefault=function(){this.__originalEvent&&this.__originalEvent.preventDefault()},e.prototype.stopPropagation=function(){this.__stopped=!0},e.prototype.isStopped=function(){return!!this.__stopped},e.prototype.markMutated=function(){this.__mutatedMarked=!0},e.prototype.mutatedMarked=function(){return!!this.__mutatedMarked},e.initTimeStamp=Date.now(),e}(),ps=f.RegExp,hs={UNSUPPORTED_Y:e((function(){var e=ps("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),BROKEN_CARET:e((function(){var e=ps("^r","gy");return e.lastIndex=2,null!=e.exec("str")}))},vs=f.RegExp,gs=e((function(){var e=vs(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),ms=f.RegExp,ys=e((function(){var e=ms("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),bs=$e.get,Es=RegExp.prototype.exec,ws=v("native-string-replace",String.prototype.replace),Os=Es,As=function(){var e=/a/,t=/b*/g;return Es.call(e,"a"),Es.call(t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),Cs=hs.UNSUPPORTED_Y||hs.BROKEN_CARET,Ss=void 0!==/()??/.exec("")[1];(As||Ss||Cs||gs||ys)&&(Os=function(e){var t,r,n,i,o,a,s,l=this,u=bs(l),c=ta(e),d=u.raw;if(d)return d.lastIndex=l.lastIndex,t=Os.call(d,c),l.lastIndex=d.lastIndex,t;var f=u.groups,_=Cs&&l.sticky,p=ra.call(l),h=l.source,v=0,g=c;if(_&&(-1===(p=p.replace("y","")).indexOf("g")&&(p+="g"),g=c.slice(l.lastIndex),l.lastIndex>0&&(!l.multiline||l.multiline&&"\n"!==c.charAt(l.lastIndex-1))&&(h="(?: "+h+")",g=" "+g,v++),r=new RegExp("^(?:"+h+")",p)),Ss&&(r=new RegExp("^"+h+"$(?!\\s)",p)),As&&(n=l.lastIndex),i=Es.call(_?r:l,g),_?i?(i.input=i.input.slice(v),i[0]=i[0].slice(v),i.index=l.lastIndex,l.lastIndex+=i[0].length):l.lastIndex=0:As&&i&&(l.lastIndex=l.global?i.index+i[0].length:n),Ss&&i&&i.length>1&&ws.call(i[0],r,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&f)for(i.groups=a=Ee(null),o=0;o<f.length;o++)a[(s=f[o])[0]]=i[s[1]];return i});var Ts=Os;dt({target:"RegExp",proto:!0,forced:/./.exec!==Ts},{exec:Ts});var Ns=D("species"),xs=RegExp.prototype,Is=function(t,r,n,i){var o=D(t),a=!e((function(){var e={};return e[o]=function(){return 7},7!=""[t](e)})),s=a&&!e((function(){var e=!1,r=/a/;return"split"===t&&((r={}).constructor={},r.constructor[Ns]=function(){return r},r.flags="",r[o]=/./[o]),r.exec=function(){return e=!0,null},r[o](""),!e}));if(!a||!s||n){var l=/./[o],u=r(o,""[t],(function(e,t,r,n,i){var o=t.exec;return o===Ts||o===xs.exec?a&&!i?{done:!0,value:l.call(t,r,n)}:{done:!0,value:e.call(r,t,n)}:{done:!1}}));Ke(String.prototype,t,u[0]),Ke(xs,o,u[1])}i&&ke(xs[o],"sham",!0)},Rs=Sa.charAt,Ls=function(e,t,r){return t+(r?Rs(e,t).length:1)},Ms=Math.floor,ks="".replace,Ps=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,js=/\$([$&'`]|\d{1,2})/g,Ds=function(e,t,r,n,i,o){var a=r+e.length,s=n.length,l=js;return void 0!==i&&(i=g(i),l=Ps),ks.call(o,l,(function(o,l){var u;switch(l.charAt(0)){case"$":return"$";case"&":return e;case"`":return t.slice(0,r);case"'":return t.slice(a);case"<":u=i[l.slice(1,-1)];break;default:var c=+l;if(0===c)return o;if(c>s){var d=Ms(c/10);return 0===d?o:d<=s?void 0===n[d-1]?l.charAt(1):n[d-1]+l.charAt(1):o}u=n[c-1]}return void 0===u?"":u}))},Bs=function(e,t){var n=e.exec;if("function"==typeof n){var i=n.call(e,t);if("object"!=typeof i)throw TypeError("RegExp exec method returned something other than an Object or null");return i}if("RegExp"!==r(e))throw TypeError("RegExp#exec called on incompatible receiver");return Ts.call(e,t)},Fs=D("replace"),Us=Math.max,Gs=Math.min,Hs="$0"==="a".replace(/./,"$0"),Vs=!!/./[Fs]&&""===/./[Fs]("a","$0");Is("replace",(function(e,t,r){var n=Vs?"$":"$0";return[function(e,r){var n=o(this),i=null==e?void 0:e[Fs];return void 0!==i?i.call(e,n,r):t.call(ta(n),e,r)},function(e,i){var o=F(this),a=ta(e);if("string"==typeof i&&-1===i.indexOf(n)&&-1===i.indexOf("$<")){var s=r(t,o,a,i);if(s.done)return s.value}var l="function"==typeof i;l||(i=ta(i));var u=o.global;if(u){var c=o.unicode;o.lastIndex=0}for(var d=[];;){var f=Bs(o,a);if(null===f)break;if(d.push(f),!u)break;""===ta(f[0])&&(o.lastIndex=Ls(a,te(o.lastIndex),c))}for(var _,p="",h=0,v=0;v<d.length;v++){f=d[v];for(var g=ta(f[0]),m=Us(Gs(Q(f.index),a.length),0),y=[],b=1;b<f.length;b++)y.push(void 0===(_=f[b])?_:String(_));var E=f.groups;if(l){var w=[g].concat(y,m,a);void 0!==E&&w.push(E);var O=ta(i.apply(void 0,w))}else O=Ds(g,a,m,y,E,i);m>=h&&(p+=a.slice(h,m)+O,h=m+g.length)}return p+a.slice(h)}]}),!!e((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Hs||Vs);var zs=D("match"),$s=function(e){var t;return B(e)&&(void 0!==(t=e[zs])?!!t:"RegExp"==r(e))},Ys=hs.UNSUPPORTED_Y,Ws=[].push,Zs=Math.min,Js=4294967295;Is("split",(function(e,t,r){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,r){var n=ta(o(this)),i=void 0===r?Js:r>>>0;if(0===i)return[];if(void 0===e)return[n];if(!$s(e))return t.call(n,e,i);for(var a,s,l,u=[],c=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),d=0,f=new RegExp(e.source,c+"g");(a=Ts.call(f,n))&&!((s=f.lastIndex)>d&&(u.push(n.slice(d,a.index)),a.length>1&&a.index<n.length&&Ws.apply(u,a.slice(1)),l=a[0].length,d=s,u.length>=i));)f.lastIndex===a.index&&f.lastIndex++;return d===n.length?!l&&f.test("")||u.push(""):u.push(n.slice(d)),u.length>i?u.slice(0,i):u}:"0".split(void 0,0).length?function(e,r){return void 0===e&&0===r?[]:t.call(this,e,r)}:t,[function(t,r){var i=o(this),a=null==t?void 0:t[e];return void 0!==a?a.call(t,i,r):n.call(ta(i),t,r)},function(e,i){var o=F(this),a=ta(e),s=r(n,o,a,i,n!==t);if(s.done)return s.value;var l=Nr(o,RegExp),u=o.unicode,c=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(Ys?"g":"y"),d=new l(Ys?"^(?:"+o.source+")":o,c),f=void 0===i?Js:i>>>0;if(0===f)return[];if(0===a.length)return null===Bs(d,a)?[a]:[];for(var _=0,p=0,h=[];p<a.length;){d.lastIndex=Ys?0:p;var v,g=Bs(d,Ys?a.slice(p):a);if(null===g||(v=Zs(te(d.lastIndex+(Ys?p:0)),a.length))===_)p=Ls(a,p,u);else{if(h.push(a.slice(_,p)),h.length===f)return h;for(var m=1;m<=g.length-1;m++)if(h.push(g[m]),h.length===f)return h;p=_=v}}return h.push(a.slice(_)),h}]}),!!e((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var r="ab".split(e);return 2!==r.length||"a"!==r[0]||"b"!==r[1]})),Ys);var qs="[\t\n\v\f\r                　\u2028\u2029\ufeff]",Ks=RegExp("^"+qs+qs+"*"),Xs=RegExp(qs+qs+"*$"),Qs=function(e){return function(t){var r=ta(o(t));return 1&e&&(r=r.replace(Ks,"")),2&e&&(r=r.replace(Xs,"")),r}},el={start:Qs(1),end:Qs(2),trim:Qs(3)},tl=Qe.f,rl=qe.f,nl=q.f,il=el.trim,ol="Number",al=f.Number,sl=al.prototype,ll=r(Ee(sl))==ol,ul=function(e){if($(e))throw TypeError("Cannot convert a Symbol value to a number");var t,r,n,i,o,a,s,l,u=W(e,"number");if("string"==typeof u&&u.length>2)if(43===(t=(u=il(u)).charCodeAt(0))||45===t){if(88===(r=u.charCodeAt(2))||120===r)return NaN}else if(48===t){switch(u.charCodeAt(1)){case 66:case 98:n=2,i=49;break;case 79:case 111:n=8,i=55;break;default:return+u}for(a=(o=u.slice(2)).length,s=0;s<a;s++)if((l=o.charCodeAt(s))<48||l>i)return NaN;return parseInt(o,n)}return+u};if(ut(ol,!al(" 0o1")||!al("0b1")||al("+0x1"))){for(var cl,dl=function(t){var n=arguments.length<1?0:t,i=this;return i instanceof dl&&(ll?e((function(){sl.valueOf.call(i)})):r(i)!=ol)?kn(new al(ul(n)),i,dl):ul(n)},fl=U?tl(al):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),_l=0;fl.length>_l;_l++)y(al,cl=fl[_l])&&!y(dl,cl)&&nl(dl,cl,rl(al,cl));dl.prototype=sl,sl.constructor=dl,Ke(f,ol,dl)}var pl=function(e){if(!e||e.length<=0)throw new Error("Parsing failed: the path string should not be empty");for(var t=[],r=(e=e.replace(/\n|\\|\r|\t|\f/g,"")).split(","),n=r.length,i=0;i<n;i++){for(var o="",a=!1,s=0,l=r[i],u=l.length,c=[],d=0;d<u;d++){s++;var f=l.charAt(d);if(("."===f||"]"===f)&&o||"."===f&&"]"===l.charAt(d-1)){if(!a&&"]"===f)throw new Error("Parsing failed at character position "+s);a&&"]"===f?(a=!1,o&&c.push(Number(o))):o&&c.push(o),o=""}else if("["!==f||!o&&"]"!==l.charAt(d-1))if(a){if(!("9">=f&&f>="0"))throw new Error("Parsing failed at character position "+s);o+=f}else{var _=f.charCodeAt(0);if(!("9">=f&&f>="0"||97<=_&&_<=122||65<=_&&_<=90||42===_))throw new Error("Parsing failed at character position "+s);o+=f}else a=!0,o&&c.push(o),o=""}o&&c.push(o),t.push(c)}return t},hl=function(e){for(var t=e.length,r=[],n="",i=0,o=!1,a=!1,s=0;s<t;s++){var l=e[s];if("\\"===l){if(s+1<t){var u=e[s+1];"."===u||"["===u||"]"===u||"\\"===u?(n+=u,s++):n+="\\"}}else if("."===l)n&&(r.push(n),n="");else if("["===l){if(n&&(r.push(n),n=""),0===r.length)throw new Error("The path string should not start with []: "+e);a=!0,o=!1}else if("]"===l){if(!o)throw new Error("There should be digits inside [] in the path string: "+e);a=!1,r.push(i),i=0}else if(a){if(l<"0"||l>"9")throw new Error("Only digits (0-9) can be put inside [] in the path string: "+e);o=!0,i=10*i+l.charCodeAt(0)-48}else n+=l}if(n&&r.push(n),0===t)throw new Error("The path string should not be empty");return r},vl=Object.freeze({__proto__:null,parseMultiPaths:pl,parseSinglePath:hl}),gl=Rn.filter,ml=ho("filter");dt({target:"Array",proto:!0,forced:!ml},{filter:function(e){return gl(this,e,arguments.length>1?arguments[1]:void 0)}});var yl=Rn.forEach,bl=vi("forEach")?[].forEach:function(e){return yl(this,e,arguments.length>1?arguments[1]:void 0)};for(var El in qa){var wl=f[El],Ol=wl&&wl.prototype;if(Ol&&Ol.forEach!==bl)try{ke(Ol,"forEach",bl)}catch(e){Ol.forEach=bl}}function Al(e){for(var t=[],r=0;r<e.length;r++)t[r]=e[r];return t}function Cl(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(e,r)&&"object"===ea(e[r])&&"object"===ea(t[r])&&null!==t[r]&&(fa(t[r])?e[r]=Al(t[r]):(e[r]=function(e){var t={};for(var r in e)t[r]=e[r];return t}(e[r]),Cl(e[r],t[r])))}function Sl(){}var Tl=["created","ready","cacheAttached","attached","moved","detached","saved","restored","error","listenerChanged","performanceData"],Nl=[String,Number,Boolean,Object,Array,null],xl=function(){function e(){this.properties=Object.create(null),this.methods=Object.create(null),this.listeners=Object.create(null),this.lifetimes=Object.create(null),this.pageLifetimes=Object.create(null),this.observers=[],this.relations=Object.create(null),this.ancestors=[]}return e.matchTypeWithValue=function(e,t){if(e===String){if("string"!=typeof t)return!1}else if(e===Number){if(!Number.isFinite(t))return!1}else if(e===Boolean){if("boolean"!=typeof t)return!1}else if(e===Object){if(null===t||t.constructor!==Object)return!1}else if(e===Array){if(t.constructor!==Array)return!1}else if(void 0===t)return!1;return!0},e.create=function(t){var r=new e;r.is=t.is||"",r.using=t.using||{},r.placeholder=t.placeholder||{},r.generics=t.generics||{},r.template=t.template,r.externalClasses=t.externalClasses||[],r.data=la(t.data)?t.data:null,r.initiator=t.initiator,r.definitionFilter=t.definitionFilter,r.options={publicProperties:!!t.options&&(t.options.publicProperties||Qo.publicProperties)},r._unprepared=t;var n=t.options&&void 0!==t.options.lazyRegistration?t.options.lazyRegistration:Qo.lazyRegistration;return t.options&&n||e.prepare(r),t.is&&(e._list[r.is]=r),r},e.prepare=function(t){var r=t._unprepared;if(r){t._unprepared=null;for(var n=t.ancestors,i=void 0,o=fa(r.behaviors)?r.behaviors:[],a=0,s=o.length,l=void 0;a<s;a++){for(i in ua(l=o[a])&&(l=e._list[l]),l._unprepared&&e.prepare(l),"object"===ea(l.data)&&(null===t.data?t.data=l.data:Cl(t.data,l.data)),l.generics){var u=l.generics[i];la(u)||(u={}),t.generics[i]={default:u.default}}for(i in l.properties)t.properties[i]=l.properties[i];for(i in l.relations)t.relations[i]=l.relations[i];for(i in l.methods)t.methods[i]=l.methods[i];for(var c=0,d=l.ancestors;c<d.length;c++){var f=d[c];n.indexOf(f)<0&&n.push(f)}}"object"===ea(r.data)&&(null===t.data?t.data=r.data:Cl(t.data,r.data));var _=void 0;for(i in r.properties)_=r.properties[i],Nl.indexOf(_)>=0?_={type:_}:Nl.indexOf(_.type)<0&&_.optionalTypes&&_.optionalTypes.length>0&&(_.type=_.optionalTypes[0]),void 0===_.value&&(_.type===String?_.value="":_.type===Number?_.value=0:_.type===Boolean?_.value=!1:_.type===Array?_.value=[]:_.value=null),t.properties[i]={type:_.type,optionalTypes:_.optionalTypes,value:_.value,filter:_.filter,observer:_.observer,public:!!(void 0===_.public?t.options.publicProperties:_.public),availability:_.availability,observeAssignments:!!_.observeAssignments};if(la(r.lifetimes))for(i in r.lifetimes)t.lifetimes[i]=r.lifetimes[i];for(var p=0,h=Tl;p<h.length;p++){var v=h[p],g=r[v];void 0===t.lifetimes[v]&&(t.lifetimes[v]=da(g)?g:void 0)}for(i in r.listeners)t.listeners[i]=r.listeners[i];if(fa(r.observers))for(var m=0,y=r.observers;m<y.length;m++){l=y[m];t.observers.push({paths:pl(l.fields||"**"),observer:l.observer})}else for(i in r.observers)t.observers.push({paths:pl(i),observer:r.observers[i]});if(la(r.pageLifetimes))for(i in r.pageLifetimes)t.pageLifetimes[i]=r.pageLifetimes[i];for(i in r.relations){var b=r.relations[i];t.relations[i]={target:b.target||i,type:b.type,linked:b.linked||Sl,linkChanged:b.linkChanged||Sl,unlinked:b.unlinked||Sl,linkFailed:b.linkFailed||Sl}}for(i in r.methods)da(r.methods[i])&&(t.methods[i]=r.methods[i]);n.push(t)}},e.callDefinitionFilter=function(t){var r=t.definitionFilter,n=[];return fa(t.behaviors)&&t.behaviors.forEach((function(r){ua(r)&&(r=e._list[r]),r.definitionFilter&&(n.push(r.definitionFilter),r.definitionFilter.call(null,t))})),da(r)?function(e){r(e,n)}:null},e.prototype.destroy=function(){var e;for(e in this.is=null,this.data=null,this.properties=null,this.methods)this.methods[e]=null,delete this.methods[e];for(e in this.listeners)this.listeners[e]=null,delete this.listeners[e];for(e in this.lifetimes)this.lifetimes[e]=null,delete this.lifetimes[e];for(e in this.pageLifetimes)this.pageLifetimes[e]=null,delete this.pageLifetimes[e];for(e in this.relations)this.relations[e]=null,delete this.relations[e];this.observers=null,this.using=null,this.externalClasses=null,this.generics=null,this.initiator=null,this.definitionFilter=null,this.template=null,this._unprepared=null,this.ancestors=null},e.prototype.hasBehavior=function(t){var r;this._unprepared&&e.prepare(this);for(var n=0,i=this.ancestors;n<i.length;n++)if(r=i[n],t instanceof e){if(r===t)return!0}else if(r===e._list[t])return!0;return!1},e.prototype._addObserversToDataProxy=function(e){for(var t,r=0,n=this.ancestors;r<n.length;r++)for(var i=0,o=n[r].observers;i<o.length;i++)t=o[i],e.addObserver(t.observer,t.paths)},e.prototype._getAllLifeTimeFuncs=function(){var e,t,r={};Tl.forEach((function(e){r[e]=Aa.create("Lifetime Method")}));for(var n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).lifetimes)da(e.lifetimes[t])&&(r[t]||(r[t]=Aa.create("Lifetime Method")),r[t].add(e.lifetimes[t]));return r},e.prototype._getAllListeners=function(){for(var e,t,r,n={},i=0,o=this.ancestors;i<o.length;i++)for(t in(e=o[i]).listeners)r=e.listeners[t],Object.prototype.hasOwnProperty.call(n,t)?n[t].push(r):n[t]=[r];return n},e.prototype._getAllPageLifeTimeFuncs=function(){for(var e,t,r={},n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).pageLifetimes)da(e.pageLifetimes[t])&&(r[t]||(r[t]=Aa.create("Page Lifetime Method")),r[t].add(e.pageLifetimes[t]));return r},e._list=Object.create(null),e}();Is("match",(function(e,t,r){return[function(t){var r=o(this),n=null==t?void 0:t[e];return void 0!==n?n.call(t,r):new RegExp(t)[e](ta(r))},function(e){var n=F(this),i=ta(e),o=r(t,n,i);if(o.done)return o.value;if(!n.global)return Bs(n,i);var a=n.unicode;n.lastIndex=0;for(var s,l=[],u=0;null!==(s=Bs(n,i));){var c=ta(s[0]);l[u]=c,""===c&&(n.lastIndex=Ls(i,te(n.lastIndex),a)),u++}return 0===u?null:l}]}));var Il=e((function(){de(1)}));dt({target:"Object",stat:!0,forced:Il},{keys:function(e){return de(g(e))}});var Rl=function(){function e(){}return e.create=function(t){var r=new e;return r._cb=t,r._noSubtreeCb=function(e){e.target===this&&t.call(this,e)},r._binded=[],r},e._createObserverTree=function(){throw new Error("Method not implemented.")},e._updateSubtreeCaches=function(t,r){t.__subtreeObserversCount+=r;var n=t.childNodes;if(n)for(var i=0;i<n.length;i++)e._updateSubtreeCaches(n[i],r)},e._callSingleObserver=function(e,t,r){var n=e[t];n&&n.call(e,[r])},e._callObservers=function(e,t,r){do{e[t]&&e[t].call(e,[r]),e=e.parentNode}while(e&&e.__subtreeObserversCount)},e.prototype.observe=function(t,r){void 0===r&&(r={});var n=0,i=r.subtree?this._cb:this._noSubtreeCb;r.properties&&(t.__propObservers||(t.__propObservers=Aa.create("Observer Callback")),this._binded.push({funcArr:t.__propObservers,id:t.__propObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.childList&&(t.__childObservers||(t.__childObservers=Aa.create("Observer Callback")),this._binded.push({funcArr:t.__childObservers,id:t.__childObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.characterData&&(t.__textObservers||(t.__textObservers=Aa.create("Observer Callback")),this._binded.push({funcArr:t.__textObservers,id:t.__textObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.subtree&&e._updateSubtreeCaches(t,n),r.attachStatus&&(t.__attachedObservers||(t.__attachedObservers=Aa.create("Observer Callback")),this._binded.push({funcArr:t.__attachedObservers,id:t.__attachedObservers.add(i),subtree:null}))},e.prototype.disconnect=function(){for(var t=0,r=this._binded;t<r.length;t++){var n=r[t];n.funcArr.remove(n.id),n.subtree&&e._updateSubtreeCaches(n.subtree,-1)}this._binded=[]},e}(),Ll=function(){function e(e){this.tagName=e,this.id="",this.attrs={}}return e.toElement=function(e){var t,r=document.createElement(e.tagName);for(t in e.id&&(r.id=e.id),e.attrs)r.setAttribute(t,e.attrs[t]);return r},e.fromElement=function(t){var r=new e(t.tagName);r.id=t.id;for(var n=0,i=t.attributes;n<i.length;n++)r.attrs[i[n].name]=i[n].value;return r},e.prototype.cloneNode=function(){var t,r=new e;for(t in r.id=this.id,this.attrs)r.attrs[t]=this.attrs[t];return r},e.prototype.removeAttribute=function(e){delete this.attrs[e]},e.prototype.setAttribute=function(e,t){this.attrs[e]=t},e.prototype.getAttribute=function(e){return this.attrs[e]},e}(),Ml=function(e,t,r,n){if(t&&e.ownerShadowRoot!==t.ownerShadowRoot)throw new Error("Cannot move the node from one shadow tree to another shadow tree.");var i=n?r:t,o=-1;r&&(o=e.childNodes.indexOf(r));var a=_a.element.insertChildToElement;return r&&o<0||!a(e,t,o,n)?null:i},kl=function(e,t,r){if(e.__childObservers&&!e.__childObservers.empty||e.__subtreeObserversCount){var n=[r],i=void 0;i="add"===t?{type:"childList",target:e,addedNodes:n}:"remove"===t?{type:"childList",target:e,removedNodes:n}:{type:"childList",target:e,addedNodes:n,removedNodes:n},Rl._callObservers(e,"__childObservers",i)}},Pl=function e(t,r){for(var n=t.childNodes,i=0;i<n.length;i++){var o=n[i];r(t,o),o.__inheritSlots&&e(o,r)}};function jl(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?jl(n,t):t.appendChild(n.__domElement)}function Dl(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?Dl(n,t):t.removeChild(n.__domElement)}function Bl(e){if(e.__virtual)for(var t=0;t<e.__ddSlotChildren.length;t++)Bl(e.__ddSlotChildren[t]);else{var r=e.__domElement;r&&r.parentNode&&r.parentNode.removeChild(r)}}function Fl(e,t){for(;t<e.__ddSlotChildren.length;t++){var r=e.__ddSlotChildren[t];if(!r.__virtual)return r;var n=Fl(r,0);if(n)return n}}var Ul=function(e,t,r,n,i){var o=e,a=document.createDocumentFragment();if(Ea(o)){for(;o.__virtual;){var s=o.__ddSlotParent;if(!s){o=null;break}if(t&&!r){var l=s.__ddSlotChildren.indexOf(o);r=s.__ddSlotChildren[l+1]}o=s}Ea(o)&&(o=o.__domElement)}if(o){var u=n,c=null,d=null;if(t&&(t.__virtual?(jl(t,a),c=a):c=t.__domElement),r)if(r.__virtual){var f=e,_=void 0;if(n?(Dl(r,o),u=!1,_=i+1):(f=r.__ddSlotParent,_=r===t?i:f.__ddSlotChildren.indexOf(r)),t){r=null;for(var p=f;!(r=Fl(p,_))&&p.__virtual;p=p.__ddSlotParent)_=p.__ddSlotParent.__ddSlotChildren.indexOf(p)+1;r&&(d=r.__domElement)}}else d=r.__domElement;u?c?o.replaceChild(c,d):o.removeChild(d):c&&(d?o.insertBefore(c,d):o.appendChild(c))}else t&&t.__ddSlotParent&&Bl(t);return i},Gl=function(e,t,r,n,i,o,a){if(n&&(r.__ddSlotParent=null),i&&(a=e.__ddSlotChildren.indexOf(r)),t){var s=t.__ddSlotParent;if(t.__ddSlotParent=e,s&&o){var l=s.__ddSlotChildren.indexOf(t);s.__ddSlotChildren.splice(l,1),s===e&&l<a&&a--}}t&&t.__backendExtracted||r&&r.__backendExtracted||(a=Ul(e,t,r,n,a)),Qo.writeExtraInfoToAttr&&(n&&Ea(r)&&r.__domElement&&r.__domElement.removeAttribute("exparser:info-in-slot-of"),Ea(t)&&t.__domElement&&(void 0!==e.__slotName&&e.ownerShadowRoot?t.__domElement.setAttribute("exparser:info-in-slot-of",e.ownerShadowRoot.__ddHost.__componentInstanceId):t.__domElement.removeAttribute("exparser:info-in-slot-of"))),i&&(-1===a&&(a=e.__ddSlotChildren.length),t?e.__ddSlotChildren.splice(a,n?1:0,t):e.__ddSlotChildren.splice(a,n?1:0))},Hl=function(e,t,r,n){var i=e.childNodes;if(n){var o=t[""];if(o)for(var a=0;a<i.length;a++)Gl(o,i[a],null,!1,!1,!1,-1);else if(r[""]){o=r[""];for(a=0;a<i.length;a++)Gl(o,null,i[a],!0,!1,!1,a)}}else{!function e(n){for(var i=0;i<n.length;i++){var o=n[i],a=o.__slot||"",s=t[a];s?Gl(s,o,null,!1,!0,!0):r[a]&&(s=r[a],Gl(s,null,o,!0,!0,!0)),o.__inheritSlots&&e(o.childNodes)}}(i)}},Vl=function(e){if(e.__hostAssociated&&e.__slotCacheDirty){e.__slotCacheDirty=!1;var t=e.__ddHost,r=Object.create(null),n=void 0!==t.__singleSlot?{"":t.__singleSlot}:t.__slots;!function e(t){void 0!==t.__slotName&&(r[t.__slotName]||(r[t.__slotName]=t));for(var n=t.childNodes,i=0;i<n.length;i++)Ea(n[i])&&e(n[i])}(e),void 0!==t.__singleSlot?t.__singleSlot!==r[""]&&(r[""]&&(r[""].__ddSlotChildren=t.childNodes),Hl(t,r,n,!0),t.__singleSlot&&(t.__singleSlot.__ddSlotChildren=[]),t.__singleSlot=r[""]||null):(Hl(t,r,n,!1),t.__slots=r)}},zl=function(e,t){if(!(!Ea(e)||t.__ddHost.__idCacheDirty&&t.__slotCacheDirty)){!function e(r){r.__id&&(t.__ddHost.__idCacheDirty=!0),void 0!==r.__slotName&&(t.__slotCacheDirty=!0);for(var n=r.childNodes,i=0;i<n.length;i++){var o=n[i];Ea(o)&&e(o)}}(e)}},$l=function(e,t,r,n){for(var i=function e(t,n,i){var o=t.childNodes,a=0;for(n&&(a=o.indexOf(n)+(i?0:1));a<o.length;a++){var s=o[a];if(s.__slot===r)return s;if(s.__inheritSlots){var l=e(s,null,!1);if(l)return l}}return null};t!==e;t=t.parentNode){var o=i(t.parentNode,t,n);if(o)return o;n=!1}return null};function Yl(e){if((!e.parentNode||e.parentNode.__attached)&&Ea(e)){e.__attached=!0,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.attached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("attached"),e.__attachedObservers&&!e.__attachedObservers.empty&&Rl._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"attached"}),Ea(e.shadowRoot)&&Yl(e.shadowRoot);for(var t=0,r=e.childNodes;t<r.length;t++)Yl(r[t])}}function Wl(e){if(Ea(e)&&e.__attached){for(var t=0,r=e.childNodes;t<r.length;t++)Wl(r[t]);Ea(e.shadowRoot)&&Wl(e.shadowRoot),e.__attached=!1,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.detached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("detached"),e.__attachedObservers&&!e.__attachedObservers.empty&&Rl._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"detached"}),e.destroy&&e.destroy(!1)}}function Zl(e){var t=!0,r=!0;if(Ea(e)?(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,r=!1):Oa(e)&&(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,t=!1,r=!1),t&&e.__ddSlotChildren)for(var n=0,i=e.__ddSlotChildren;n<i.length;n++){Zl(i[n])}else if(r&&e.childNodes)for(var o=0,a=e.childNodes;o<a.length;o++){Zl(a[o])}}function Jl(e,t,r){var n,i=Ea(e)&&e.__virtual,o=t.childNodes?t.childNodes[r]:void 0,a=!0,s=!0;if(Ea(e)){var l;if(e.__backendExtracted=!1,!1===i)if(o)e.__domElement.tagName.toUpperCase()===o.tagName?(e.__domElement=o,e.$$=o):(l=Ll.toElement(e.__domElement),e.__domElement=l,e.$$=l,o.parentNode.replaceChild(l,o)),n=null;else l=Ll.toElement(e.__domElement),e.__domElement=l,e.$$=l,n=l;s=!1}else if(Oa(e)){if(e.__backendExtracted=!1,o){if(void 0!==o.textContent)o.textContent=e.textContent,e.__domElement=o,e.$$=o;else{var u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,o.parentNode.replaceChild(u,o)}n=null}else{u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,n=u}s=!1,a=!1}else{var c=document.createDocumentFragment();if(c.__ddSlotChildren=e.__ddSlotChildren,o&&o.childNodes)for(;o.childNodes.length;)c.appendChild(o.childNodes[0]);if(o){for(;e.childNodes&&o.childNodes&&o.childNodes.length;)e.appendChild(o.childNodes[0]);o.parentNode.replaceChild(e,o),n=null}else n=e;e=c}n?(t.appendChild(n),o=n):o=t?t.childNodes[r]:void 0;var d=0;if(a&&e.__ddSlotChildren)for(var f=0,_=e.__ddSlotChildren;f<_.length;f++){var p=_[f];if(i)r=Jl(p,t,r);else if(p.asShadowRoot){for(var h=0,v=p.asShadowRoot.childNodes;h<v.length;h++){d=Jl(v[h],o,d)}o.__ddSlotParent=e,o.__ddHost=e,e.shadowRoot=o,e.__ddSlotChildren[0]=o,e.__singleSlot===p&&(e.__singleSlot=o)}else d=Jl(p,o,d)}else if(s&&e.childNodes)for(var g=0,m=e.childNodes;g<m.length;g++){d=Jl(p=m[g],o,d)}if(i)return r;for(;o.childNodes.length>d;)o.removeChild(o.childNodes[d]);return r+1}function ql(e,t,r,n,i){if(t===e)return!1;var o=r[n],a=!0;o.id&&o.id!==t.__id&&(a=!1);for(var s=o.classes,l=0;a&&l<s.length;l++)t.classList.contains(s[l])||(a=!1);if(!a&&">"===i)return!1;var u=t;if(a&&0===n){if(null===e)return!0;for(u=u.parentNode;u;u=u.parentNode)if(u===e)return!0;if(">>>"!==i)return!1;u=t,a=!1}for(var c=a?o.relation:i;(u=u.parentNode?u.parentNode:">>>"===c?u.__ddHost:">>>"===i?(a=!1,u.__ddHost):null)===e&&(u=null),u&&u.__virtual;);if(!u)return!1;if(a){if(ql(e,u,r,n-1,c))return!0;if(">>>"!==i)return!1}return ql(e,u,r,n,i)}function Kl(e,t,r){if(r.__virtual)return!1;for(var n=e.union,i=0;i<n.length;i++){var o=n[i];if(ql(t,r,o,o.length-1,">"))return!0}return!1}function Xl(e,t,r,n,i){if(Kl(t,r,n)&&(e.push(n),i))return!0;if(n.shadowRoot&&t.crossShadow&&((n.ownerShadowRoot?n.ownerShadowRoot.__ddHost.__componentOptions.domain:Qo.domain)===n.__componentOptions.domain&&Xl(e,t,r,n.shadowRoot,i)&&i))return!0;for(var o=n.childNodes,a=0;a<o.length;a++)if(Ea(o[a])&&Xl(e,t,r,o[a],i)&&i)return!0;return!1}var Ql=new(function(){function e(){this.backendExtractedDefault=!1}return e.prototype.enableBackendExtractedDefault=function(){this.backendExtractedDefault=!0},e.prototype.disableBackendExtractedDefault=function(){this.backendExtractedDefault=!1},e}()),eu=function(){function e(){}return Object.defineProperty(e.prototype,"id",{get:function(){return this.__id},set:function(e){var t=String(e);if(this.__id!==t){if(this.__id=t,this.ownerShadowRoot){var r=this.ownerShadowRoot.__ddHost;r.__idCacheDirty=!0,this.__domElement&&r.__componentOptions.writeIdToDOM&&(this.__domElement.id=t)}Qo.writeExtraInfoToAttr&&this.__domElement&&this.__domElement.setAttribute("exparser:info-attr-id",t),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"id"})}},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"slot",{get:function(){return this.__slot},set:function(e){var t=String(e);this.__slot!==t&&(this.__inheritSlots||(this.__slot=t,function(e){for(var t=e.parentNode;t&&t.__inheritSlots;)t=t.parentNode;if(t&&!t.__singleSlot){var r=e.__slot||"",n=t.__slots[r];if(n){var i=$l(t,e,r,!1);Gl(n,e,i,!1,!0,!0)}else e.__ddSlotParent&&(n=e.__ddSlotParent,Gl(n,null,e,!0,!0,!0))}}(this),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"slot"})))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"attributes",{get:function(){var e=[];if(!this.__attributes)return e;for(var t in this.__attributes)e.push({name:t,value:this.__attributes[t]});return e},set:function(e){},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"class",{get:function(){return this.classList&&this.classList.getClassNames?this.classList.getClassNames():null},set:function(e){this.classList&&(this.classList.setClassNames(e),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"class"}))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"style",{get:function(){return this.__domElement?this.__domElement.style:null},set:function(e){this.setNodeStyle(e)},enumerable:!1,configurable:!0}),e.initialize=function(e,t,r){e.__id="",e.__slot="",e.__virtual=!1,e.__inheritSlots=!1,e.__attributes=null,e.__marks=null,e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=r,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Ql.backendExtractedDefault,e.__domElement=t,(e.$$=t)&&(t.__ddElement=e)},e.create=function(t){var r=new e;return e.initialize(r,t,null),r},e._clone=function(e,t,r,n){if(e.__id=t.__id,e.__slot=t.__slot,e.__virtual=t.__virtual,e.__inheritSlots=t.__inheritSlots,e.__marks=t.__marks?{}:null,e.__marks)for(var i in t.__marks)e.__marks[i]=t.__marks[i];for(var o in e.__attributes=Object.create(null),e.__attributes)e.__attributes[o]=t.__attributes[o];e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=n,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Ql.backendExtractedDefault,e.__domElement=r,e.$$=r,r&&(r.__ddElement=e)},e._updateIdMap=function(t){if(t.__idCacheDirty){t.__idCacheDirty=!1;var r=t.__idCache=Object.create(null);!function t(n){n.__id&&!r[n.__id]&&(r[n.__id]=n);for(var i=n.childNodes,o=0;o<i.length;o++)i[o]instanceof e&&t(i[o])}(t.shadowRoot)}},e.insertChildToElement=function(t,r,n,i){if(void 0===n&&(n=-1),void 0===i&&(i=!1),void 0!==t.__slotName)return!1;var o=0<=n?t.childNodes[n]:null;i&&r===o&&(i=!1);var a=null;if(r){a=r.parentNode,r.parentNode=t;var s=t.__subtreeObserversCount;if(a){var l=a.childNodes.indexOf(r);a.childNodes.splice(l,1),a===t&&l<n&&n--,s-=a.__subtreeObserversCount}s&&Rl._updateSubtreeCaches(r,s)}for(var u=t;u&&u.__inheritSlots;)u=u.parentNode;for(var c=!(u&&u.__slots),d=!(c&&!t.__inheritSlots),f=a;f&&f.__inheritSlots;)f=f.parentNode;var _=!(f&&f.__slots),p=!(_&&!(null==a?void 0:a.__inheritSlots)),h=t;if(c)void 0!==t.__singleSlot&&(h=t.__singleSlot),h?Gl(h,r,o,i,d,p,n):r.__ddSlotParent&&Gl(r.__ddSlotParent,null,r,!0,p,!1),r&&!_&&r.__inheritSlots&&Pl(r,(function(e,t){Gl(e,t,null,!1,!0,!0,-1)}));else{var v="";if(r&&(v=r.__slot||"",h=u.__slots[v]||null),o){var g=u.__slots[o.__slot||""]||null;g&&i&&Gl(g,null,o,i,!0,!1)}if(r)if(h){var m=o?$l(u,o,v,!i):$l(u,t,v,!1);Gl(h,r,m,!1,!0,p)}else r.__ddSlotParent&&Gl(r.__ddSlotParent,null,r,!0,p,!1);o&&i&&o.__inheritSlots&&Pl(o,(function(e,t){Gl(e,t,null,!1,!0,!0,-1)})),r&&r.__inheritSlots&&Pl(r,(function(e,r){var n=r.__slot||"",a=u.__slots[n]||null;if(a){var s=o?$l(u,o,n,!i):$l(u,t,n,!1);Gl(a,r,s,!1,!0,!0)}else r.__ddSlotParent&&Gl(r.__ddSlotParent,null,r,!0,!0,!1)}))}if(i&&(t.__subtreeObserversCount&&Rl._updateSubtreeCaches(o,-t.__subtreeObserversCount),o.parentNode=null),-1===n&&(n=t.childNodes.length),r?t.childNodes.splice(n,i?1:0,r):t.childNodes.splice(n,i?1:0),t.ownerShadowRoot&&(i&&zl(o,t.ownerShadowRoot),r&&zl(r,t.ownerShadowRoot),Vl(t.ownerShadowRoot)),i&&(Wl(o),kl(t,"remove",o)),r){if(a){r.__attached||Yl(r);!function t(r){if(r instanceof e){for(var n=r.childNodes,i=0;i<n.length;i++)t(n[i]);r.shadowRoot instanceof e&&t(r.shadowRoot),r.__lifeTimeFuncs&&r.__lifeTimeFuncs.moved.call(r.__methodCaller,[],r),r.__relationHandler&&r.__relationHandler("moved")}}(r)}else Yl(r);a===t?kl(t,"move",r):(a&&kl(a,"remove",r),kl(t,"add",r))}return!0},e.appendChild=function(e,t){return Ml(e,t,null,!1)},e.insertBefore=function(e,t,r){return Ml(e,t,r,!1)},e.removeChild=function(e,t){return Ml(e,null,t,!0)},e.replaceChild=function(e,t,r){return Ml(e,t,r,!0)},e.extractBackend=function(e){return e.__backendExtracted?null:(Zl(e),e.__domElement)},e.getMethodCaller=function(e){return e.__methodCaller},e.setMethodCaller=function(e,t){e.__methodCaller=t},e.setSlotName=function(e,t){if(t=null==t?"":String(t),!e.__slotName){if(0!==e.childNodes.length||0!==e.__ddSlotChildren.length)return;e.__ddSlotChildren=[]}e.__slotName=t,e.ownerShadowRoot&&(e.ownerShadowRoot.__slotCacheDirty=!0,Vl(e.ownerShadowRoot))},e.injectBackend=function(e,t){if(e.__backendExtracted){var r=document.createDocumentFragment();r.appendChild(t),Jl(e,r,0)}},e.parseSelector=function(e){for(var t=[],r=!1,n=0,i=String(e||"").split(",");n<i.length;n++){for(var o=i[n].split(/( |\t|>+)/g),a=[],s=0,l=void 0,u="";s<o.length;s++)if((l=o[s])&&" "!==l&&"\t"!==l)if(">"!==l[0]){var c=function(e,t){var r=e.match(/^(#[_a-zA-Z][-_a-zA-Z0-9:]*|)((?:\.-?[_a-zA-Z][-_a-zA-Z0-9]*)+|)$/);if(!r)return null;var n=r[1].slice(1),i=r[2].split(".");return i.shift(),n||i.length?{id:n,classes:i,relation:t||""}:null}(l,u);if(u="",!c)break;a.push(c)}else{if(""!==u)break;">>>"===(u=l)&&(r=!0)}s===o.length&&a.length&&t.push(a)}return t.length?{crossShadow:r,union:t}:null},e.delayDestroy=function(t){if(ca(t)){var r=t,n=e.delayDestroyViewElements[r],i=__virtualDOM__.TreeManager.get(r);if(i&&fa(n))for(var o=i.nodeId,a=0,s=void 0,l=n.length;a<l;a++)s=n[a],o&&o.removeNode(s),s.destroy(!0),n[a]=null;e.delayDestroyViewElements[r]=null}else if(t&&t.__treeManager__){ca(r=t.__treeManager__.viewId)&&r>0&&(e.delayDestroyViewElements[r]||(e.delayDestroyViewElements[r]=[]),e.delayDestroyViewElements[r].push(t))}},e.prototype.appendChild=function(e){return Ml(this,e,null,!1)},e.prototype.insertBefore=function(e,t){return Ml(this,e,t,!1)},e.prototype.removeChild=function(e){return Ml(this,null,e,!0)},e.prototype.replaceChild=function(e,t){return Ml(this,e,t,!0)},e.prototype.triggerEvent=function(e,t,r){_s.triggerEvent(this,e,t,r)},e.prototype.dispatchEvent=function(e){_s.dispatchEvent(this,e)},e.prototype.addListener=function(e,t,r){_s.addListenerToElement(this,e,t,r)},e.prototype.removeListener=function(e,t,r){_s.removeListenerFromElement(this,e,t,r)},e.prototype.getAttribute=function(e){if(!this.__attributes)return null;var t=this.__attributes[e];return void 0===t?null:t},e.prototype.setAttribute=function(e,t){this.__attributes||(this.__attributes=Object.create(null)),t=String(t),this.__attributes[e]=t,this.__domElement&&this.__domElement.setAttribute(e,t)},e.prototype.removeAttribute=function(e){this.__attributes&&(delete this.__attributes[e],this.__domElement&&this.__domElement.removeAttribute(e))},e.prototype.setMark=function(e,t){this.__marks||(this.__marks={}),this.__marks[e]=t},e.prototype.collectMarks=function(){for(var e={},t=this;t;t=t.parentNode)if(t.__marks)for(var r in t.__marks)Object.prototype.hasOwnProperty.call(e,r)||(e[r]=t.__marks[r]);return e},e.prototype.setNodeStyle=function(e,t){this.__styleSegments||(this.__styleSegments=[]),this.__styleSegments[t||0]=e;var r=this.__styleSegments.join(";");if(this.__domElement&&this.ownerShadowRoot&&this.ownerShadowRoot.__childrenPropsFilter){var n=this.ownerShadowRoot.__childrenPropsFilter.style;if("function"==typeof n)return void this.__domElement.setAttribute("style",n.call(this,r))}this.__domElement&&this.__domElement.setAttribute("style",r),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"style"})},e.replaceDocumentElement=function(e,t){e.__attached&&(t.parentNode.replaceChild(e.__domElement,t),Yl(e))},e.pretendAttached=function(e){e.__attached||Yl(e)},e.pretendDetached=function(e){e.__attached&&Wl(e)},e.isAttached=function(e){return e.__attached},e.setInheritSlots=function(e){e.__singleSlot||e.__slots||e.__ddSlotChildren.length||(e.__ddSlotChildren=[],e.__inheritSlots=!0)},e.getInheritSlots=function(e){return e.__inheritSlots},e.prototype._querySelector=function(t){var r;if(!(r="object"===ea(t)?t:e.parseSelector(t)))return null;var n=[];return Xl(n,r,this,this,!0),n[0]||null},e._attachShadowRoot=function(e){var t=e.__ddHost;t.__ddSlotChildren=[e],Gl(t,e,null,!1,!1,0),e.__hostAssociated=!0,Vl(e)},e.prototype.querySelector=function(t){var r="object"===ea(t)?t:e.parseSelector(t);if(!r)return null;var n=[];return Xl(n,r,this,this,!0),n[0]||null},e.prototype.querySelectorAll=function(t){var r="object"===ea(t)?t:e.parseSelector(t);if(!r)return[];var n=[];return Xl(n,r,this,this,!1),n},e.matchSelector=function(t,r){var n="object"===ea(t)?t:e.parseSelector(t);return!!n&&Kl(n,null,r)},e.prototype.matchSelector=function(t,r){var n="object"===ea(t)?t:e.parseSelector(t);return!!n&&Kl(n,this,r)},e.prototype.destroy=function(t){for(var r in void 0===t&&(t=!1),this.__ddEvents)this.__ddEvents[r].destroy(),this.__ddEvents[r]=void 0;for(var r in this.__ddEvents=void 0,this.__ddCaptureEvents)this.__ddCaptureEvents[r].destroy(),this.__ddCaptureEvents[r]=void 0;if(this.clearNodeRelation(),this.clearMPXProxy(),wa(this)&&this.__dataProxy&&this.__dataProxy.destroy(),t){if(wa(this)){if(this.__behavior){var n=Object.keys(this.__behavior.methods);for(var r in n)this[r]=null;this.__behavior&&this.__behavior.destroy()}this.__dataProxy=null,this.__using=null,this.__lifeTimeFuncs=null,this.__pageLifeTimeFuncs=null,this.__generics=null,this.__templateInstance=null,this.__innerData=null,this.__propData=null,this.__externalClassAlias=null,this.__idCacheDirty=null,this.__idCache=null,this.__relationMap=null,this.__componentInstanceId=null,this.__propertyChangeListeners=null,this.__componentOptions=null,this.__propPublic=null}this.__ddHost=null,this.__ddCaptureEvents=void 0,this.__propObservers&&this.__propObservers.destroy(),this.__propObservers=void 0,this.__childObservers&&this.__childObservers.destroy(),this.__childObservers=void 0,this.__textObservers&&this.__textObservers.destroy(),this.__textObservers=void 0,this.__attachedObservers&&this.__attachedObservers.destroy(),this.__attachedObservers=void 0,this.__vtObj=void 0,this.__treeManager__=void 0,this.__customConstructor__&&(this.__customConstructor__=void 0),this.__propData=void 0,this.__innerData=void 0,this.__dataProxy=void 0,this.dataset=null,this.classList=null,this.__styleSegments=null}else e.delayDestroy(this);this.__treeManager__=null},e.prototype.clearNodeRelation=function(){if(this.ownerShadowRoot&&(this.ownerShadowRoot.__treeManager__=null,this.ownerShadowRoot=null),this.shadowRoot&&(this.shadowRoot.__treeManager__=null,this.shadowRoot=null),this.__ddSlotParent&&(this.__ddSlotParent.__treeManager__=null,this.__ddSlotParent=void 0),this.__ddSlotChildren){for(var e=0;e<this.__ddSlotChildren.length;e++)this.__ddSlotChildren[e]&&(this.__ddSlotChildren[e].__treeManager__=null,this.__ddSlotChildren[e]=null);this.__ddSlotChildren=null}this.__ddSlotParent&&(this.__ddSlotParent=null),this.parentNode&&(this.parentNode.__treeManager__=null,this.parentNode=null)},e.prototype.clearMPXProxy=function(){if(this.__methodCaller){if(__virtualDOM__.CustomComponent.callerMap.delete(this.__methodCaller),this.__methodCaller.__mpxProxy){if(this.__methodCaller.__mpxProxy.data)for(var e=Object.keys(this.__methodCaller.__mpxProxy.data),t=0,r=void 0;t<e.length;t++)r=e[t],this.__methodCaller.__mpxProxy.data[r]=void 0,this.__methodCaller[r]=void 0;this.__methodCaller.__mpxProxy._watcher&&this.__methodCaller.__mpxProxy._watcher.cleanupDeps(),this.__methodCaller.__mpxProxy.clearWatchers(),this.__methodCaller.__mpxProxy.target=null,this.__methodCaller.__mpxProxy.data=null,this.__methodCaller.__mpxProxy=null}this.__methodCaller.__displayReporter&&(this.__methodCaller.__displayReporter=null),this.__methodCaller.__data__=null,this.__methodCaller.__exitState__=null,this.__methodCaller.__freeData__=null,this.__methodCaller=void 0}},e.delayDestroyViewElements={},e}();function tu(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=0,a=i[n];o<a.length;o++){var s=a[o];if(e["**"]||(e["**"]=[]),"**"===s)return void e["**"].push(r);e[s]||(e[s]={}),e=e[s]}e["~"]||(e["~"]=[]),e["~"].push(r)}}function ru(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=i[n],a="",s=0;s<o.length&&"**"!==(a=o[s]);s++){if(!e)return;e=e[a]}var l="**"===a?e["**"]:e["~"];if(l)for(s=0;s<l.length;s++)if(l[s]===r){l.splice(s,1);break}}}function nu(e,t,r,n,i){for(var o,a,s=0;s<e.length;s++)if(o=e[s],t[s]){t[s]=!1,a=i?void 0:n;for(var l=[],u=0,c=o.pathObj;u<c.length;u++){for(var d=0,f=c[u];d<f.length;d++){var _=f[d];if("**"===_)break;if("object"!==ea(a)){a=void 0;break}a=a[_]}l.push(a)}Aa.safeCallback("Data Observer",o.func,r.__methodCaller,l,r)}}pa(eu);var iu=function(){function e(e){this._observerTree={},this._propFields=e,this._observerIdInc=0,this._observers=[],this._observerTree={}}return e.prototype.addObserver=function(e,t){var r=this._observerIdInc++;return this._observers[r]={pathObj:t,func:e},tu(this._observerTree,t,r),r},e.prototype.removeObserver=function(e){var t=this._observers[e];ru(this._observerTree,t.pathObj,e),this._observers[e]=null},e.prototype.moveObserver=function(e,t){var r=this._observers[e];ru(this._observerTree,r.pathObj,e),r.pathObj=t,tu(this._observerTree,t,e)},e}(),ou=function(){function e(e,t,r,n,i,o){this._data=t,this._innerData=r,this._innerDataExclude=n,this._comp=e,this._updateCb=o,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=!1,this._changes=[],this._doingUpdates=null,this._propFields=i._propFields,this._observers=i._observers,this._observerTree=i._observerTree,this._relatedObserverTreeObj=i,this._observerStatus=[]}return e.setPropUpdater=function(t){e.propUpdater=t},e.setPropObserver=function(t){e.propObserver=t},e.create=function(t,r,n){return new e({__methodCaller:t},r,null,null,new iu({}),n)},e._advancedCreate=function(t,r,n,i,o,a){return new e(t,r,n,i,o,a)},e._createObserverTree=function(e){return new iu(e)},e.prototype.destroy=function(){this._data=null,this._innerData=null,this._innerDataExclude=null,this._comp&&this._comp.__dataProxy&&(this._comp.__dataProxy=null),this._comp=null,this._updateCb=null,this._relatedObserverTreeObj=null,this._observerStatus=null,this._propFields=null,this._observers=null,this._observerTree=null,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=null,this._changes=null,this._doingUpdates=null},e.prototype.scheduleReplace=function(e,t,r){fa(this._changes)&&this._changes.push([e,t,r])},e.prototype.setChanges=function(e){this._changes=e},e.prototype.doUpdates=function(t,r){var n=this._propFields,i=this._comp,o=this._hidingValue,a=this._innerDataExclude,s=!!this._doingUpdates,l=this._relatedObserverTreeObj._observerIdInc||null,u=null,c=null,d=null,f=this._changes;l?(s||(this._doingUpdates={changedPaths:[],changedValues:[],combinedChanges:[],changesTotal:0}),u=this._doingUpdates.changedPaths,c=this._doingUpdates.changedValues,d=this._doingUpdates.combinedChanges):(u=[],c=[],d=[]),this._changes=[];var _=[];this._beforeMergeCb&&this._beforeMergeCb(f,_,t);for(var p=0;p<f.length;p++){var h=f[p],v=h[0],g=v[0],m=!!a&&a.test(g),y=n[g],b=h[1],E=b,w=void 0;if(y&&1===v.length)w=this._data[g],b=e.propUpdater.call(this._comp,v,y,b,this._hidingValue),m||(this._innerData?(E=as(b),_[p]||(this._innerData[g]=E)):E=b,h[1]=E),m&&!this._innerData||(this._data[g]=b);else{var O=this._data,A=g,C=null,S=1;if(!m||this._innerData){for(;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?os.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!os.call(O,A)||null===O[A]||"object"!==ea(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;O[A]=b}if(this._innerData&&!m){for(O=this._innerData,A=g,S=1;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?os.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!os.call(O,A)||null===O[A]||"object"!==ea(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;E=as(b),_[p]||(O[A]=E),h[1]=E}}su(this._observerTree,this._observerStatus,v),m||(u.push(v),c.push([E,w,b]),d.push(h)),l&&(this._doingUpdates.changesTotal+=1)}if(!s){if(this._beforeUpdateCb&&this._beforeUpdateCb(t),l){var T=0;do{T=this._doingUpdates.changesTotal,nu(this._observers,this._observerStatus,i,this._data,o)}while(T!==this._doingUpdates.changesTotal);this._doingUpdates=null}this._updateCb(u,c,d,t);for(var N=0;N<c.length;N++){var x=c[N];if(x){var I=u[N],R=n[I[0]];R&&e.propObserver.call(i,x[2],x[1],I,R,o,r)}}}},e.prototype.getChanges=function(){return this._changes},e.prototype.getObserverTree=function(){return this._relatedObserverTreeObj},e.prototype.replaceWholeData=function(e){this._data=e},e.prototype.setHidingValue=function(e){this._hidingValue=!!e},e.prototype.setBeforeMergeCb=function(e){this._beforeMergeCb=e},e.prototype.setBeforeUpdateCb=function(e){this._beforeUpdateCb=e},e}();function au(e,t){for(var r in e)if("~"!==r)if("**"!==r)au(e[r],t);else for(var n=e["**"],i=0;i<n.length;i++)t[n[i]]=!0;else for(n=e["~"],i=0;i<n.length;i++)t[n[i]]=!0}function su(e,t,r){for(var n=0,i=r;n<i.length;n++){var o=i[n],a=e["**"];if(a&&a.forEach((function(e){t[e]=!0})),ca(o)){if(!os.call(e,o)){e=null;break}}else if(!/^[_a-zA-Z]/.test(o)||!os.call(e,o)){e=null;break}e=e[o]}e&&au(e,t)}var lu=/(~|\^+)?-?[_0-9a-z][-_0-9a-z]*/gi,uu=function(){function e(){}return e.create=function(t,r){void 0===r&&(r=null);var n=new e;for(var i in n._prefix="",n._addOriginalClass=!1,n._alias=r,n._resolvedAlias={},r)n._resolvedAlias[i]="";return n._rawNames=[],n._elem=t,n._owner=null,n},e.composeClassName=function(e){var t=e._rawNames,r=e._prefix,n=e._addOriginalClass,i=e._owner?e._owner._resolvedAlias:null,o="";r&&(r+="--");for(var a=0,s=void 0,l=t.length;a<l;a++)if(s=t[a],a>0&&(o+=" "),i&&Object.prototype.hasOwnProperty.call(i,s))o+=i[s];else if("~"===s[0])o+=s.slice(1);else if("^"===s[0]){s=s.slice(1);for(var u=e._owner||null;"^"===t[0];)s=s.slice(1),u=u?u._owner:null;var c=u?u._prefix:"";c&&(o+=(c+="--")+s)}else n&&(o+=s+" "),o+=r+s;return o},e.handleClassName=function(t){var r=t._elem.__domElement;if(r){var n=e.composeClassName(t);n?r.setAttribute("class",n):r.removeAttribute("class")}},e.aliasClassName=function(t){var r=t.classList;if(r instanceof e&&(r._alias&&e.resolveAlias(r),e.handleClassName(r)),fa(t.childNodes))for(var n=0,i=t.childNodes;n<i.length;n++){var o=i[n];Ea(o)&&e.aliasClassName(o)}},e.resolveAlias=function(t){var r=t._owner;if(r){var n,i,o=!1;for(n in t._alias){var a=[];if((i=t._alias[n])&&fa(i))for(var s=void 0,l=0,u=i;l<u.length;l++){var c=u[l];s=Object.prototype.hasOwnProperty.call(r._alias,c)?r._resolvedAlias[c]:t._prefix&&c?t._prefix+"--"+c:c,a.push(s)}var d=a.join(" ");t._resolvedAlias[n]!==d&&(o=!0,t._resolvedAlias[n]=d)}o&&Ea(t._elem.shadowRoot)&&e.aliasClassName(t._elem.shadowRoot)}},e.prototype.toggle=function(t,r){var n=this._rawNames.indexOf(t);r||(r=n<0),r?n<0&&(this._rawNames.push(t),e.handleClassName(this)):n>=0&&(this._rawNames.splice(n,1),e.handleClassName(this))},e.prototype.contains=function(e){for(var t=0,r=void 0,n=this._rawNames.length;t<n;t++)if("~"===(r=this._rawNames[t])[0]){if(r.slice(1)===e)return!0}else if("^"===r[0]){for(;"^"===r[0];)if(r.slice(1)===e)return!0}else if(r===e)return!0;return!1},e.prototype._setOwnerOptions=function(t,r,n){this._prefix!==r&&(this._prefix=r,this._addOriginalClass=n,this._owner=t,this._alias&&e.resolveAlias(this),e.handleClassName(this))},e.prototype._setAlias=function(t,r){var n=this._owner,i=String(r).match(lu),o=[];if(this._alias&&i){this._alias[t]=i;for(var a=0,s=i;a<s.length;a++){var l=s[a];n&&Object.prototype.hasOwnProperty.call(n._alias,l)?o.push(n._resolvedAlias[l]):o.push(this._prefix?this._prefix+"--"+l:l)}}this._resolvedAlias[t]=o.join(" "),e.aliasClassName(this._elem.shadowRoot)},e.prototype.setClassNames=function(t){t=null==t?"":String(t),this._rawNames=t.match(lu)||[],e.handleClassName(this)},e.prototype.getClassNames=function(){return e.composeClassName(this)},e.prototype.getPrefix=function(){return this._prefix},e.prototype.getAddOriginalClass=function(){return this._addOriginalClass},e}(),cu=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Eo(t,e),t.create=function(e){return t._advancedCreate(e,null)},t.cloneNode=function(e){return t._advancedCreate(e,null)},t._advancedCreate=function(e,r){var n=new t;n.is=e.toLowerCase();var i=null;if("dom"===Qo.documentBackend&&(i=Ql.backendExtractedDefault?new Ll(e):document.createElement(e)),eu.initialize(n,i,r),n.classList=uu.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),Qo.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t._advancedClone=function(e,r){var n=new t;n.is=e.is;var i=null;if(e.__domElement&&(i=e.__domElement instanceof Ll?Ql.backendExtractedDefault?e.__domElement.cloneNode():Ll.toElement(e.__domElement):Ql.backendExtractedDefault?Ll.fromElement(e.__domElement):document.importNode?document.importNode(e.__domElement,!1):e.__domElement.cloneNode(!1)),eu._clone(n,e,i,r),n.classList=uu.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),Qo.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t}(eu);ma(cu);var du=function(e){var t=e.is,r=e.classPrefix,n=e.generics,i=e.initiator,o=e.behavior,a=e.options;this._unprepared=o,this.is=t||"",this.behavior=o,this.protoFunc=null,this.props=null,this.template=null,this.innerEvents=null,this.generics=n,this.initiator=i||null,this.options={availability:a.availability||Qo.availability,domain:a.domain||Qo.domain,writeOnly:a.writeOnly||Qo.writeOnly,allowInWriteOnly:a.allowInWriteOnly||Qo.allowInWriteOnly,classPrefix:r,addGlobalClass:a.addGlobalClass||Qo.addGlobalClass,templateEngine:a.templateEngine||Qo.templateEngine||_a.freeTemplateEngine,renderingMode:a.renderingMode||Qo.renderingMode,multipleSlots:a.multipleSlots||Qo.multipleSlots,reflectToAttributes:a.reflectToAttributes||Qo.reflectToAttributes,writeFieldsToNode:a.writeFieldsToNode||Qo.writeFieldsToNode,writeIdToDOM:a.writeIdToDOM||Qo.writeIdToDOM,separateInnerData:a.separateInnerData||Qo.separateInnerData,innerDataExclude:a.innerDataExclude||Qo.innerDataExclude,listenerChangeLifeTimes:a.listenerChangeLifeTimes||Qo.listenerChangeLifeTimes,randomizeTagName:a.randomizeTagName||Qo.randomizeTagName,virtualHost:a.virtualHost||Qo.virtualHost,placeholder:a.placeholder}};function fu(e,t,r){t.__relationLinks||(t.__relationLinks={}),t.__relationLinks[r]=new Array(e.length).fill(null)}function _u(e,t,r){if(void 0===r&&(r=[]),Ea(e)){if(wa(e)){e.__pageLifeTimeFuncs[t]&&e.__pageLifeTimeFuncs[t].call(e.__methodCaller,r);for(var n=0,i=e.childNodes;n<i.length;n++)_u(i[n],t,r);e=e.shadowRoot}for(var o=0,a=e.childNodes;o<a.length;o++)_u(a[o],t,r)}}function pu(e,t,r,n,i){for(var o=ba().prototype.hasBehavior,a="parent"===n,s="shadowHost"===n,l=0,u=void 0;l<e.length;l++){var c="object"===ea((u=e[l]).target)?u.target:xl._list[u.target];if(c){var d=void 0;if(!i)for(var f=s?r.ownerShadowRoot&&r.ownerShadowRoot.__ddHost:r.parentNode;f;){if(!f.__virtual&&o.call(f,c)){for(var _=0,p=a?f.__relationMap.child:s?f.__relationMap.shadowContent:f.__relationMap.descendant;_<p.length;_++){var h=p[_],v="object"===ea(h.target)?h.target:xl._list[h.target];if(v&&o.call(r,v)){d={parent:f,relation:h};break}}if(a||d)break}f=s?f.ownerShadowRoot&&f.ownerShadowRoot.__ddHost:f.parentNode}var g=t[l];t[l]=d,!g||d&&g.parent===d.parent||(Aa.safeCallback("Relation Unlinked Callback",g.relation.unlinked,g.parent.__methodCaller,[r.__methodCaller],g.parent),Aa.safeCallback("Relation Unlinked Callback",u.unlinked,r.__methodCaller,[g.parent.__methodCaller],r)),!d||g&&g.parent===d.parent||(Aa.safeCallback("Relation Linked Callback",d.relation.linked,d.parent.__methodCaller,[r.__methodCaller],d.parent),Aa.safeCallback("Relation Linked Callback",u.linked,r.__methodCaller,[d.parent.__methodCaller],r)),g&&d&&g.parent===d.parent&&(Aa.safeCallback("Relation Link Changed Callback",d.relation.linkChanged,d.parent.__methodCaller,[r.__methodCaller],d.parent),Aa.safeCallback("Relation Link Changed Callback",u.linkChanged,r.__methodCaller,[d.parent.__methodCaller],r)),i||d||Aa.safeCallback("Relation Link Failed Callback",u.linkFailed,r.__methodCaller,[],r)}}}function hu(e,t){return function(r){return e.call(t.__methodCaller,r,t)}}dt({target:"Array",proto:!0},{fill:Zt}),Ae("fill");var vu=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Eo(t,e),t.register=function(e){var r=e.options||Object.create(null),n=xl.create(e),i=r.classPrefix||Qo.classPrefix;null==i&&(i=n.is||"");var o=new du({is:e.is,behavior:n,classPrefix:i,generics:n.generics,initiator:n.initiator,options:r});return n._unprepared&&t.prepare(o),e.is&&(t._list[n.is]=o),o},t.isPrepared=function(e){return!e._unprepared},t.prototype.getPlaceholder=function(e){return this.__placeholder[e]},t.prepare=function(e){var r=e._unprepared;function n(){}if(!t.isPrepared(e)){e._unprepared=null;var i=void 0;r._unprepared&&xl.prepare(r);var o=e.options,a=e.props={},s={};if(o.writeOnly&&(s.data={value:null}),Object.keys(r.properties).forEach((function(e){var t=r.properties[e];a[e]={type:t.type,optionalTypes:t.optionalTypes,value:t.value,filter:da(t.filter)?t.filter:null==t.filter?null:r.methods[t.filter],observer:da(t.observer)?t.observer:null==t.observer?null:r.methods[t.observer],public:t.public,availability:t.availability,observeAssignments:t.observeAssignments},o.writeFieldsToNode&&(s[e]={enumerable:!0,get:function(){return this.__propData[e]},set:function(t){this.__dataProxy.scheduleReplace([e],t),this.__dataProxy.doUpdates()}})})),e.protoFunc=n,n.prototype=Object.create(t.prototype,s),n.prototype.is=e.is,n.prototype.__componentOptions=o,n.prototype.__using=r.using,n.prototype.__placeholder=r.placeholder,e.dataGroupObserverTree=ou._createObserverTree(a),r._addObserversToDataProxy(e.dataGroupObserverTree),n.prototype.__behavior=r,o.writeFieldsToNode)for(i in r.methods)n.prototype[i]=r.methods[i];n.prototype.__lifeTimeFuncs=r._getAllLifeTimeFuncs(),n.prototype.__pageLifeTimeFuncs=r._getAllPageLifeTimeFuncs(),n.prototype.__relationMap={};var l=r.relations;for(i in l){var u=l[i];n.prototype.__relationMap[u.type]?n.prototype.__relationMap[u.type].push(u):n.prototype.__relationMap[u.type]=[u]}var c=[];n.prototype.__relationMap.parent&&c.push((function(e){pu(this.__relationMap.parent,this.__relationLinks.parent,this,"parent","detached"===e)})),n.prototype.__relationMap.ancestor&&c.push((function(e){pu(this.__relationMap.ancestor,this.__relationLinks.ancestor,this,"ancestor","detached"===e)})),n.prototype.__relationMap.shadowHost&&c.push((function(e){pu(this.__relationMap.shadowHost,this.__relationLinks.shadowHost,this,"shadowHost","detached"===e)})),e.relationHandler=function(e){for(var t=0;t<c.length;t++)c[t].call(this,e)};var d={},f={};for(i in r.data)f[i]=r.data[i];var _=void 0;for(i in a)_=a[i],f[i]=_.value,d[i]=_.public;var p=f,h=o.separateInnerData,v=o.innerDataExclude;if(v){for(i in p={},f)!1===v.test(i)&&(p[i]=f[i]);h||(f=p)}e.template=o.templateEngine.create(r,f,p,o),n.prototype.__propPublic=d,e.innerEvents=[];var g=r._getAllListeners();for(i in g){for(var m=g[i],y=i.indexOf("."),b=i.slice(y+1),E=y<1?"":i.slice(0,y),w=[],O=0,A=m.length,C=void 0;O<A;O++)da(C=m[O])||(C=null==C?null:r.methods[C]),w.push(C);e.innerEvents.push({id:E,name:b,funcs:w})}}},t._advancedCreate=function(e,r,n,i,o){var a;if(r&&r._unprepared&&t.prepare(r),!r||!r.options)throw new Error("Framework inner error (exparser not found "+e+")");da(r.options.availability)&&(Aa.safeCallback("Availablity Controller",r.options.availability,r,[n?n.__ddHost.__componentOptions.domain:void 0])||(r=t._list[""]));var s=new r.protoFunc,l=r.generics;if(l){var u={},c=void 0,d=void 0;for(a in l)c=l[a],"object"!==ea(d=i[a])&&(d=t._list[d]),"object"!==ea(d)&&null!=c.default&&(d=t._list[c.default]),d&&(u[a]=d);s.__generics=u}else s.__generics={};var f=null;r.options.virtualHost?(f="dom"===Qo.documentBackend?void 0:null,eu.initialize(s,f,n),s.__virtual=!0):"dom"===Qo.documentBackend?(f=Ql.backendExtractedDefault?new Ll(e):document.createElement(e),eu.initialize(s,f,n)):eu.initialize(s,null,n),s.__externalClassAlias={};var _=r.behavior.externalClasses;if(_&&fa(_))for(var p=0;p<_.length;p++)s.__externalClassAlias[_[p]]=null;if(s.classList=uu.create(s,s.__externalClassAlias),n){var h=n.__ddHost;if(s.classList._setOwnerOptions(h.classList,h.__componentOptions.classPrefix,h.__componentOptions.addGlobalClass),Qo.writeExtraInfoToAttr&&f){var v=h.__componentOptions.classPrefix&&h.__componentOptions.classPrefix+"--";f.setAttribute("exparser:info-class-prefix",v)}}Qo.writeExtraInfoToAttr&&f&&(s.__componentInstanceId=t.componentInstanceId++,f.setAttribute("exparser:info-component-id",String(s.__componentInstanceId))),s.__templateInstance=r.template.createInstance(s,o),s.__propData=s.__templateInstance.data;var g=r.options.separateInnerData,m=r.options.innerDataExclude;if(s.__innerData=g?as(s.__propData):null,g&&m){var y={};for(a in s.__innerData)m.test(a)||(y[a]=s.__innerData[a]);s.__innerData=y}if(s.__dataProxy=ou._advancedCreate(s,s.__propData,s.__innerData,m,r.dataGroupObserverTree,(function(e,t,r,n){var i=Qo.separateInnerData?s.__innerData:s.__propData;s.__templateInstance.updateValues(s,i,e,t,r,n)})),s.__templateInstance.beforeMergeValues&&s.__dataProxy.setBeforeMergeCb((function(e,t,r){s.__templateInstance.beforeMergeValues(e,t,r)})),s.__templateInstance.beforeUpdateValues){var b=g?s.__innerData:s.__propData;s.__dataProxy.setBeforeUpdateCb((function(e){s.__templateInstance.beforeUpdateValues(s,b,e)}))}Qo.writeOnly&&s.__dataProxy.setHidingValue(!0),s.__idCacheDirty=!1,s.__idCache=s.__templateInstance.idMap,null===s.__templateInstance.slots[""]&&(s.__templateInstance.slots[""]=f),r.options.multipleSlots?s.__slots=s.__templateInstance.slots:(s.__singleSlot=s.__templateInstance.slots[""]||null,s.__singleSlot&&(s.__singleSlot.__ddSlotChildren=s.childNodes)),Ea(s.__templateInstance.shadowRoot)?(s.shadowRoot=s.__templateInstance.shadowRoot,eu._attachShadowRoot(s.__templateInstance.shadowRoot)):(f instanceof Ll?(s.shadowRoot=f,s.shadowRoot.__ddHost=s,s.shadowRoot.__ddHost.__domElement.asShadowRoot=s.__templateInstance.shadowRoot):(s.shadowRoot=f,s&&s.shadowRoot&&(s.shadowRoot.__ddHost=s),s&&s.shadowRoot&&s.shadowRoot.__ddHost.__domElement.appendChild(s.__templateInstance.shadowRoot)),s.__ddSlotChildren=[f],f&&(f.__ddSlotParent=s));for(var E=0,w=s.__templateInstance.listeners;E<w.length;E++){var O=w[E];_s.addListenerToElement(O.target,O.name,hu(O.func,s))}for(var A=0,C=r.innerEvents;A<C.length;A++){var S=C[A],T=S.id?"this"===S.id?s:s.__idCache[S.id]:s.shadowRoot;if(T)for(var N=S.name,x=0,I=S.funcs;x<I.length;x++){var R=I[x];_s.addListenerToElement(T,N,hu(R,s))}}var L=s.__relationMap;return L.parent&&(fu(L.parent,s,"parent"),s.__relationHandler=r.relationHandler),L.ancestor&&(fu(L.ancestor,s,"ancestor"),s.__relationHandler=r.relationHandler),L.shadowHost&&(fu(L.shadowHost,s,"shadowHost"),s.__relationHandler=r.relationHandler),s.__propertyChangeListeners=null,r.initiator&&Aa.safeCallback("Component Initiator",r.initiator,s.__methodCaller,[],s),s.__lifeTimeFuncs.created.call(s.__methodCaller,[],s),s},t.createWithGenerics=function(e,r,n,i){var o;if(e instanceof du)o=t._advancedCreate(e.is,e,null,n,i);else if(e)if(-1!==e.indexOf("-")||r){var a=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];o=t._advancedCreate(e.toLowerCase(),a,null,n,i)}else o=cu.create(e);else o=t._advancedCreate("virtual",t._list[""],null,n,i);return o},t.create=function(e,r,n){var i;if(e instanceof du)i=t._advancedCreate(e.is,e,null,null,n);else if(e)if(-1!==e.indexOf("-")||r){var o=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];i=t._advancedCreate(e.toLowerCase(),o,null,null,n)}else i=cu.create(e);else i=t._advancedCreate("virtual",t._list[""],null,null,n);return i},t.listProperties=function(e){var t=[];for(var r in e.__propPublic)void 0!==e.__propPublic[r]&&t.push(r);return t},t.listPublicProperties=function(e){var t=[];for(var r in e.__propPublic)!0===e.__propPublic[r]&&t.push(r);return t},t.hasProperty=function(e,t){return void 0!==e.__propPublic[t]},t.hasPublicProperty=function(e,t){return!0===e.__propPublic[t]},t.getMethodsFromDef=function(e){return e.behavior._unprepared&&xl.prepare(e.behavior),e.behavior.methods},t.getMethod=function(e,t){return e.__behavior.methods[t]},t.getComponentOptions=function(e){if(e)return e.__componentOptions},t.getInnerData=function(e){return e.__innerData},t.getDataProxy=function(e){return e.__dataProxy},t.replaceWholeData=function(e,t){e.__propData=t,e.__dataProxy.replaceWholeData(t)},t.prototype.triggerLifeTime=function(e,t){void 0===t&&(t=[]),this.__lifeTimeFuncs[e].call(this.__methodCaller,t||[])},t.prototype.triggerPageLifeTime=function(e,t){void 0===t&&(t=[]),_u(this,e,t)},t.prototype.hasBehavior=function(e){return"object"!==ea(e)&&Object.prototype.hasOwnProperty.call(this.__using,e)&&(e=this.__using[e]),this.__behavior instanceof xl&&this.__behavior.hasBehavior(e)},t.prototype.getRootBehavior=function(){return this.__behavior},t.prototype.getRelationNodes=function(e){var t=this.__behavior.relations[e];if(!t)return null;var r=t.type,n="child"===r,i="shadowContent"===r;if("parent"!==r&&"ancestor"!==r&&"shadowHost"!==r){var o=this,a=[];return function e(r){var s=r.childNodes;if(Array.isArray(s))for(var l=0,u=void 0;l<s.length;l++)if((u=s[l])instanceof eu)if(u.__virtual)e(u);else{if(u.__relationLinks){var c=n?u.__relationLinks.parent:i?u.__relationLinks.shadowHost:u.__relationLinks.ancestor;if(c)for(var d=0,f=void 0;d<c.length;d++)if((f=c[d])&&f.parent===o&&f.relation===t){a.push(u);break}}i&&wa(u)&&e(u.shadowRoot),n||e(u)}}(i?o.shadowRoot:o),a}for(var s=this.__relationMap[t.type],l=0;l<s.length;l++)if(s[l]===t)return this.__relationLinks[t.type][l]?[this.__relationLinks[t.type][l].parent]:[]},t.prototype.hasExternalClass=function(e){return Object.prototype.hasOwnProperty.call(this.__externalClassAlias,e)},t.prototype.setExternalClass=function(e,t){this.classList._setAlias(e,t)},t.prototype.setPropertyChangeListener=function(e,t){this.__propertyChangeListeners||(this.__propertyChangeListeners={}),this.__propertyChangeListeners[e]=t},t.prototype.replaceDataOnPath=function(e,t){this.__dataProxy.scheduleReplace(e,t)},t.prototype.isInnerDataExcluded=function(e){var t=this.__componentOptions.innerDataExclude;return!!t&&t.test(e)},t.prototype.applyDataUpdates=function(){this.__dataProxy.doUpdates()},t.prototype.setData=function(e){var t=this.__dataProxy;for(var r in e)t.scheduleReplace(hl(r),e[r]);t.doUpdates()},Object.defineProperty(t.prototype,"data",{get:function(){return this.__dataProxy?this.__dataProxy._data:null},set:function(e){if(this.__dataProxy){for(var t in e)this.__dataProxy.scheduleReplace([t],e[t]);this.__dataProxy.doUpdates()}},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"$",{get:function(){return eu._updateIdMap(this),this.__idCache},set:function(e){},enumerable:!1,configurable:!0}),t._list={},t.componentInstanceId=1,t}(eu);ou.setPropUpdater((function(e,t,r,n){var i=e[0],o=this.__propData[i];if(r=function(e,t,r){if(r)for(var n=0;n<r.length;n++)if(xl.matchTypeWithValue(r[n],e))return e;switch(t){case String:return null===e?"":String(e);case Number:return isFinite(e)?Number(e):e;case Boolean:return!!e;case Array:return e instanceof Array?e:[];case Object:return"object"===ea(e)?e:null;default:return void 0===e?null:e}}(r,t.type,t.optionalTypes),t.availability){var a=this,s=t.availability,l=[a.ownerShadowRoot?a.ownerShadowRoot.__wxHost.__componentOptions.domain:void 0,n?void 0:r];if(!Aa.safeCallback("Availablity Controller",s,a.__methodCaller,l,a))return o}if(t.filter){var u=Aa.safeCallback("Property Filter",t.filter,this.__methodCaller,n?[]:[r,o,e],this);void 0!==u&&(r=u)}if(this.__domElement&&this.__componentOptions.reflectToAttributes&&this.__propPublic[i]){a=this;var c=i.replace(/(\w)([A-Z])/g,(function(e,t,r){return t+"-"+r.toLowerCase()})),d=ea(r);"boolean"===d?r?a.__domElement.setAttribute(c,""):a.__domElement.removeAttribute(c):"object"===d?a.__domElement.setAttribute(c,JSON.stringify(r)):a.__domElement.setAttribute(c,r)}return r})),ou.setPropObserver((function(e,t,r,n,i,o){if(n.observeAssignments||e!==t){var a=r[0];this.__propertyChangeListeners&&this.__propertyChangeListeners[a]&&!o&&Aa.safeCallback("Property Observer",this.__propertyChangeListeners[a],this.__methodCaller,[e],this),da(n.observer)&&Aa.safeCallback("Property Observer",n.observer,this.__methodCaller,i?[]:[e,t,r],this),n.public&&(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:a})}})),ha(vu);var gu=function(){function e(){}return e.create=function(t){return void 0===t&&(t=""),e._advancedCreate(t,null)},e._advancedCreate=function(t,r){void 0===t&&(t="");var n=new e;n.__slot="";var i=null;return!1===Ql.backendExtractedDefault&&("dom"===Qo.documentBackend?(i=document.createTextNode(t)).__ddElement=n:n.__textContent=t),n.$$=i,n.__domElement=i,n.__backendExtracted=Ql.backendExtractedDefault,n.__subtreeObserversCount=0,n.parentNode=null,n.ownerShadowRoot=r,n},Object.defineProperty(e.prototype,"textContent",{get:function(){return this.__domElement?this.__domElement.textContent:this.__textContent},set:function(e){this.__domElement?this.__domElement.textContent=e:this.__textContent=e,(this.__textObservers&&!this.__textObservers.empty||this.__subtreeObserversCount)&&Rl._callObservers(this,"__textObservers",{type:"characterData",target:this})},enumerable:!1,configurable:!0}),e.prototype.destroy=function(e){this.__textContent=null,this.parentNode=null,this.ownerShadowRoot=null,this.$$=null,this.__slot=null,this.__ddHost=null,this.__ddSlotParent=null,e?(this.__textObservers.destroy(),this.__textObservers=null):eu.delayDestroy(this)},e}();ga(gu);var mu=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Eo(t,e),t.initialize=function(e,t,r){e.is=t||"";var n=null;"dom"===Qo.documentBackend&&(n=void 0),eu.initialize(e,n,r),e.__virtual=!0},t.create=function(e){var r=new t;return t.initialize(r,e,null),r},t._advancedCreate=function(e,r){var n=new t;return t.initialize(n,e,r),n},t}(eu);ya(mu);var yu=function(e){function t(t){var r=e.call(this)||this;return mu.initialize(r,"shadow",r),r.__hostAssociated=!1,r.__ddHost=t,r.__childrenPropsFilter=null,r.__slotCacheDirty=!1,r}return Eo(t,e),t.create=function(e){var r=new t(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(r.__childrenPropsFilter)for(var n in e.ownerShadowRoot.__childrenPropsFilter)r.__childrenPropsFilter[n]||(r.__childrenPropsFilter[n]=e.ownerShadowRoot.__childrenPropsFilter[n]);else r.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;return r},t.prototype.createTextNode=function(e){return gu._advancedCreate(e,this)},t.prototype.createNativeNode=function(e){return cu._advancedCreate(e,this)},t.prototype.cloneNativeNode=function(e){return cu._advancedClone(e,this)},t.prototype.createVirtualNode=function(e){return mu._advancedCreate(e,this)},t.prototype.createComponent=function(e,t,r,n){var i=Object.prototype.hasOwnProperty,o=t||e,a=this.__ddHost;if("object"!==ea(o)&&(i.call(a.__using,o)?o=a.__using[o]:i.call(a.__generics,o)&&(o=a.__generics[o]),"object"!==ea(o)&&(o=vu._list[o]||vu._list[""])),r&&(r=function(e,t){var r={};for(var n in e){var o=e[n];"object"!==ea(o)&&(i.call(t.__using,o)?o=t.__using[o]:i.call(t.__generics,o)&&(o=t.__generics[o]||vu._list[""]),r[n]=o)}return r}(r,a)),"object"===ea(e)&&(e=o.is),a.__componentOptions.randomizeTagName){e=function(){for(var e=Date.now(),t="exparser-",r=0;r<8;r++){var n=(e+Math.floor(26*Math.random()))%26;e=Math.floor(e/26),t+="abcdefghijklmnopqrstuvwxyz"[n]}return t}()}return a.__componentOptions.writeOnly&&!o.options.allowInWriteOnly&&(o=vu._list[""]),vu._advancedCreate(e,o,this,r,n)},t.prototype.tagNameUsed=function(e){var t=this.__ddHost,r=Object.prototype.hasOwnProperty;return!!r.call(t.__using,e)||!!r.call(t.__generics,e)},t.prototype.getHostNode=function(){return this.__ddHost},t.prototype.getElementById=function(e){return eu._updateIdMap(this.__ddHost),this.__ddHost.__idCache[e]},t}(mu),bu=function(){function e(){}return e.getInstance=function(){return e.instance||(e.instance=new e)},e.iterator=function(t){var r=e.getInstance();return r._iterator=r._getElementChildren(t),r._iterator},e.create=function(t,r,n){var i=new e;if(!Ea(t)&&!Oa(t))throw new Error("ElementIterator can only be used for exparser.Element or exparser.TextNode");i._elem=t,i._elemTypeLimit=n||eu;var o=r.split("-");if("shadow"===o[0])i._composed=!1;else{if("composed"!==o[0])throw new Error("Unrecognized iterator type: "+r);i._composed=!0}if("ancestors"===o[1])i._relation="ancestors",i._order=0;else{if("descendants"!==o[1])throw new Error("Unrecognized iterator type: "+r);if(i._relation="descendants","root"!==o[2])throw new Error("Unrecognized iterator type: "+r);if("first"===o[3])i._order=-1;else{if("last"!==o[3])throw new Error("Unrecognized iterator type: "+r);i._order=1}}return i},e.prototype.forEach=function(e){if("ancestors"===this._relation){for(var t=this._elem;t;){if(t instanceof this._elemTypeLimit&&!1===e(t))return!1;t=this._composed&&(t.__ddSlotParent||t.__ddHost)||t.parentNode}return!0}return Eu(this._elem,this._elemTypeLimit,this._composed,this._order,e)},e.prototype._getElementChildren=function(e){var t=this;return e.childNodes&&e.childNodes.length&&e.childNodes.forEach((function(e){t._getElementChildren(e)})),e},e}();function Eu(e,t,r,n,i){if(n<0&&e instanceof t&&!1===i(e))return!1;var o=r&&e.__ddSlotChildren||e.childNodes;if(o)for(var a=0;a<o.length;a++){if(!1===Eu(o[a],t,r,n,i))return!1}return!(0<n&&e instanceof t&&!1===i(e))}var wu=D("isConcatSpreadable"),Ou=9007199254740991,Au="Maximum allowed index exceeded",Cu=R>=51||!e((function(){var e=[];return e[wu]=!1,e.concat()[0]!==e})),Su=ho("concat"),Tu=function(e){if(!B(e))return!1;var t=e[wu];return void 0!==t?!!t:Sn(e)};function Nu(){}dt({target:"Array",proto:!0,forced:!Cu||!Su},{concat:function(e){var t,r,n,i,o,a=g(this),s=Nn(a,0),l=0;for(t=-1,n=arguments.length;t<n;t++)if(Tu(o=-1===t?a:arguments[t])){if(l+(i=te(o.length))>Ou)throw TypeError(Au);for(r=0;r<i;r++,l++)r in o&&_o(s,l,o[r])}else{if(l>=Ou)throw TypeError(Au);_o(s,l++,o)}return s.length=l,s}});var xu={title:"browser",browser:!0,env:{},argv:[],version:"",versions:{},on:Nu,addListener:Nu,once:Nu,off:Nu,removeListener:Nu,removeAllListeners:Nu,emit:Nu,prependListener:Nu,prependOnceListener:Nu,listeners:function(){return[]},binding:function(){throw new Error("process.binding is not supported")},cwd:function(){return"/"},chdir:function(){throw new Error("process.chdir is not supported")},umask:function(){return 0}};function Iu(e,t,r,n,i){var o;e.linked?Ru.updateBinding(e,t,r,n,i):(o=n[e.name],n[e.name]=e.exp(r,n,i),Ru.updateBinding(e,t,r,n,i),n[e.name]=o)}var Ru={create:function(e,t,r,n,i,o,a){for(var s={inc:1,name:e,exp:n,lp:i,scopes:{},targets:{},children:null,lu:a,__scopeBinded:[]},l=0;l<o.length;l++){var u=o[l];null===u[0]?Ru.addBinding(t,u,null,s):Ru.addBinding(r[u[0]],u,null,s)}return s},proxyTopScope:function(e){var t={inc:1,linked:e,scopes:{},targets:{},children:null,__scopeBinded:[]};return Ru.addBinding(e,[null],null,t),t},proxySubScopes:function(e){var t={};for(var r in e)t[r]={inc:1,linked:e[r],scopes:{},targets:{},children:null,__scopeBinded:[]},Ru.addBinding(e[r],[null],null,t[r]);return t},addBinding:function(e,t,r,n){for(var i=e,o=1,a=void 0;o<t.length;o++){a=t[o],i.children||(i.children=Object.create(null));var s=i.children;s[a]||(s[a]={scopes:{},targets:{},children:null}),i=s[a]}var l=e.inc++;return r?i.targets[l]=[r,n]:(i.scopes[l]=n,i.scopes[l].__scopeBinded.push([i,l])),l},addBindings:function(e,t,r,n,i){for(var o=0;o<r.length;o++){var a=r[o];a[0]?Ru.addBinding(t[a[0]],a,n,i):Ru.addBinding(e,a,n,i)}},updateBinding:function(e,t,r,n,i){for(var o,a=e,s=0;s<t.length;s++){for(o in a.scopes)Iu(a.scopes[o],t,r,n,i);var l=t[s],u=a.children;if(!u||!u[l])return;a=u[l]}!function e(t){for(o in t.targets){var a=t.targets[o],s=a[1];s.o(a[0],s.n,s.e(r,n,i))}for(o in t.scopes)Iu(t.scopes[o],[],r,n,i);for(o in t.children)e(t.children[o])}(a)},updateLvaluePath:function(e,t){e.lp=t},removeBindingsForScope:function(e){for(var t=e.__scopeBinded,r=0,n=void 0;r<t.length;r++)delete(n=t[r])[0].scopes[n[1]]}},Lu=q.f,Mu=Qe.f,ku=$e.enforce,Pu=D("match"),ju=f.RegExp,Du=ju.prototype,Bu=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Fu=/a/g,Uu=/a/g,Gu=new ju(Fu)!==Fu,Hu=hs.UNSUPPORTED_Y,Vu=U&&(!Gu||Hu||gs||ys||e((function(){return Uu[Pu]=!1,ju(Fu)!=Fu||ju(Uu)==Uu||"/a/i"!=ju(Fu,"i")})));if(ut("RegExp",Vu)){for(var zu=function(e,t){var r,n,i,o,a,s,l=this instanceof zu,u=$s(e),c=void 0===t,d=[],f=e;if(!l&&u&&c&&e.constructor===zu)return e;if((u||e instanceof zu)&&(e=e.source,c&&(t="flags"in f?f.flags:ra.call(f))),e=void 0===e?"":ta(e),t=void 0===t?"":ta(t),f=e,gs&&"dotAll"in Fu&&(n=!!t&&t.indexOf("s")>-1)&&(t=t.replace(/s/g,"")),r=t,Hu&&"sticky"in Fu&&(i=!!t&&t.indexOf("y")>-1)&&(t=t.replace(/y/g,"")),ys&&(e=(o=function(e){for(var t,r=e.length,n=0,i="",o=[],a={},s=!1,l=!1,u=0,c="";n<=r;n++){if("\\"===(t=e.charAt(n)))t+=e.charAt(++n);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:Bu.test(e.slice(n+1))&&(n+=2,l=!0),i+=t,u++;continue;case">"===t&&l:if(""===c||y(a,c))throw new SyntaxError("Invalid capture group name");a[c]=!0,o.push([c,u]),l=!1,c="";continue}l?c+=t:i+=t}return[i,o]}(e))[0],d=o[1]),a=kn(ju(e,t),l?this:Du,zu),(n||i||d.length)&&(s=ku(a),n&&(s.dotAll=!0,s.raw=zu(function(e){for(var t,r=e.length,n=0,i="",o=!1;n<=r;n++)"\\"!==(t=e.charAt(n))?o||"."!==t?("["===t?o=!0:"]"===t&&(o=!1),i+=t):i+="[\\s\\S]":i+=t+e.charAt(++n);return i}(e),r)),i&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{ke(a,"source",""===f?"(?:)":f)}catch(e){}return a},$u=function(e){e in zu||Lu(zu,e,{configurable:!0,get:function(){return ju[e]},set:function(t){ju[e]=t}})},Yu=Mu(ju),Wu=0;Yu.length>Wu;)$u(Yu[Wu++]);Du.constructor=zu,zu.prototype=Du,Ke(f,"RegExp",zu)}Mn("RegExp");var Zu,Ju={TAG_START:1,TAG_END:-1,TEXT:3,COMMENT:8},qu="m",Ku="f",Xu="e",Qu="c",ec="t",tc="s",rc={n:"\n",r:"\r",b:"\b",f:"\f",t:"\t",v:"\v",'"':'"',"'":"'","\\":"\\","\r":"\r","\n":"\n"},nc={},ic="";for(Zu in rc)nc[rc[Zu]]=Zu,ic+=rc[Zu];var oc=new RegExp("["+ic+"]","g"),ac=1,sc=-1,lc=8,uc=["area","base","br","col","embed","hr","img","link","meta","input","keygen","source","param","track","wbr"];function cc(e,t){return e.substring(t)}function dc(e){var t=new RegExp("^<((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)"),r=/^\s*(\/?)>/,n=/^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/,i=e.match(t);if(i){e=cc(e,i[0].length);for(var o={t:ac,n:i[1],a:[],selfClose:!(uc.indexOf(i[1])<0)||void 0},a=void 0,s=void 0;!(a=e.match(r))&&(s=e.match(n));){e=cc(e,s[0].length);var l=s[3]||s[4]||s[5]||"";o.a.push({n:String(s[1]),v:String(l)})}if(a)return{match:o,html:e=cc(e,a[0].length)}}}function fc(e){var t=new RegExp("^<\\/((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)[^>]*>"),r=e.match(t);return e=cc(e,r[0].length),{match:{t:sc,n:r[1]},html:e}}function _c(e){var t=e.indexOf("--\x3e");if(t<0)throw new Error("💔fail to compile html template: comment no end");var r={t:lc,c:e.substring(4,t)};return{html:e=cc(e,t+3),match:r}}function pc(e){var t,r={t:3,c:null},n="[a-zA-Z_][\\w\\-\\.]*",i="((?:"+n+"\\:)?"+n+")",o=new RegExp("^<"+i),a=new RegExp("^<\\/"+i+"[^>]*>"),s=e.indexOf("<");if(s>=0){for(t=e.slice(s);!o.test(t)&&!a.test(t);){var l=t.indexOf("<",1);if(l<0){s+=t.length;break}s+=l,t=e.slice(s)}r.c=e.substring(0,s),e=cc(e,s)}return s<0&&(r.c=e,e=""),{match:r,html:e}}var hc={parse:function(e){var t="[a-zA-Z_][\\w\\-\\.]*",r="((?:"+t+"\\:)?"+t+")",n=new RegExp("^<"+r),i=new RegExp("^<\\/"+r+"[^>]*>"),o=new RegExp("^\x3c!--"),a=[];e=function(e){return e.replace(/\n|\r|\t|\f/g," ")}(e);try{for(;e;){var s=void 0;s=e.match(n)?dc(e):e.match(i)?fc(e):e.match(o)?_c(e):pc(e),e=s.html,a.push(s.match)}return a}catch(e){}}},vc=/^[ \n\r\t\f]+|[ \n\r\t\f]+$/g,gc=Qo.hasDOMBackend?document.createElement("div"):null,mc={amp:"&",gt:">",lt:"<",nbsp:" ",quot:'"',apos:"'"},yc=function(){function e(){}return e.decodeEntities=function(e){return e.replace(/&(([a-zA-Z]+)|(#x{0,1}[\da-zA-Z]+));/gi,(function(e,t){if(mc[t])return mc[t];if(/^#[0-9]{1,4}$/.test(t))return String.fromCharCode(t.slice(1));if(/^#x[0-9a-f]{1,4}$/i.test(t))return String.fromCharCode("0"+t.slice(1));if(Qo.hasDOMBackend){var r=e;return gc?(gc.innerHTML=r,gc.innerText||gc.textContent):r}return e}))},e.parse=function(t,r){for(var n=hc.parse(t)||[],i={c:[]},o=i,a=[],s=0;s<n.length;s++){var l=n[s];if(l.t===Ju.TAG_START){var u={t:Ju.TAG_START,n:l.n,a:l.a,c:[]};o.c.push(u),l.selfClose||(a.push(o),o=u)}else if(l.t===Ju.TAG_END){var c=a.length-1,d=!0;for(u=o;l.n!==u.n;)if(!(u=a[c--])){d=!1;break}if(d)for(;a.length>c;)o=a.pop()}else l.t===Ju.TEXT&&(l.c=e.decodeEntities(r?l.c:l.c.replace(vc,"")),l.c&&o.c.push(l))}return i.c},e.TAG_TYPES=Ju,e}(),bc=" \n\r\t\f",Ec=["true","false","null","undefined"],wc={$1:{VARIABLE:[{id:"_concat",states:["a-zA-Z_$","VARIABLE_AFTER"]}],VARIABLE_AFTER:[{id:"_concat",states:["a-zA-Z_$0-9","VARIABLE_AFTER"]},{id:"_null",states:["NULL"]}],STRING:[{id:"str^",states:["'","STRING_INNER_1"]},{id:"str^",states:['"',"STRING_INNER_2"]}],STRING_INNER_1:[{id:"str$",states:["'"]},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_1"]},{id:"_concat",states:["ALL","STRING_INNER_1"]}],STRING_INNER_2:[{id:"str$",states:['"']},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_2"]},{id:"_concat",states:["ALL","STRING_INNER_2"]}],NUMBER:[{id:"_concat",states:["NUMBER_BEFORE_E","NUMBER_E"]}],NUMBER_E:[{id:"_concat",states:["e","NUMBER_AFTER_E"]},{id:"_null",states:["NULL"]}],NUMBER_AFTER_E:[{id:"_concat",states:["-","NUMBER_AFTER_E-INT"]},{id:"_jump",states:["NUMBER_AFTER_E-INT"]}],"NUMBER_AFTER_E-INT":[{id:"_concat",states:["NUMBER_AFTER_E-INT","0-9"]},{id:"_jump",states:["0-9"]}],NUMBER_BEFORE_E:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0","NUMBER_AFTER_ZERO"]},{id:"_concat",states:["1-9","NUMBER_AFTER_NON_ZERO"]}],NUMBER_AFTER_ZERO:[{id:"_concat",states:["x","NUMBER_BASE_16"]},{id:"_jump",states:["NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_BASE_16:[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]}],"NUMBER_BASE_16-AFTER":[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_NON_ZERO:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0-9","NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_DOT:[{id:"_concat",states:["NUMBER_AFTER_DOT","0-9"]},{id:"_jump",states:["0-9"]}],VALUE:[{id:"_blank",states:[bc,"VALUE"],overwrite:!0},{id:"_jump",states:["VALUE_NOSPACE"]}],VALUE_NOSPACE:[{id:"_jump",states:["VALUE_NOSPACE",bc]},{id:"var",states:["VARIABLE"]},{id:"str",states:["STRING"]},{id:"num",states:["NUMBER"]},{id:"()",states:["(","COMMA",")"]},{id:"al",states:["[","ARRAY_ITEMS","]"]},{id:"ol",states:["{","OBJECT_ITEMS","}"]}],ARRAY_ITEMS:[{id:"_blank",states:[bc,"ARRAY_ITEMS"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEMS_NOSPACE"]}],ARRAY_ITEMS_NOSPACE:[{id:"_join",states:["ARRAY_ITEMS_NOSPACE",",","ARRAY_ITEM"]},{id:"_jump",states:["ARRAY_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],ARRAY_ITEM:[{id:"_blank",states:[bc,"ARRAY_ITEM"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEM_NOSPACE"]}],ARRAY_ITEM_NOSPACE:[{id:"ai",states:["CONDITIONAL"]},{id:"aie",states:["NULL"],overwrite:!0}],OBJECT_ITEMS:[{id:"_join",states:["OBJECT_ITEMS",",","OBJECT_ITEM_AFTER_COMMA"]},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM_AFTER_COMMA:[{id:"_blank",states:[bc,"OBJECT_ITEM_AFTER_COMMA"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM:[{id:"_blank",states:[bc,"OBJECT_ITEM"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM_NOSPACE"]}],OBJECT_ITEM_NOSPACE:[{id:"_jump",states:["OBJECT_ITEM_NOSPACE",bc]},{id:"onv",states:["VARIABLE","OBJECT_ITEM_AFTER"]},{id:"ons",states:["STRING","OBJECT_ITEM_AFTER"]},{id:"onn",states:["NUMBER","OBJECT_ITEM_AFTER"]}],OBJECT_ITEM_AFTER:[{id:"_blank",states:[bc,"OBJECT_ITEM_AFTER"],overwrite:!0},{id:"ov",states:[":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],MEMBER:[{id:"_jump",states:["MEMBER",bc]},{id:"_op2",states:["MEMBER",".","VARIABLE_WITH_BLACK"]},{id:"[]",states:["MEMBER","[","CONDITIONAL","]"]},{id:"f()",states:["MEMBER","(","FUNCARGS",")"]},{id:"_jump",states:["VALUE"]}],VARIABLE_WITH_BLACK:[{id:"_blank",states:[bc,"VARIABLE_WITH_BLACK"],overwrite:!0},{id:"_jump",states:["VARIABLE"]}],FUNCARGS:[{id:"_blank",states:[bc,"FUNCARGS"],overwrite:!0},{id:"_join",states:["FUNCARGS",",","CONDITIONAL"]},{id:"fa",states:["CONDITIONAL"]},{id:"_empty",states:["NULL"],overwrite:!0}],LOGICAL:[{id:"_blank",states:[bc,"LOGICAL"],overwrite:!0},{id:"_jump",states:["LOGICAL_NOSPACE"]}],LOGICAL_NOSPACE:[{id:"!",states:["!","LOGICAL"]},{id:"!",states:["+","LOGICAL"]},{id:"!",states:["-","LOGICAL"]},{id:"_jump",states:["MEMBER"]}],MULTIPLY:[{id:"_op2",states:["MULTIPLY","*","LOGICAL"]},{id:"_op2",states:["MULTIPLY","/","LOGICAL"]},{id:"_op2",states:["MULTIPLY","%","LOGICAL"]},{id:"_jump",states:["LOGICAL"]}],ADDITION:[{id:"_op2",states:["ADDITION","+","MULTIPLY"]},{id:"_op2",states:["ADDITION","-","MULTIPLY"]},{id:"_jump",states:["MULTIPLY"]}],COMPARISON:[{id:"<>",states:["COMPARISON","<","COMPARISON_AFTER"]},{id:"<>",states:["COMPARISON",">","COMPARISON_AFTER"]},{id:"_jump",states:["ADDITION"]}],COMPARISON_AFTER:[{id:"a=",states:["=","ADDITION"]},{id:"_jump",states:["ADDITION"]}],EQUALITY:[{id:"=!",states:["EQUALITY","=","=","EQUALITY_AFTER"]},{id:"=!",states:["EQUALITY","!","=","EQUALITY_AFTER"]},{id:"_jump",states:["COMPARISON"]}],EQUALITY_AFTER:[{id:"a=",states:["=","COMPARISON"]},{id:"_jump",states:["COMPARISON"]}],LOGICAL_AND:[{id:"&&||",states:["LOGICAL_AND","&","&","EQUALITY"]},{id:"_jump",states:["EQUALITY"]}],LOGICAL_OR:[{id:"&&||",states:["LOGICAL_OR","|","|","LOGICAL_AND"]},{id:"_jump",states:["LOGICAL_AND"]}],CONDITIONAL:[{id:"?",states:["LOGICAL_OR","CONDITIONAL_AFTER"]}],CONDITIONAL_AFTER:[{id:"?:",states:["?","LOGICAL_OR",":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],COMMA:[{id:",",states:["COMMA",",","CONDITIONAL"]},{id:"_jump",states:["CONDITIONAL"]}]},$2:{_null:function(e){},_empty:function(e){return[]},_jump:function(e){return e[0]},_concat:function(e){return(e[0]||"")+(e[1]||"")},_blank:function(e){return e[1]},"str^":function(e){return e[1]},str$:function(e){return""},"str\\":function(e){if(!rc[e[1]])throw new Error('String escaping "\\'+e[1]+'" is currently not supported.');return rc[e[1]]+e[2]},var:function(e){return{p:"var",v:e[0]}},str:function(e){return{p:"str",v:e[0]}},num:function(e){return{p:"num",v:Number(e[0])}},"()":function(e){return{p:"()",v:e[1]}},al:function(e){return e[1].forEach((function(t,r){null===t&&(r!==e[1].length-1?e[1][r]={p:"var",v:"undefined"}:e[1].pop())})),{p:"arr",v:e[1]}},ai:function(e){return[e[0]]},aie:function(e){return[null]},_join:function(e){return e[0].concat(e[2])},ol:function(e){for(var t={},r=e[1],n=0;n<r.length;n++)t[r[n].n]=r[n].v;return{p:"obj",v:t}},onv:function(e){return[{n:e[0],v:e[1]||{p:"var",v:e[0]}}]},ons:function(e){return[{n:e[0],v:e[1]||{p:"str",v:e[0]}}]},onn:function(e){return[{n:e[0],v:e[1]||{p:"num",v:Number(e[0])}}]},ov:function(e){return e[1]},"!":function(e){return{p:e[0]+"n",v:e[1]}},_op1:function(e){return{p:e[0],v:e[1]}},_op2:function(e){return{p:e[1],v:[e[0],e[2]]}},"f()":function(e){return{p:"f()",v:[e[0],e[2]]}},fa:function(e){return[e[0]]},"[]":function(e){return{p:"[]",v:[e[0],e[2]]}},"<>":function(e){return"a="===e[2].p?{p:e[1]+"=",v:[e[0],e[2].v]}:{p:e[1],v:[e[0],e[2]]}},"a=":function(e){return{p:"a=",v:e[1]}},"=!":function(e){return"a="===e[3].p?{p:e[1]+"==",v:[e[0],e[3].v]}:{p:e[1]+"=",v:[e[0],e[3]]}},"&&||":function(e){return{p:e[1]+e[2],v:[e[0],e[3]]}},"?":function(e){return e[1]?{p:"?:",v:[e[0],e[1][0],e[1][1]]}:e[0]},"?:":function(e){return[e[1],e[3]]},",":function(e){return{p:",",v:[e[0],e[2]]}}}},Oc=function(){function e(){}return e.parse=function(t){return e.r||(e.r=Yo.create(wc.$1,wc.$2)),e.r.parse("COMMA",t)},e.stringify=function(e,t){return"("+function e(r){var n=[];switch(r.p){case"var":return 0<=Ec.indexOf(r.v)?r.v:0<=t.indexOf(r.v)?tc+"."+r.v:ec+"."+r.v;case"str":return'"'+r.v.replace(oc,(function(e){return"\\"+nc[e]}))+'"';case"num":return r.v;case"arr":return r.v.forEach((function(t){n.push(e(t))})),"["+n.join(",")+"]";case"obj":for(var i in r.v){var o='"'+i.replace(oc,(function(e){return"\\"+nc[e]}))+'"';n.push(o+":"+e(r.v[i]))}return"{"+n.join(",")+"}";case"()":return"("+e(r.v)+")";case".":return qu+"("+e(r.v[0])+',"'+r.v[1]+'")';case"[]":return qu+"("+e(r.v[0])+","+e(r.v[1])+")";case"f()":if("var"!==r.v[0].p)throw new Error("The function name could only be a variable identifier.");return r.v[1].forEach((function(t){n.push(e(t))})),Ku+"("+Qu+","+Xu+',"'+r.v[0].v+'",['+n.join(",")+"])";case"!n":case"+n":case"-n":return"("+r.p[0]+e(r.v)+")";case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return e(r.v[0])+r.p+e(r.v[1]);case"?:":return e(r.v[0])+"?"+e(r.v[1])+":"+e(r.v[2]);default:throw new Error("The AST is illegal.")}}(e)+")"},e.lvalueStringify=function(t,r){for(var n=[],i=t;i;){if("var"===i.p)return 0<=Ec.indexOf(i.v)?null:0<=r.indexOf(i.v)?'["'+i.v+'",'+n.join(",")+"]":"[null,"+n.join(",")+"]";if("."!==i.p)if("[]"!==i.p){if("()"!==i.p)return null;i=i.v}else n.unshift(e.stringify(i.v[1],r)),i=i.v[0];else n.unshift('"'+i.v[1]+'"'),i=i.v[0]}return null},e.searchBindingPaths=function(t,r){var n=[],i="",o=function t(o,a,s){if(s>1)throw new Error("Dynamical binding paths are not supported.");switch(o.p){case"var":if(a){if(Ec.indexOf(o.v)>=0)return;return r.indexOf(o.v)>=0?['"'+o.v+'"']:['null,"'+o.v+'"']}if(s>=1)throw new Error("Dynamical binding paths are not supported.");if(0<=Ec.indexOf(o.v))return;return void(r.indexOf(o.v)>=0?n.push('["'+o.v+'"]'):n.push('[null,"'+o.v+'"]'));case"str":case"num":case"arr":case"obj":return;case"()":return t(o.v,a,s);case".":if(a){if(!(i=t(o.v[0],!0,s)))return;return i.push('"'+o.v[1]+'"'),i}if(!(i=t(o.v[0],!0,s+1)))return;return i.push('"'+o.v[1]+'"'),void n.push("["+i.join(",")+"]");case"[]":if(a){if(!(i=t(o.v[0],!0,s)))return;return t(o.v[1],!0,s),i.push(e.lvalueStringify(o.v[1])),i}if(!(i=t(o.v[0],!0,s+1)))return;return t(o.v[1],!0,s+1),i.push(e.lvalueStringify(o.v[1])),void n.push("["+i.join(",")+"]");case"f()":return t(o.v[0],!1,s),void o.v[1].forEach((function(e){t(e,!1,s)}));case"!n":case"+n":case"-n":return void t(o.v,!1,s);case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return t(o.v[0],!1,s),void t(o.v[1],!1,s);case"?:":return t(o.v[0],!1,s),t(o.v[1],!1,s),void t(o.v[2],!1,s);default:throw new Error("The AST is illegal.")}};return t.forEach((function(e){o(e,!1,0)})),"["+n.join(",")+"]"},e}(),Ac=ec+","+tc+","+Qu,Cc={requireBlock:!0,precompile:function(e,t,r){if("else"===e)return{s:[],d:"true"};var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in dd:"+e+".");var i=Oc.parse(n[1]),o=Oc.searchBindingPaths([i],r);return{s:[],d:"function("+Ac+"){return "+Oc.stringify(i,r)+"}",b:o}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u,c){var d=l.createVirtualNode("dd:"+e);d.__ddIfCondValue=!0,d.__ddIfNextNode=null,d.__ddIfHasTrueCond=!0;var f=null;"if"!==e&&(f=c.childNodes[c.childNodes.length-1])&&("dd:if"!==f.is&&"dd:elif"!==f.is?f=null:f.__ddIfNextNode=d),r.id&&(d.id=r.id);var _=d.__ddIfUpdateNode=function(){var e=d.__ddIfCondValue;if(f&&f.__ddIfHasTrueCond&&(e=!0),e&&!d.childNodes.length){var t=Ru.proxyTopScope(o),c=Ru.proxySubScopes(a);d.__ddTopScope=t,d.__ddSubScopes=c,u(r.c,l,d,n,i,t,c,s)}else if(!e&&d.childNodes.length){for(var _ in Ru.removeBindingsForScope(d.__ddTopScope),d.__ddSubScopes)Ru.removeBindingsForScope(d.__ddSubScopes[_]);for(;d.childNodes.length;)d.removeChild(d.childNodes[0])}d.__ddIfNextNode&&d.__ddIfNextNode.__ddIfUpdateNode()};function p(e){d.__ddIfCondValue=!!e,d.__ddIfHasTrueCond=d.__ddIfCondValue||f&&f.__ddIfHasTrueCond,_()}return"else"===e?p(!0):(Ru.addBindings(o,a,t.b,d,{e:t.d,o:function(e,t,r){p(r)}}),p(t.d(n,i,null))),d}},Sc=ec+","+tc+","+Qu,Tc={requireBlock:!0,addDefaultAttrs:[{n:"wx:for-index",v:"index"},{n:"wx:for-item",v:"item"}],precompile:function(e,t,r){var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:for.");var i=Oc.parse(n[1]),o=Oc.lvalueStringify(i,r),a=Oc.searchBindingPaths([i],r);return{s:[],d:"function("+Sc+"){return "+Oc.stringify(i,r)+"}",l:o,b:a}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=r._ddForIndex||"index",d=r._ddForItem||"item",f=r._ddKey,_=l.createVirtualNode("wx:for:list");function p(e,t,n,i,f){var p=l.createVirtualNode("wx:for:item"),h=Ru.proxyTopScope(o),v=Ru.proxySubScopes(a);p.__ddTopScope=h,p.__ddSubScopes=v,p.__ddForToRemove=!1,p.__ddForKeyStr="";var g=Ru.create(c,h,v,null,null,[]),m=Ru.create(d,h,v,null,[n],[]);return v[c]=g,v[d]=m,t[c]=n,t[d]=i,u(r.c,l,p,e,t,h,v,s),void 0===f?_.appendChild(p):_.insertBefore(p,f),p}function h(e){for(var t in _.__ddSubScopes,Ru.removeBindingsForScope(e.__ddTopScope),_.__ddSubScopes)Ru.removeBindingsForScope(e.__ddSubScopes[t]);_.removeChild(e)}r.id&&(_.id=r.id),Ru.create("",o,a,(function(e,r,n){var i=t.d(e,r,null);return v(i,e,r,n),i}),t.l,t.b);var v=function(e,t,r,i){var o="",a=e;"object"==ea(e)&&null!==e||(a=[]);var s={};for(o in r)s[o]=r[o];var l,u,v,g,m,y,b=0;if(f){var E=[],w=e instanceof Array,O=[];if(!w){var A=a;for(o in a=[],A)a.push(A[o]),O.push(o)}for(b=0;b<a.length;b++)E.push(String(a[b][f]));if(0===a.length)for(;_.childNodes.length;)h(_.childNodes[0]);else{var C=Object.create(null),S=Object.create(null),T=_.childNodes,N=null,x="";for(b=0;b<T.length;b++)0<=C[x=(N=T[b]).__ddForKeyStr]?(h(N),b--):(C[x]=b,(S[x]=N).__ddForToRemove=!0);var I=-1,R=0,L=1,M=[];for(0<=(R=C[a[0][f]])||(R=-1),T[R]&&(T[R].__ddForToRemove=!1),b=1;b<a.length;b++)0<=(L=C[a[b][f]])&&(I<R&&(R<L||L<I)&&(M.push(T[R]),I=R),T[R=L]&&(T[R].__ddForToRemove=!1));for(I<R&&M.push(T[R]),b=0;b<T.length;b++)(N=T[b]).__ddForToRemove&&(h(N),b--);var k=M.shift(),P=0;for(b=0;b<a.length;b++){var j=a[b],D=S[j[f]];if(S[j[f]]=null,D){var B=!0;if(D===k){for(;T[P]!==k;)P++;P++,k=M.shift(),B=!1}(function(e,t,r,i,o,a){var s=e.__ddSubScopes[d];Ru.updateLvaluePath(s,[i]),o&&(a?_.insertBefore(e,a):_.appendChild(e));var l=e.__ddSubScopes[c];r[c]=i,Ru.updateBinding(l,[],n,r,t)})(N=D,i,s,w?b:O[b],B,T[P]),B&&T[P]===N&&P++,l=N,u=[],v=t,g=s,m=a[b],y=i,g[d]=m,Ru.updateBinding(l.__ddSubScopes[d],u,v,g,y)}else N=p(t,s,w?b:O[b],a[b],T[P]),P++,N.__ddForKeyStr=String(j[f])}}}else{for(;_.childNodes.length;)h(_.childNodes[0]);if(e instanceof Array)for(b=0;b<a.length;b++)p(t,s,b,a[b]);else for(o in a)p(t,s,o,a[o])}};return v(t.d(n,i,null),n,i,null),_}},Nc=ec+","+tc+","+Qu,xc={if:Cc,elif:Cc,else:Cc,for:Tc,key:{attachedToBlock:!0,precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-key.");return{s:[],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddKey=t.d},create:function(){}},"for-index":{attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-index.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._wxForIndex=t.d},create:function(){}},"for-item":{attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-item.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddForItem=t.d},create:function(){}},alias:{requireBlock:!0,precompile:function(e,t,r){var n=t.match(/^\{\{\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*=(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:alias.");var i=n[1],o=Oc.parse(n[2]),a=Oc.lvalueStringify(o,r),s=Oc.searchBindingPaths([o],r);return{s:[i],d:"function("+Nc+"){return "+Oc.stringify(o,r)+"}",l:a,b:s}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=t.s[0],d=Ru.create(c,o,a,t.d,t.l,t.b),f={},_="";for(_ in a)f[_]=a[_];f[c]=d;var p={};for(_ in i)p[_]=i[_];p[c]=t.d(n,i,null);var h=l.createVirtualNode("wx:alias");return r.id&&(h.id=r.id),u(r.c,l,h,n,p,o,f,s),h}}},Ic=ec+","+tc+","+Qu,Rc=qu+","+Ku+","+Xu,Lc=function(){function e(){}return e.toUpperCase=function(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))},e.addBackSlashToSign=function(e){return'"'+e.replace(oc,(function(e){return"\\"+nc[e]}))+'"'},e.formatToArrayStr=function(e){return"["+e.join(",")+"]"},e.formatToObjStr=function(e){var t=[];for(var r in e)void 0!==e[r]&&(/^[_a-z]+$/i.test(r)?t.push(r+":"+e[r]):t.push(this.addBackSlashToSign(r)+":"+e[r]));return"{"+t.join(",")+"}"},e.parseDynamicValue=function(e,t){for(var r=e.split(/\{\{(.*?)\}\}/),n=[],i=[],o=null,a=0;a<r.length;a++){var s=r[a];if(a%2){var l=Oc.parse(s);o=Oc.lvalueStringify(l,t),n.push(Oc.stringify(l,t)),i.push(l)}else n.push(this.addBackSlashToSign(s))}if(1===n.length)return{c:n[0]};var u=Oc.searchBindingPaths(i,t);return'""'===n[n.length-1]&&n.pop(),2===n.length&&'""'===n[0]?{c:void 0,e:"function("+Ic+"){return "+n[1]+"}",l:o,b:u}:{c:void 0,e:"function("+Ic+"){return "+n.join("+")+"}",l:void 0,b:u}},e.format=function(e,t){for(var r=[],n=0;n<e.length;n++){var i=e[n];if(3!==i.t){var o={t:1,n:'"'+i.n+'"',g:void 0,v:void 0,id:void 0,cl:void 0,cpf:void 0,st:void 0,sl:void 0,sn:void 0,a:"",c:""},a=i.c;"slot"===i.n?(o.v=!0,o.sn='""',a=[]):"block"!==i.n&&"virtual"!==i.n||(o.v=!0);var s=i.a;if(s){for(var l=0,u=[],c=[],d=null,f=Object.create(null),_=Object.create(null),p=Object.create(null),h=!1,v=!1,g=!1,m=!1,y=0;y<s.length;y++){var b=s[y],E=b.n;if(!f[E]){f[E]=!0;var w=null;if("id"===E)o.id=this.addBackSlashToSign(b.v);else if("class"===E||"class$"===E||"class:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(h=!0),o.cl=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("style"===E||"style$"===E||"style:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(v=!0),o.st=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("slot"===E)o.sl=this.addBackSlashToSign(b.v);else if("name"===E&&"slot"===i.n)o.sn=this.addBackSlashToSign(b.v);else if("generic:"===E.slice(0,8))o.g="",_[E.slice(8)]=this.addBackSlashToSign(b.v);else if("filter:"===E.slice(0,7))o.cpf="",p[E.slice(7)]=this.addBackSlashToSign(b.v);else if("wx:"===E.slice(0,3)||"dd:"===E.slice(0,3)){var O=E.slice(3);if(!Object.prototype.hasOwnProperty.call(xc,O))throw new Error('Directive "'+O+'" is not found.');var A=xc[O].precompile(O,b.v,t);l+=A.s.length,t=t.concat(A.s);var C=this.formatToObjStr({s:JSON.stringify(A.s),n:'"'+O+'"',d:A.d,l:A.l,b:A.b}),S=xc[O].addDefaultAttrs;if(S&&s.push.apply(s,S),xc[O].attachedToBlock)u.push(C);else if(xc[O].requireBlock){if(null!==d)throw new Error("Uncompatible directives are used in a single element.");d=C}else c.push(C)}else{var T={n:'"'+b.n+'"',v:this.addBackSlashToSign(b.v),o:void 0,e:void 0,l:void 0,b:void 0};if("$"===E.slice(-1)?(T.o='"$"',T.n='"'+E.slice(0,-1)+'"'):":"===E.slice(-1)?(T.o='":"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"&"===E.slice(-1)?(T.o='"&"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"class."===E.slice(0,6)?(T.o='"c"',T.n='"'+E.slice(6)+'"',m=!0):"style."===E.slice(0,6)?(T.o='"s"',T.n='"'+E.slice(6)+'"',g=!0):"data-"===E.slice(0,5)&&(T.o='"d"',T.n='"'+this.toUpperCase(E.slice(5))+'"',m=!0),"id"===T.n||"slot"===T.n)throw new Error('"id" and "slot" do not support dynamic binding symbol.');w=this.parseDynamicValue(b.v,t),T.v=w.c,T.e=w.e,T.l=w.l,T.b=w.b,c.push(this.formatToObjStr(T))}}}if(h&&m)throw new Error("Class bindings cannot be used with dynamic class property.");if(v&&g)throw new Error("Style bindings cannot be used with dynamic style property.");o.a=this.formatToArrayStr(c),o.c=this.format(a,t),""===o.g&&(o.g=this.formatToObjStr(_)),""===o.cpf&&(o.cpf=this.formatToObjStr(p)),d?'"block"'===o.n&&"[]"===o.a?(o.a="["+u.concat(d).join(",")+"]",r.push(this.formatToObjStr(o))):r.push(this.formatToObjStr({t:1,n:'"block"',v:!0,a:"["+u.concat(d).join(",")+"]",c:"["+this.formatToObjStr(o)+"]"})):r.push(this.formatToObjStr(o)),t.splice(t.length-l,l)}}else{var N=this.parseDynamicValue(i.c,t);N.t=3,N.l=void 0,N.c=N.c||'""',r.push(this.formatToObjStr(N))}}return this.formatToArrayStr(r)},e.compile=function(t){var r=yc.parse(t),n=e.format(r,[]);return"function("+Rc+"){return "+n+"}"},e}();function Mc(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))}function kc(e,t){if(null!==e&&"object"===ea(e)&&Object.prototype.hasOwnProperty.call(e,t))return e[t]}function Pc(e,t,r){e[t]=r}function jc(e,t,r){var n=e.__dataProxy;n.scheduleReplace([t],r),n.doUpdates()}function Dc(e,t,r,n){if(void 0===n&&(n=[]),Object.prototype.hasOwnProperty.call(t,r)){var i=t[r];if(da(i))return Aa.safeCallback("Template Method",i,e,n)}}function Bc(e,t,r){e.setAttribute("style",r)}function Fc(e,t,r){e.class=r}function Uc(e,t,r){e.setAttribute("class",r)}function Gc(e,t,r){e.textContent=r}function Hc(e,t,r){e.dataset||(e.dataset={}),e.dataset[t]=r}function Vc(e,t,r){e.classList.toggle(t,!!r)}function zc(){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]}function $c(){return[{t:1,n:"slot",a:[],c:[],p:null}]}var Yc={t:1,n:'"slot"',v:!0,sn:"",a:[],c:[],p:null},Wc={$:function(e,t,r){!0===r?e.setAttribute(t,""):!1===r||null==r?e.removeAttribute(t):e.setAttribute(t,r)},":":Pc,c:Vc,s:function(e,t,r){e.style&&(e.style[t]=r)},d:Hc};function Zc(e,t){return function(r){if(this[e](r),t)return!1}}function Jc(e,t,r,n,i,o,a,s){for(var l=null,u=0,c=e;u<c.length;u++){var d=c[u],f=a;if(3===d.t)l=d.e?t.createTextNode(d.e(n,i,null)):t.createTextNode(d.c),d.e&&Ru.addBindings(o,a,d.b,l,d),eu.appendChild(r,l);else{for(var _=d.id,p=d.n,h=d.a,v=d.g,g=d.cl,m=d.st,y=d.cpf,b=!1,E=0,w=h;E<w.length;E++){if((M=w[E]).d&&xc[M.n]){var O=xc[M.n].create(M.n,M,d,n,i,o,f,s,t,Jc,r);if(xc[M.n].requireBlock){l=O,eu.appendChild(r,l),b=!0;break}}}if(b)continue;if(d.v)l=t.createVirtualNode(p);else if(d.p){l=t.cloneNativeNode(d.p);for(var A=0,C=h;A<C.length;A++){(M=C[A]).d||(M.ev?s(l,M.ev,M.v,M.evCatch):M.o===Pc?l.__domElement&&(M.o(l.__domElement,M.n,M.e(n,i,null)),Ru.addBindings(o,f,M.b,l.__domElement,M)):M.e&&(M.o(l,M.n,M.e(n,i,null)),M.o!==Vc&&M.o!==Hc||Ru.addBindings(o,f,M.b,l,M)))}m&&m.e&&(l.setAttribute("style",m.e(n,i,null)),Ru.addBindings(o,f,m.b,l,m))}else{if(y){var S={},T=t.__ddHost,N=void 0,x=void 0;for(N in y)x=y[N],S[N]=T.__behavior.methods[x];t.__childrenPropsFilter=S}l=t.createComponent(p,void 0,v,void 0);for(var I=void 0,R=0,L=h;R<L.length;R++){var M;(M=L[R]).d||(I=M.v,M.o===jc&&vu.hasPublicProperty(l,M.n)?M.e?(I=M.e(n,i,null),Ru.addBindings(o,f,M.b,l,M)):l.__behavior.properties[M.n].type===Boolean?jc(l,M.n,!0):jc(l,M.n,I):M.ev?s(l,M.ev,I,M.evCatch):M.o!==jc&&(M.e&&(I=M.e(n,i,null),Ru.addBindings(o,f,M.b,l,M)),M.o(l,M.n,I)))}m&&(m.e?(l.__domElement.setAttribute("style",m.e(n,i,null)),Ru.addBindings(o,f,m.b,l.__domElement,m)):l.__domElement.setAttribute("style",m.v))}_&&(l.id=_),g&&(g.e?l.class=g.e(n,i,null):l.class=g.v,g.o&&Ru.addBindings(o,f,g.b,l,g)),d.sl&&(l.slot=d.sl),void 0!==d.sn&&eu.setSlotName(l,d.sn),eu.appendChild(r,l),Jc(d.c,t,l,n,i,o,f,s)}}}function qc(e,t,r){for(var n=e.childNodes,i=0,o=void 0;i<n.length;i++)(o=n[i])instanceof gu||(o.__id&&(t[o.__id]=o),void 0!==o.__slotName&&(r[o.__slotName]=o),qc(o,t,r))}function Kc(e,t,r,n,i,o){for(var a=null,s=0;s<e.length;s++){var l=e[s];if(void 0===l.n)a=document.createTextNode(l.c),l.e&&Ru.addBindings(i,o,l.b,a,l),t.appendChild(a);else{var u=l.cl,c=l.st,d=l.a,f=l.id;a=l.v?document.createElement("virtual"):document.importNode?document.importNode(l.p,!1):l.p.cloneNode(!1);for(var _=0,p=d;_<p.length;_++){var h=p[_];h.e&&Ru.addBindings(i,o,h.b,a,h)}t.appendChild(a),f&&(r[f]=a),u&&u.e&&Ru.addBindings(i,o,u.b,a,u),c&&c.e&&Ru.addBindings(i,o,c.b,a,c),void 0!==l.sn&&(n[l.sn]=a),Kc(l.c,a,r,n,i,o)}}}var Xc=function(){function e(){}return e.prototype.updateValues=function(e,t,r){for(var n=eu.getMethodCaller(e),i=0,o=r;i<o.length;i++){var a=o[i];Ru.updateBinding(this._topScope,a,t,{},n)}},e}(),Qc=function(){function e(){}return e.create=function(t,r,n,i){var o=t.template||zc;if(!da(o)){var a="undefined"!=typeof window&&"undefined"!=typeof document;if(Lc&&a){var s="__exparserFreeTmpl",l=Lc.compile(o),u=document.createElement("script");u.type="text/javascript",u.innerHTML="window.__exparserFreeTmpl="+l,document.head.appendChild(u),document.head.removeChild(u),o=window[s],window[s]=null}else o=void 0!==xu&&void 0!==xu.versions&&void 0!==xu.versions.node?e.precompileAndGetCreator(o):$c}var c=new e;return c._initValuesJSON=JSON.stringify(n),c._dataJSON=r!==n?JSON.stringify(r):null,c._tagTreeRoot=function(e,t,r,n){var i="native"===n.renderingMode;i&&!Qo.hasDOMBackend&&(e=$c);var o=e(kc,Dc,r),a=!1,s=Object.create(null);return function e(r){for(var n=0,o=r;n<o.length;n++){var l=o[n];if(3!==l.t){var u=l.n,c=l.st,d=l.cl,f=l.a,_=l.c,p=!(i||ua(u)&&u.indexOf("-")<0);"slot"===u&&""===l.sn&&(a=!0),l.n=u,c&&c.e&&(c.o=Bc,i&&(c.v=c.e(t,s,null))),d&&d.e&&(d.o=i?Uc:Fc,i&&(d.v=d.e(t,s,null))),p||(l.p=i?document.createElement(u):cu.create(u),c&&void 0!==c.v&&l.p.setAttribute("style",c.v),i&&d&&void 0!==d.v&&l.p.setAttribute("class",d.v));for(var h=0,v=f;h<v.length;h++){var g=v[h],m=g.n,y=void 0;g.d?i||xc[m]&&xc[m].register(g.n,g,l):(i||("bind"===m.slice(0,4)?(g.evCatch=!1,g.ev=Mc(m.slice(4)),":"===g.ev[0]&&(g.ev=g.ev.slice(1))):"catch"===m.slice(0,5)&&(g.evCatch=!0,g.ev=Mc(m.slice(5)),":"===g.ev[0]&&(g.ev=g.ev.slice(1)))),y=g.o,p?(y?g.o="&"===y?Wc[":"]:Wc[y]:(g.o=Wc[":"],g.n=Mc(g.n)),g.o===Pc&&(g.o=jc),i&&g.e&&(g.v=g.e(t,s,null))):g.ev||(g.o=y?"&"===y?Wc[":"]:Wc[y]:Wc.$,i?(g.e&&(g.v=g.e(t,s,null)),g.o!==Vc&&g.o(l.p,g.n,g.v)):g.e||g.o(l.p,g.n,g.v)))}e(_),i&&1===_.length&&void 0!==_[0].sn&&!_[0].compressed&&(l.sn=_[0].sn,l.compressed=!0,_.pop())}else l.e&&(l.o=Gc,l.c=i?l.e(t,s,null):"")}}(o),i&&(a||o.push(Yc),1!==o.length||""!==o[0].sn||o[0].compressed||o.pop()),o}(o,n,t.methods,i),c._renderingMode=i.renderingMode,c},e.precompileAndGetCreator=function(e){return e},e.prototype.createInstance=function(e){var t,r=new Xc,n=JSON.parse(this._initValuesJSON),i=null===this._dataJSON?n:JSON.parse(this._dataJSON),o=Object.create(null),a=Object.create(null),s=[],l=Ru.create("",null,null,null,null,[],(function(){}));if("native"===this._renderingMode)"dom"===Qo.documentBackend&&(t=document.createDocumentFragment()),Kc(this._tagTreeRoot,t,o,a,l,{}),a[""]||(a[""]=null);else{var u=yu.create(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(u.__childrenPropsFilter){var c=void 0;for(c in e.ownerShadowRoot.__childrenPropsFilter)u.__childrenPropsFilter[c]||(u.__childrenPropsFilter[c]=e.ownerShadowRoot.__childrenPropsFilter[c])}else u.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;Jc(this._tagTreeRoot,u,u,n,{},l,{},(function(e,t,r,n){u.__ddHost?e.addListener(t,Zc(r,n).bind(u.__ddHost)):s.push({target:e,name:t,func:Zc(r,n)})})),qc(u,o,a),t=u}return r.data=i,r.shadowRoot=t,r.idMap=o,r.slots=a,r.listeners=s,r._topScope=l,r},e.precompiler=Lc,e.htmlParser=yc,e}();return va(Qc),function(){var e=ba();delete e._list[""],e.register({is:"",options:{writeOnly:!0,allowInWriteOnly:!0,lazyRegistration:!1,classPrefix:"",addGlobalClass:!1,templateEngine:null,renderingMode:"full",multipleSlots:!1,reflectToAttributes:!1}})}(),{precompileTemplate:Qc.precompiler?Qc.precompiler.compile:null,precompiler:Qc.precompiler?Qc.precompiler:null,HtmlLLParser:Qc.htmlParser?Qc.htmlParser:null,LLParser:Yo,dataPath:vl,dataUtils:ss,Event:_s,EventBus:Aa,Element:eu,TextNode:gu,NativeNode:cu,VirtualNode:mu,ShadowRoot:yu,Behavior:xl,Component:vu,Observer:Rl,DataGroup:ou,ElementIterator:bu,FakeDomElement:Ll,registerBehavior:xl.create,registerElement:vu.register,createElement:vu.create,createTextNode:gu.create,createVirtualNode:mu.create,appendChild:eu.appendChild,insertBefore:eu.insertBefore,removeChild:eu.removeChild,replaceChild:eu.replaceChild,addListenerToElement:_s.addListenerToElement,removeListenerFromElement:_s.removeListenerFromElement,triggerEvent:_s.triggerEvent,safeCallback:Aa.safeCallback,addGlobalErrorListener:Aa.addGlobalErrorListener,removeGlobalErrorListener:Aa.removeGlobalErrorListener,globalState:Ql,globalOptions:Qo}}();

!function(t){"function"==typeof define&&define.amd?define(t):t()}((function(){"use strict";var t={is:"dd-view",options:{renderingMode:"full"},template:function(t,n,e){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]},properties:{hoverClass:String},listeners:{"this.touchstart":function(){this.hoverStart()},"this.touchend":function(){this.hoverEnd()},"this.canceltap":function(){this.hoverEnd()}},methods:{hoverStart:function(){},hoverEnd:function(){}}};exparser.registerElement(t)}));

exparser.globalOptions.renderingMode = 'full';
exparser.globalState.enableBackendExtractedDefault();

var __virtualDOMDataThread__ = true;
var __virtualDOMTunnelPrintLog__ = false;
var __virtualDOM__=function(){"use strict";var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function t(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var n,r,o=function(e){return e&&e.Math==Math&&e},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof e&&e)||function(){return this}()||Function("return this")(),a=function(e){try{return!!e()}catch(e){return!0}},s=!a((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),l={}.propertyIsEnumerable,u=Object.getOwnPropertyDescriptor,c={f:u&&!l.call({1:2},1)?function(e){var t=u(this,e);return!!t&&t.enumerable}:l},d=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},f={}.toString,p=function(e){return f.call(e).slice(8,-1)},_="".split,h=a((function(){return!Object("z").propertyIsEnumerable(0)}))?function(e){return"String"==p(e)?_.call(e,""):Object(e)}:Object,v=function(e){if(null==e)throw TypeError("Can't call method on "+e);return e},g=function(e){return h(v(e))},E=function(e){return"object"==typeof e?null!==e:"function"==typeof e},m=function(e){return"function"==typeof e?e:void 0},y=function(e,t){return arguments.length<2?m(i[e]):i[e]&&i[e][t]},N=y("navigator","userAgent")||"",b=i.process,w=i.Deno,C=b&&b.versions||w&&w.version,A=C&&C.v8;A?r=(n=A.split("."))[0]<4?1:n[0]+n[1]:N&&(!(n=N.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=N.match(/Chrome\/(\d+)/))&&(r=n[1]);var T=r&&+r,S=!!Object.getOwnPropertySymbols&&!a((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&T&&T<41})),O=S&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,I=O?function(e){return"symbol"==typeof e}:function(e){var t=y("Symbol");return"function"==typeof t&&Object(e)instanceof t},x=function(e,t){try{Object.defineProperty(i,e,{value:t,configurable:!0,writable:!0})}catch(n){i[e]=t}return t},D="__core-js_shared__",M=i[D]||x(D,{}),L=t((function(e){(e.exports=function(e,t){return M[e]||(M[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),R=function(e){return Object(v(e))},P={}.hasOwnProperty,F=Object.hasOwn||function(e,t){return P.call(R(e),t)},V=0,k=Math.random(),j=function(e){return"Symbol("+String(void 0===e?"":e)+")_"+(++V+k).toString(36)},Y=L("wks"),W=i.Symbol,B=O?W:W&&W.withoutSetter||j,H=function(e){return F(Y,e)&&(S||"string"==typeof Y[e])||(S&&F(W,e)?Y[e]=W[e]:Y[e]=B("Symbol."+e)),Y[e]},U=H("toPrimitive"),G=function(e,t){if(!E(e)||I(e))return e;var n,r=e[U];if(void 0!==r){if(void 0===t&&(t="default"),n=r.call(e,t),!E(n)||I(n))return n;throw TypeError("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&"function"==typeof(n=e.toString)&&!E(r=n.call(e)))return r;if("function"==typeof(n=e.valueOf)&&!E(r=n.call(e)))return r;if("string"!==t&&"function"==typeof(n=e.toString)&&!E(r=n.call(e)))return r;throw TypeError("Can't convert object to primitive value")}(e,t)},$=function(e){var t=G(e,"string");return I(t)?t:String(t)},z=i.document,q=E(z)&&E(z.createElement),X=function(e){return q?z.createElement(e):{}},K=!s&&!a((function(){return 7!=Object.defineProperty(X("div"),"a",{get:function(){return 7}}).a})),Q=Object.getOwnPropertyDescriptor,Z={f:s?Q:function(e,t){if(e=g(e),t=$(t),K)try{return Q(e,t)}catch(e){}if(F(e,t))return d(!c.f.call(e,t),e[t])}},J=function(e){if(!E(e))throw TypeError(String(e)+" is not an object");return e},ee=Object.defineProperty,te={f:s?ee:function(e,t,n){if(J(e),t=$(t),J(n),K)try{return ee(e,t,n)}catch(e){}if("get"in n||"set"in n)throw TypeError("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},ne=s?function(e,t,n){return te.f(e,t,d(1,n))}:function(e,t,n){return e[t]=n,e},re=Function.toString;"function"!=typeof M.inspectSource&&(M.inspectSource=function(e){return re.call(e)});var oe,ie,ae,se=M.inspectSource,le=i.WeakMap,ue="function"==typeof le&&/native code/.test(se(le)),ce=L("keys"),de=function(e){return ce[e]||(ce[e]=j(e))},fe={},pe="Object already initialized",_e=i.WeakMap;if(ue||M.state){var he=M.state||(M.state=new _e),ve=he.get,ge=he.has,Ee=he.set;oe=function(e,t){if(ge.call(he,e))throw new TypeError(pe);return t.facade=e,Ee.call(he,e,t),t},ie=function(e){return ve.call(he,e)||{}},ae=function(e){return ge.call(he,e)}}else{var me=de("state");fe[me]=!0,oe=function(e,t){if(F(e,me))throw new TypeError(pe);return t.facade=e,ne(e,me,t),t},ie=function(e){return F(e,me)?e[me]:{}},ae=function(e){return F(e,me)}}var ye,Ne={set:oe,get:ie,has:ae,enforce:function(e){return ae(e)?ie(e):oe(e,{})},getterFor:function(e){return function(t){var n;if(!E(t)||(n=ie(t)).type!==e)throw TypeError("Incompatible receiver, "+e+" required");return n}}},be=t((function(e){var t=Ne.get,n=Ne.enforce,r=String(String).split("String");(e.exports=function(e,t,o,a){var s,l=!!a&&!!a.unsafe,u=!!a&&!!a.enumerable,c=!!a&&!!a.noTargetGet;"function"==typeof o&&("string"!=typeof t||F(o,"name")||ne(o,"name",t),(s=n(o)).source||(s.source=r.join("string"==typeof t?t:""))),e!==i?(l?!c&&e[t]&&(u=!0):delete e[t],u?e[t]=o:ne(e,t,o)):u?e[t]=o:x(t,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&t(this).source||se(this)}))})),we=Math.ceil,Ce=Math.floor,Ae=function(e){return isNaN(e=+e)?0:(e>0?Ce:we)(e)},Te=Math.min,Se=function(e){return e>0?Te(Ae(e),9007199254740991):0},Oe=Math.max,Ie=Math.min,xe=function(e,t){var n=Ae(e);return n<0?Oe(n+t,0):Ie(n,t)},De=function(e){return function(t,n,r){var o,i=g(t),a=Se(i.length),s=xe(r,a);if(e&&n!=n){for(;a>s;)if((o=i[s++])!=o)return!0}else for(;a>s;s++)if((e||s in i)&&i[s]===n)return e||s||0;return!e&&-1}},Me={includes:De(!0),indexOf:De(!1)},Le=Me.indexOf,Re=function(e,t){var n,r=g(e),o=0,i=[];for(n in r)!F(fe,n)&&F(r,n)&&i.push(n);for(;t.length>o;)F(r,n=t[o++])&&(~Le(i,n)||i.push(n));return i},Pe=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Fe=Pe.concat("length","prototype"),Ve={f:Object.getOwnPropertyNames||function(e){return Re(e,Fe)}},ke={f:Object.getOwnPropertySymbols},je=y("Reflect","ownKeys")||function(e){var t=Ve.f(J(e)),n=ke.f;return n?t.concat(n(e)):t},Ye=function(e,t){for(var n=je(t),r=te.f,o=Z.f,i=0;i<n.length;i++){var a=n[i];F(e,a)||r(e,a,o(t,a))}},We=/#|\.prototype\./,Be=function(e,t){var n=Ue[He(e)];return n==$e||n!=Ge&&("function"==typeof t?a(t):!!t)},He=Be.normalize=function(e){return String(e).replace(We,".").toLowerCase()},Ue=Be.data={},Ge=Be.NATIVE="N",$e=Be.POLYFILL="P",ze=Be,qe=Z.f,Xe=function(e,t){var n,r,o,a,s,l=e.target,u=e.global,c=e.stat;if(n=u?i:c?i[l]||x(l,{}):(i[l]||{}).prototype)for(r in t){if(a=t[r],o=e.noTargetGet?(s=qe(n,r))&&s.value:n[r],!ze(u?r:l+(c?".":"#")+r,e.forced)&&void 0!==o){if(typeof a==typeof o)continue;Ye(a,o)}(e.sham||o&&o.sham)&&ne(a,"sham",!0),be(n,r,a,e)}},Ke=function(e){if(I(e))throw TypeError("Cannot convert a Symbol value to a string");return String(e)},Qe=function(){var e=J(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},Ze=i.RegExp,Je={UNSUPPORTED_Y:a((function(){var e=Ze("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),BROKEN_CARET:a((function(){var e=Ze("^r","gy");return e.lastIndex=2,null!=e.exec("str")}))},et=Object.keys||function(e){return Re(e,Pe)},tt=s?Object.defineProperties:function(e,t){J(e);for(var n,r=et(t),o=r.length,i=0;o>i;)te.f(e,n=r[i++],t[n]);return e},nt=y("document","documentElement"),rt=de("IE_PROTO"),ot=function(){},it=function(e){return"<script>"+e+"</"+"script>"},at=function(e){e.write(it("")),e.close();var t=e.parentWindow.Object;return e=null,t},st=function(){try{ye=new ActiveXObject("htmlfile")}catch(e){}var e,t;st="undefined"!=typeof document?document.domain&&ye?at(ye):((t=X("iframe")).style.display="none",nt.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(it("document.F=Object")),e.close(),e.F):at(ye);for(var n=Pe.length;n--;)delete st.prototype[Pe[n]];return st()};fe[rt]=!0;var lt=Object.create||function(e,t){var n;return null!==e?(ot.prototype=J(e),n=new ot,ot.prototype=null,n[rt]=e):n=st(),void 0===t?n:tt(n,t)},ut=i.RegExp,ct=a((function(){var e=ut(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),dt=i.RegExp,ft=a((function(){var e=dt("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),pt=Ne.get,_t=RegExp.prototype.exec,ht=L("native-string-replace",String.prototype.replace),vt=_t,gt=function(){var e=/a/,t=/b*/g;return _t.call(e,"a"),_t.call(t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),Et=Je.UNSUPPORTED_Y||Je.BROKEN_CARET,mt=void 0!==/()??/.exec("")[1];(gt||mt||Et||ct||ft)&&(vt=function(e){var t,n,r,o,i,a,s,l=this,u=pt(l),c=Ke(e),d=u.raw;if(d)return d.lastIndex=l.lastIndex,t=vt.call(d,c),l.lastIndex=d.lastIndex,t;var f=u.groups,p=Et&&l.sticky,_=Qe.call(l),h=l.source,v=0,g=c;if(p&&(-1===(_=_.replace("y","")).indexOf("g")&&(_+="g"),g=c.slice(l.lastIndex),l.lastIndex>0&&(!l.multiline||l.multiline&&"\n"!==c.charAt(l.lastIndex-1))&&(h="(?: "+h+")",g=" "+g,v++),n=new RegExp("^(?:"+h+")",_)),mt&&(n=new RegExp("^"+h+"$(?!\\s)",_)),gt&&(r=l.lastIndex),o=_t.call(p?n:l,g),p?o?(o.input=o.input.slice(v),o[0]=o[0].slice(v),o.index=l.lastIndex,l.lastIndex+=o[0].length):l.lastIndex=0:gt&&o&&(l.lastIndex=l.global?o.index+o[0].length:r),mt&&o&&o.length>1&&ht.call(o[0],n,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&f)for(o.groups=a=lt(null),i=0;i<f.length;i++)a[(s=f[i])[0]]=o[s[1]];return o});var yt=vt;Xe({target:"RegExp",proto:!0,forced:/./.exec!==yt},{exec:yt});var Nt=H("species"),bt=RegExp.prototype,wt=function(e,t,n,r){var o=H(e),i=!a((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),s=i&&!a((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[Nt]=function(){return n},n.flags="",n[o]=/./[o]),n.exec=function(){return t=!0,null},n[o](""),!t}));if(!i||!s||n){var l=/./[o],u=t(o,""[e],(function(e,t,n,r,o){var a=t.exec;return a===yt||a===bt.exec?i&&!o?{done:!0,value:l.call(t,n,r)}:{done:!0,value:e.call(n,t,r)}:{done:!1}}));be(String.prototype,e,u[0]),be(bt,o,u[1])}r&&ne(bt[o],"sham",!0)},Ct=function(e){return function(t,n){var r,o,i=Ke(v(t)),a=Ae(n),s=i.length;return a<0||a>=s?e?"":void 0:(r=i.charCodeAt(a))<55296||r>56319||a+1===s||(o=i.charCodeAt(a+1))<56320||o>57343?e?i.charAt(a):r:e?i.slice(a,a+2):o-56320+(r-55296<<10)+65536}},At={codeAt:Ct(!1),charAt:Ct(!0)},Tt=At.charAt,St=function(e,t,n){return t+(n?Tt(e,t).length:1)},Ot=function(e,t){var n=e.exec;if("function"==typeof n){var r=n.call(e,t);if("object"!=typeof r)throw TypeError("RegExp exec method returned something other than an Object or null");return r}if("RegExp"!==p(e))throw TypeError("RegExp#exec called on incompatible receiver");return yt.call(e,t)};wt("match",(function(e,t,n){return[function(t){var n=v(this),r=null==t?void 0:t[e];return void 0!==r?r.call(t,n):new RegExp(t)[e](Ke(n))},function(e){var r=J(this),o=Ke(e),i=n(t,r,o);if(i.done)return i.value;if(!r.global)return Ot(r,o);var a=r.unicode;r.lastIndex=0;for(var s,l=[],u=0;null!==(s=Ot(r,o));){var c=Ke(s[0]);l[u]=c,""===c&&(r.lastIndex=St(o,Se(r.lastIndex),a)),u++}return 0===u?null:l}]}));var It=Array.isArray||function(e){return"Array"==p(e)},xt=function(e,t,n){var r=$(t);r in e?te.f(e,r,d(0,n)):e[r]=n},Dt=H("species"),Mt=function(e){return T>=51||!a((function(){var t=[];return(t.constructor={})[Dt]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},Lt=Mt("slice"),Rt=H("species"),Pt=[].slice,Ft=Math.max;Xe({target:"Array",proto:!0,forced:!Lt},{slice:function(e,t){var n,r,o,i=g(this),a=Se(i.length),s=xe(e,a),l=xe(void 0===t?a:t,a);if(It(i)&&("function"!=typeof(n=i.constructor)||n!==Array&&!It(n.prototype)?E(n)&&null===(n=n[Rt])&&(n=void 0):n=void 0,n===Array||void 0===n))return Pt.call(i,s,l);for(r=new(void 0===n?Array:n)(Ft(l-s,0)),o=0;s<l;s++,o++)s in i&&xt(r,o,i[s]);return r.length=o,r}});var Vt=function(e,t){var n=[][e];return!!n&&a((function(){n.call(null,t||function(){throw 1},1)}))},kt=Me.indexOf,jt=[].indexOf,Yt=!!jt&&1/[1].indexOf(1,-0)<0,Wt=Vt("indexOf");Xe({target:"Array",proto:!0,forced:Yt||!Wt},{indexOf:function(e){return Yt?jt.apply(this,arguments)||0:kt(this,e,arguments.length>1?arguments[1]:void 0)}});var Bt=H("match"),Ht=function(e){var t;return E(e)&&(void 0!==(t=e[Bt])?!!t:"RegExp"==p(e))},Ut=function(e){if("function"!=typeof e)throw TypeError(String(e)+" is not a function");return e},Gt=H("species"),$t=Je.UNSUPPORTED_Y,zt=[].push,qt=Math.min,Xt=4294967295;wt("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=Ke(v(this)),o=void 0===n?Xt:n>>>0;if(0===o)return[];if(void 0===e)return[r];if(!Ht(e))return t.call(r,e,o);for(var i,a,s,l=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),c=0,d=new RegExp(e.source,u+"g");(i=yt.call(d,r))&&!((a=d.lastIndex)>c&&(l.push(r.slice(c,i.index)),i.length>1&&i.index<r.length&&zt.apply(l,i.slice(1)),s=i[0].length,c=a,l.length>=o));)d.lastIndex===i.index&&d.lastIndex++;return c===r.length?!s&&d.test("")||l.push(""):l.push(r.slice(c)),l.length>o?l.slice(0,o):l}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:t.call(this,e,n)}:t,[function(t,n){var o=v(this),i=null==t?void 0:t[e];return void 0!==i?i.call(t,o,n):r.call(Ke(o),t,n)},function(e,o){var i=J(this),a=Ke(e),s=n(r,i,a,o,r!==t);if(s.done)return s.value;var l=function(e,t){var n,r=J(e).constructor;return void 0===r||null==(n=J(r)[Gt])?t:Ut(n)}(i,RegExp),u=i.unicode,c=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+($t?"g":"y"),d=new l($t?"^(?:"+i.source+")":i,c),f=void 0===o?Xt:o>>>0;if(0===f)return[];if(0===a.length)return null===Ot(d,a)?[a]:[];for(var p=0,_=0,h=[];_<a.length;){d.lastIndex=$t?0:_;var v,g=Ot(d,$t?a.slice(_):a);if(null===g||(v=qt(Se(d.lastIndex+($t?_:0)),a.length))===p)_=St(a,_,u);else{if(h.push(a.slice(p,_)),h.length===f)return h;for(var E=1;E<=g.length-1;E++)if(h.push(g[E]),h.length===f)return h;_=p=v}}return h.push(a.slice(p)),h}]}),!!a((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]})),$t);var Kt={};Kt[H("toStringTag")]="z";var Qt="[object z]"===String(Kt),Zt=H("toStringTag"),Jt="Arguments"==p(function(){return arguments}()),en=Qt?p:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Object(e),Zt))?n:Jt?p(t):"Object"==(r=p(t))&&"function"==typeof t.callee?"Arguments":r},tn=Qt?{}.toString:function(){return"[object "+en(this)+"]"};Qt||be(Object.prototype,"toString",tn,{unsafe:!0});var nn=!a((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),rn=de("IE_PROTO"),on=Object.prototype,an=nn?Object.getPrototypeOf:function(e){return e=R(e),F(e,rn)?e[rn]:"function"==typeof e.constructor&&e instanceof e.constructor?e.constructor.prototype:e instanceof Object?on:null},sn=a((function(){an(1)}));Xe({target:"Object",stat:!0,forced:sn,sham:!nn},{getPrototypeOf:function(e){return an(R(e))}});var ln="toString",un=RegExp.prototype,cn=un.toString,dn=a((function(){return"/a/b"!=cn.call({source:"a",flags:"b"})})),fn=cn.name!=ln;(dn||fn)&&be(RegExp.prototype,ln,(function(){var e=J(this),t=Ke(e.source),n=e.flags;return"/"+t+"/"+Ke(void 0===n&&e instanceof RegExp&&!("flags"in un)?Qe.call(e):n)}),{unsafe:!0});var pn=function(e,t,n){if(Ut(e),void 0===t)return e;switch(n){case 0:return function(){return e.call(t)};case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,o){return e.call(t,n,r,o)}}return function(){return e.apply(t,arguments)}},_n=H("species"),hn=function(e,t){return new(function(e){var t;return It(e)&&("function"!=typeof(t=e.constructor)||t!==Array&&!It(t.prototype)?E(t)&&null===(t=t[_n])&&(t=void 0):t=void 0),void 0===t?Array:t}(e))(0===t?0:t)},vn=[].push,gn=function(e){var t=1==e,n=2==e,r=3==e,o=4==e,i=6==e,a=7==e,s=5==e||i;return function(l,u,c,d){for(var f,p,_=R(l),v=h(_),g=pn(u,c,3),E=Se(v.length),m=0,y=d||hn,N=t?y(l,E):n||a?y(l,0):void 0;E>m;m++)if((s||m in v)&&(p=g(f=v[m],m,_),e))if(t)N[m]=p;else if(p)switch(e){case 3:return!0;case 5:return f;case 6:return m;case 2:vn.call(N,f)}else switch(e){case 4:return!1;case 7:vn.call(N,f)}return i?-1:r||o?o:N}},En={forEach:gn(0),map:gn(1),filter:gn(2),some:gn(3),every:gn(4),find:gn(5),findIndex:gn(6),filterReject:gn(7)},mn=En.map,yn=Mt("map");Xe({target:"Array",proto:!0,forced:!yn},{map:function(e){return mn(this,e,arguments.length>1?arguments[1]:void 0)}});var Nn=a((function(){et(1)}));Xe({target:"Object",stat:!0,forced:Nn},{keys:function(e){return et(R(e))}});var bn=/^[-+a-z]+:\/\//i;function wn(e,t){if(bn.test(t))return t;var n=e.match(bn),r="";n&&(r=n[0],e=e.slice(r.length)),0===t.indexOf("/")&&(e="");var o=e.split("/");o.pop();for(var i=t.split("/");i.length;){var a=i.shift();""!==a&&"."!==a&&(".."===a?o.pop():o.push(a))}return r+o.join("/")}function Cn(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function An(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}function Tn(e){var t=("undefined"==typeof window?this:window).__wcc_version_info__;if(t)return t[e]}function Sn(){return Math.floor(4294967296*(1+Math.random())).toString(16).slice(1)}function On(e,t,n){e instanceof exparser.Component&&(t>0&&n(e),t&&e.shadowRoot instanceof exparser.Element&&On(e.shadowRoot,t,n),t<0&&n(e));for(var r=e.childNodes||[],o=0;o<r.length;o++)r[o]instanceof exparser.Element&&On(r[o],t,n)}var In=function(){function e(){this._idNodeMap={}}return e.prototype.getAll=function(){return this._idNodeMap},e.prototype.getNodeById=function(e){return this._idNodeMap[e]},e.prototype.getNodeId=function(e){return e.__ddTmplId},e.prototype.allocNodeId=function(e,t){var n=t||Sn();return e.__ddTmplId=n,this._idNodeMap[e.__ddTmplId]=e,n},e.prototype.addNode=function(){},e.prototype.removeNode=function(e){if(e){if(e.__ddTmplId&&(this._idNodeMap[e.__ddTmplId]=null,delete this._idNodeMap[e.__ddTmplId]),e.childNodes)for(var t=0;t<e.childNodes.length;t++)this.removeNode(e.childNodes[t]);e.shadowRoot instanceof exparser.Element&&this.removeNode(e.shadowRoot)}},e.prototype.destroy=function(){var e;for(e in this._idNodeMap)this._idNodeMap[e]=null;e=null,this._idNodeMap=null},e}(),xn=Mt("splice"),Dn=Math.max,Mn=Math.min,Ln=9007199254740991,Rn="Maximum allowed length exceeded";Xe({target:"Array",proto:!0,forced:!xn},{splice:function(e,t){var n,r,o,i,a,s,l=R(this),u=Se(l.length),c=xe(e,u),d=arguments.length;if(0===d?n=r=0:1===d?(n=0,r=u-c):(n=d-2,r=Mn(Dn(Ae(t),0),u-c)),u+n-r>Ln)throw TypeError(Rn);for(o=hn(l,r),i=0;i<r;i++)(a=c+i)in l&&xt(o,i,l[a]);if(o.length=r,n<r){for(i=c;i<u-r;i++)s=i+n,(a=i+r)in l?l[s]=l[a]:delete l[s];for(i=u;i>u-r+n;i--)delete l[i-1]}else if(n>r)for(i=u-r;i>c;i--)s=i+n-1,(a=i+r-1)in l?l[s]=l[a]:delete l[s];for(i=0;i<n;i++)l[i+c]=arguments[i+2];return l.length=u-r+n,o}});var Pn={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},Fn=En.forEach,Vn=Vt("forEach")?[].forEach:function(e){return Fn(this,e,arguments.length>1?arguments[1]:void 0)};for(var kn in Pn){var jn=i[kn],Yn=jn&&jn.prototype;if(Yn&&Yn.forEach!==Vn)try{ne(Yn,"forEach",Vn)}catch(e){Yn.forEach=Vn}}
/*! *****************************************************************************
	Copyright (c) Microsoft Corporation.

	Permission to use, copy, modify, and/or distribute this software for any
	purpose with or without fee is hereby granted.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
	REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
	INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
	LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
	OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
	PERFORMANCE OF THIS SOFTWARE.
	***************************************************************************** */var Wn=function(){return(Wn=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var o in t=arguments[n])Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e}).apply(this,arguments)};var Bn={TEST:0,FLOW_DEPTH:2,FLOW_INITIAL_CREATION:3,FLOW_APPLY_PROPERTY:4,FLOW_CREATE_NODE:5,FLOW_UPDATE:6,FLOW_MINIPULATE_CHILD:7,FLOW_DATA_OBSERVER:8,FLOW_REPEAT:9,DD_EVENT:11,REQUEST_SAVE:12,COMPONENT_DEF:21,SAVE_STATE:22,RESTORE_STATE:23,FLOW_INITIAL_RENDERING_CACHE:24,FLOW_CLEAR_INITIAL_RENDERING_CACHE:25,SET_DATA_CALLBACK:32,FLOW_SET_DATA:33,FLOW_GROUP:41,FLOW_GROUP_END:42,FLUSH_BLOCKED:43,CALL_METHOD_FROM_DDS:50,REQUEST_TAB:51,COMPONENT_DEF_TAB:52,FLOW_CREATE_TAB:53,DESTROY_TAB:54,REQUEST_BROADCAST_VIEW_ID:61,RESPONSE_BROADCAST_VIEW_ID:62,FLOW_VIEW_INFO:63,RESPONSE_VIEW_INFO:64,MODEL_VALUE_CHANGE:65,BANNING_MAP:90,PERFORMANCE_DATA:91,FLOW_SET_NODE_ANIMATION_INFO:100,ANIMATION_TRANSITION_END:101,FLOW_CLEAR_NODE_ANIMATION_INFO:102,CLEAR_ANIMATION_COMPLETE:103,FLOW_SET_NODE_NEXT_ANIMATION_INFO:104,LOAD_COMPONENT_DEF:110,COMPONENT_DEF_LAZY:111,FLOW_DO_REPLACE_PLACEHOLDER:112,FLOW_REPLACE_PLACEHOLDER:113,UPDATE_PERFORMANCE_STAT:800,ENABLE_UPDATE_PERFORMANCE_STAT:801,DISABLE_UPDATE_PERFORMANCE_STAT:802,FLOW_HOT_UPDATE:900,FLOW_HOT_UPDATE_CHILD:901,FLOW_HOT_UPDATE_RESET:902,UPDATE_COMPONENT_DEF:903},Hn={};Object.keys(Bn).forEach((function(e){Hn[Bn[e]]=e}));var Un={RPX_RATE:20,BASE_DEVICE_WIDTH:750,SYNC_EVENT_NAME:Bn,STYLE_SEGMENT_INDEX:{ATTR:0,ANIMATION:1,DDS_STYLE:2},getEvName:function(e){return Hn[e]||"UNKNOWN_EVENT_"+e}},Gn=function(){function e(e,t,n){this._treeManager=e,this._arr=t,this._depth=0,this._startCb=n}return e.prototype.destroy=function(){this._treeManager=null,this._arr=null,this._startCb=null,this._depth=null},e.prototype._consumeHead=function(){return this._arr.shift()},e.prototype.nextStepType=function(){return this._arr[0][0]},e.prototype.nextStep=function(){for(;this._arr[0][0]===Un.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);if(this._arr[0][0]!==Un.SYNC_EVENT_NAME.FLOW_REPEAT)return this._consumeHead();var e=this._arr[0][2];return--this._arr[0][1]||this._consumeHead(),[e]},e.prototype.nextStepIf=function(e){for(;this._arr[0][0]===Un.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);return this._arr[0][0]===e?this._consumeHead():null},e.prototype.expectStart=function(){var e=this._consumeHead(),t=e[0],n=e[1],r=e[2];if(this._depth++,t!==Un.SYNC_EVENT_NAME.FLOW_DEPTH||n!==this._depth)throw new Error("Framework inner error (expect START descriptor with depth "+this._depth+" but get "+Un.getEvName(t)+")");return r},e.prototype.expectEnd=function(){for(;this._arr[0][0]===Un.SYNC_EVENT_NAME.FLOW_DEPTH&&this._arr[0][1]!==this._depth-1;)this._startCb(this._treeManager);var e=this._consumeHead(),t=e[0],n=e[1];if(this._depth--,t!==Un.SYNC_EVENT_NAME.FLOW_DEPTH||n!==this._depth)throw new Error("Framework inner error (expect END descriptor with depth "+this._depth+" but get "+Un.getEvName(t)+")")},e.prototype.skipToEnd=function(){for(;this._arr[0];)if(this._arr[0][0]!==Un.SYNC_EVENT_NAME.FLOW_DEPTH)this._consumeHead();else{if(this._arr[0][1]===this._depth-1)break;this._startCb(this._treeManager)}},e.prototype.getQueueLength=function(){return this._arr.length},e.prototype.getDepth=function(){return this._depth},e}(),$n=H("isConcatSpreadable"),zn=9007199254740991,qn="Maximum allowed index exceeded",Xn=T>=51||!a((function(){var e=[];return e[$n]=!1,e.concat()[0]!==e})),Kn=Mt("concat"),Qn=function(e){if(!E(e))return!1;var t=e[$n];return void 0!==t?!!t:It(e)};Xe({target:"Array",proto:!0,forced:!Xn||!Kn},{concat:function(e){var t,n,r,o,i,a=R(this),s=hn(a,0),l=0;for(t=-1,r=arguments.length;t<r;t++)if(Qn(i=-1===t?a:arguments[t])){if(l+(o=Se(i.length))>zn)throw TypeError(qn);for(n=0;n<o;n++,l++)n in i&&xt(s,l,i[n])}else{if(l>=zn)throw TypeError(qn);xt(s,l++,i)}return s.length=l,s}});var Zn=null,Jn={},er=-1,tr=null,nr=[],rr=null,or=null,ir=!1;function ar(e,t){void 0===t&&(t=0);var n,r=e.shift();if(ur()||(t=0),__virtualDOMTunnelPrintLog__&&lr(r,e,!1,t),""===r)return er=t,tr&&tr(t),0;Jn[t]&&(n=Jn[t][r]),!n&&Jn.$GLOBAL&&(n=Jn.$GLOBAL[r]),Cn(n)&&n(e,r,t)}function sr(){(Zn=ur()?__appServiceSDK__._virtualDOMTunnel:__webViewSDK__._virtualDOMTunnel).onVdSync((function(e,t){ar(e,t)})),Zn.onVdSyncBatch((function(e,t){for(var n=0;n<e.length;n++)ar(e[n],t)}))}function lr(e,t,n,r){void 0===r&&(r=0);ur()}function ur(){return __virtualDOMDataThread__}function cr(){or=or&&clearTimeout(or),nr.length&&Zn.vdSyncBatch(nr,rr),rr=null,nr.length=0,ir=!1}function dr(e,t,n,r){if(__virtualDOMTunnelPrintLog__&&lr(0,0,0,n),t=[e].concat(t),!ir||r)return cr(),ir=!0,void Zn.vdSync(t,n);rr!==n&&cr(),rr=n,nr.push(t),ir=!0,or=or||setTimeout((function(){or=null,cr()}),15)}function fr(e,t,n){if(void 0===n&&(n=0),""===e)return tr=t,void(0<=er&&tr(er));Jn[n]||(Jn[n]={}),Jn[n][e]=t}ur()&&"undefined"!=typeof __clientsubcontext&&__clientsubcontext?__clientsubcontext.onInitReady(sr):sr();var pr=Math.floor,_r="".replace,hr=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,vr=/\$([$&'`]|\d{1,2})/g,gr=function(e,t,n,r,o,i){var a=n+e.length,s=r.length,l=vr;return void 0!==o&&(o=R(o),l=hr),_r.call(i,l,(function(i,l){var u;switch(l.charAt(0)){case"$":return"$";case"&":return e;case"`":return t.slice(0,n);case"'":return t.slice(a);case"<":u=o[l.slice(1,-1)];break;default:var c=+l;if(0===c)return i;if(c>s){var d=pr(c/10);return 0===d?i:d<=s?void 0===r[d-1]?l.charAt(1):r[d-1]+l.charAt(1):i}u=r[c-1]}return void 0===u?"":u}))},Er=H("replace"),mr=Math.max,yr=Math.min,Nr="$0"==="a".replace(/./,"$0"),br=!!/./[Er]&&""===/./[Er]("a","$0");function wr(e,t){var n=e.$$,r={};if(t.id&&(r.id=e.id),t.dataset&&(r.dataset=e.dataset),t.mark&&(r.mark=e.collectMarks()||{}),t.rect||t.size){var o=n.getBoundingClientRect();t.rect&&(r.left=o.left,r.right=o.right,r.top=o.top,r.bottom=o.bottom),t.size&&(r.width=o.width,r.height=o.height)}if(t.properties)for(var i=void 0,a=0,s=t.properties;a<s.length;a++)i=(i=s[a]).replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()})),exparser.Component.hasPublicProperty(e,i)&&(r[i]=e[i]);if(t.scrollOffset)if(e.hasBehavior("dd-positioning-container")){var l=e.getScrollPosition();r.scrollLeft=l.scrollLeft,r.scrollTop=l.scrollTop,r.scrollWidth=l.scrollWidth,r.scrollHeight=l.scrollHeight}else r.scrollLeft=0,r.scrollTop=0,r.scrollWidth=0,r.scrollHeight=0;if(t.computedStyle&&t.computedStyle.length)for(var u=window.getComputedStyle(n),c=t.computedStyle.length,d=0,f=void 0;d<c;d++)(f=t.computedStyle[d])&&u[f]&&(r[f]=u[f]);return t.context&&(r.contextIs=e.is),t.node&&(r.nodeIs=e.is,r.nodeId="function"==typeof e.getContextId&&e.getContextId(),r.nodeCanvasId=e.canvasId||"",r.nodeCanvasType=e.type||""),r}wt("replace",(function(e,t,n){var r=br?"$":"$0";return[function(e,n){var r=v(this),o=null==e?void 0:e[Er];return void 0!==o?o.call(e,r,n):t.call(Ke(r),e,n)},function(e,o){var i=J(this),a=Ke(e);if("string"==typeof o&&-1===o.indexOf(r)&&-1===o.indexOf("$<")){var s=n(t,i,a,o);if(s.done)return s.value}var l="function"==typeof o;l||(o=Ke(o));var u=i.global;if(u){var c=i.unicode;i.lastIndex=0}for(var d=[];;){var f=Ot(i,a);if(null===f)break;if(d.push(f),!u)break;""===Ke(f[0])&&(i.lastIndex=St(a,Se(i.lastIndex),c))}for(var p,_="",h=0,v=0;v<d.length;v++){f=d[v];for(var g=Ke(f[0]),E=mr(yr(Ae(f.index),a.length),0),m=[],y=1;y<f.length;y++)m.push(void 0===(p=f[y])?p:String(p));var N=f.groups;if(l){var b=[g].concat(m,E,a);void 0!==N&&b.push(N);var w=Ke(o.apply(void 0,b))}else w=gr(g,a,E,m,N,o);E>=h&&(_+=a.slice(h,E)+w,h=E+g.length)}return _+a.slice(h)}]}),!!a((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Nr||br);var Cr={},Ar={},Tr={},Sr=!1;function Or(e){return{left:e.left,top:e.top,right:e.right,bottom:e.bottom,width:e.width,height:e.height}}function Ir(e,t){var n={left:e.left<t.left?t.left:e.left,top:e.top<t.top?t.top:e.top,right:e.right>t.right?t.right:e.right,bottom:e.bottom>t.bottom?t.bottom:e.bottom,width:0,height:0};return n.right>n.left?n.width=n.right-n.left:n.right=n.left=n.bottom=n.top=0,n.bottom>n.top?n.height=n.bottom-n.top:n.right=n.left=n.bottom=n.top=0,n}"undefined"!=typeof window&&"undefined"!=typeof document&&"function"==typeof document.addEventListener&&(document.addEventListener("pageReRender",(function(){Mr()})),window.addEventListener("scroll",(function(){Mr()}),{capture:!0,passive:!0}));function xr(e){var t=e.targetNode,n=e.relatives,r=e.thresholds,o=e.minWidthOrHeight,i=e.cb,a=e.currentRatio,s=function(e){for(var t=document.documentElement.clientWidth,n=document.documentElement.clientHeight,r=null,o=0;o<e.length;o++){var i=e[o],a=i.node,s=i.margins,l=a?a.$$.getBoundingClientRect():{left:0,top:0,right:t,bottom:n,width:t,height:n},u={left:l.left-s.left,top:l.top-s.top,right:l.right+s.right,bottom:l.bottom+s.bottom};r=r?Ir(l,u):u}return r}(n),l=Or(t.$$.getBoundingClientRect());l.right-l.left<o&&(l.right=l.left+o,l.width=o),l.bottom-l.top<o&&(l.bottom=l.top+o,l.height=o);var u=Ir(s,l),c=l.width*l.height,d=c?u.width*u.height/c:0;e.currentRatio=d;var f=void 0===a;a!==d&&r.forEach((function(e){void 0!==a&&(d<=e&&e<=a||e<=d&&a<=e)&&(f=!0)})),f&&i.call(t,{id:t.id,dataset:t.dataset,time:Date.now(),boundingClientRect:l,intersectionRatio:d,intersectionRect:Or(u),relativeRect:s})}function Dr(e,t,n,r,o){var i=e.querySelector(t)?[e.querySelector(t)]:[],a=r||{},s=a.observeAll?e.querySelectorAll(t):i,l=[];return n.forEach((function(t){var n=t.selector,r=t.margins,o=null==n?null:e.querySelector(n);if(o||null==n){var i=r||{};l.push({node:o,margins:{left:i.left||0,top:i.top||0,right:i.right||0,bottom:i.bottom||0}})}})),l.length,function(e,t,n,r,o,i){var a=Sn();if(!e.length||!t.length)return a;var s=e.length;return Tr[a]=s,e.forEach((function(e,l){var u=a+"#"+l,c={targetNode:e,relatives:t,thresholds:n,currentRatio:r,minWidthOrHeight:o,cb:i},d=exparser.Observer.create((function(e){"attached"===e.status?(Cr[u]=c,requestAnimationFrame((function(){xr(c)}))):"detached"===e.status&&(delete Cr[u],d.disconnect(),delete Ar[u],--s>0&&delete Tr[a])}));(Ar[u]=d).observe(e,{attachStatus:!0}),exparser.Element.isAttached(e)&&(Cr[u]=c,requestAnimationFrame((function(){xr(c)})))})),a}(s,l,a.thresholds||[0],a.initialRatio||0,a.minWidthOrHeight||0,o)}function Mr(){Sr||(Sr=!0,requestAnimationFrame((function(){for(var e in Sr=!1,Cr)xr(Cr[e])})))}function Lr(e,t,n){if("addIntersectionObserver"===e.type){var r=null;if(e.nodeId){var o=t.nodeId.getNodeById(e.nodeId);if(!o)return;r=o.shadowRoot}else e.pluginId||(r=window.__DOMTree__.shadowRoot);if(!r)return;return{observerId:Dr(r,e.targetSelector,e.relativeInfo,e.options,(function(e){n({info:e})}))}}if("removeIntersectionObserver"===e.type)return function(e){var t=Tr[e];delete Tr[e];for(var n=0;n<t;n++){var r=e+"#"+n,o=Ar[r];if(!o)break;delete Cr[r],o.disconnect(),delete Ar[r]}}(e.observerId),{reqEnd:!0}}var Rr=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return J(n),function(e){if(!E(e)&&null!==e)throw TypeError("Can't set "+String(e)+" as a prototype")}(r),t?e.call(n,r):n.__proto__=r,n}}():void 0),Pr=function(e,t,n){var r,o;return Rr&&"function"==typeof(r=t.constructor)&&r!==n&&E(o=r.prototype)&&o!==n.prototype&&Rr(e,o),e},Fr="\t\n\v\f\r                　\u2028\u2029\ufeff",Vr="["+Fr+"]",kr=RegExp("^"+Vr+Vr+"*"),jr=RegExp(Vr+Vr+"*$"),Yr=function(e){return function(t){var n=Ke(v(t));return 1&e&&(n=n.replace(kr,"")),2&e&&(n=n.replace(jr,"")),n}},Wr={start:Yr(1),end:Yr(2),trim:Yr(3)},Br=Ve.f,Hr=Z.f,Ur=te.f,Gr=Wr.trim,$r="Number",zr=i.Number,qr=zr.prototype,Xr=p(lt(qr))==$r,Kr=function(e){if(I(e))throw TypeError("Cannot convert a Symbol value to a number");var t,n,r,o,i,a,s,l,u=G(e,"number");if("string"==typeof u&&u.length>2)if(43===(t=(u=Gr(u)).charCodeAt(0))||45===t){if(88===(n=u.charCodeAt(2))||120===n)return NaN}else if(48===t){switch(u.charCodeAt(1)){case 66:case 98:r=2,o=49;break;case 79:case 111:r=8,o=55;break;default:return+u}for(a=(i=u.slice(2)).length,s=0;s<a;s++)if((l=i.charCodeAt(s))<48||l>o)return NaN;return parseInt(i,r)}return+u};if(ze($r,!zr(" 0o1")||!zr("0b1")||zr("+0x1"))){for(var Qr,Zr=function(e){var t=arguments.length<1?0:e,n=this;return n instanceof Zr&&(Xr?a((function(){qr.valueOf.call(n)})):p(n)!=$r)?Pr(new zr(Kr(t)),n,Zr):Kr(t)},Jr=s?Br(zr):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),eo=0;Jr.length>eo;eo++)F(zr,Qr=Jr[eo])&&!F(Zr,Qr)&&Ur(Zr,Qr,Hr(zr,Qr));Zr.prototype=qr,qr.constructor=Zr,be(i,$r,Zr)}function to(e){return(to="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function no(){return(no=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}var ro=Ve.f,oo={}.toString,io="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],ao={f:function(e){return io&&"[object Window]"==oo.call(e)?function(e){try{return ro(e)}catch(e){return io.slice()}}(e):ro(g(e))}},so={f:H},lo=i,uo=te.f,co=function(e){var t=lo.Symbol||(lo.Symbol={});F(t,e)||uo(t,e,{value:so.f(e)})},fo=te.f,po=H("toStringTag"),_o=function(e,t,n){e&&!F(e=n?e:e.prototype,po)&&fo(e,po,{configurable:!0,value:t})},ho=En.forEach,vo=de("hidden"),go="Symbol",Eo=H("toPrimitive"),mo=Ne.set,yo=Ne.getterFor(go),No=Object.prototype,bo=i.Symbol,wo=y("JSON","stringify"),Co=Z.f,Ao=te.f,To=ao.f,So=c.f,Oo=L("symbols"),Io=L("op-symbols"),xo=L("string-to-symbol-registry"),Do=L("symbol-to-string-registry"),Mo=L("wks"),Lo=i.QObject,Ro=!Lo||!Lo.prototype||!Lo.prototype.findChild,Po=s&&a((function(){return 7!=lt(Ao({},"a",{get:function(){return Ao(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Co(No,t);r&&delete No[t],Ao(e,t,n),r&&e!==No&&Ao(No,t,r)}:Ao,Fo=function(e,t){var n=Oo[e]=lt(bo.prototype);return mo(n,{type:go,tag:e,description:t}),s||(n.description=t),n},Vo=function(e,t,n){e===No&&Vo(Io,t,n),J(e);var r=$(t);return J(n),F(Oo,r)?(n.enumerable?(F(e,vo)&&e[vo][r]&&(e[vo][r]=!1),n=lt(n,{enumerable:d(0,!1)})):(F(e,vo)||Ao(e,vo,d(1,{})),e[vo][r]=!0),Po(e,r,n)):Ao(e,r,n)},ko=function(e,t){J(e);var n=g(t),r=et(n).concat(Bo(n));return ho(r,(function(t){s&&!jo.call(n,t)||Vo(e,t,n[t])})),e},jo=function(e){var t=$(e),n=So.call(this,t);return!(this===No&&F(Oo,t)&&!F(Io,t))&&(!(n||!F(this,t)||!F(Oo,t)||F(this,vo)&&this[vo][t])||n)},Yo=function(e,t){var n=g(e),r=$(t);if(n!==No||!F(Oo,r)||F(Io,r)){var o=Co(n,r);return!o||!F(Oo,r)||F(n,vo)&&n[vo][r]||(o.enumerable=!0),o}},Wo=function(e){var t=To(g(e)),n=[];return ho(t,(function(e){F(Oo,e)||F(fe,e)||n.push(e)})),n},Bo=function(e){var t=e===No,n=To(t?Io:g(e)),r=[];return ho(n,(function(e){!F(Oo,e)||t&&!F(No,e)||r.push(Oo[e])})),r};if(S||(be((bo=function(){if(this instanceof bo)throw TypeError("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Ke(arguments[0]):void 0,t=j(e),n=function(e){this===No&&n.call(Io,e),F(this,vo)&&F(this[vo],t)&&(this[vo][t]=!1),Po(this,t,d(1,e))};return s&&Ro&&Po(No,t,{configurable:!0,set:n}),Fo(t,e)}).prototype,"toString",(function(){return yo(this).tag})),be(bo,"withoutSetter",(function(e){return Fo(j(e),e)})),c.f=jo,te.f=Vo,Z.f=Yo,Ve.f=ao.f=Wo,ke.f=Bo,so.f=function(e){return Fo(H(e),e)},s&&(Ao(bo.prototype,"description",{configurable:!0,get:function(){return yo(this).description}}),be(No,"propertyIsEnumerable",jo,{unsafe:!0}))),Xe({global:!0,wrap:!0,forced:!S,sham:!S},{Symbol:bo}),ho(et(Mo),(function(e){co(e)})),Xe({target:go,stat:!0,forced:!S},{for:function(e){var t=Ke(e);if(F(xo,t))return xo[t];var n=bo(t);return xo[t]=n,Do[n]=t,n},keyFor:function(e){if(!I(e))throw TypeError(e+" is not a symbol");if(F(Do,e))return Do[e]},useSetter:function(){Ro=!0},useSimple:function(){Ro=!1}}),Xe({target:"Object",stat:!0,forced:!S,sham:!s},{create:function(e,t){return void 0===t?lt(e):ko(lt(e),t)},defineProperty:Vo,defineProperties:ko,getOwnPropertyDescriptor:Yo}),Xe({target:"Object",stat:!0,forced:!S},{getOwnPropertyNames:Wo,getOwnPropertySymbols:Bo}),Xe({target:"Object",stat:!0,forced:a((function(){ke.f(1)}))},{getOwnPropertySymbols:function(e){return ke.f(R(e))}}),wo){var Ho=!S||a((function(){var e=bo();return"[null]"!=wo([e])||"{}"!=wo({a:e})||"{}"!=wo(Object(e))}));Xe({target:"JSON",stat:!0,forced:Ho},{stringify:function(e,t,n){for(var r,o=[e],i=1;arguments.length>i;)o.push(arguments[i++]);if(r=t,(E(t)||void 0!==e)&&!I(e))return It(t)||(t=function(e,t){if("function"==typeof r&&(t=r.call(this,e,t)),!I(t))return t}),o[1]=t,wo.apply(null,o)}})}bo.prototype[Eo]||ne(bo.prototype,Eo,bo.prototype.valueOf),_o(bo,go),fe[vo]=!0;var Uo=te.f,Go=i.Symbol;if(s&&"function"==typeof Go&&(!("description"in Go.prototype)||void 0!==Go().description)){var $o={},zo=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:String(arguments[0]),t=this instanceof zo?new Go(e):void 0===e?Go():Go(e);return""===e&&($o[t]=!0),t};Ye(zo,Go);var qo=zo.prototype=Go.prototype;qo.constructor=zo;var Xo=qo.toString,Ko="Symbol(test)"==String(Go("test")),Qo=/^Symbol\((.*)\)[^)]+$/;Uo(qo,"description",{configurable:!0,get:function(){var e=E(this)?this.valueOf():this,t=Xo.call(e);if(F($o,e))return"";var n=Ko?t.slice(7,-1):t.replace(Qo,"$1");return""===n?void 0:n}}),Xe({global:!0,forced:!0},{Symbol:zo})}co("iterator");var Zo=H("unscopables"),Jo=Array.prototype;null==Jo[Zo]&&te.f(Jo,Zo,{configurable:!0,value:lt(null)});var ei,ti,ni,ri=function(e){Jo[Zo][e]=!0},oi={},ii=H("iterator"),ai=!1;[].keys&&("next"in(ni=[].keys())?(ti=an(an(ni)))!==Object.prototype&&(ei=ti):ai=!0),(null==ei||a((function(){var e={};return ei[ii].call(e)!==e})))&&(ei={}),F(ei,ii)||ne(ei,ii,(function(){return this}));var si={IteratorPrototype:ei,BUGGY_SAFARI_ITERATORS:ai},li=si.IteratorPrototype,ui=function(){return this},ci=si.IteratorPrototype,di=si.BUGGY_SAFARI_ITERATORS,fi=H("iterator"),pi="keys",_i="values",hi="entries",vi=function(){return this},gi=function(e,t,n,r,o,i,a){!function(e,t,n){var r=t+" Iterator";e.prototype=lt(li,{next:d(1,n)}),_o(e,r,!1),oi[r]=ui}(n,t,r);var s,l,u,c=function(e){if(e===o&&v)return v;if(!di&&e in _)return _[e];switch(e){case pi:case _i:case hi:return function(){return new n(this,e)}}return function(){return new n(this)}},f=t+" Iterator",p=!1,_=e.prototype,h=_[fi]||_["@@iterator"]||o&&_[o],v=!di&&h||c(o),g="Array"==t&&_.entries||h;if(g&&(s=an(g.call(new e)),ci!==Object.prototype&&s.next&&(an(s)!==ci&&(Rr?Rr(s,ci):"function"!=typeof s[fi]&&ne(s,fi,vi)),_o(s,f,!0))),o==_i&&h&&h.name!==_i&&(p=!0,v=function(){return h.call(this)}),_[fi]!==v&&ne(_,fi,v),oi[t]=v,o)if(l={values:c(_i),keys:i?v:c(pi),entries:c(hi)},a)for(u in l)(di||p||!(u in _))&&be(_,u,l[u]);else Xe({target:t,proto:!0,forced:di||p},l);return l},Ei="Array Iterator",mi=Ne.set,yi=Ne.getterFor(Ei),Ni=gi(Array,"Array",(function(e,t){mi(this,{type:Ei,target:g(e),index:0,kind:t})}),(function(){var e=yi(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values");oi.Arguments=oi.Array,ri("keys"),ri("values"),ri("entries");var bi=At.charAt,wi="String Iterator",Ci=Ne.set,Ai=Ne.getterFor(wi);gi(String,"String",(function(e){Ci(this,{type:wi,string:Ke(e),index:0})}),(function(){var e,t=Ai(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=bi(n,r),t.index+=e.length,{value:e,done:!1})}));var Ti=H("iterator"),Si=H("toStringTag"),Oi=Ni.values;for(var Ii in Pn){var xi=i[Ii],Di=xi&&xi.prototype;if(Di){if(Di[Ti]!==Oi)try{ne(Di,Ti,Oi)}catch(e){Di[Ti]=Oi}if(Di[Si]||ne(Di,Si,Ii),Pn[Ii])for(var Mi in Ni)if(Di[Mi]!==Ni[Mi])try{ne(Di,Mi,Ni[Mi])}catch(e){Di[Mi]=Ni[Mi]}}}var Li=function(e){var t=e.return;if(void 0!==t)return J(t.call(e)).value},Ri=function(e,t,n,r){try{return r?t(J(n)[0],n[1]):t(n)}catch(t){throw Li(e),t}},Pi=H("iterator"),Fi=Array.prototype,Vi=function(e){return void 0!==e&&(oi.Array===e||Fi[Pi]===e)},ki=H("iterator"),ji=function(e){if(null!=e)return e[ki]||e["@@iterator"]||oi[en(e)]},Yi=H("iterator"),Wi=!1;try{var Bi=0,Hi={next:function(){return{done:!!Bi++}},return:function(){Wi=!0}};Hi[Yi]=function(){return this},Array.from(Hi,(function(){throw 2}))}catch(e){}var Ui=function(e,t){if(!t&&!Wi)return!1;var n=!1;try{var r={};r[Yi]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Gi=!Ui((function(e){Array.from(e)}));Xe({target:"Array",stat:!0,forced:Gi},{from:function(e){var t,n,r,o,i,a,s=R(e),l="function"==typeof this?this:Array,u=arguments.length,c=u>1?arguments[1]:void 0,d=void 0!==c,f=ji(s),p=0;if(d&&(c=pn(c,u>2?arguments[2]:void 0,2)),null==f||l==Array&&Vi(f))for(n=new l(t=Se(s.length));t>p;p++)a=d?c(s[p],p):s[p],xt(n,p,a);else for(i=(o=f.call(s)).next,n=new l;!(r=i.call(o)).done;p++)a=d?Ri(o,c,[r.value,p],!0):r.value,xt(n,p,a);return n.length=p,n}});var $i=function(e){return($i="function"==typeof Symbol&&"symbol"===to(Symbol.iterator)?function(e){return to(e)}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":to(e)})(e)};function zi(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var qi={},Xi=1;function Ki(e,t){function n(e){t({matches:e.matches})}var r=function(e){if("object"!==$i(e))return"";var t="";return["minWidth","maxWidth","width","minHeight","maxHeight","height"].forEach((function(n){var r,o;void 0!==e[n]&&(0<=(r=Number(e[n]))||(r=""),o=n.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+r+"px)")})).orientation.forEach((function(n){var r,o;void 0!==e[n]&&(r=/^[-_a-z0-9]+$/i.test(e[n])?e[n]:"",o=n.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+r+")")})),t}(e),o=window.matchMedia(r),i=Xi++;return qi[i]={observer:o,listener:n},o.addListener(n),t({matches:o.matches}),i}function Qi(e,t){return"addMediaQueryObserver"===e.type?{observerId:Ki(e.mediaQueryCond,(function(e){t({info:e})}))}:"removeMediaQueryObserver"===e.type?(function(e){var t=qi[e],n=t.observer,r=t.listener;n.removeListener(r),delete qi[e]}(e.observerId),{reqEnd:!0}):void 0}var Zi=function(){function e(t,n){var r=this;for(var o in this.flowSetData=function(e){r._pendingSetDataCallbacks.push(e[0])},this.viewInfoCb=function(e){r._received.length||r._blocked?r._fetchingViewInfoCallbacks.push(r.handleViewInfo.bind(r,e)):r.handleViewInfo(e)},this.handleViewInfo=function(e){var t=e[0],n=e[1],o=e[2],i=null;"selectorQuery"===t?i=function(e,t){for(var n=[],r=e.pluginId,o=0,i=e.queue;o<i.length;o++){var a=i[o],s=a.component,l=a.selector,u=a.single,c=a.fields,d=null;if(0===s){var f={};c.id&&(f.id=""),c.dataset&&(f.dataset={}),c.mark&&(f.mark={}),c.rect&&(f.left=0,f.right=0,f.top=0,f.bottom=0),c.size&&(f.width=document.documentElement.clientWidth,f.height=document.documentElement.clientHeight),c.scrollOffset&&(f.scrollLeft=document.documentElement.scrollLeft||document.body.scrollLeft||0,f.scrollTop=document.documentElement.scrollTop||document.body.scrollTop||0,f.scrollWidth=document.documentElement.scrollWidth||document.body.scrollWidth||0,f.scrollHeight=document.documentElement.scrollHeight||document.body.scrollHeight||0),d=f}else{var p=void 0,_=!1;if((p=t.nodeId.getNodeById(s))?(exparser.Component.getComponentOptions(p).writeOnly&&(_=!0),p=p.shadowRoot):r||(p=window.__DOMTree__?window.__DOMTree__.shadowRoot:null),u){var h=p&&!_?p.querySelector(l):null;d=h?wr(h,c):null}else{var v=p&&!_?p.querySelectorAll(l):[];d=[];for(var g=0;g<v.length;g++)d.push(wr(v[g],c))}}n.push(d)}return n}(n,r._treeManager):"intersection"===t?i=Lr(n,r._treeManager,(function(e){dr(Un.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])})):"matchMedia"===t&&(i=Qi(n,(function(e){dr(Un.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])}))),i&&dr(Un.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[i,o])},this.receiveSyncEvent=function(t,n){if(r._received.push(function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),o=0;for(t=0;t<n;t++)for(var i=arguments[t],a=0,s=i.length;a<s;a++,o++)r[o]=i[a];return r}([n],t)),n===Un.SYNC_EVENT_NAME.FLOW_DEPTH&&(r._depth=t[0],0===r._depth)){var o=r._received;r._received=[],r._blocked?r._blocked.push(o):(r.iterator=new Gn(r._treeManager,o,e._startCb),e._startCb(r._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{})),dr(Un.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[r._pendingSetDataCallbacks],-1,!0),r._pendingSetDataCallbacks=[],r.checkDelayFetchingViewInfo())}},this._viewId=t,this._treeManager=n,this._depth=0,this._curWinSize=0,this._setDataCallbackInc=1,this._pendingSetDataCallbacks=[],this._setDataCallbackMap={},this._received=[],this._cache=[],this._blocked=[],this._fetchingViewInfoCallbacks=[],Un.SYNC_EVENT_NAME)if("FLOW_"===o.slice(0,5))switch(o){case"FLOW_SET_DATA":fr(Un.SYNC_EVENT_NAME[o],this.flowSetData,t);break;case"FLOW_VIEW_INFO":fr(Un.SYNC_EVENT_NAME[o],this.viewInfoCb,t);break;case"FLOW_SET_NODE_ANIMATION_INFO":case"FLOW_CLEAR_NODE_ANIMATION_INFO":case"FLOW_SET_NODE_NEXT_ANIMATION_INFO":break;default:fr(Un.SYNC_EVENT_NAME[o],this.receiveSyncEvent,t)}fr(Un.SYNC_EVENT_NAME.SET_DATA_CALLBACK,(function(e){r.triggerSetDataCallbacks(e[0])}),t)}return e.setStartOperation=function(t){e._startCb=t},e.prototype.destroy=function(){for(var e in this.flowSetData=null,this.viewInfoCb=null,this.receiveSyncEvent=null,delete this.flowSetData,delete this.viewInfoCb,delete this.receiveSyncEvent,this.iterator&&this.iterator.destroy(),this._pendingSetDataCallbacks=null,this._received=null,this._blocked=null,this._fetchingViewInfoCallbacks=null,this._cache=null,this._treeManager=null,this._setDataCallbackMap)delete this._setDataCallbackMap[e];this._setDataCallbackMap=null},e.prototype.flushBlocked=function(){if(this._blocked){for(;this._blocked.length;)try{var t=this._blocked.shift();this.iterator=new Gn(this._treeManager,t,e._startCb),e._startCb(this._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{}))}catch(e){}if(!this._blocked.length){var n=ur()?this._treeManager.viewId:-1;dr(Un.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[this._pendingSetDataCallbacks],n,!0),this._pendingSetDataCallbacks=[],this.checkDelayFetchingViewInfo()}}},e.prototype.unblock=function(){this.flushBlocked(),this._blocked&&0===this._blocked.length&&(this._blocked=null)},e.prototype.block=function(){null===this._blocked&&(this._blocked=[])},e.prototype.start=function(){this.flush(),this._depth++,dr(Un.SYNC_EVENT_NAME.FLOW_DEPTH,[this._depth,Date.now()],this._viewId)},e.prototype.dedupe=function(){var e=this._cache;if(this._curWinSize){if(2===e.length)if(e[0][0]===e[1][2])e.shift(),e[0][1]++;else dr((n=e.pop()).shift(),n,this._viewId)}else{var t=e[0][0];if(e.length>2&&t===e[1][0]&&t===e[2][0]&&t!==Un.SYNC_EVENT_NAME.FLOW_SET_DATA&&t!==Un.SYNC_EVENT_NAME.FLOW_VIEW_INFO)e.splice(0,3),this.flush(),this._curWinSize=1,e.unshift([Un.SYNC_EVENT_NAME.FLOW_REPEAT,3,t]);else if(e.length>3){var n;dr((n=e.pop()).shift(),n,this._viewId)}}},e.prototype.push=function(e){this._cache.unshift(e),1===e.length?this.dedupe():this.flush()},e.prototype.flush=function(){for(this._curWinSize=0;this._cache.length;){var e=this._cache.pop();dr(e.shift(),e,this._viewId)}},e.prototype.end=function(){this.flush(),this._depth--,dr(Un.SYNC_EVENT_NAME.FLOW_DEPTH,this._depth,this._viewId),0===this._depth&&cr()},e.prototype.checkDelayFetchingViewInfo=function(){var e;this._fetchingViewInfoCallbacks.length&&(e=this._fetchingViewInfoCallbacks,this._fetchingViewInfoCallbacks=[],e.forEach((function(e){e()})))},e.prototype.registerSetDataCallback=function(e,t,n){var r=this._setDataCallbackInc++;this._setDataCallbackMap[r]=[e,t,n],this.push([Un.SYNC_EVENT_NAME.FLOW_SET_DATA,r])},e.prototype.triggerSetDataCallbacks=function(e){for(var t=0;t<e.length;t++){var n=e[t],r=this._setDataCallbackMap[n],o=r[0],i=r[1],a=r[2];delete this._setDataCallbackMap[n],exparser.safeCallback("SetData Callback",o,i,[],a)}},e}(),Ji={};function ea(e,t){if(e){if(An(e.childNodes))for(var n=0,r=e.childNodes;n<r.length;n++)ea(r[n],t);if(An(e.__ddSlotChildren)){n=0;for(var o=e.__ddSlotChildren;n<o.length;n++)ea(o[n],t)}e.shadowRoot instanceof exparser.Element&&ea(e.shadowRoot,t),t(e)}}var ta=function(){function e(e){this.listenerInited=!1,this.root=null,this.tabRoot=null,this.tabDestroyed=!1,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow=new Zi(e,this),this.nodeId=new In,this.rootNodeId="",this.tabNodeId="",this.rootCompName="",this.tabCompName="",this.applyAnimationCbMap={},this.clearAnimationCbMap={},this.viewInfoCbMap={},this.initialRootData=null,this.lifetimeListener=null}return e.create=function(t){var n=new e(t);return n.viewId=t,Ji[t]=n,n},e.destroy=function(e){var t=Ji[e],n=t.nodeId;ea(t.root,(function(e){n.removeNode(e),e.destroy(!0)})),exparser.Element.delayDestroy(e),n=null,t.destroy(),t=null,Ji[e]=null,dd&&Cn(dd.triggerGC)&&dd.triggerGC()},e.get=function(e){return Ji[e]},e.listViewId=function(){var e=[];for(var t in Ji)e.push(Ji[t].viewId);return e},e.list=function(){var e=[];for(var t in Ji)e.push(Ji[t]);return e},e.prototype.destroy=function(){if(this.listenerInited=null,this.root=null,this.tabRoot=null,this.tabDestroyed=null,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow&&this.operationFlow.destroy(),this.operationFlow=null,this.nodeId&&this.nodeId.destroy(),this.nodeId=null,this.rootNodeId=null,this.tabNodeId=null,this.rootCompName=null,this.tabCompName=null,this.applyAnimationCbMap=null,this.clearAnimationCbMap=null,this.viewInfoCbMap)for(var e in this.viewInfoCbMap)this.viewInfoCbMap[e]=null;this.viewInfoCbMap=null,this.initialRootData=null,this.lifetimeListener=null,this.viewId=null},e}(),na=null;function ra(){na={};var e,t=null;__ddConfig&&__ddConfig.plugins?t=__ddConfig.plugins:"undefined"!=typeof window&&window&&window.__ddConfigAppService__&&window.__ddConfigAppService__.plugins&&(t=window.__ddConfigAppService__.plugins);var n=!1;if(t)for(var r in t){var o=t[r],i=o.provider,a=o.subpackage,s=void 0;void 0!==a&&(n=!0,"__APP__"===(s=a||"")&&(s=""),"/"===s[0]&&s.slice(1),s&&"/"!==s.slice(-1)&&(s+="/"),na[i]=s)}if(!n){if(__ddConfig&&__ddConfig.subPackages)e=__ddConfig.subPackages;else{if("undefined"==typeof window||!window||!window.__subPackages)return;e=window.__subPackages}if(An(e))for(var l=0,u=e;l<u.length;l++){var c=u[l],d=(i=void 0,c.root||"");if(d&&"/"!==d.slice(-1)&&(d+="/"),c.plugins)for(var r in c.plugins)Object.prototype.hasOwnProperty.call(c.plugins,r)&&(i=c.plugins[r]&&c.plugins[r].provider,na[i]=d)}}}function oa(e){var t=e.match(/(?:^|\/)__(dd|plugin)__\/(.*)$/);return t?"dd"===t[1]?"dd://"+t[2]:"plugin-private://"+t[2]:e}function ia(e){return na[e]||""}var aa=0;function sa(){return aa=Date.now()+Math.random()}function la(){return!!aa}function ua(e){aa===e&&(aa=0)}function ca(e){var t,n=sa();try{t=e(n)}catch(e){throw setTimeout((function(){ua(n)}),0),e}return setTimeout((function(){ua(n)}),0),t}var da=!a((function(){return Object.isExtensible(Object.preventExtensions({}))})),fa=t((function(e){var t=te.f,n=!1,r=j("meta"),o=0,i=Object.isExtensible||function(){return!0},a=function(e){t(e,r,{value:{objectID:"O"+o++,weakData:{}}})},s=e.exports={enable:function(){s.enable=function(){},n=!0;var e=Ve.f,t=[].splice,o={};o[r]=1,e(o).length&&(Ve.f=function(n){for(var o=e(n),i=0,a=o.length;i<a;i++)if(o[i]===r){t.call(o,i,1);break}return o},Xe({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:ao.f}))},fastKey:function(e,t){if(!E(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!F(e,r)){if(!i(e))return"F";if(!t)return"E";a(e)}return e[r].objectID},getWeakData:function(e,t){if(!F(e,r)){if(!i(e))return!0;if(!t)return!1;a(e)}return e[r].weakData},onFreeze:function(e){return da&&n&&i(e)&&!F(e,r)&&a(e),e}};fe[r]=!0})),pa=function(e,t){this.stopped=e,this.result=t},_a=function(e,t,n){var r,o,i,a,s,l,u,c=n&&n.that,d=!(!n||!n.AS_ENTRIES),f=!(!n||!n.IS_ITERATOR),p=!(!n||!n.INTERRUPTED),_=pn(t,c,1+d+p),h=function(e){return r&&Li(r),new pa(!0,e)},v=function(e){return d?(J(e),p?_(e[0],e[1],h):_(e[0],e[1])):p?_(e,h):_(e)};if(f)r=e;else{if("function"!=typeof(o=ji(e)))throw TypeError("Target is not iterable");if(Vi(o)){for(i=0,a=Se(e.length);a>i;i++)if((s=v(e[i]))&&s instanceof pa)return s;return new pa(!1)}r=o.call(e)}for(l=r.next;!(u=l.call(r)).done;){try{s=v(u.value)}catch(e){throw Li(r),e}if("object"==typeof s&&s&&s instanceof pa)return s}return new pa(!1)},ha=function(e,t,n){if(!(e instanceof t))throw TypeError("Incorrect "+(n?n+" ":"")+"invocation");return e},va=function(e,t,n){var r=-1!==e.indexOf("Map"),o=-1!==e.indexOf("Weak"),s=r?"set":"add",l=i[e],u=l&&l.prototype,c=l,d={},f=function(e){var t=u[e];be(u,e,"add"==e?function(e){return t.call(this,0===e?0:e),this}:"delete"==e?function(e){return!(o&&!E(e))&&t.call(this,0===e?0:e)}:"get"==e?function(e){return o&&!E(e)?void 0:t.call(this,0===e?0:e)}:"has"==e?function(e){return!(o&&!E(e))&&t.call(this,0===e?0:e)}:function(e,n){return t.call(this,0===e?0:e,n),this})};if(ze(e,"function"!=typeof l||!(o||u.forEach&&!a((function(){(new l).entries().next()})))))c=n.getConstructor(t,e,r,s),fa.enable();else if(ze(e,!0)){var p=new c,_=p[s](o?{}:-0,1)!=p,h=a((function(){p.has(1)})),v=Ui((function(e){new l(e)})),g=!o&&a((function(){for(var e=new l,t=5;t--;)e[s](t,t);return!e.has(-0)}));v||((c=t((function(t,n){ha(t,c,e);var o=Pr(new l,t,c);return null!=n&&_a(n,o[s],{that:o,AS_ENTRIES:r}),o}))).prototype=u,u.constructor=c),(h||g)&&(f("delete"),f("has"),r&&f("get")),(g||_)&&f(s),o&&u.clear&&delete u.clear}return d[e]=c,Xe({global:!0,forced:c!=l},d),_o(c,e),o||n.setStrong(c,e,r),c},ga=function(e,t,n){for(var r in t)be(e,r,t[r],n);return e},Ea=H("species"),ma=function(e){var t=y(e),n=te.f;s&&t&&!t[Ea]&&n(t,Ea,{configurable:!0,get:function(){return this}})},ya=te.f,Na=fa.fastKey,ba=Ne.set,wa=Ne.getterFor,Ca=(va("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),{getConstructor:function(e,t,n,r){var o=e((function(e,i){ha(e,o,t),ba(e,{type:t,index:lt(null),first:void 0,last:void 0,size:0}),s||(e.size=0),null!=i&&_a(i,e[r],{that:e,AS_ENTRIES:n})})),i=wa(t),a=function(e,t,n){var r,o,a=i(e),u=l(e,t);return u?u.value=n:(a.last=u={index:o=Na(t,!0),key:t,value:n,previous:r=a.last,next:void 0,removed:!1},a.first||(a.first=u),r&&(r.next=u),s?a.size++:e.size++,"F"!==o&&(a.index[o]=u)),e},l=function(e,t){var n,r=i(e),o=Na(t);if("F"!==o)return r.index[o];for(n=r.first;n;n=n.next)if(n.key==t)return n};return ga(o.prototype,{clear:function(){for(var e=i(this),t=e.index,n=e.first;n;)n.removed=!0,n.previous&&(n.previous=n.previous.next=void 0),delete t[n.index],n=n.next;e.first=e.last=void 0,s?e.size=0:this.size=0},delete:function(e){var t=this,n=i(t),r=l(t,e);if(r){var o=r.next,a=r.previous;delete n.index[r.index],r.removed=!0,a&&(a.next=o),o&&(o.previous=a),n.first==r&&(n.first=o),n.last==r&&(n.last=a),s?n.size--:t.size--}return!!r},forEach:function(e){for(var t,n=i(this),r=pn(e,arguments.length>1?arguments[1]:void 0,3);t=t?t.next:n.first;)for(r(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!l(this,e)}}),ga(o.prototype,n?{get:function(e){var t=l(this,e);return t&&t.value},set:function(e,t){return a(this,0===e?0:e,t)}}:{add:function(e){return a(this,e=0===e?0:e,e)}}),s&&ya(o.prototype,"size",{get:function(){return i(this).size}}),o},setStrong:function(e,t,n){var r=t+" Iterator",o=wa(t),i=wa(r);gi(e,t,(function(e,t){ba(this,{type:r,target:e,state:o(e),kind:t,last:void 0})}),(function(){for(var e=i(this),t=e.kind,n=e.last;n&&n.removed;)n=n.previous;return e.target&&(e.last=n=n?n.next:e.state.first)?"keys"==t?{value:n.key,done:!1}:"values"==t?{value:n.value,done:!1}:{value:[n.key,n.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),n?"entries":"values",!n,!0),ma(t)}}),En.filter),Aa=Mt("filter");Xe({target:"Array",proto:!0,forced:!Aa},{filter:function(e){return Ca(this,e,arguments.length>1?arguments[1]:void 0)}});var Ta=te.f,Sa=Ve.f,Oa=Ne.enforce,Ia=H("match"),xa=i.RegExp,Da=xa.prototype,Ma=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,La=/a/g,Ra=/a/g,Pa=new xa(La)!==La,Fa=Je.UNSUPPORTED_Y,Va=s&&(!Pa||Fa||ct||ft||a((function(){return Ra[Ia]=!1,xa(La)!=La||xa(Ra)==Ra||"/a/i"!=xa(La,"i")})));if(ze("RegExp",Va)){for(var ka=function(e,t){var n,r,o,i,a,s,l=this instanceof ka,u=Ht(e),c=void 0===t,d=[],f=e;if(!l&&u&&c&&e.constructor===ka)return e;if((u||e instanceof ka)&&(e=e.source,c&&(t="flags"in f?f.flags:Qe.call(f))),e=void 0===e?"":Ke(e),t=void 0===t?"":Ke(t),f=e,ct&&"dotAll"in La&&(r=!!t&&t.indexOf("s")>-1)&&(t=t.replace(/s/g,"")),n=t,Fa&&"sticky"in La&&(o=!!t&&t.indexOf("y")>-1)&&(t=t.replace(/y/g,"")),ft&&(e=(i=function(e){for(var t,n=e.length,r=0,o="",i=[],a={},s=!1,l=!1,u=0,c="";r<=n;r++){if("\\"===(t=e.charAt(r)))t+=e.charAt(++r);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:Ma.test(e.slice(r+1))&&(r+=2,l=!0),o+=t,u++;continue;case">"===t&&l:if(""===c||F(a,c))throw new SyntaxError("Invalid capture group name");a[c]=!0,i.push([c,u]),l=!1,c="";continue}l?c+=t:o+=t}return[o,i]}(e))[0],d=i[1]),a=Pr(xa(e,t),l?this:Da,ka),(r||o||d.length)&&(s=Oa(a),r&&(s.dotAll=!0,s.raw=ka(function(e){for(var t,n=e.length,r=0,o="",i=!1;r<=n;r++)"\\"!==(t=e.charAt(r))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+e.charAt(++r);return o}(e),n)),o&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{ne(a,"source",""===f?"(?:)":f)}catch(e){}return a},ja=function(e){e in ka||Ta(ka,e,{configurable:!0,get:function(){return xa[e]},set:function(t){xa[e]=t}})},Ya=Sa(xa),Wa=0;Ya.length>Wa;)ja(Ya[Wa++]);Da.constructor=ka,ka.prototype=Da,be(i,"RegExp",ka)}ma("RegExp");var Ba=Math.min,Ha=[].lastIndexOf,Ua=!!Ha&&1/[1].lastIndexOf(1,-0)<0,Ga=Vt("lastIndexOf"),$a=Ua||!Ga?function(e){if(Ua)return Ha.apply(this,arguments)||0;var t=g(this),n=Se(t.length),r=n-1;for(arguments.length>1&&(r=Ba(r,Ae(arguments[1]))),r<0&&(r=n+r);r>=0;r--)if(r in t&&t[r]===e)return r||0;return-1}:Ha;Xe({target:"Array",proto:!0,forced:$a!==[].lastIndexOf},{lastIndexOf:$a});var za=!0,qa=Object.create(null);function Xa(){return za}var Ka={},Qa=function(){return this}();try{Qa=globalThis||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":to(window))&&(Qa=window)}var Za=Qa,Ja=ao.f,es=a((function(){return!Object.getOwnPropertyNames(1)}));Xe({target:"Object",stat:!0,forced:es},{getOwnPropertyNames:Ja});var ts=Wr.trim;Xe({target:"String",proto:!0,forced:function(e){return a((function(){return!!Fr[e]()||"​᠎"!="​᠎"[e]()||Fr[e].name!==e}))}("trim")},{trim:function(){return ts(this)}});var ns=Wr.trim,rs=i.parseInt,os=/^[+-]?0[Xx]/,is=8!==rs(Fr+"08")||22!==rs(Fr+"0x16")?function(e,t){var n=ns(Ke(e));return rs(n,t>>>0||(os.test(n)?16:10))}:rs;Xe({global:!0,forced:parseInt!=is},{parseInt:is});var as=fa.onFreeze,ss=Object.freeze,ls=a((function(){ss(1)}));Xe({target:"Object",stat:!0,forced:ls,sham:!da},{freeze:function(e){return ss&&E(e)?ss(as(e)):e}});var us={restoring:null,idDataMap:null,compIdArr:null,compExtraDataMap:null,compIdArrIndex:0};function cs(e,t,n){var r;void 0===e.__resizers&&(e.__resizers=[],r=e,exparser.Observer.create((function(e){e.status})).observe(r,{attachStatus:!0})),e.__resizers[t]=n}var ds=null,fs=!1,ps=!1,_s=[],hs=null,vs=[],gs=0,Es=null,ms=Object.prototype.hasOwnProperty;function ys(e){return e instanceof exparser.Component&&exparser.Component.getComponentOptions(e).domain}function Ns(e,t){var n=this;if(e){var r,o=e,i=ys(o),a=(r=o)instanceof exparser.Component&&"//"===exparser.Component.getComponentOptions(r).domain,s={selectAllComponents:function(n){if(t!==i)return[];var r=ps?e.shadowRoot.querySelectorAll(n):e.querySelectorAll(n),o=[];return r.forEach((function(e){o.push(ws(Ns(e,t),!0))})),o},selectComponent:function(n){if(t!==i)return null;var r=ps?e.shadowRoot.querySelector(n):e.querySelector(n);return r?ws(Ns(r,t),!0):null},removeClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(ur()||!o||!e.length)return n;var r=o.__wxsClass?o.__wxsClass.split(/\s+/):[],i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&o.classList.contains(e)&&(o.classList.toggle(e),fs=!0,i.push(e))})),i.forEach((function(e){r.forEach((function(t,n){return t!==e||(r.splice(n,1),!1)}))})),o.__wxsClass=r.join(" "),n},addClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(ur()||!o||!e.length)return n;var r=o.__wxsClass||"",i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&(o.classList.contains(e)||(o.classList.toggle(e),i.push(e),fs=!0))})),o.__wxsClass=r+(r?" ":"")+i.join(" "),n},hasClass:function(e){return!(ur()||!o)&&o.classList.contains(e)},setStyle:function(e){if(ur()||!o)return n;if(e===o.__wxsStyle)return n;var t=[];if("object"===$i(e))for(var r in e=e?Cs(e):{})ms.call(e,r)&&t.push(r+":"+e[r]);else t=[String(e)];function i(){var e=dd.transformRpx(o.__wxsStyle,!0);o.setNodeStyle(e,Un.STYLE_SEGMENT_INDEX.DDS_STYLE)}return o.__wxsStyle=t.join(";"),i(),cs(o,Un.STYLE_SEGMENT_INDEX.DDS_STYLE,i),fs=!0,n},getDataset:function(){return o?ws(o.dataset):null},getState:function(){return o?(o.__wxsState=o.__wxsState||{},o.__wxsState):null},triggerEvent:function(t,r,i){return!a&&e&&(r=r?Cs(r):r,i=i?Cs(i):i,gs++,o.triggerEvent(t,r,i),gs--),n},callMethod:function(t,r){var o,i,a=r||{};return!ur()&&t&&(a=Cs(a),ps?dr(Un.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,[null===(o=window.nativeParam)||void 0===o?void 0:o.webViewId,e&&e.__ddTmplId||0,t,a,la()]):dd.callMethodFromWxs([(null===(i=window.nativeParam)||void 0===i||i.webViewId,e&&e.__ddTmplId||0),t,a,la()])),n},requestAnimationFrame:function(e){if(!ur()&&"function"==typeof e){var t=e;ur()||"function"!=typeof t||(_s.push(t),hs||window.requestAnimationFrame((function(){hs=null;var e=_s;_s=[],e.forEach((function(e){e(),Ts()}))})))}return n},getComputedStyle:function(e){Array.isArray(e)||(e=[]);var t={computedStyle:e.filter((function(e){return"string"==typeof e}))};return ws(wr(o,t))},animate:function(){},clearAnimation:function(e,t){var n=Math.random()+"-"+ +new Date,r=ta.instance;"function"==typeof t?(e=Cs(e),r.clearAnimationCbMap[n]=t):"function"==typeof e&&(r.clearAnimationCbMap[n]=e)}};return Object.freeze(s),s}}function bs(){return"function"==typeof ds?ds:null}function ws(e,t){return ds?ds(e,"nv_",t?2:void 0):e}function Cs(e,t){var n;return 1<arguments.length&&t&&(n=2),ds?ds(e,void 0,n):e}function As(e,t,n){return t?n?t+e+n:t||"":n||""}function Ts(){!ur()&&fs&&0===gs&&(fs=!1,document.dispatchEvent(new CustomEvent("pageReRender",{})))}function Ss(e,t){var n=e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:window.__DOMTree__,r=t?n:e;return ps=!!e.ownerShadowRoot,Ns(r,ys(r))}function Os(e){var t=e[0],n=e[1],r=e[2],o=e[3],i=void 0===o?{}:o,a=e[4];if(n){var s=ta.get(t);if(!s)return;var l=s.nodeId.getNodeById(n);if(!l)return;var u=exparser.Element.getMethodCaller(l);u&&"function"==typeof u[r]&&(a?ca((function(){u[r](i)})):u[r](i))}else{var c=__appServiceEngine__.getCurrentPagesByDomain("");if(!c.length)return;var d=c[c.length-1];d&&"function"==typeof d[r]&&(a?ca((function(){d[r](i)})):d[r](i))}}function Is(e,t,n){if(e){var r=null;if(t.ownerShadowRoot&&ta.instance&&e._custom){var o=ta.instance.nodeId.getNodeId(t.ownerShadowRoot.__ddHost);if(!(e=e._custom)[o])return;e=e[o]}var i=t.is;if(e[i]&&e[i].length&&e[i][0]&&e[i][0].index===n&&(r=e[i].shift()),r){if(t.__ddsStyle=r.ddsStyle,t.__ddsClass=r.ddsClass,t.__ddsState=ws(r.ddsState),r.ddsStyle){var a=function(){var e=window.dd.transformRpx(t.__ddsStyle,!0);t.setNodeStyle(e,Un.STYLE_SEGMENT_INDEX.DDS_STYLE)};a(),cs(t,Un.STYLE_SEGMENT_INDEX.DDS_STYLE,a)}r.ddsClass&&(t.class=As(" ",t.class,r.ddsClass))}}}ur()&&__appServiceSDK__.onCallMethodFromWxs(Os);var xs=null,Ds=null;function Ms(e){e.$$.style.display="none"}function Ls(e){if(e instanceof exparser.Component)Ms(e);else if(e instanceof exparser.VirtualNode)for(var t=0;t<e.childNodes.length;t++)Ls(e.childNodes[t]);else e instanceof exparser.TextNode&&(e.textContent="");e.__banned=!0}function Rs(e){var t,n;e&&(xs&&(t=exparser.Component.getComponentOptions(e).domain.split("/",1)[0],n=e.shadowRoot,xs[t]&&function(e,t){Ls(e),Ds=Ds||exparser.registerElement({options:{renderingMode:"native"}});var n=e.createComponent("dd-hint",Ds),r=document.createElement("div");r.innerText=t.hint,n.$$.appendChild(r),e.appendChild(n)}(n,xs[t])))}var Ps={},Fs=void 0!==dd&&dd.transformRpx,Vs=/-[a-z]/g,ks=/([A-Z])/g;function js(e){return Ps[e]||(Ps[e]=e.replace(ks,"-$1").toLowerCase()),Ps[e]}function Ys(e){return ur()&&e instanceof exparser.Component?ta.get(e.__ddWebViewId__).nodeId.getNodeById(e.__ddExparserNodeId__):e}function Ws(e,t,n){var r=Ys(e);return n&&r instanceof exparser.VirtualNode&&!r.id&&!Object.getOwnPropertyNames(r.dataset).length&&(r=Ys(n)),{id:t?"":r.id,offsetLeft:r.$$&&!t?r.$$.offsetLeft:0,offsetTop:r.$$&&!t?r.$$.offsetTop:0,dataset:t?{}:r.dataset}}function Bs(e,t,n){var r=Ys(e);return n&&r instanceof exparser.VirtualNode&&!r.id&&!Object.getOwnPropertyNames(r.dataset).length&&(r=Ys(n)),{id:t?"":r.id,dataset:t?{}:r.dataset}}function Hs(e){if(e){for(var t=[],n=0,r=e;n<r.length;n++){var o=r[n];t.push({identifier:o.identifier,pageX:o.pageX,pageY:o.pageY,clientX:o.clientX,clientY:o.clientY,force:o.force||0})}return t}}function Us(e,t,n,r,o,i,a){var s=o?"__ddEventCaptureHandleName":"__ddEventHandleName";e[s]||(e[s]=Object.create(null)),void 0===e[s][t]&&e.addListener(t,(function(n){var o=e[s][t],l=n.mutatedMarked();if((!a||!l)&&(a&&n.markMutated(),o)){n._hasListeners=!0;var u=e.ownerShadowRoot;if(u){var c=u.getHostNode();if(!c)return;var d=exparser.Component.getComponentOptions(c).writeOnly;if(!d||n._allowWriteOnly)if(ur()){if(i&&Cn(o))return;var f=exparser.Element.getMethodCaller(c);Cn(f[o])&&f[o]({type:n.type,timeStamp:n.timeStamp,target:Bs(n.target,d,this),currentTarget:Bs(this,d,null),mark:n.mark,detail:n.detail,touches:n.touches,changedTouches:n.changedTouches,mut:l,_requireActive:n._requireActive})}else if(i){if(Cn(o)&&bs()){var p={type:n.type,timeStamp:n.timeStamp,target:Ws(n.target,d,this),currentTarget:Ws(this,d,null),mark:n.mark,detail:n.detail,touches:Hs(n.touches),changedTouches:Hs(n.changedTouches),mut:l};p.instance=Ss(e);var _=o(ws(p,!0),ws(Ss(e,!0),!0));if(Ts(),!1===_)return _}}else{var h={type:n.type,timeStamp:n.timeStamp,target:Ws(n.target,d,this),currentTarget:Ws(this,d,null),mark:n.mark,detail:n.detail,touches:Hs(n.touches),changedTouches:Hs(n.changedTouches),mut:l,_requireActive:n._requireActive,_relatedInfo:n._relatedInfo,_userTap:la()};dr(Un.SYNC_EVENT_NAME.DD_EVENT,[ta.instance.nodeId.getNodeId(c),o,h],void 0,!!n._requireActive||void 0)}}if(r)return!1}}),{capture:o}),i?e[s][t]=n:(e[s][t]=null==n?"":String(n),Cn(e.__eventHandlerChangeListener__)&&e.__eventHandlerChangeListener__(n,e[s][t],o))}function Gs(e,t,n,r){if(e){e.dataset=e.dataset||{};var o=0,i=!1,a=[],s=e instanceof exparser.Component,l=s&&"//"===exparser.Component.getComponentOptions(e).domain,u=exparser.Component.getDataProxy(e);for(var c in t)v(c);i&&u.doUpdates(o,!ur());for(var d,f,p=function(t){e.__ddPropertyListener__&&e.__ddPropertyListener__[t]||(e.setPropertyChangeListener(t,(function(n){var r=e.ownerShadowRoot.getHostNode();if(ur())r.setData(zi({},e.__modelValueName[t],n));else{var o=ta.instance.nodeId.getNodeId(r);dr(Un.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,{data:n,modelValueName:e.__modelValueName&&e.__modelValueName[t],nodeId:o})}})),e.__ddPropertyListener__=e.__ddPropertyListener__||{},e.__ddPropertyListener__[t]=!0)},_=0,h=a;_<h.length;_++){p(h[_])}if(!ur()&&e.ddsObserver&&bs()&&(f=t,!(d=e).ddsObserver||ur()||us.restoring||(vs.push({node:d,props:f}),Es=Es||window.requestAnimationFrame((function(){Es=null;var e=vs;vs=[],e.forEach((function(e){var t;for(t in d.node.ddsObserver){var n=void 0;ms.call(d.props,t)&&e.ddsObserver[t]&&"function"==typeof e.ddsObserver[t].observer&&(n=e.ddsObserver[t].value,exparser.safeCallback("DDS Observer",e.ddsObserver[t].observer,null,[ws(d.props[t]),ws(n),ws(Ss(e,!0),!0),ws(Ss(e),!0)],e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:void 0),e.ddsObserver[t].value=d.props[t])}}))})))),e.__component__&&!us.restoring)if(ur())e.__treeManager__.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY]);else if(ta.instance.operationFlow.iterator.nextStep()[0]!==Un.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY)throw new Error("Framework inner error (expect FLOW_APPLY_PROPERTY but get another)")}function v(c){var d,f,p,_,h,v=t[c],g=null,E=function(e){return null==e?"":e};if("slot"===e.is&&e instanceof exparser.VirtualNode&&"name"===c)return exparser.Element.setSlotName(e,v),"continue";if("id"===c)return e.id=E(v),"continue";if("slot"===c)return e.slot=E(v),"continue";if("class"===c&&s&&(e.class=e.__ddsClass?As(" ",E(v),e.__ddsClass):E(v),e.hasExternalClass("class")&&e.setExternalClass("class",v)),"style"===c&&s&&e.$$&&(d=Fs(v,!0),e.setNodeStyle(d,Un.STYLE_SEGMENT_INDEX.ATTR),d===v?(p=e,_=Un.STYLE_SEGMENT_INDEX.ATTR,void 0!==p.__resizers&&(p.__resizers[_]=void 0)):cs(e,Un.STYLE_SEGMENT_INDEX.ATTR,(function(){var t=Fs(v,!0);e.setNodeStyle(t,Un.STYLE_SEGMENT_INDEX.ATTR),e.__transformedPropValue=t})),e.__banned&&Ms(e)),s&&exparser.Component.hasPublicProperty(e,c)){!l&&us.restoring||(u.scheduleReplace([c],v,null!=n?n[c]:null),l?u.doUpdates(void 0,!0):(i=!0,e.isInnerDataExcluded(c)||o++));var m=r&&r["model:"+js(c)];if(m){var y=m.match(/^\{\{(.*?)\}\}$/);if(y){var N=y[1].match(/^\s*([_a-zA-Z$][_a-zA-Z0-9$]+)\s*$/);if(N){var b=N[1];e.__modelValueName=no(e.__modelValueName||{},zi({},c,b)),a.push(c)}}}return"continue"}if("style"===c)return"continue";if(/^data-/.test(c)){f=c.slice(5).toLowerCase();var w=Ps[f]?Ps[f]:Ps[f]=f.indexOf("-")<=0?f:f.replace(Vs,(function(e){return e[1].toUpperCase()}));return e.dataset[w]=v,e.setAttribute(c,v),"continue"}if("$gdc"===c&&"function"==typeof(h=v)&&(ds=h),(g=c.match(/^\$wxs:(capture-)?(mut-)?(bind|catch):?(.+)$/))&&(Cn(v)||!v))return Us(e,g[4],v,"catch"===g[3],g[1],!0,g[2]),ur()||e.setAttribute("exparser:info-attr-"+c.slice(4),v.name),"continue";if(g=c.match(/^(capture-)?(mut-)?(bind|catch):?(.+)$/))return Us(e,g[4],v,"catch"===g[3],g[1],!1,g[2]),ur()||e.setAttribute("exparser:info-attr-"+c,v),"continue";if("on"===c.slice(0,2))return Us(e,c.slice(2),v,!1,!1,!1),"continue";if("animation"===c){if(s&&e.$$&&null!==v&&"object"===$i(v)&&v.actions&&v.actions.length>0){var C=0,A=v.actions,T=v.actions.length,S=function(){if(C<T){var t=dd.animationToStyle(A[C]),n=t.transition,r=t.transitionProperty,o=t.transform,i=t.transformOrigin,a=t.style,s={transition:n,transform:o,transitionProperty:r,transformOrigin:i},l=e.__styleObj?Wn(Wn({},e.__styleObj),s):s;for(var u in l["-webkit-transition"]=l.transition,l["-webkit-transform"]=l.transform,l["-webkit-transition-property"]=l.transitionProperty,l["-webkit-transform-origin"]=l.transformOrigin,a)l[u]=a[u];e.__styleObj=l,""!==e.__styleObj.transform&&(e.__transformNoneEnabled=!0);var c=Object.keys(l).filter((function(t){return!(/transition/i.test(t)&&""===l[t]||""===t.trim()||void 0===l[t]||!/transform/i.test(t)&&""===l[t]||!isNaN(parseInt(t,10)))&&(/transform/i.test(t)&&""===l[t]&&e.__transformNoneEnabled&&(l[t]="none"),!0)})).map((function(e){return e.replace(/([A-Z]{1})/g,(function(e){return"-"+e.toLowerCase()}))+":"+l[e]})).join(";"),d=function(){e.setNodeStyle(Fs(c,!0),Un.STYLE_SEGMENT_INDEX.ANIMATION)};d(),cs(e,Un.STYLE_SEGMENT_INDEX.ANIMATION,d),e.__banned&&Ms(e)}};e.addListener("transitionend",(function(){C+=1,S()})),S()}return"continue"}if(g=c.match(/^\$wxs:change:(.+)$/))return e.ddsObserver=e.ddsObserver||{},e.ddsObserver[g[1]]=e.ddsObserver[g[1]]||{},e.ddsObserver[g[1]].observer=v,"continue";if(g=c.match(/^mark:(.+)$/))return e.setMark(g[1],v),"continue";var O=js(c);return s&&e.hasExternalClass(O)?(e.setExternalClass(O,v),"continue"):void 0}}var $s={tag:"shadow",children:[]};function zs(e,t,n){if((3!==e.wxXCkey&&4!==e.wxXCkey||ur()||window&&window.__customComponentMode__)&&(t.__ddDynamicSync__=4===e.wxXCkey?"wx:for":"wx:if"),!ur()){if(e.extraAttr)for(var r in e.extraAttr)t.setAttribute(r,e.extraAttr[r]);void 0!==e.wxScopeData&&(t.__wxScopeData__=e.wxScopeData)}var o=t.__component__,i=t.__placeholder__;if(o||i)if(ur())exparser.Element.getMethodCaller(t).__ddExparserNodeId__=n.nodeId.allocNodeId(t,""),exparser.Element.getMethodCaller(t).__wxExparserNodeId__=exparser.Element.getMethodCaller(t).__ddExparserNodeId__,n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_CREATE_NODE,n.nodeId.getNodeId(t)]);else{if(n=ta.instance,us.restoring){var a=us.idDataMap[n.nodeId.getNodeId(t)];exparser.Component.replaceWholeData(t,a,null)}else{var s=n.operationFlow.iterator.nextStep();if(s[0]!==Un.SYNC_EVENT_NAME.FLOW_CREATE_NODE)throw new Error("Framework inner error (expect FLOW_CREATE_NODE but get another)");n.nodeId.allocNodeId(t,s[1])}Rs(t),t.setAttribute("is",t.is)}Gs(t,e.attr,e.raw,e.rawAttr)}function qs(e,t){var n=e?e(t,null,Za):$s;return n.tag="shadow",n}function Xs(e,t,n,r,o){var i,a,s=null;if(ur()||r||(r=ta.instance),"shadow"===e.tag&&t)n=s=exparser.ShadowRoot.create(t);else if("shadow"===e.tag||"virtual"===e.tag)i="virtual",1===e.wxXCkey||3===e.wxXCkey?i="wx:if":2!==e.wxXCkey&&4!==e.wxXCkey||(i="wx:for"),s=n.createVirtualNode(i),exparser.Element.setInheritSlots(s),ur()?s.__treeManager__=r:s.__wxVkey__=e.wxVkey;else if("dd-slot"===e.tag)s=n.createVirtualNode("slot"),exparser.Element.setSlotName(s,"");else{var l=n.tagNameUsed(e.tag);if(ur()&&!l)(s=n.createVirtualNode(e.tag)).__treeManager__=r;else if(l){var u=n.getHostNode().__using[e.tag],c=n.getHostNode().getPlaceholder(e.tag);Iu(r.viewId,u)&&void 0!==c?((s=n.createComponent(e.tag,c,e.generics,r)).__placeholder__=!0,a=function(t){xu(u,t,r,(function(){var t=n.createComponent(e.tag,void 0,e.generics,r);zs(e,t,r),s.childNodes.forEach((function(e){s.removeChild(e),t.appendChild(e)})),s.parentNode&&s.parentNode.replaceChild(t,s)}))}):s=n.createComponent(e.tag,void 0,e.generics,r)}else s=n.createComponent(e.tag,void 0,e.generics,r)}zs(e,s,r),a&&a(r.nodeId.getNodeId(s));var d=e.children;if(d)for(var f=0,p=void 0,_=d.length;f<_;++f)if(null!==(p=d[f]))if("object"===$i(p))s.appendChild(Xs(p,null,n,r));else{var h=n.createTextNode(p);s.appendChild(h)}return s}var Ks={id:null,prev:null,data:[],clear:function(){this.id=null,this.prev=null,this.data=[]}};function Qs(e){!function(e){var t,n=e.__page__;n&&(t=parseInt(n.scrollTop,10),requestAnimationFrame((function(){document.body.scrollTop=document.documentElement.scrollTop=t})))}(e);var t=0;window.__TAB_BAR__&&(On(window.__TAB_BAR__,1,(function(n){n.triggerLifeTime("restored",[e]),Is(e.compExtraDataMap,n,t++)})),function(e){if(!ur()&&e){var t=window.__TAB_BAR__;t&&(t.__ddsState=ws(e.ddsTabRootState))}}(e.compExtraDataMap)),On(window.__DOMTree__,1,(function(n){n.triggerLifeTime("restored",[e]),Is(e.compExtraDataMap,n,t++)})),function(e){if(!ur()&&e){var t=ps?ta.instance.nodeId.getNodeById(ta.instance.rootNodeId):window.__DOMTree__;t&&(t.__ddsState=e.ddsPageState)}}(e.compExtraDataMap)}function Zs(e,t){return e+"/"+t}fr(Un.SYNC_EVENT_NAME.SAVE_STATE,(function(){Cn(dd.webViewReadyToTerminate)&&dd.webViewReadyToTerminate()})),fr(Un.SYNC_EVENT_NAME.RESTORE_STATE,(function(e){var t=e[0],n=e[1],r=e[2];if(t&&t.isSplitData){var o=t.splitInfo,i=o.id,a=o.index,s=o.total,l=o.data;if(1!==a&&(a!==Ks.prev+1||i!==Ks.id))return Ks.clear();if(a!==s)return Ks.id=i,Ks.prev=a,void Ks.data.push(l);Ks.data.push(l);var u=e.data.join("");try{u=JSON.parse(u)}catch(e){Reporter&&Reporter.errorReport({key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error")}),Reporter&&Reporter.ravenReport("pub_saga_error_message_bt",{key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error"),fail:function(e){}}),u=null}if(Ks.clear(),!u)return;t=u[0],n=u[1],r=u[2]}us.restoring=t||{},us.idDataMap=n,us.compIdArr=r,us.compIdArrIndex=0}));var Js,el={},tl={};function nl(e,t){Cn(Js)&&Js()}var rl=exparser.dataUtils.deepCopy,ol=Object.prototype.hasOwnProperty;function il(e){return"number"==typeof e&&isNaN(e)}function al(e){if(ur())e.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD]);else if(e.operationFlow.iterator.nextStep()[0]!==Un.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD)throw new Error("Expect FLOW_MINIPULATE_CHILD but get another")}function sl(e,t,n,r,o){for(var i=o?rl(e):e,a=0;a<t.length;a++){var s=t[a],l=s[0],u=s[1],c=s[2];if(void 0!==u){for(var d=i,f=l[0],p=1;p<l.length;p++)if(null!=(d=d[f])&&d.__wxspec__&&(d=d.__value__),f=l[p],null!=d&&!ol.call(d,f)){d=null;break}null!=d&&ol.call(d,f)&&(n?null!=c&&"object"===$i(u)&&u instanceof Array==c instanceof Array?d[f]={__value__:c,__wxspec__:!0}:null!=d[f]&&d[f].__wxspec__||(d[f]={__value__:d[f],__wxspec__:!0}):d[f]=r?rl(u,!1):u)}}return i}function ll(e,t,n){if(e!==t&&(!e||n))if(null==t)n.parentNode.removeChild(n);else if("object"===$i(t)){if("object"!==$i(e)||null===e||e.tag!==t.tag||String(e.wxKey)!==String(t.wxKey)||"virtual"===e.tag&&e.wxVkey!==t.wxVkey){var r=ur()?n.__treeManager__:ta.instance,o=n.parentNode,i=Xs(t,null,o.ownerShadowRoot,r);o&&("wx:for"===o.__ddDynamicSync__||"wx:if"===n.__ddDynamicSync__?(r.nodeId.addNode(i),o.replaceChild(i,n),al(r),r.nodeId.removeNode(n)):o.replaceChild(i,n),n.__banned&&Ls(i))}else{if(t.n&&t.n.length){for(var a=t.n,s=t.attr,l={},u=0,c=a;u<c.length;u++){var d=c[u];l[d]=s[d]}Gs(n,l,t.attr,t.rawAttr)}void 0!==t.wxScopeData&&(n.__wxScopeData__=t.wxScopeData),function(e,t,n){var r=!!Tn("customComponents"),o=e.children,i=t.children,a="virtual"===e.tag&&(2===e.wxXCkey||4===e.wxXCkey||void 0===e.wxXCkey)||!r&&i.length!==o.length,s=null,l=null;if(a){var u=function(e,t){for(var n=function(e){for(var t={},n=0;n<e.length;++n){var r=e[n],o=r&&r.wxKey;o?ol.call(t,o)?r.wxKey=void 0:t[o]=n:il(o)&&(r.wxKey=void 0)}return t}(e),r=function(e){for(var t={},n=[],r=0;r<e.length;++r){var o=e[r],i=o&&o.wxKey;i?ol.call(t,i)?(o.wxKey=void 0,n.push(r)):t[i]=r:(il(i)&&(o.wxKey=void 0),n.push(r))}return[t,n]}(t),o=r[0],i=r[1],a=[],s=[],l=[],u=0,c=0,d=0;d<e.length;++d){var f=void 0,p=void 0,_=e[d].wxKey;_?ol.call(o,_)?(f=o[_],a.push(t[f])):(s.push(d-c),++c,a.push(null)):u<i.length?(p=i[u],a.push(t[p]),++u):(s.push(d-c),++c,a.push(null))}var h=a,v=0,g=[];for(d=0;d<t.length;){for(var E=t[d],m=E&&E.wxKey,y=h[v],N=y&&y.wxKey;null===y;)N=(y=h[++v])&&y.wxKey;v>=h.length?(l.push({oldIndex:n[m],index:d,pos:-1}),++v,++d):N===m?(g.push(v),++v,++d):m?(N&&o[N]!==d+1?(y=h[++v])&&y.wxKey===m?(g.push(v),++v):(--v,l.push({oldIndex:n[m],index:d,pos:v})):l.push({oldIndex:n[m],index:d,pos:v}),++d):++v}var b=0;for(d=0;d<l.length;d++){var w=l[d].pos;if(-1===w)break;for(;b<g.length&&w>g[b];)b++;b>=g.length?l[d].pos=-1:l[d].pos=g[b]}return{children:a,removes:s,inserts:l}}(o,t.children);i=u.children,s=u.removes,l=u.inserts}for(var c=n.childNodes,d=0,f=void 0,p=void 0;d<o.length;d++)f=o[d],!(p=i[d])&&a||ll(f,p,c[d]);if(a){for(var _=ur()?n.__treeManager__:ta.instance,h=n.childNodes,v=n.ownerShadowRoot,g=l.length,E=[],m=(d=0,void 0);d<g;d++)m=l[d],E.push({node:void 0!==m.oldIndex?h[m.oldIndex]:null,before:m.pos>=0?h[m.pos]:void 0,index:m.index});d=0;for(var y=void 0,N=s.length;d<N;d++)y=h[s[d]],n.removeChild(y),_.nodeId.removeNode(y),"wx:for"===h.__ddDynamicSync__&&(al(_),_.nodeId.removeNode(y));d=0;var b=void 0,w=void 0,C=void 0;for(m=void 0;d<g;d++)b=(m=E[d]).before,w=m.index,null===(C=E[d].node)&&(C=Xs(t.children[w],null,v,_)),"wx:for"===n.__ddDynamicSync__?(_.nodeId.addNode(C),n.insertBefore(C,b),al(_)):n.insertBefore(C,b);n.__banned&&Ls(n)}}(e,t,n)}}else if("string"==typeof e)t!==e&&(n.textContent=t);else{var f=n.ownerShadowRoot.createTextNode(t);n.parentNode.replaceChild(f,n)}}var ul={},cl={},dl=1,fl=[];function pl(){fl.pop()}function _l(e,t){if(cl[e]){var n=cl[e],r=fl[fl.length-1],o=fl[fl.length-2],i=t(n),a=i.isMergedUpdate,s=i.dataPaths,l=i.pendingStartTimestamp,u=i.updateEndTimestamp,c=i.updateStartTimestamp;dr(Un.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,[e,{isMergedUpdate:a,dataPaths:s,updateProcessId:r,parentUpdateProcessId:o,pendingStartTimestamp:l,updateStartTimestamp:c,updateEndTimestamp:u}])}}fr(Un.SYNC_EVENT_NAME.PERFORMANCE_DATA,(function(e){var t=e[0],n=e[1];ta.get(t).root.triggerLifeTime("performanceData",[n])}));var hl=function(){function e(){}return e.prototype.beforeMergeValues=function(e,t,n){if(ur())if("number"!=typeof n)e.forEach((function(e,n){void 0!==e[1]?t[n]=!1:t[n]=!0}));else{for(var r=0;r<n;r++)t[r]=!1;for(var o=n;o<e.length;o++){void 0!==e[o][1]?t[o]=!1:t[o]=!0}}},e.prototype.beforeUpdateValues=function(e,t,n){if(!ur()&&"number"==typeof n){var r=ta.instance.operationFlow.iterator.nextStepIf(Un.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER);if(r){var o=r[1];if(e&&o.length){_l(ta.instance.nodeId.getNodeId(e),(function(e){return{isMergedUpdate:!0,dataPaths:e.withDataPaths?o.map((function(e){return e[0]})):void 0}}));var i=exparser.Component.getDataProxy(e);i.setChanges(o),i.doUpdates(void 0,!0)}}}},e.prototype.updateValues=function(e,t,n,r,o,i){if(!us.restoring){var a,s="number"!=typeof i;if(ur())if(a=e.__treeManager__,s){a.operationFlow.start();var l=o.filter((function(e){return void 0!==e[1]})),u=a.nodeId.getNodeId(e);a.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_UPDATE,u,rl(l)])}else{for(var c=[],d=i,f=void 0;d<o.length;d++)void 0!==(f=o[d])[1]&&c.push(f);a.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER,rl(c)])}if(this._delayedUpdateValues)this._delayedUpdateValues.push([rl(t),n,r,o,i]);else{this._delayedUpdateValues=[];try{this._updateValues(e,t,n,r,o,i);var p=this._delayedUpdateValues;this._delayedUpdateValues=null;for(var _=0,h=p;_<h.length;_++){var v=h[_];this._updateValues(e,v[0],v[1],v[2],v[3],v[4])}}catch(e){throw this._delayedUpdateValues=null,e}}s&&ur()&&a.operationFlow.end()}},e.prototype._updateValues=function(e,t,n,r,o,i){var a="number"!=typeof i,s=sl(t,o,!0,!1,!Tn("propValueDeepCopy")),l=qs(this._generateFunc,s);sl(t,o,!1,a,!1);var u=this._virtualTree;this._virtualTree=l,ll(u,l,this.shadowRoot),u=null},e.prototype._resetShadowChildren=function(e,t,n){function r(){if(ur())n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD]);else if(n.operationFlow.iterator.nextStep()[0]!==Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD)throw new Error("Expect FLOW_HOT_UPDATE_CHILD but get another")}ur()&&(n.operationFlow.start(),n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE,n.nodeId.getNodeId(e)]));for(var o=this.shadowRoot,i=(this._virtualTree.children||[]).length,a=0;a<i;a++)o.removeChild(o.childNodes[0]);r();var s=qs(this._generateFunc,t);r(),this._virtualTree=s;var l=Xs(s,null,e.shadowRoot,n).childNodes;for(a=0;a<l.length;a++)o.insertBefore(l[0],o.childNodes[a]);ur()&&n.operationFlow.end()},e}(),vl=function(){function e(){}return e.create=function(t,n,r,o){var i=new e;i._initValues=r,i._data=n;var a,s=t.template;try{i._generateFunc="function"==typeof(a=s.func)?a:a.shift().call(void 0,a.shift())}catch(e){}return i._isSimpleComponent="simple://"===o.domain.slice(0,9),i},e.collectIdAndSlotsToMap=function(t,n,r){for(var o=t&&t.childNodes||[],i=0,a=void 0;i<o.length;i++)(a=o[i])instanceof exparser.TextNode||(a.__id&&(n[a.__id]=a),void 0!==a.__slotName&&(r[a.__slotName]=a),e.collectIdAndSlotsToMap(a,n,r))},e.prototype.createInstance=function(t,n){var r=new hl;if(ur()||(n=ta.instance),r._template=this,r._generateFunc=this._generateFunc,r.data=rl(this._data),r.idMap=Object.create(null),r.slots=Object.create(null),us.restoring){if(us.compIdArrIndex>=us.compIdArr.length)throw new Error("Component count unmatched while page recovering");n.nodeId.allocNodeId(t,us.compIdArr[us.compIdArrIndex++]);var o=us.idDataMap[n.nodeId.getNodeId(t)];r._virtualTree=qs(this._generateFunc,o)}else r._virtualTree=qs(this._generateFunc,r.data);return r.shadowRoot=Xs(r._virtualTree,t,null,n),e.collectIdAndSlotsToMap(r.shadowRoot,r.idMap,r.slots),r.listeners=[],this._isSimpleComponent||(t.__component__=!0),ur()&&(t.__treeManager__=n,r.shadowRoot.__treeManager__=n,n.operationFlow.registerSetDataCallback((function(){t.triggerLifeTime("ready")}))),r._delayedUpdateValues=null,r},e}(),gl=fa.getWeakData,El=Ne.set,ml=Ne.getterFor,yl=En.find,Nl=En.findIndex,bl=0,wl=function(e){return e.frozen||(e.frozen=new Cl)},Cl=function(){this.entries=[]},Al=function(e,t){return yl(e.entries,(function(e){return e[0]===t}))};Cl.prototype={get:function(e){var t=Al(this,e);if(t)return t[1]},has:function(e){return!!Al(this,e)},set:function(e,t){var n=Al(this,e);n?n[1]=t:this.entries.push([e,t])},delete:function(e){var t=Nl(this.entries,(function(t){return t[0]===e}));return~t&&this.entries.splice(t,1),!!~t}};var Tl={getConstructor:function(e,t,n,r){var o=e((function(e,i){ha(e,o,t),El(e,{type:t,id:bl++,frozen:void 0}),null!=i&&_a(i,e[r],{that:e,AS_ENTRIES:n})})),i=ml(t),a=function(e,t,n){var r=i(e),o=gl(J(t),!0);return!0===o?wl(r).set(t,n):o[r.id]=n,e};return ga(o.prototype,{delete:function(e){var t=i(this);if(!E(e))return!1;var n=gl(e);return!0===n?wl(t).delete(e):n&&F(n,t.id)&&delete n[t.id]},has:function(e){var t=i(this);if(!E(e))return!1;var n=gl(e);return!0===n?wl(t).has(e):n&&F(n,t.id)}}),ga(o.prototype,n?{get:function(e){var t=i(this);if(E(e)){var n=gl(e);return!0===n?wl(t).get(e):n?n[t.id]:void 0}},set:function(e,t){return a(this,e,t)}}:{add:function(e){return a(this,e,!0)}}),o}};t((function(e){var t,n=Ne.enforce,r=!i.ActiveXObject&&"ActiveXObject"in i,o=Object.isExtensible,a=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},s=e.exports=va("WeakMap",a,Tl);if(ue&&r){t=Tl.getConstructor(a,"WeakMap",!0),fa.enable();var l=s.prototype,u=l.delete,c=l.has,d=l.get,f=l.set;ga(l,{delete:function(e){if(E(e)&&!o(e)){var r=n(this);return r.frozen||(r.frozen=new t),u.call(this,e)||r.frozen.delete(e)}return u.call(this,e)},has:function(e){if(E(e)&&!o(e)){var r=n(this);return r.frozen||(r.frozen=new t),c.call(this,e)||r.frozen.has(e)}return c.call(this,e)},get:function(e){if(E(e)&&!o(e)){var r=n(this);return r.frozen||(r.frozen=new t),c.call(this,e)?d.call(this,e):r.frozen.get(e)}return d.call(this,e)},set:function(e,r){if(E(e)&&!o(e)){var i=n(this);i.frozen||(i.frozen=new t),c.call(this,e)?f.call(this,e,r):i.frozen.set(e,r)}else f.call(this,e,r);return this}})}}));function Sl(e,t,n){e instanceof xl&&Object.defineProperty(e,t,{value:n,writable:!0,enumerable:!0,configurable:!0})}function Ol(e,t,n){var r=xl.getExparserComponent(e);if(!r)return n?[]:null;var o=exparser.Component.getComponentOptions(r).domain,i=r.shadowRoot;if(n)return i.querySelectorAll(t).map((function(t){return Il(o,t,e)}));var a=i.querySelector(t);return a?Il(o,a,e):null}function Il(e,t,n){if(!t)return null;var r=exparser.Component.getComponentOptions(t).domain,o=exparser.Component.getMethod(t,"__export__"),i=r===e?exparser.Element.getMethodCaller(t):null;if(o){var a=r===e?n:null,s=o.call(exparser.Element.getMethodCaller(t),a);return void 0===s?i:s}return i}var xl=function(){function e(){this.__data__=null,this.__exitState__=null}return e.getExparserComponent=function(t){return e.callerMap.get(t)},e.getExparserProtocol=function(e){return e?exparser.Component.getComponentOptions(e).domain.split("/",1)[0]:""},Object.defineProperty(e.prototype,"is",{get:function(){var t=e.getExparserComponent(this);return t?t.is:""},set:function(e){Sl(this,"is",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"id",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?"":t.id:""},set:function(e){Sl(this,"id",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getPageId",{get:function(){return function(){var t=e.getExparserComponent(this);return t?"pageId:"+t.__treeManager__.viewId:""}},set:function(e){Sl(this,"getPageId",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?null:t.dataset:null},set:function(e){Sl(this,"dataset",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"properties",{get:function(){return this.__data__},set:function(e){Sl(this,"properties",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"data",{get:function(){return this.__data__},set:function(e){Sl(this,"data",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setData",{get:function(){return function(t,n){var r=e.getExparserComponent(this);if(r)return Cn(n)&&r.__treeManager__.operationFlow.registerSetDataCallback(n,this,r),r.setData(t)}},set:function(e){Sl(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"groupSetData",{get:function(){return function(t){var n=e.getExparserComponent(this);if(n){var r=n.__treeManager__;r.operationFlow.start(),r.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_GROUP]);var o=null;try{t.call(this)}catch(e){o=e}if(r.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_GROUP_END]),r.operationFlow.end(),o)throw o}}},set:function(e){Sl(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"replaceDataOnPath",{get:function(){var t=this;return function(n,r){var o=e.getExparserComponent(t);return o?o.replaceDataOnPath(n,r):void 0}},set:function(e){Sl(this,"replaceDataOnPath",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyDataUpdates",{get:function(){var t=this;return function(){var n=e.getExparserComponent(t);return n?n.applyDataUpdates():void 0}},set:function(e){Sl(this,"applyDataUpdates",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"hasBehavior",{get:function(){var t=this;return function(n){var r=e.getExparserComponent(t);return!!r&&r.hasBehavior(n)}},set:function(e){Sl(this,"hasBehavior",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"triggerEvent",{get:function(){var t=this;return function(n,r,o){var i=e.getExparserComponent(t);return i?i.triggerEvent(n,r,o):void 0}},set:function(e){Sl(this,"triggerEvent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createSelectorQuery",{get:function(){var t=this;return function(){var n=e.getExparserComponent(t);return n?__appServiceSDK__._createSelectorQuery({},e.getExparserProtocol(n)).in(t):null}},set:function(e){Sl(this,"createSelectorQuery",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createIntersectionObserver",{get:function(){var t=this;return function(n){var r=e.getExparserComponent(t);return r?__appServiceSDK__._createIntersectionObserver(t,n,e.getExparserProtocol(r)):null}},set:function(e){Sl(this,"createIntersectionObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createMediaQueryObserver",{get:function(){return function(){}},set:function(e){Sl(this,"createMediaQueryObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getOpenerEventChannel",{get:function(){return function(){return __appServiceEngine__.getCurrentPageWithAdditionalInfo().eventChannel}},set:function(e){Sl(this,"getOpenerEventChannel",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyAnimation",{get:function(){return function(){}},set:function(e){Sl(this,"applyAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"clearAnimation",{get:function(){return function(){}},set:function(e){Sl(this,"clearAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"animate",{get:function(){return function(){}},set:function(e){Sl(this,"animate",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectOwnerComponent",{get:function(){var t=this;return function(){var n=e.getExparserComponent(t);if(!n)return null;if(exparser.Component.getComponentOptions(n).writeOnly)return null;var r=exparser.Component.getComponentOptions(n).domain,o=n.ownerShadowRoot;if(!(o instanceof exparser.ShadowRoot))return null;var i=o.getHostNode();return i?Il(r,i,t):null}},set:function(e){Sl(this,"selectOwnerComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectComponent",{get:function(){var t=this;return function(n){var r=e.getExparserComponent(t);return r?exparser.Component.getComponentOptions(r).writeOnly?null:Ol(t,n,!1):null}},set:function(e){Sl(this,"selectComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectAllComponents",{get:function(){var t=this;return function(n){var r=e.getExparserComponent(t);return r?exparser.Component.getComponentOptions(r).writeOnly?[]:Ol(t,n,!0):[]}},set:function(e){Sl(this,"selectAllComponents",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getRelationNodes",{get:function(){var t=this;return function(n){var r=e.getExparserComponent(t);if(!r)return null;var o=r.getRelationNodes(n);return null===o?null:o.map((function(e){return exparser.Element.getMethodCaller(e)}))}},set:function(e){Sl(this,"getRelationNodes",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getTabBar",{get:function(){return function(){var t=e.getExparserComponent(this);if(!t)return null;var n=t.__treeManager__;return n.tabDestroyed||!n.tabRoot?null:exparser.Element.getMethodCaller(n.tabRoot)}},set:function(e){Sl(this,"getTabBar",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"exitState",{get:function(){return this.__exitState__},set:function(e){Sl(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setInitialRenderingCache",{get:function(){return function(t){var n=e.getExparserComponent(this);if(n){var r=n.__treeManager__;null===t?function(e){e.operationFlow.start(),e.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,"",null]),e.operationFlow.end()}(r):function(e,t){var n=oa(e.rootCompName),r=Sn();e.operationFlow.start(),e.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,n,r]);var o=exparser.createElement("initial-rendering-cache",exparser.Component._list[n],e);exparser.Element.getMethodCaller(o).__ddExparserNodeId__=e.nodeId.allocNodeId(o,r),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,e.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE]),e.nodeId.addNode(),o.setData(t),e.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,t]),e.operationFlow.end(),e.nodeId.removeNode(o)}(r,t)}}},set:function(e){Sl(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setUpdatePerformanceListener",{get:function(){return function(t,n){var r=e.getExparserComponent(this);if(r){var o=r.__treeManager__,i=o.nodeId.getNodeId(r);"function"==typeof n?(r.__updatePerformanceListener__=n,o.operationFlow.push([Un.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,i,t])):(r.__updatePerformanceListener__=null,o.operationFlow.push([Un.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,i]))}}},set:function(e){Sl(this,"exitState",e)},enumerable:!1,configurable:!0}),e.callerMap=new WeakMap,e}();function Dl(){return __ddConfigWindow__&&__ddConfigWindow__.initialRenderingCache?String(__ddConfigWindow__.initialRenderingCache):""}function Ml(e,t){var n=[],r={},o={};exparser.ElementIterator.create(e,"composed-descendants-root-first",exparser.Component).forEach((function(t){t instanceof exparser.Component&&!t.hasBehavior("dd-base")&&(r["./"+e.is+".wxss"]=!0)})),Object.keys(exparser.Component._list).forEach((function(e){o["./"+e+".wxss"]=!0}));for(var i=document.head.querySelectorAll("style")||[],a=0,s=void 0,l=void 0;a<i.length;a++)null!=(l=(s=i[a]).getAttribute("wxss:path"))&&(o[l]&&!r[l]||n.push("<style>"+s.innerHTML+"</style>"));var u=n.join("")+e.$$.innerHTML;dd.saveInitialRenderingCache({content:u,appserviceData:t})}function Ll(e,t){return"dynamic"!==Dl()&&(e?Ml(e,t):dd.saveInitialRenderingCache({content:""}),!0)}var Rl,Pl=1<<18,Fl=Date.now();function Vl(e,t){var n=ta.get(e);n&&(n.statesData=t,n.tabRoot&&On(n.tabRoot,1,(function(e){e.triggerLifeTime("saved")})),On(n.root,1,(function(e){e.triggerLifeTime("saved")})),dr(Un.SYNC_EVENT_NAME.SAVE_STATE,[],e))}var kl={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",templateEngine:vl,renderingMode:"full",multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!0,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},jl={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",renderingMode:"full",templateEngine:vl,multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},Yl=1,Wl=!1,Bl=!1,Hl=[],Ul=[],Gl={},$l=new Set,zl=new Set,ql="custom-tab-bar/index",Xl=new Set([ql]),Kl={},Ql={},Zl=void 0,Jl={},eu={},tu={},nu={},ru={},ou=[],iu=!1,au=Object.create(null),su={lazyRegistration:!0,publicProperties:!0},lu=null,uu=null,cu=null,du={String:String,Number:Number,Boolean:Boolean,Object:Object,Array:Array,null:null},fu={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]},pu=function(e){fu.jsFileLoaded?e():fu.jsFileLoadedCallback.push(e)},_u=function(){fu.compDefLoaded=!0,fu.compDefLoadedCallback.forEach((function(e){e()})),fu.compDefLoadedCallback=[]},hu=function(e){fu.compDefLoaded?e():fu.compDefLoadedCallback.push(e)},vu=function(){fu={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]}},gu=!1,Eu=[];function mu(e){gu?e():Eu.push(e)}function yu(){!0!==gu&&(gu=!0,Eu.forEach((function(e){return e()})))}function Nu(e){for(var t,n,r=Object.create(null),o=0,i=e;o<i.length;o++){var a=i[o];n="";for(var s=0,l=(t="string"==typeof a?a:a.is).length,u=void 0,c=void 0;s<l;++s)n+=(c=(u=t[s]).charCodeAt(0))>=48&&c<=57||c>=65&&c<=90||c>=97&&c<=122||45===c||95===c?u:"/"===u?"-":c;r[t]=n}return r}function bu(e,t){var n={},r=(t[e+".json"]||{}).usingComponents;for(var o in r)n["dd-"+o]=wn(e,String(r[o]));return n}function wu(e,t){for(var n in t){var r=t[n];r.target=null!=r.target?String(r.target):wn(e,String(n))}return t}function Cu(e,t){if("undefined"!=typeof __DDML_DEP__){var n=__DDML_DEP__["./"+e+".wxml"];An(n)&&n.forEach((function(e){var n=e.substr(2,e.length-7);Rl[n]&&t.add(n)}))}}function Au(e,t){var n,r,o,i,a=t.set,s=t.dropLazy;a.has(e)||(a.add(e),n=Rl?Object.keys(Rl[e]||{}):[],s&&(r=new Set(n),o=Gl[e]||{},Object.keys(o).forEach((function(e){r.delete(e)})),(i=o,Object.keys(i).map((function(e){return i[e]}))).forEach((function(e){r.add(e)})),n=Array.from(r)),n.forEach((function(t){Au(Rl[e][t],{set:a,dropLazy:s})})))}function Tu(e,t,n){void 0===n&&(n=null);var r=ur()?__ddConfig.subPackages:void 0,o=(r=(r=r||[]).filter((function(t){return 0===e.indexOf(t.root)})))[0]&&r[0].root||"",i=r[0]&&r[0].allExtendedComponents||[],a=Array.from(t).map((function(e){return-1<i.indexOf(e)?o+e:e}));ur()&&(Kl[n]||(Kl[n]=new Set),a.forEach((function(e){return Kl[n].add(e)})));var s=a.filter((function(e){return!$u(e)}));return s.forEach((function(e){Xl.add(e)})),s}function Su(e,t,n,r){var o,i;if(void 0===r&&(r=!1),__ddConfig&&__ddConfig.isLazyLoad){var a="undefined"!=typeof __ddAppCode__?__ddAppCode__:{};for(var s in void 0===Rl&&(Rl={}),a)if(".json"===s.substr(s.length-5)){var l=s.slice(0,-5),u=a[s],c={},d={},f=u.usingComponents;for(var p in f)c[p]=wn(l,f[p]);var _=u.componentGenerics;for(var h in _){var v=_[h].default;v&&(c[String(v)]=wn(l,v))}var g=u.componentPlaceholder;for(var p in g)d[p]=g[p];Rl[l]=c,Gl[l]=d||{}}var E=Object.keys(Rl);lu=Nu(E),r||(nl(),nl(0,ur()),nl(0,E.length)),o=new Set,Au(e,{set:o,dropLazy:!0}),Object.keys(Gl).forEach((function(e){Au(e,{set:zl})})),o.forEach((function(e){return Cu(e,o)}));var m=Tu(e,o,t);if(r||(nl(0,m.length),nl(),nl()),ur()){!function(e){if(0===e.length)return 0;var t=Date.now();Date.now()}(m.map((function(e){return"/"+e+".appservice.js"})))}else{var y=m.map((function(e){return"/"+e+".webview.js"}));i=function(t){function n(){var t,n;nl(),void 0!==(t=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})[e+".ddss"])&&"function"==typeof t||(t=function(){}),window.__setCssStartTime__=Date.now(),t(),window.__setCssEndTime__=Date.now(),n=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})["./"+e+".ddml"],Array.isArray(n)&&(n=n[0][n[1]]),window.__ddAppCodeReadyCallback__?window.__ddAppCodeReadyCallback__(n):document.dispatchEvent(new CustomEvent("generateFuncReady",{detail:{generateFunc:n}}))}r?!0!==iu&&(iu=!0,ou.forEach((function(e){e()}))):Gu()?Hu(n):n()},y.length||i&&i(0)}}}function Ou(e,t,n,r){var o=ta.get(n).nodeId.getNodeById(r);if(o&&t){var i=zi({},t,e);exparser.Element.getMethodCaller(o).setData(i)}}function Iu(e,t){return ur()?t!==ql&&!(Kl[e]&&Kl[e].has(t)):!$u(t)}function xu(e,t,n,r){$l.add(e),Ql[t]=r,void 0!==Zl&&clearTimeout(Zl),Zl=setTimeout((function(){var e=Array.from($l),t=n.rootCompName,r=n.viewId;if($l=new Set,ur()){Lu(e,t,r),e.forEach((function(e){zl.delete(e)}));var o=[[],[],t,el];e.forEach((function(e){Ru(o,e,au,t)})),dr(Un.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,o,r),n.operationFlow.start(),n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER]),n.operationFlow.end();var i=Object.keys(Ql);n.operationFlow.start(),n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER,i]),i.forEach((function(e){Ql[e](),delete Ql[e]})),n.operationFlow.end()}else Lu(e,t,null)}),50)}function Du(e,t){var n,r={};for(var o in e.properties){var i=e.properties[o];null===i?r[o]={type:null}:(n=i)===Number||n===String||n===Boolean||n===Object||n===Array?r[o]={type:i.name}:(void 0===i.public||i.public)&&(r[o]={type:i.type?i.type.name:null,value:i.value})}var a=e.options.innerDataExclude;return{is:e.is,using:e.using,generics:e.generics,behaviors:e.behaviors,placeholder:e.placeholder,data:e.data,properties:r,externalClasses:e.externalClasses,template:t,options:{domain:e.options.domain,writeOnly:e.options.writeOnly||void 0,multipleSlots:e.options.multipleSlots||void 0,writeIdToDOM:e.options.writeIdToDOM||void 0,styleIsolation:e.options.styleIsolation||void 0,addGlobalClass:e.options.addGlobalClass||void 0,hasObservers:!!e.observers,innerDataExcludeString:a?a.toString():null,virtualHost:e.options.virtualHost||void 0}}}function Mu(e){if(e.behaviors){for(var t=[],n=0,r=e.behaviors;n<r.length;n++){var o=r[n],i=String(o);if("/"!==i[0]&&"dd://"!==i.slice(0,5))throw new Error("Behaviors should be constructed with Behavior()");t.push(i)}e.behaviors=t,nu[e.is]=t}else e.behaviors=null}ur()||(ur()||(fr(Un.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0],n=e[1];cl[t]=n})),fr(Un.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0];cl[t]=null}))),"undefined"!=typeof __ddAppCode__?yu():window.__mainPageFrameReady__=yu,mu((function(){if(__ddConfig.isFirstPage){var e=__ddConfig.appLaunchInfo.path.replace(/\.html$/,"").replace(/^\//,"");setTimeout((function(){Su(e,null)}),0)}})),mu((function(){Su(ql,null,__ddConfig.isFirstPage,!0),Hu((function(){Bu()}))})),fr(Un.SYNC_EVENT_NAME.DESTROY_TAB,(function(){ta.instance.tabDestroyed=!0,window.__TAB_BAR__&&window.__TAB_BAR__.parentNode.removeChild(window.__TAB_BAR__)}))),fr(Un.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,(function(e){Yu(e,!1),pu((function(){_u()}))}),0),fr(Un.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,(function(e){Su(e[0],null)}),0),fr(Un.SYNC_EVENT_NAME.COMPONENT_DEF,(function(e){Bl?Yu(e,!1):Hl.push(e)}),0),fr(Un.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,(function(e){Bl?Yu(e[0],!0):Ul.push(e[0])}),0),fr(Un.SYNC_EVENT_NAME.UPDATE_COMPONENT_DEF,(function(e){var t=e[0],n=ta.instance;exparser.Component._list[t.is]&&Vu(t,n.rootCompName===t.is)})),ur()||fr(Un.SYNC_EVENT_NAME.FLUSH_BLOCKED,(function(){ta.instance.operationFlow.flushBlocked()}),0);var Lu=function(e,t,n){var r=new Set;e.forEach((function(e){Au(e,{set:r})})),r.forEach((function(e){return Cu(e,r)}));var o=Tu(t,r,n);o.forEach((function(e){return Xl.add(e)})),0!==o.length&&ur()&&Array.from(o).forEach((function(e){var t=new Set;__appServiceSDK__.requireByRoute(e,t)}))};function Ru(e,t,n,r){var o;ol.call(el,t)&&(t=el[t]);var i=Jl[t];if(!i){if(zl.has(t))return;throw new Error('Component is not found in path "'+t+'"'+(r?' (using by "'+r+'")':""))}"dd://"!==t.slice(0,5)&&(e[1].unshift(i),n[t]=!0);var a,s=eu[i.is];for(o in s)ol.call(s,o)&&(n[a=s[o]]||Ru(e,a,n,t));var l,u=tu[i.is];for(o in u)ol.call(u,o)&&(l=u[o].default)&&(n[l]||Ru(e,l,n,t));var c=nu[i.is];if(c)for(var d=function e(t,n,r){if("dd://"!==n.slice(0,5)){var o=ru[n];if(!o)throw new Error('"'+n+'" is not a behavior registered by Behavior()');t[0].unshift(o),r[n]=!0;var i=nu[o.is];if(i)for(var a=0,s=i;a<s.length;a++){var l=s[a];r[l]||e(t,l,r)}}},f=0,p=c;f<p.length;f++){var _=p[f];n[_]||d(e,_,n)}return e}function Pu(e,t,n){var r=t[n+".json"]||{};void 0!==r.styleIsolation&&(e.options||(e.options={}),e.options.styleIsolation=r.styleIsolation),void 0!==r.pureDataPattern&&(e.options||(e.options={}),e.options.pureDataPattern=new RegExp(r.pureDataPattern))}function Fu(e,t){e.using=eu[e.is]=bu(e.is,t),e.placeholder=function(e,t){var n=t[e+".json"]||{},r={},o=n.componentPlaceholder||{};return Object.keys(o).forEach((function(e){r["dd-"+e]="dd-"+String(o[e])})),r}(e.is,t),e.generics=tu[e.is]=function(e,t){var n={},r=(t[e+".json"]||{}).componentGenerics;for(var o in r){var i=r[o];"object"===$i(i)?n["dd-"+o]={default:wn(e,String(i.default||""))}:null!=i&&(n["dd-"+o]={})}return n}(e.is,t),Mu(e);var n=e.is;t[n+".wxml"]?n+=".wxml":t[n+".ddml"]&&(n+=".ddml"),e.template={path:n,func:Ka[n]||t[n]||null},Jl[e.is]=Du(e,n);var r=exparser.registerElement(e),o=new xl;exparser.Behavior.prepare(r.behavior);var i=r.behavior.methods;for(var a in i)o[a]=i[a];return o}function Vu(e,t,n){var r;for(r in e.properties){var o=e.properties[r].type;e.properties[r].type=du[o]}var i="";t||(i=n?cu[e.is]:uu[e.is]);var a=e.options,s=!(!a.writeIdToDOM&&!t);e.options=jl,e.options.multipleSlots=a.multipleSlots||!1,e.options.writeOnly=a.writeOnly||!1,e.options.writeIdToDOM=s,e.options.domain=a.domain,e.options.randomizeTagName=!1,e.options.virtualHost=a.virtualHost,e.options.innerDataExclude=function(e){if(!e)return null;var t=e.lastIndexOf("/"),n=e.slice(1,t),r=e.slice(t+1);return new RegExp(n,r)}(a.innerDataExcludeString);var l=!1;if(a.styleIsolation){var u=a.styleIsolation;"page-"===u.slice(0,5)&&(l=!0,u=u.slice(5)),"isolated"===u?(i=uu[e.is],e.options.addGlobalClass=!1):"strong-isolated"===u?(i=uu[e.is],e.options.addGlobalClass=!1,e.options.randomizeTagName=!0):"apply-shared"===u?(i=uu[e.is],e.options.addGlobalClass=!0):"shared"===u&&"/"===a.domain?(i="",e.options.addGlobalClass=!1):l=!1}else e.options.addGlobalClass=a.addGlobalClass||!1;e.options.classPrefix=i,a.hasObservers&&(e.observers={"**":function(){}});var c="undefined"!=typeof __ddAppCode__&&__ddAppCode__[e.template];window.__customComponentMode__=c;var d=c?__ddAppCode__[e.template]:window.__generateFunc__,f=e.template;return e.template={path:f,func:d},exparser.registerElement(e),{disableAppDdss:l,classPrefix:i}}function ku(e){var t=Date.now(),n=e.operationFlow.iterator,r=n.expectStart(),o=n.nextStepType();if(o===Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION)ju(e,Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION);else if(o===Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)ju(e,Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE);else if(o===Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB)ju(e,Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB);else if(o===Un.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER)n.nextStep(),ta.instance.operationFlow.block(),ta.instance.operationFlow.unblock(),hu((function(){vu(),ta.instance.operationFlow.unblock()}));else{var i=n.nextStep(),a=void 0;if((o=i[0])===Un.SYNC_EVENT_NAME.FLOW_UPDATE){var s=i[1];if(a=e.nodeId.getNodeById(s)){var l=i[2];if(An(l)&&l.length){var u=exparser.Component.getDataProxy(a);u.setChanges(l),u.doUpdates(void 0,!ur()),_l(s,(function(e){return{isMergedUpdate:!1,dataPaths:e.withDataPaths?l.map((function(e){return e[0]})):void 0,pendingStartTimestamp:r,updateStartTimestamp:t,updateEndTimestamp:Date.now()}}))}}else n.skipToEnd()}else if(o===Un.SYNC_EVENT_NAME.FLOW_GROUP){var c=n.nextStep();if(c[0]!==Un.SYNC_EVENT_NAME.FLOW_GROUP_END)throw new Error("Framework inner error (expect FLOW_GROUP_END but get "+Un.getEvName(c[0])+")")}else if(o===Un.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER)i[1].forEach((function(e){Ql[e](),delete Ql[e]}));else if(o===Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE)(a=e.nodeId.getNodeById(i[1]))?a.__templateInstance._resetShadowChildren(a,a.data,e):n.skipToEnd();else{if(o!==Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Framework inner error (expect an update event but get "+Un.getEvName(o)+")");!function(e,t){if(Xa()){ur()&&(t.operationFlow.start(),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET,t.nodeId.getNodeId(e)]));var n="";e===t.root?n="body":e===t.tabRoot&&(n="tab-bar");var r=e.__vtObj,o=e.ownerShadowRoot?e.ownerShadowRoot.createComponent(r.tag,void 0,r.generics,t):exparser.createElement(n,exparser.Component._list[e.is],t);if(ur())t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET]);else if(t.operationFlow.iterator.nextStep()[0]!==Un.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Expect FLOW_HOT_UPDATE_RESET but get another");var i=t.nodeId.getNodeId(e);if(t.nodeId.removeNode(e),t.nodeId.allocNodeId(o,i),e===t.root){exparser.Element.pretendDetached(e),t.root=o,ur()||(window.__DOMTree__=o,document.body=o.$$),exparser.Element.pretendAttached(o);var a={},s=!1;Object.keys(t.initialRootData).forEach((function(e){exparser.Component.hasProperty(o,e)&&(a[e]=t.initialRootData[e],s=!0)})),s&&t.root.setData(a)}else t.tabRoot;ur()&&t.operationFlow.end()}}(e.nodeId.getNodeById(i[1]),e)}}n.expectEnd()}function ju(e,t){var n,r,o,i,a=t===Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB,s=t===Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,l=e.operationFlow.iterator,u=l.nextStep(),c=null,d=u[1],f=u[2];if(a)e.tabNodeId=f,e.tabRoot=c=window.__TAB_BAR__=exparser.createElement("tab-bar",exparser.Component._list[d]);else if(s){if(!d)return void Ll(null);c=exparser.createElement("initial-rendering-cache",exparser.Component._list[d])}else{var p=u[3]||{};e.rootNodeId=f,e.root=c=window.__DOMTree__=exparser.Component.createWithGenerics("body",exparser.Component._list[d],p,e)}if(e.nodeId.allocNodeId(c,f),c.setAttribute("is",d),us.restoring&&!a&&(n=us.idDataMap[e.nodeId.getNodeId(c)],exparser.Component.replaceWholeData(c,n,null),Qs(us.restoring),us.restoring=null,us.idDataMap=null),(u=l.nextStep())[0]!==t)throw new Error("Framework inner error (expect "+Un.getEvName(t)+" end but get "+Un.getEvName(u[0])+")");if(e.nodeId.addNode(),a){var _=exparser.createElement("dd-tab-bar-wrapper",exparser.Component._list["dd://tab-bar-wrapper"]);_.appendChild(c),document.documentElement.insertBefore(_.$$,document.body),exparser.Element.pretendAttached(_),e.tabDestroyed&&_.removeChild(c)}else if(s){var h=document.createElement("dd-initial-rendering-cache-wrapper");if(h.setAttribute("style","height: 0; overflow: hidden"),h.appendChild(c.$$),document.documentElement.insertBefore(h,document.body),(u=l.nextStep())[0]!==Un.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)throw new Error("Framework inner error (expect initial rendering end but get another)");On(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),Ll(c,u[1]),e.nodeId.removeNode(c),document.documentElement.removeChild(h)}else document.body=c.$$,On(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),i=c,"static"===Dl()&&Ml(i),exparser.Element.pretendAttached(c),r="initialRenderingDone",o=Date.now(),ul[r]=o,setTimeout((function(){var e;dr(Un.SYNC_EVENT_NAME.PERFORMANCE_DATA,[(null===(e=window.nativeParam)||void 0===e?void 0:e.webViewId)||0,ul],void 0,!0)}),0)}function Yu(e,t){var n=e[0],r=e[1],o=e[2],i=e[3];t||(ta.instance.rootCompName=o);var a=__ddAppCode__[o+".wxss"]||__ddAppCode__[o+".ddss"];"function"==typeof a&&a(o);for(var s=0,l=n;s<l.length;s++){var u=l[s];u.options=su,exparser.registerBehavior(u)}var c,d=r.map((function(e){return e.is}));t?cu=lu||Nu(d):uu=Nu(r);for(var f=0,p=r;f<p.length;f++){var _=(c=p[f]).is===o&&!t;Vu(c,_,t).disableAppDdss&&_&&(__webviewEngine__.disableStyleElement("app.wxss"),__webviewEngine__.disableStyleElement("app.ddss"));var h=__ddAppCode__[c.is+".wxss"]||__ddAppCode__[c.is+".ddss"];"function"==typeof h&&h(c.is)}for(var v in i)exparser.Component._list[v]=exparser.Component._list[i[v]]}function Wu(e,t,n){var r=[[],[],n=oa(n),el];Ru(r,n,au=Object.create(null),"");dr(Un.SYNC_EVENT_NAME.COMPONENT_DEF,r,e),function(e){xs&&dr(Un.SYNC_EVENT_NAME.BANNING_MAP,[xs],e,null)}(e),t.rootCompName=n,t.rootNodeId=Sn(),t.operationFlow.start(),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,n,t.rootNodeId,null]);var o=exparser.Component.createWithGenerics("body",exparser.Component._list[n],null,t);return t.root=o,t.usedDef=r,exparser.Element.getMethodCaller(o).__ddExparserNodeId__=t.nodeId.allocNodeId(o,t.rootNodeId),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.nodeId.addNode(),o}function Bu(){Wl||(Wl=!0,dr(Un.SYNC_EVENT_NAME.REQUEST_TAB,[]))}function Hu(e){__ddConfig&&__ddConfig.isLazyLoad&&!iu?ou.push(e):e()}function Uu(e,t){if(Gu()){var n=ta.get(e)||ta.create(e);if(!n.tabRoot&&!n.tabDestroyed){Su(ql,e,0,!0);var r=oa(ql),o=[[],[],r,{}];Ru(o,r,Object.create(null),""),n.operationFlow.push([Un.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,o,e]),n.tabCompName=r,n.tabNodeId=Sn(),n.operationFlow.start(),n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB,r,n.tabNodeId]);var i=exparser.createElement("tab-bar",exparser.Component._list[r],n);n.tabRoot=i,n.tabUsedDef=o,exparser.Element.getMethodCaller(i).__ddExparserNodeId__=n.nodeId.allocNodeId(i,n.tabNodeId),exparser.Element.getMethodCaller(i).__wxExparserNodeId__=exparser.Element.getMethodCaller(i).__ddExparserNodeId__,n.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),n.nodeId.addNode(),exparser.Element.pretendAttached(n.tabRoot),n.operationFlow.end(),t&&n.operationFlow.push([Un.SYNC_EVENT_NAME.FLUSH_BLOCKED,[],e]),n.rootCompName&&function(e,t,n){var r=!0,o=__ddConfig.tabBar&&__ddConfig.tabBar.list;o instanceof Array&&(o=o.map((function(e){return e&&e.pagePath}))).indexOf(t+".html")&&(r=!1),r&&(e.tabDestroyed=!0,dr(Un.SYNC_EVENT_NAME.DESTROY_TAB,[],n))}(n,n.rootCompName,e)}}}function Gu(){var e=!1;return __ddConfig.tabBar&&!0===__ddConfig.tabBar.custom&&(e=!0),function(e){e=oa(e),ol.call(el,e)&&(e=el[e]);return Jl[e]}(ql)||(e=!1),__ddConfig.appLaunchInfo&&"singlePage"===__ddConfig.appLaunchInfo.mode&&(e=!1),e}function $u(e){return Xl.has(e)}var zu={sendData:dr,setDataListener:fr,TreeManager:ta,requestViewInfo:function(e,t,n,r){var o=Math.random()+"-"+Date.now(),i=ta.get(n);if(i)return i.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_VIEW_INFO,e,t,o]),Cn(r)&&(i.viewInfoCbMap[o]=r),o},endViewInfoCallback:function(e,t){var n=ta.get(e);n&&delete n.viewInfoCbMap[t]},setModelValueData:Ou,getLazyCompPlaceholder:function(e){if(!Gl[e])return{};var t={};return Object.keys(Gl[e]).forEach((function(n){t["dd-"+n]="dd-"+Gl[e][n]})),t},componentLoaded:$u,shouldUsePlaceholder:Iu,arrangePlaceholderReplace:xu,getOwnerPluginAppId:function(e){var t=xl.getExparserComponent(e);return t?xl.getExparserProtocol(t):""},Behavior:function(e){var t="/"+Yl+++"/"+Sn(),n={},r=e.behaviors;if(r&&r.length)for(var o=0;o<r.length;o++){var i=String(r[o]);-1!==i.indexOf("wx://")&&(r[o]="dd://"+i.substr(5))}for(var a in n.behaviors=r,e)n[a]="data"===a?rl(e[a]):e[a];return n.is=t,Mu(n),n.options=su,ru[t]=Du(n),n.definitionFilter=exparser.Behavior.callDefinitionFilter(n),exparser.registerBehavior(n),n.is},CustomComponent:xl,Component:function e(t,n,r,o){var i=o||__ddAppCurrentFile__,a=r||__ddAppCode__,s=a[i+"on"];if(!i||!s)return"";var l=t.behaviors;if(l&&l.length)for(var u=0;u<l.length;u++){var c=String(l[u]);-1!==c.indexOf("wx://")&&(l[u]="dd://"+c.substr(5))}t.behaviors=l;var d=i.slice(0,-3);if(s.component&&"simple"===s.component.type)return function(e,t,n,r){Pu(e,r,t);var o={is:t,using:bu(t,r),properties:e.properties,externalClasses:e.externalClasses,options:kl},i=e.options||{};o.options=Wn(Wn({},kl),{multipleSlots:i.multipleSlots||!1,writeOnly:!0,writeIdToDOM:!1,domain:"simple://"+(n||"/"),styleIsolation:i.styleIsolation||"",addGlobalClass:i.addGlobalClass||!1,innerDataExclude:null,virtualHost:!1});var a=t;r[a+".wxml"]?a+=".wxml":r[a+".ddml"]&&(a+=".ddml");Jl[t]=Du(o,a)}(t,d,n,a),d;Pu(t,a,d);var f=exparser.Behavior.callDefinitionFilter(t),p=t.options||{},_={is:d,properties:t.properties,data:rl(t.data),methods:t.methods,behaviors:t.behaviors,lifetimes:t.lifetimes,pageLifetimes:t.pageLifetimes,created:t.created,attached:t.attached,ready:t.ready,moved:t.moved,detached:t.detached,saved:t.saved,restored:t.restored,relations:t.relations?wu(i,t.relations):void 0,externalClasses:t.externalClasses,observers:t.observers,definitionFilter:f,options:Wn(Wn({},kl),{addGlobalClass:p.addGlobalClass||!1,multipleSlots:p.multipleSlots||!1,writeOnly:p.writeOnly||!1,writeIdToDOM:!1,domain:(p.writeOnly?"wo://":"")+(n||"/"),styleIsolation:p.styleIsolation||"",innerDataExclude:p.pureDataPattern||null,virtualHost:p.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(h);xl.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}},h=Fu(_,a);return _.is},Page:function e(t,n,r,o){var i=o||__ddAppCurrentFile__;if(!i)return"";var a,s=i.slice(0,-3),l=r||"undefined"!=typeof __ddAppCode__&&__ddAppCode__||{},u=Object.create(null),c={methods:{}};for(a in t)"data"===a?c.data=t.data:Cn(t[a])?c.methods[a]=t[a]:"methods"===a?u.methods=t.methods:c[a]=t[a];var d=c.behaviors;if(d&&d.length)for(var f=0;f<d.length;f++){var p=String(d[f]);-1!==p.indexOf("wx://")&&(d[f]="dd://"+p.substr(5))}c.behaviors=d;var _,h=function(e){if(!e)return!1;if(An(e)){for(var t=0;t<e.length;t++){var n=String(e[t]);if("dd://"!==n.slice(0,5)&&!ru[n])return!1}return!0}return!1}(c.behaviors);for(a in Pu(c,l,s),h&&exparser.Behavior.callDefinitionFilter(c),c)"data"!==a&&"methods"!==a&&(u[a]=c[a]);var v=c.options||{},g={is:s,behaviors:h?c.behaviors:void 0,data:rl(c.data),methods:c.methods,properties:void 0===t.properties?c.properties:void 0,lifetimes:void 0===t.lifetimes?c.lifetimes:void 0,pageLifetimes:void 0===t.pageLifetimes?c.pageLifetimes:void 0,created:void 0===t.created?c.created:void 0,attached:void 0===t.attached?c.attached:void 0,ready:void 0===t.ready?c.ready:void 0,moved:void 0===t.moved?c.moved:void 0,detached:void 0===t.detached?c.detached:void 0,saved:void 0===t.saved?c.saved:void 0,restored:void 0===t.restored?c.restored:void 0,relations:void 0===t.relations&&c.relations?wu(i,c.relations):void 0,externalClasses:void 0===t.externalClasses?c.externalClasses:void 0,observers:void 0===t.observers?c.observers:void 0,options:Wn(Wn({},kl),{multipleSlots:!1,writeOnly:!1,writeIdToDOM:!0,domain:n||"/",styleIsolation:v.styleIsolation||"shared",addGlobalClass:!1,innerDataExclude:v.pureDataPattern||null,virtualHost:v.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(_);xl.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}};return(_=Fu(g,l)).__freeData__=u,g.is},initViewThread:function(){Zi.setStartOperation((function(e){fl.push(dl),dl+=1;try{ku(e)}catch(e){pl();var t="[webview-error]: flowUpdateView error\n";throw e.name&&(t+="["+e.name+"] "),e.message&&(t+=e.message+"\n"),e.stack&&(t+=e.stack),t.length>1e3&&(t=t.substr(0,1e3)+" ..."),Reporter.errorReport({key:"webview-error",type:"flowUpdateView",error:t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"webview-error",type:"flowUpdateView",error:t,fail:function(e){}}),e}pl()})),ta.instance=ta.create(0)},runComponentDef:function(){Bl=!0,Bu(),Hl.forEach((function(e){return Yu(e,!1)})),Hl=[],Ul.forEach((function(e){return Yu(e,!0)})),Ul=[]},sendTabBarCreationRequest:Bu,addView:function(e,t,n){var r=ta.get(e)||ta.create(e);r.lifetimeListener=n,r.operationFlow.unblock(),function(e,t){t.listenerInited||(t.listenerInited=!0,fr(Un.SYNC_EVENT_NAME.DD_EVENT,(function(n){var r=n[0],o=n[1],i=n[2],a=t.nodeId.getNodeById(r);if(a){var s=exparser.Element.getMethodCaller(a),l=i._userTap,u=i._requireActive,c=i._relatedInfo;if(u){var d=__appServiceEngine__.getCurrentPagesByDomain("");if(d[d.length-1].__ddWebViewId__!==e)return;delete i._requireActive}c&&delete i._relatedInfo;var f=s&&s[o];Cn(f)&&(l?ca((function(){exparser.safeCallback("Event Handler",f,s,[i],a)})):exparser.safeCallback("Event Handler",f,s,[i],a))}}),e),fr(Un.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,(function(e,t,n){var r=e[0];Ou(r.data,r.modelValueName,n,r.nodeId)}),e),fr(Un.SYNC_EVENT_NAME.REQUEST_SAVE,(function(t){Vl(e,t)}),e),fr(Un.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,(function(e){Os(e)}),e),fr(Un.SYNC_EVENT_NAME.ANIMATION_TRANSITION_END,(function(e){var n,r;e&&e[0]&&e[0].reqId&&("function"==typeof(n=t.applyAnimationCbMap[e[0].reqId])&&(delete t.applyAnimationCbMap[e[0].reqId],exparser.safeCallback("Animation",n,null,[])),r=JSON.parse(e[0].args),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_SET_NODE_NEXT_ANIMATION_INFO,r]))}),e),fr(Un.SYNC_EVENT_NAME.CLEAR_ANIMATION_COMPLETE,(function(e){var n;e&&e[0]&&e[0].reqId&&"function"==typeof(n=t.clearAnimationCbMap[e[0].reqId])&&(delete t.clearAnimationCbMap[e[0].reqId],exparser.safeCallback("Clear Animation",n,null,[]))}),e),fr(Un.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,(function(e){var n=e[0],r=e[1];if(r){var o=t.viewInfoCbMap[r];o&&o(n)}}),e),fr(Un.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,(function(e){var n=e[0],r=e[1],o=t.nodeId.getNodeById(n);o&&o.__updatePerformanceListener__&&exparser.safeCallback("Update Performance Listener",o.__updatePerformanceListener__,exparser.Element.getMethodCaller(o),[r],o)}),e))}(e,r),t=oa(t),dr(Un.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,[t],e),Su(t,e),!1;var o=Wu(e,r,t);return function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;return t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0}(t)&&Uu(e,!0),o},attachView:function(e,t){var n=ta.get(e);if(n){var r=n.root,o=!1,i={};Object.keys(t).forEach((function(e){exparser.Component.hasProperty(r,e)&&(i[e]=t[e],o=!0)})),o&&n.root.setData(i),Xa()&&(n.initialRootData=t),exparser.Element.pretendAttached(r),n.root.__treeManager__.operationFlow.end()}},removeView:function(e){var t=ta.get(e);t&&(exparser.Element.pretendDetached(t.root),ta.destroy(e),function(e){for(var t in Jn[e])Jn[e][t]=null,delete Jn[e][t];delete Jn[e]}(e))},componentAliases:el,componentPathToAlias:tl,getDomainByPluginId:Zs,publishDomainComponents:function(e,t){var n;for(var r in t){var o=t[r];if(!(n=o.match(/^plugin-private:\/\/(.*?)\//)))return;if(Zs(n[1],"0")!==e)return;if(!(n=r.match(/^plugin:\/\/(.*?)\//)))return;Zs(n[1],"0")===e&&(exparser.Component._list[r]||(exparser.Component._list[r]=exparser.Component._list[o],el[r]=o,tl[o]=r))}return{componentAliases:el,componentPathToAlias:tl}},getNodeById:function(e,t){if(ur()){var n=ta.get(t);return n?n.nodeId.getNodeById(e):null}return ta.instance?ta.instance.nodeId.getNodeById(e):null},getNodeId:function(e,t){return ur()?ta.get(t).nodeId.getNodeId(e):ta.instance?ta.instance.nodeId.getNodeId(e):""},getRootNodeId:function(e){if(ur()){var t=ta.get(e);return t?t.rootNodeId:""}return ta.instance.rootNodeId},saveView:Vl,restoreView:function(e){var t=ta.get(e);if(t){var n=t.nodeId.getAll(),r={},o=[],i=function(e){var i=t.nodeId.getNodeId(e);o.push(i),r[i]=n[i].data};t.tabRoot&&!t.tabDestroyed&&On(t.tabRoot,1,i),On(t.root,1,i);var a=[t.statesData||{},r,o],s=JSON.stringify(a),l=s.length;if(l>Pl){for(var u=[],c=0;c<l;)u.push(s.substr(c,Pl)),c+=Pl;for(var d=++Fl,f=u.length,p=0;p<f;p++)dr(Un.SYNC_EVENT_NAME.RESTORE_STATE,[{isSplitData:!0,splitInfo:{id:d,index:p+1,total:f,data:u[p]}}],e)}else dr(Un.SYNC_EVENT_NAME.RESTORE_STATE,a,e);if(t.statesData=void 0,!t.tabDestroyed&&t.tabRoot){dr(Un.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,t.tabUsedDef,e);var _=t.tabRoot;t.operationFlow.start(),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB,_.is,t.nodeId.getNodeId(_)]),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),t.operationFlow.end()}dr(Un.SYNC_EVENT_NAME.COMPONENT_DEF,t.usedDef,e);var h=t.root;t.operationFlow.start(),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,h.is,t.nodeId.getNodeId(h),{}]),t.operationFlow.push([Un.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.operationFlow.end(),t.tabRoot&&On(t.tabRoot,1,(function(e){e.triggerLifeTime("restored")})),On(t.root,1,(function(e){e.triggerLifeTime("restored")}))}},convertRouteToComponentAlias:oa,convertComponentAliasToRoute:function(e){na||ra();var t=exparser.Component._list[e]&&exparser.Component._list[e].is||e;return t=(t=t.replace(/^plugin-private:\/\/([0-9a-zA-Z]+)\//,(function(e,t){return(na[t]||"")+"__plugin__/"+t+"/"}))).replace(/^dd:\/\//,"__dd__/")},getPluginRoutePrefix:function(e){return na||ra(),ia(e)+"__plugin__/"+e+"/"},getPluginSubPackagePrefix:ia,initBannedMap:function(e){Object.keys(e).length>0&&(xs=e,ta.listViewId().forEach((function(t){dr(Un.SYNC_EVENT_NAME.BANNING_MAP,[e],t,null)})))},beginTapMark:sa,endTapMark:ua,checkTapMark:la,wrapTapMark:ca,updateDdAppCode:function(e,t){var n=qa[e];if(ur()){if(n)return Ka[e]=t,n(t)}else if(n)return Ka[e]=t,__ddAppCode__[e]=t,n(t)},enableUpdateDdAppCode:function(){za=!0},mergeData:function(e){return e},globalThis:Za};return exparser.globalOptions.createFakeDomElement=!1,exparser.globalOptions.inDocument=!1,exparser.globalOptions.documentBackend="none",exparser.registerBehavior({is:"dd://form-field",properties:{name:{type:null,public:!0},value:{type:null,public:!0}}}),exparser.registerBehavior({is:"dd://form-field-group"}),exparser.registerBehavior({is:"dd://form-field-button"}),exparser.registerBehavior({is:"dd://style-filter"}),exparser.registerBehavior({is:"dd://request-filter"}),exparser.registerBehavior({is:"dd://request-sender"}),exparser.registerBehavior({is:"dd://component-export",definitionFilter:function(e){"function"==typeof e.export&&("object"===$i(e.methods)?e.methods.__export__=e.export:e.methods={__export__:e.export})}}),zu}();


var __appServiceEngine__=function(){"use strict";function e(t){return(e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(t)}function t(){return(t=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}var n="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var o,i,a=function(e){return e&&e.Math==Math&&e},c=a("object"==typeof globalThis&&globalThis)||a("object"==typeof window&&window)||a("object"==typeof self&&self)||a("object"==typeof n&&n)||function(){return this}()||Function("return this")(),u=function(e){try{return!!e()}catch(e){return!0}},l=!u((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),f={}.propertyIsEnumerable,s=Object.getOwnPropertyDescriptor,p={f:s&&!f.call({1:2},1)?function(e){var t=s(this,e);return!!t&&t.enumerable}:f},d=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},g={}.toString,_=function(e){return g.call(e).slice(8,-1)},h="".split,v=u((function(){return!Object("z").propertyIsEnumerable(0)}))?function(e){return"String"==_(e)?h.call(e,""):Object(e)}:Object,y=function(e){if(null==e)throw TypeError("Can't call method on "+e);return e},b=function(e){return v(y(e))},m=function(e){return"object"==typeof e?null!==e:"function"==typeof e},w=function(e){return"function"==typeof e?e:void 0},S=function(e,t){return arguments.length<2?w(c[e]):c[e]&&c[e][t]},P=S("navigator","userAgent")||"",O=c.process,E=c.Deno,T=O&&O.versions||E&&E.version,I=T&&T.v8;I?i=(o=I.split("."))[0]<4?1:o[0]+o[1]:P&&(!(o=P.match(/Edge\/(\d+)/))||o[1]>=74)&&(o=P.match(/Chrome\/(\d+)/))&&(i=o[1]);var x=i&&+i,R=!!Object.getOwnPropertySymbols&&!u((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&x&&x<41})),C=R&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,k=C?function(e){return"symbol"==typeof e}:function(e){var t=S("Symbol");return"function"==typeof t&&Object(e)instanceof t},A=function(e,t){try{Object.defineProperty(c,e,{value:t,configurable:!0,writable:!0})}catch(n){c[e]=t}return t},j="__core-js_shared__",D=c[j]||A(j,{}),L=r((function(e){(e.exports=function(e,t){return D[e]||(D[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.16.2",mode:"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})})),B=function(e){return Object(y(e))},M={}.hasOwnProperty,N=Object.hasOwn||function(e,t){return M.call(B(e),t)},V=0,F=Math.random(),U=function(e){return"Symbol("+String(void 0===e?"":e)+")_"+(++V+F).toString(36)},$=L("wks"),G=c.Symbol,K=C?G:G&&G.withoutSetter||U,H=function(e){return N($,e)&&(R||"string"==typeof $[e])||(R&&N(G,e)?$[e]=G[e]:$[e]=K("Symbol."+e)),$[e]},W=H("toPrimitive"),J=function(e,t){if(!m(e)||k(e))return e;var n,r=e[W];if(void 0!==r){if(void 0===t&&(t="default"),n=r.call(e,t),!m(n)||k(n))return n;throw TypeError("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&"function"==typeof(n=e.toString)&&!m(r=n.call(e)))return r;if("function"==typeof(n=e.valueOf)&&!m(r=n.call(e)))return r;if("string"!==t&&"function"==typeof(n=e.toString)&&!m(r=n.call(e)))return r;throw TypeError("Can't convert object to primitive value")}(e,t)},Y=function(e){var t=J(e,"string");return k(t)?t:String(t)},q=c.document,z=m(q)&&m(q.createElement),Q=function(e){return z?q.createElement(e):{}},X=!l&&!u((function(){return 7!=Object.defineProperty(Q("div"),"a",{get:function(){return 7}}).a})),Z=Object.getOwnPropertyDescriptor,ee={f:l?Z:function(e,t){if(e=b(e),t=Y(t),X)try{return Z(e,t)}catch(e){}if(N(e,t))return d(!p.f.call(e,t),e[t])}},te=function(e){if(!m(e))throw TypeError(String(e)+" is not an object");return e},ne=Object.defineProperty,re={f:l?ne:function(e,t,n){if(te(e),t=Y(t),te(n),X)try{return ne(e,t,n)}catch(e){}if("get"in n||"set"in n)throw TypeError("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},oe=l?function(e,t,n){return re.f(e,t,d(1,n))}:function(e,t,n){return e[t]=n,e},ie=Function.toString;"function"!=typeof D.inspectSource&&(D.inspectSource=function(e){return ie.call(e)});var ae,ce,ue,le=D.inspectSource,fe=c.WeakMap,se="function"==typeof fe&&/native code/.test(le(fe)),pe=L("keys"),de=function(e){return pe[e]||(pe[e]=U(e))},ge={},_e="Object already initialized",he=c.WeakMap;if(se||D.state){var ve=D.state||(D.state=new he),ye=ve.get,be=ve.has,me=ve.set;ae=function(e,t){if(be.call(ve,e))throw new TypeError(_e);return t.facade=e,me.call(ve,e,t),t},ce=function(e){return ye.call(ve,e)||{}},ue=function(e){return be.call(ve,e)}}else{var we=de("state");ge[we]=!0,ae=function(e,t){if(N(e,we))throw new TypeError(_e);return t.facade=e,oe(e,we,t),t},ce=function(e){return N(e,we)?e[we]:{}},ue=function(e){return N(e,we)}}var Se,Pe={set:ae,get:ce,has:ue,enforce:function(e){return ue(e)?ce(e):ae(e,{})},getterFor:function(e){return function(t){var n;if(!m(t)||(n=ce(t)).type!==e)throw TypeError("Incompatible receiver, "+e+" required");return n}}},Oe=r((function(e){var t=Pe.get,n=Pe.enforce,r=String(String).split("String");(e.exports=function(e,t,o,i){var a,u=!!i&&!!i.unsafe,l=!!i&&!!i.enumerable,f=!!i&&!!i.noTargetGet;"function"==typeof o&&("string"!=typeof t||N(o,"name")||oe(o,"name",t),(a=n(o)).source||(a.source=r.join("string"==typeof t?t:""))),e!==c?(u?!f&&e[t]&&(l=!0):delete e[t],l?e[t]=o:oe(e,t,o)):l?e[t]=o:A(t,o)})(Function.prototype,"toString",(function(){return"function"==typeof this&&t(this).source||le(this)}))})),Ee=Math.ceil,Te=Math.floor,Ie=function(e){return isNaN(e=+e)?0:(e>0?Te:Ee)(e)},xe=Math.min,Re=function(e){return e>0?xe(Ie(e),9007199254740991):0},Ce=Math.max,ke=Math.min,Ae=function(e,t){var n=Ie(e);return n<0?Ce(n+t,0):ke(n,t)},je=function(e){return function(t,n,r){var o,i=b(t),a=Re(i.length),c=Ae(r,a);if(e&&n!=n){for(;a>c;)if((o=i[c++])!=o)return!0}else for(;a>c;c++)if((e||c in i)&&i[c]===n)return e||c||0;return!e&&-1}},De={includes:je(!0),indexOf:je(!1)},Le=De.indexOf,Be=function(e,t){var n,r=b(e),o=0,i=[];for(n in r)!N(ge,n)&&N(r,n)&&i.push(n);for(;t.length>o;)N(r,n=t[o++])&&(~Le(i,n)||i.push(n));return i},Me=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ne=Me.concat("length","prototype"),Ve={f:Object.getOwnPropertyNames||function(e){return Be(e,Ne)}},Fe={f:Object.getOwnPropertySymbols},Ue=S("Reflect","ownKeys")||function(e){var t=Ve.f(te(e)),n=Fe.f;return n?t.concat(n(e)):t},$e=function(e,t){for(var n=Ue(t),r=re.f,o=ee.f,i=0;i<n.length;i++){var a=n[i];N(e,a)||r(e,a,o(t,a))}},Ge=/#|\.prototype\./,Ke=function(e,t){var n=We[He(e)];return n==Ye||n!=Je&&("function"==typeof t?u(t):!!t)},He=Ke.normalize=function(e){return String(e).replace(Ge,".").toLowerCase()},We=Ke.data={},Je=Ke.NATIVE="N",Ye=Ke.POLYFILL="P",qe=Ke,ze=ee.f,Qe=function(e,t){var n,r,o,i,a,u=e.target,l=e.global,f=e.stat;if(n=l?c:f?c[u]||A(u,{}):(c[u]||{}).prototype)for(r in t){if(i=t[r],o=e.noTargetGet?(a=ze(n,r))&&a.value:n[r],!qe(l?r:u+(f?".":"#")+r,e.forced)&&void 0!==o){if(typeof i==typeof o)continue;$e(i,o)}(e.sham||o&&o.sham)&&oe(i,"sham",!0),Oe(n,r,i,e)}},Xe=function(e){if(k(e))throw TypeError("Cannot convert a Symbol value to a string");return String(e)},Ze=function(){var e=te(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t},et=c.RegExp,tt={UNSUPPORTED_Y:u((function(){var e=et("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),BROKEN_CARET:u((function(){var e=et("^r","gy");return e.lastIndex=2,null!=e.exec("str")}))},nt=Object.keys||function(e){return Be(e,Me)},rt=l?Object.defineProperties:function(e,t){te(e);for(var n,r=nt(t),o=r.length,i=0;o>i;)re.f(e,n=r[i++],t[n]);return e},ot=S("document","documentElement"),it=de("IE_PROTO"),at=function(){},ct=function(e){return"<script>"+e+"</"+"script>"},ut=function(e){e.write(ct("")),e.close();var t=e.parentWindow.Object;return e=null,t},lt=function(){try{Se=new ActiveXObject("htmlfile")}catch(e){}var e,t;lt="undefined"!=typeof document?document.domain&&Se?ut(Se):((t=Q("iframe")).style.display="none",ot.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(ct("document.F=Object")),e.close(),e.F):ut(Se);for(var n=Me.length;n--;)delete lt.prototype[Me[n]];return lt()};ge[it]=!0;var ft=Object.create||function(e,t){var n;return null!==e?(at.prototype=te(e),n=new at,at.prototype=null,n[it]=e):n=lt(),void 0===t?n:rt(n,t)},st=c.RegExp,pt=u((function(){var e=st(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),dt=c.RegExp,gt=u((function(){var e=dt("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),_t=Pe.get,ht=RegExp.prototype.exec,vt=L("native-string-replace",String.prototype.replace),yt=ht,bt=function(){var e=/a/,t=/b*/g;return ht.call(e,"a"),ht.call(t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),mt=tt.UNSUPPORTED_Y||tt.BROKEN_CARET,wt=void 0!==/()??/.exec("")[1];(bt||wt||mt||pt||gt)&&(yt=function(e){var t,n,r,o,i,a,c,u=this,l=_t(u),f=Xe(e),s=l.raw;if(s)return s.lastIndex=u.lastIndex,t=yt.call(s,f),u.lastIndex=s.lastIndex,t;var p=l.groups,d=mt&&u.sticky,g=Ze.call(u),_=u.source,h=0,v=f;if(d&&(-1===(g=g.replace("y","")).indexOf("g")&&(g+="g"),v=f.slice(u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==f.charAt(u.lastIndex-1))&&(_="(?: "+_+")",v=" "+v,h++),n=new RegExp("^(?:"+_+")",g)),wt&&(n=new RegExp("^"+_+"$(?!\\s)",g)),bt&&(r=u.lastIndex),o=ht.call(d?n:u,v),d?o?(o.input=o.input.slice(h),o[0]=o[0].slice(h),o.index=u.lastIndex,u.lastIndex+=o[0].length):u.lastIndex=0:bt&&o&&(u.lastIndex=u.global?o.index+o[0].length:r),wt&&o&&o.length>1&&vt.call(o[0],n,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=a=ft(null),i=0;i<p.length;i++)a[(c=p[i])[0]]=o[c[1]];return o});var St=yt;Qe({target:"RegExp",proto:!0,forced:/./.exec!==St},{exec:St});var Pt=H("species"),Ot=RegExp.prototype,Et=function(e,t,n,r){var o=H(e),i=!u((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),a=i&&!u((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[Pt]=function(){return n},n.flags="",n[o]=/./[o]),n.exec=function(){return t=!0,null},n[o](""),!t}));if(!i||!a||n){var c=/./[o],l=t(o,""[e],(function(e,t,n,r,o){var a=t.exec;return a===St||a===Ot.exec?i&&!o?{done:!0,value:c.call(t,n,r)}:{done:!0,value:e.call(n,t,r)}:{done:!1}}));Oe(String.prototype,e,l[0]),Oe(Ot,o,l[1])}r&&oe(Ot[o],"sham",!0)},Tt=function(e){return function(t,n){var r,o,i=Xe(y(t)),a=Ie(n),c=i.length;return a<0||a>=c?e?"":void 0:(r=i.charCodeAt(a))<55296||r>56319||a+1===c||(o=i.charCodeAt(a+1))<56320||o>57343?e?i.charAt(a):r:e?i.slice(a,a+2):o-56320+(r-55296<<10)+65536}},It={codeAt:Tt(!1),charAt:Tt(!0)},xt=It.charAt,Rt=function(e,t,n){return t+(n?xt(e,t).length:1)},Ct=function(e,t){var n=e.exec;if("function"==typeof n){var r=n.call(e,t);if("object"!=typeof r)throw TypeError("RegExp exec method returned something other than an Object or null");return r}if("RegExp"!==_(e))throw TypeError("RegExp#exec called on incompatible receiver");return St.call(e,t)};Et("match",(function(e,t,n){return[function(t){var n=y(this),r=null==t?void 0:t[e];return void 0!==r?r.call(t,n):new RegExp(t)[e](Xe(n))},function(e){var r=te(this),o=Xe(e),i=n(t,r,o);if(i.done)return i.value;if(!r.global)return Ct(r,o);var a=r.unicode;r.lastIndex=0;for(var c,u=[],l=0;null!==(c=Ct(r,o));){var f=Xe(c[0]);u[l]=f,""===f&&(r.lastIndex=Rt(o,Re(r.lastIndex),a)),l++}return 0===l?null:u}]}));var kt={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},At=function(e){if("function"!=typeof e)throw TypeError(String(e)+" is not a function");return e},jt=function(e,t,n){if(At(e),void 0===t)return e;switch(n){case 0:return function(){return e.call(t)};case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,o){return e.call(t,n,r,o)}}return function(){return e.apply(t,arguments)}},Dt=Array.isArray||function(e){return"Array"==_(e)},Lt=H("species"),Bt=function(e,t){return new(function(e){var t;return Dt(e)&&("function"!=typeof(t=e.constructor)||t!==Array&&!Dt(t.prototype)?m(t)&&null===(t=t[Lt])&&(t=void 0):t=void 0),void 0===t?Array:t}(e))(0===t?0:t)},Mt=[].push,Nt=function(e){var t=1==e,n=2==e,r=3==e,o=4==e,i=6==e,a=7==e,c=5==e||i;return function(u,l,f,s){for(var p,d,g=B(u),_=v(g),h=jt(l,f,3),y=Re(_.length),b=0,m=s||Bt,w=t?m(u,y):n||a?m(u,0):void 0;y>b;b++)if((c||b in _)&&(d=h(p=_[b],b,g),e))if(t)w[b]=d;else if(d)switch(e){case 3:return!0;case 5:return p;case 6:return b;case 2:Mt.call(w,p)}else switch(e){case 4:return!1;case 7:Mt.call(w,p)}return i?-1:r||o?o:w}},Vt={forEach:Nt(0),map:Nt(1),filter:Nt(2),some:Nt(3),every:Nt(4),find:Nt(5),findIndex:Nt(6),filterReject:Nt(7)},Ft=function(e,t){var n=[][e];return!!n&&u((function(){n.call(null,t||function(){throw 1},1)}))},Ut=Vt.forEach,$t=Ft("forEach")?[].forEach:function(e){return Ut(this,e,arguments.length>1?arguments[1]:void 0)};for(var Gt in kt){var Kt=c[Gt],Ht=Kt&&Kt.prototype;if(Ht&&Ht.forEach!==$t)try{oe(Ht,"forEach",$t)}catch(e){Ht.forEach=$t}}var Wt=Math.floor,Jt="".replace,Yt=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,qt=/\$([$&'`]|\d{1,2})/g,zt=function(e,t,n,r,o,i){var a=n+e.length,c=r.length,u=qt;return void 0!==o&&(o=B(o),u=Yt),Jt.call(i,u,(function(i,u){var l;switch(u.charAt(0)){case"$":return"$";case"&":return e;case"`":return t.slice(0,n);case"'":return t.slice(a);case"<":l=o[u.slice(1,-1)];break;default:var f=+u;if(0===f)return i;if(f>c){var s=Wt(f/10);return 0===s?i:s<=c?void 0===r[s-1]?u.charAt(1):r[s-1]+u.charAt(1):i}l=r[f-1]}return void 0===l?"":l}))},Qt=H("replace"),Xt=Math.max,Zt=Math.min,en="$0"==="a".replace(/./,"$0"),tn=!!/./[Qt]&&""===/./[Qt]("a","$0");Et("replace",(function(e,t,n){var r=tn?"$":"$0";return[function(e,n){var r=y(this),o=null==e?void 0:e[Qt];return void 0!==o?o.call(e,r,n):t.call(Xe(r),e,n)},function(e,o){var i=te(this),a=Xe(e);if("string"==typeof o&&-1===o.indexOf(r)&&-1===o.indexOf("$<")){var c=n(t,i,a,o);if(c.done)return c.value}var u="function"==typeof o;u||(o=Xe(o));var l=i.global;if(l){var f=i.unicode;i.lastIndex=0}for(var s=[];;){var p=Ct(i,a);if(null===p)break;if(s.push(p),!l)break;""===Xe(p[0])&&(i.lastIndex=Rt(a,Re(i.lastIndex),f))}for(var d,g="",_=0,h=0;h<s.length;h++){p=s[h];for(var v=Xe(p[0]),y=Xt(Zt(Ie(p.index),a.length),0),b=[],m=1;m<p.length;m++)b.push(void 0===(d=p[m])?d:String(d));var w=p.groups;if(u){var S=[v].concat(b,y,a);void 0!==w&&S.push(w);var P=Xe(o.apply(void 0,S))}else P=zt(v,a,y,b,w,o);y>=_&&(g+=a.slice(_,y)+P,_=y+v.length)}return g+a.slice(_)}]}),!!u((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!en||tn);var nn=De.indexOf,rn=[].indexOf,on=!!rn&&1/[1].indexOf(1,-0)<0,an=Ft("indexOf");Qe({target:"Array",proto:!0,forced:on||!an},{indexOf:function(e){return on?rn.apply(this,arguments)||0:nn(this,e,arguments.length>1?arguments[1]:void 0)}});var cn=H("match"),un=function(e){var t;return m(e)&&(void 0!==(t=e[cn])?!!t:"RegExp"==_(e))},ln=H("species"),fn=function(e,t){var n,r=te(e).constructor;return void 0===r||null==(n=te(r)[ln])?t:At(n)},sn=tt.UNSUPPORTED_Y,pn=[].push,dn=Math.min,gn=4294967295;Et("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=Xe(y(this)),o=void 0===n?gn:n>>>0;if(0===o)return[];if(void 0===e)return[r];if(!un(e))return t.call(r,e,o);for(var i,a,c,u=[],l=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),f=0,s=new RegExp(e.source,l+"g");(i=St.call(s,r))&&!((a=s.lastIndex)>f&&(u.push(r.slice(f,i.index)),i.length>1&&i.index<r.length&&pn.apply(u,i.slice(1)),c=i[0].length,f=a,u.length>=o));)s.lastIndex===i.index&&s.lastIndex++;return f===r.length?!c&&s.test("")||u.push(""):u.push(r.slice(f)),u.length>o?u.slice(0,o):u}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:t.call(this,e,n)}:t,[function(t,n){var o=y(this),i=null==t?void 0:t[e];return void 0!==i?i.call(t,o,n):r.call(Xe(o),t,n)},function(e,o){var i=te(this),a=Xe(e),c=n(r,i,a,o,r!==t);if(c.done)return c.value;var u=fn(i,RegExp),l=i.unicode,f=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+(sn?"g":"y"),s=new u(sn?"^(?:"+i.source+")":i,f),p=void 0===o?gn:o>>>0;if(0===p)return[];if(0===a.length)return null===Ct(s,a)?[a]:[];for(var d=0,g=0,_=[];g<a.length;){s.lastIndex=sn?0:g;var h,v=Ct(s,sn?a.slice(g):a);if(null===v||(h=dn(Re(s.lastIndex+(sn?g:0)),a.length))===d)g=Rt(a,g,l);else{if(_.push(a.slice(d,g)),_.length===p)return _;for(var y=1;y<=v.length-1;y++)if(_.push(v[y]),_.length===p)return _;g=d=h}}return _.push(a.slice(d)),_}]}),!!u((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]})),sn);var _n={};_n[H("toStringTag")]="z";var hn="[object z]"===String(_n),vn=H("toStringTag"),yn="Arguments"==_(function(){return arguments}()),bn=hn?_:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Object(e),vn))?n:yn?_(t):"Object"==(r=_(t))&&"function"==typeof t.callee?"Arguments":r},mn=hn?{}.toString:function(){return"[object "+bn(this)+"]"};hn||Oe(Object.prototype,"toString",mn,{unsafe:!0});var wn=c.Promise,Sn=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return te(n),function(e){if(!m(e)&&null!==e)throw TypeError("Can't set "+String(e)+" as a prototype")}(r),t?e.call(n,r):n.__proto__=r,n}}():void 0),Pn=re.f,On=H("toStringTag"),En=function(e,t,n){e&&!N(e=n?e:e.prototype,On)&&Pn(e,On,{configurable:!0,value:t})},Tn=H("species"),In=function(e){var t=S(e),n=re.f;l&&t&&!t[Tn]&&n(t,Tn,{configurable:!0,get:function(){return this}})},xn={},Rn=H("iterator"),Cn=Array.prototype,kn=function(e){return void 0!==e&&(xn.Array===e||Cn[Rn]===e)},An=H("iterator"),jn=function(e){if(null!=e)return e[An]||e["@@iterator"]||xn[bn(e)]},Dn=function(e){var t=e.return;if(void 0!==t)return te(t.call(e)).value},Ln=function(e,t){this.stopped=e,this.result=t},Bn=function(e,t,n){var r,o,i,a,c,u,l,f=n&&n.that,s=!(!n||!n.AS_ENTRIES),p=!(!n||!n.IS_ITERATOR),d=!(!n||!n.INTERRUPTED),g=jt(t,f,1+s+d),_=function(e){return r&&Dn(r),new Ln(!0,e)},h=function(e){return s?(te(e),d?g(e[0],e[1],_):g(e[0],e[1])):d?g(e,_):g(e)};if(p)r=e;else{if("function"!=typeof(o=jn(e)))throw TypeError("Target is not iterable");if(kn(o)){for(i=0,a=Re(e.length);a>i;i++)if((c=h(e[i]))&&c instanceof Ln)return c;return new Ln(!1)}r=o.call(e)}for(u=r.next;!(l=u.call(r)).done;){try{c=h(l.value)}catch(e){throw Dn(r),e}if("object"==typeof c&&c&&c instanceof Ln)return c}return new Ln(!1)},Mn=H("iterator"),Nn=!1;try{var Vn=0,Fn={next:function(){return{done:!!Vn++}},return:function(){Nn=!0}};Fn[Mn]=function(){return this},Array.from(Fn,(function(){throw 2}))}catch(e){}var Un,$n,Gn,Kn,Hn=function(e,t){if(!t&&!Nn)return!1;var n=!1;try{var r={};r[Mn]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Wn=/(?:ipad|iphone|ipod).*applewebkit/i.test(P),Jn="process"==_(c.process),Yn=c.setImmediate,qn=c.clearImmediate,zn=c.process,Qn=c.MessageChannel,Xn=c.Dispatch,Zn=0,er={},tr="onreadystatechange";try{Un=c.location}catch(e){}var nr=function(e){if(er.hasOwnProperty(e)){var t=er[e];delete er[e],t()}},rr=function(e){return function(){nr(e)}},or=function(e){nr(e.data)},ir=function(e){c.postMessage(String(e),Un.protocol+"//"+Un.host)};Yn&&qn||(Yn=function(e){for(var t=[],n=arguments.length,r=1;n>r;)t.push(arguments[r++]);return er[++Zn]=function(){("function"==typeof e?e:Function(e)).apply(void 0,t)},$n(Zn),Zn},qn=function(e){delete er[e]},Jn?$n=function(e){zn.nextTick(rr(e))}:Xn&&Xn.now?$n=function(e){Xn.now(rr(e))}:Qn&&!Wn?(Kn=(Gn=new Qn).port2,Gn.port1.onmessage=or,$n=jt(Kn.postMessage,Kn,1)):c.addEventListener&&"function"==typeof postMessage&&!c.importScripts&&Un&&"file:"!==Un.protocol&&!u(ir)?($n=ir,c.addEventListener("message",or,!1)):$n=tr in Q("script")?function(e){ot.appendChild(Q("script")).onreadystatechange=function(){ot.removeChild(this),nr(e)}}:function(e){setTimeout(rr(e),0)});var ar,cr,ur,lr,fr,sr,pr,dr,gr={set:Yn,clear:qn},_r=/ipad|iphone|ipod/i.test(P)&&void 0!==c.Pebble,hr=/web0s(?!.*chrome)/i.test(P),vr=ee.f,yr=gr.set,br=c.MutationObserver||c.WebKitMutationObserver,mr=c.document,wr=c.process,Sr=c.Promise,Pr=vr(c,"queueMicrotask"),Or=Pr&&Pr.value;Or||(ar=function(){var e,t;for(Jn&&(e=wr.domain)&&e.exit();cr;){t=cr.fn,cr=cr.next;try{t()}catch(e){throw cr?lr():ur=void 0,e}}ur=void 0,e&&e.enter()},Wn||Jn||hr||!br||!mr?!_r&&Sr&&Sr.resolve?((pr=Sr.resolve(void 0)).constructor=Sr,dr=pr.then,lr=function(){dr.call(pr,ar)}):lr=Jn?function(){wr.nextTick(ar)}:function(){yr.call(c,ar)}:(fr=!0,sr=mr.createTextNode(""),new br(ar).observe(sr,{characterData:!0}),lr=function(){sr.data=fr=!fr}));var Er,Tr,Ir,xr,Rr=Or||function(e){var t={fn:e,next:void 0};ur&&(ur.next=t),cr||(cr=t,lr()),ur=t},Cr=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=At(t),this.reject=At(n)},kr={f:function(e){return new Cr(e)}},Ar=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},jr="object"==typeof window,Dr=gr.set,Lr=H("species"),Br="Promise",Mr=Pe.get,Nr=Pe.set,Vr=Pe.getterFor(Br),Fr=wn&&wn.prototype,Ur=wn,$r=Fr,Gr=c.TypeError,Kr=c.document,Hr=c.process,Wr=kr.f,Jr=Wr,Yr=!!(Kr&&Kr.createEvent&&c.dispatchEvent),qr="function"==typeof PromiseRejectionEvent,zr="unhandledrejection",Qr=!1,Xr=qe(Br,(function(){var e=le(Ur),t=e!==String(Ur);if(!t&&66===x)return!0;if(x>=51&&/native code/.test(e))return!1;var n=new Ur((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};return(n.constructor={})[Lr]=r,!(Qr=n.then((function(){}))instanceof r)||!t&&jr&&!qr})),Zr=Xr||!Hn((function(e){Ur.all(e).catch((function(){}))})),eo=function(e){var t;return!(!m(e)||"function"!=typeof(t=e.then))&&t},to=function(e,t){if(!e.notified){e.notified=!0;var n=e.reactions;Rr((function(){for(var r=e.value,o=1==e.state,i=0;n.length>i;){var a,c,u,l=n[i++],f=o?l.ok:l.fail,s=l.resolve,p=l.reject,d=l.domain;try{f?(o||(2===e.rejection&&io(e),e.rejection=1),!0===f?a=r:(d&&d.enter(),a=f(r),d&&(d.exit(),u=!0)),a===l.promise?p(Gr("Promise-chain cycle")):(c=eo(a))?c.call(a,s,p):s(a)):p(r)}catch(e){d&&!u&&d.exit(),p(e)}}e.reactions=[],e.notified=!1,t&&!e.rejection&&ro(e)}))}},no=function(e,t,n){var r,o;Yr?((r=Kr.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),c.dispatchEvent(r)):r={promise:t,reason:n},!qr&&(o=c["on"+e])?o(r):e===zr&&function(e,t){var n=c.console;n&&n.error&&(1===arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},ro=function(e){Dr.call(c,(function(){var t,n=e.facade,r=e.value;if(oo(e)&&(t=Ar((function(){Jn?Hr.emit("unhandledRejection",r,n):no(zr,n,r)})),e.rejection=Jn||oo(e)?2:1,t.error))throw t.value}))},oo=function(e){return 1!==e.rejection&&!e.parent},io=function(e){Dr.call(c,(function(){var t=e.facade;Jn?Hr.emit("rejectionHandled",t):no("rejectionhandled",t,e.value)}))},ao=function(e,t,n){return function(r){e(t,r,n)}},co=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,to(e,!0))},uo=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw Gr("Promise can't be resolved itself");var r=eo(t);r?Rr((function(){var n={done:!1};try{r.call(t,ao(uo,n,e),ao(co,n,e))}catch(t){co(n,t,e)}})):(e.value=t,e.state=1,to(e,!1))}catch(t){co({done:!1},t,e)}}};if(Xr&&($r=(Ur=function(e){!function(e,t,n){if(!(e instanceof t))throw TypeError("Incorrect "+(n?n+" ":"")+"invocation")}(this,Ur,Br),At(e),Er.call(this);var t=Mr(this);try{e(ao(uo,t),ao(co,t))}catch(e){co(t,e)}}).prototype,(Er=function(e){Nr(this,{type:Br,done:!1,notified:!1,parent:!1,reactions:[],rejection:!1,state:0,value:void 0})}).prototype=function(e,t,n){for(var r in t)Oe(e,r,t[r],n);return e}($r,{then:function(e,t){var n=Vr(this),r=Wr(fn(this,Ur));return r.ok="function"!=typeof e||e,r.fail="function"==typeof t&&t,r.domain=Jn?Hr.domain:void 0,n.parent=!0,n.reactions.push(r),0!=n.state&&to(n,!1),r.promise},catch:function(e){return this.then(void 0,e)}}),Tr=function(){var e=new Er,t=Mr(e);this.promise=e,this.resolve=ao(uo,t),this.reject=ao(co,t)},kr.f=Wr=function(e){return e===Ur||e===Ir?new Tr(e):Jr(e)},"function"==typeof wn&&Fr!==Object.prototype)){xr=Fr.then,Qr||(Oe(Fr,"then",(function(e,t){var n=this;return new Ur((function(e,t){xr.call(n,e,t)})).then(e,t)}),{unsafe:!0}),Oe(Fr,"catch",$r.catch,{unsafe:!0}));try{delete Fr.constructor}catch(e){}Sn&&Sn(Fr,$r)}Qe({global:!0,wrap:!0,forced:Xr},{Promise:Ur}),En(Ur,Br,!1),In(Br),Ir=S(Br),Qe({target:Br,stat:!0,forced:Xr},{reject:function(e){var t=Wr(this);return t.reject.call(void 0,e),t.promise}}),Qe({target:Br,stat:!0,forced:Xr},{resolve:function(e){return function(e,t){if(te(e),m(t)&&t.constructor===e)return t;var n=kr.f(e);return(0,n.resolve)(t),n.promise}(this,e)}}),Qe({target:Br,stat:!0,forced:Zr},{all:function(e){var t=this,n=Wr(t),r=n.resolve,o=n.reject,i=Ar((function(){var n=At(t.resolve),i=[],a=0,c=1;Bn(e,(function(e){var u=a++,l=!1;i.push(void 0),c++,n.call(t,e).then((function(e){l||(l=!0,i[u]=e,--c||r(i))}),o)})),--c||r(i)}));return i.error&&o(i.value),n.promise},race:function(e){var t=this,n=Wr(t),r=n.reject,o=Ar((function(){var o=At(t.resolve);Bn(e,(function(e){o.call(t,e).then(n.resolve,r)}))}));return o.error&&r(o.value),n.promise}});var lo=H("unscopables"),fo=Array.prototype;null==fo[lo]&&re.f(fo,lo,{configurable:!0,value:ft(null)});var so,po,go,_o=function(e){fo[lo][e]=!0},ho=!u((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),vo=de("IE_PROTO"),yo=Object.prototype,bo=ho?Object.getPrototypeOf:function(e){return e=B(e),N(e,vo)?e[vo]:"function"==typeof e.constructor&&e instanceof e.constructor?e.constructor.prototype:e instanceof Object?yo:null},mo=H("iterator"),wo=!1;[].keys&&("next"in(go=[].keys())?(po=bo(bo(go)))!==Object.prototype&&(so=po):wo=!0),(null==so||u((function(){var e={};return so[mo].call(e)!==e})))&&(so={}),N(so,mo)||oe(so,mo,(function(){return this}));var So={IteratorPrototype:so,BUGGY_SAFARI_ITERATORS:wo},Po=So.IteratorPrototype,Oo=function(){return this},Eo=So.IteratorPrototype,To=So.BUGGY_SAFARI_ITERATORS,Io=H("iterator"),xo="keys",Ro="values",Co="entries",ko=function(){return this},Ao=function(e,t,n,r,o,i,a){!function(e,t,n){var r=t+" Iterator";e.prototype=ft(Po,{next:d(1,n)}),En(e,r,!1),xn[r]=Oo}(n,t,r);var c,u,l,f=function(e){if(e===o&&h)return h;if(!To&&e in g)return g[e];switch(e){case xo:case Ro:case Co:return function(){return new n(this,e)}}return function(){return new n(this)}},s=t+" Iterator",p=!1,g=e.prototype,_=g[Io]||g["@@iterator"]||o&&g[o],h=!To&&_||f(o),v="Array"==t&&g.entries||_;if(v&&(c=bo(v.call(new e)),Eo!==Object.prototype&&c.next&&(bo(c)!==Eo&&(Sn?Sn(c,Eo):"function"!=typeof c[Io]&&oe(c,Io,ko)),En(c,s,!0))),o==Ro&&_&&_.name!==Ro&&(p=!0,h=function(){return _.call(this)}),g[Io]!==h&&oe(g,Io,h),xn[t]=h,o)if(u={values:f(Ro),keys:i?h:f(xo),entries:f(Co)},a)for(l in u)(To||p||!(l in g))&&Oe(g,l,u[l]);else Qe({target:t,proto:!0,forced:To||p},u);return u},jo="Array Iterator",Do=Pe.set,Lo=Pe.getterFor(jo),Bo=Ao(Array,"Array",(function(e,t){Do(this,{type:jo,target:b(e),index:0,kind:t})}),(function(){var e=Lo(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values");xn.Arguments=xn.Array,_o("keys"),_o("values"),_o("entries");var Mo=It.charAt,No="String Iterator",Vo=Pe.set,Fo=Pe.getterFor(No);Ao(String,"String",(function(e){Vo(this,{type:No,string:Xe(e),index:0})}),(function(){var e,t=Fo(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=Mo(n,r),t.index+=e.length,{value:e,done:!1})}));var Uo=H("iterator"),$o=H("toStringTag"),Go=Bo.values;for(var Ko in kt){var Ho=c[Ko],Wo=Ho&&Ho.prototype;if(Wo){if(Wo[Uo]!==Go)try{oe(Wo,Uo,Go)}catch(e){Wo[Uo]=Go}if(Wo[$o]||oe(Wo,$o,Ko),kt[Ko])for(var Jo in Bo)if(Wo[Jo]!==Bo[Jo])try{oe(Wo,Jo,Bo[Jo])}catch(e){Wo[Jo]=Bo[Jo]}}}var Yo=function(e,t,n){var r=Y(t);r in e?re.f(e,r,d(0,n)):e[r]=n},qo=H("species"),zo=function(e){return x>=51||!u((function(){var t=[];return(t.constructor={})[qo]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},Qo=zo("splice"),Xo=Math.max,Zo=Math.min,ei=9007199254740991,ti="Maximum allowed length exceeded";Qe({target:"Array",proto:!0,forced:!Qo},{splice:function(e,t){var n,r,o,i,a,c,u=B(this),l=Re(u.length),f=Ae(e,l),s=arguments.length;if(0===s?n=r=0:1===s?(n=0,r=l-f):(n=s-2,r=Zo(Xo(Ie(t),0),l-f)),l+n-r>ei)throw TypeError(ti);for(o=Bt(u,r),i=0;i<r;i++)(a=f+i)in u&&Yo(o,i,u[a]);if(o.length=r,n<r){for(i=f;i<l-r;i++)c=i+n,(a=i+r)in u?u[c]=u[a]:delete u[c];for(i=l;i>l-r+n;i--)delete u[i-1]}else if(n>r)for(i=l-r;i>f;i--)c=i+n-1,(a=i+r-1)in u?u[c]=u[a]:delete u[c];for(i=0;i<n;i++)u[i+f]=arguments[i+2];return u.length=l-r+n,o}});var ni=u((function(){nt(1)}));Qe({target:"Object",stat:!0,forced:ni},{keys:function(e){return nt(B(e))}});var ri=zo("slice"),oi=H("species"),ii=[].slice,ai=Math.max;Qe({target:"Array",proto:!0,forced:!ri},{slice:function(e,t){var n,r,o,i=b(this),a=Re(i.length),c=Ae(e,a),u=Ae(void 0===t?a:t,a);if(Dt(i)&&("function"!=typeof(n=i.constructor)||n!==Array&&!Dt(n.prototype)?m(n)&&null===(n=n[oi])&&(n=void 0):n=void 0,n===Array||void 0===n))return ii.call(i,c,u);for(r=new(void 0===n?Array:n)(ai(u-c,0)),o=0;c<u;c++,o++)c in i&&Yo(r,o,i[c]);return r.length=o,r}});var ci="\t\n\v\f\r                　\u2028\u2029\ufeff",ui="["+ci+"]",li=RegExp("^"+ui+ui+"*"),fi=RegExp(ui+ui+"*$"),si=function(e){return function(t){var n=Xe(y(t));return 1&e&&(n=n.replace(li,"")),2&e&&(n=n.replace(fi,"")),n}},pi={start:si(1),end:si(2),trim:si(3)},di=pi.trim;Qe({target:"String",proto:!0,forced:function(e){return u((function(){return!!ci[e]()||"​᠎"!="​᠎"[e]()||ci[e].name!==e}))}("trim")},{trim:function(){return di(this)}});var gi=function(e,t,n){var r,o;return Sn&&"function"==typeof(r=t.constructor)&&r!==n&&m(o=r.prototype)&&o!==n.prototype&&Sn(e,o),e},_i=Ve.f,hi=ee.f,vi=re.f,yi=pi.trim,bi="Number",mi=c.Number,wi=mi.prototype,Si=_(ft(wi))==bi,Pi=function(e){if(k(e))throw TypeError("Cannot convert a Symbol value to a number");var t,n,r,o,i,a,c,u,l=J(e,"number");if("string"==typeof l&&l.length>2)if(43===(t=(l=yi(l)).charCodeAt(0))||45===t){if(88===(n=l.charCodeAt(2))||120===n)return NaN}else if(48===t){switch(l.charCodeAt(1)){case 66:case 98:r=2,o=49;break;case 79:case 111:r=8,o=55;break;default:return+l}for(a=(i=l.slice(2)).length,c=0;c<a;c++)if((u=i.charCodeAt(c))<48||u>o)return NaN;return parseInt(i,r)}return+l};if(qe(bi,!mi(" 0o1")||!mi("0b1")||mi("+0x1"))){for(var Oi,Ei=function(e){var t=arguments.length<1?0:e,n=this;return n instanceof Ei&&(Si?u((function(){wi.valueOf.call(n)})):_(n)!=bi)?gi(new mi(Pi(t)),n,Ei):Pi(t)},Ti=l?_i(mi):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,fromString,range".split(","),Ii=0;Ti.length>Ii;Ii++)N(mi,Oi=Ti[Ii])&&!N(Ei,Oi)&&vi(Ei,Oi,hi(mi,Oi));Ei.prototype=wi,wi.constructor=Ei,Oe(c,bi,Ei)}var xi="toString",Ri=RegExp.prototype,Ci=Ri.toString,ki=u((function(){return"/a/b"!=Ci.call({source:"a",flags:"b"})})),Ai=Ci.name!=xi;(ki||Ai)&&Oe(RegExp.prototype,xi,(function(){var e=te(this),t=Xe(e.source),n=e.flags;return"/"+t+"/"+Xe(void 0===n&&e instanceof RegExp&&!("flags"in Ri)?Ze.call(e):n)}),{unsafe:!0});var ji=Vt.map,Di=zo("map");Qe({target:"Array",proto:!0,forced:!Di},{map:function(e){return ji(this,e,arguments.length>1?arguments[1]:void 0)}});var Li=Vt.findIndex,Bi="findIndex",Mi=!0;Bi in[]&&Array(1).findIndex((function(){Mi=!1})),Qe({target:"Array",proto:!0,forced:Mi},{findIndex:function(e){return Li(this,e,arguments.length>1?arguments[1]:void 0)}}),_o(Bi);var Ni=Math.min,Vi=[].lastIndexOf,Fi=!!Vi&&1/[1].lastIndexOf(1,-0)<0,Ui=Ft("lastIndexOf"),$i=Fi||!Ui?function(e){if(Fi)return Vi.apply(this,arguments)||0;var t=b(this),n=Re(t.length),r=n-1;for(arguments.length>1&&(r=Ni(r,Ie(arguments[1]))),r<0&&(r=n+r);r>=0;r--)if(r in t&&t[r]===e)return r||0;return-1}:Vi;Qe({target:"Array",proto:!0,forced:$i!==[].lastIndexOf},{lastIndexOf:$i});var Gi=re.f,Ki=Ve.f,Hi=Pe.enforce,Wi=H("match"),Ji=c.RegExp,Yi=Ji.prototype,qi=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,zi=/a/g,Qi=/a/g,Xi=new Ji(zi)!==zi,Zi=tt.UNSUPPORTED_Y,ea=l&&(!Xi||Zi||pt||gt||u((function(){return Qi[Wi]=!1,Ji(zi)!=zi||Ji(Qi)==Qi||"/a/i"!=Ji(zi,"i")})));if(qe("RegExp",ea)){for(var ta=function(e,t){var n,r,o,i,a,c,u=this instanceof ta,l=un(e),f=void 0===t,s=[],p=e;if(!u&&l&&f&&e.constructor===ta)return e;if((l||e instanceof ta)&&(e=e.source,f&&(t="flags"in p?p.flags:Ze.call(p))),e=void 0===e?"":Xe(e),t=void 0===t?"":Xe(t),p=e,pt&&"dotAll"in zi&&(r=!!t&&t.indexOf("s")>-1)&&(t=t.replace(/s/g,"")),n=t,Zi&&"sticky"in zi&&(o=!!t&&t.indexOf("y")>-1)&&(t=t.replace(/y/g,"")),gt&&(e=(i=function(e){for(var t,n=e.length,r=0,o="",i=[],a={},c=!1,u=!1,l=0,f="";r<=n;r++){if("\\"===(t=e.charAt(r)))t+=e.charAt(++r);else if("]"===t)c=!1;else if(!c)switch(!0){case"["===t:c=!0;break;case"("===t:qi.test(e.slice(r+1))&&(r+=2,u=!0),o+=t,l++;continue;case">"===t&&u:if(""===f||N(a,f))throw new SyntaxError("Invalid capture group name");a[f]=!0,i.push([f,l]),u=!1,f="";continue}u?f+=t:o+=t}return[o,i]}(e))[0],s=i[1]),a=gi(Ji(e,t),u?this:Yi,ta),(r||o||s.length)&&(c=Hi(a),r&&(c.dotAll=!0,c.raw=ta(function(e){for(var t,n=e.length,r=0,o="",i=!1;r<=n;r++)"\\"!==(t=e.charAt(r))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+e.charAt(++r);return o}(e),n)),o&&(c.sticky=!0),s.length&&(c.groups=s)),e!==p)try{oe(a,"source",""===p?"(?:)":p)}catch(e){}return a},na=function(e){e in ta||Gi(ta,e,{configurable:!0,get:function(){return Ji[e]},set:function(t){Ji[e]=t}})},ra=Ki(Ji),oa=0;ra.length>oa;)na(ra[oa++]);Yi.constructor=ta,ta.prototype=Yi,Oe(c,"RegExp",ta)}In("RegExp");var ia=Ve.f,aa={}.toString,ca="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],ua={f:function(e){return ca&&"[object Window]"==aa.call(e)?function(e){try{return ia(e)}catch(e){return ca.slice()}}(e):ia(b(e))}},la={f:H},fa=c,sa=re.f,pa=function(e){var t=fa.Symbol||(fa.Symbol={});N(t,e)||sa(t,e,{value:la.f(e)})},da=Vt.forEach,ga=de("hidden"),_a="Symbol",ha=H("toPrimitive"),va=Pe.set,ya=Pe.getterFor(_a),ba=Object.prototype,ma=c.Symbol,wa=S("JSON","stringify"),Sa=ee.f,Pa=re.f,Oa=ua.f,Ea=p.f,Ta=L("symbols"),Ia=L("op-symbols"),xa=L("string-to-symbol-registry"),Ra=L("symbol-to-string-registry"),Ca=L("wks"),ka=c.QObject,Aa=!ka||!ka.prototype||!ka.prototype.findChild,ja=l&&u((function(){return 7!=ft(Pa({},"a",{get:function(){return Pa(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Sa(ba,t);r&&delete ba[t],Pa(e,t,n),r&&e!==ba&&Pa(ba,t,r)}:Pa,Da=function(e,t){var n=Ta[e]=ft(ma.prototype);return va(n,{type:_a,tag:e,description:t}),l||(n.description=t),n},La=function(e,t,n){e===ba&&La(Ia,t,n),te(e);var r=Y(t);return te(n),N(Ta,r)?(n.enumerable?(N(e,ga)&&e[ga][r]&&(e[ga][r]=!1),n=ft(n,{enumerable:d(0,!1)})):(N(e,ga)||Pa(e,ga,d(1,{})),e[ga][r]=!0),ja(e,r,n)):Pa(e,r,n)},Ba=function(e,t){te(e);var n=b(t),r=nt(n).concat(Fa(n));return da(r,(function(t){l&&!Ma.call(n,t)||La(e,t,n[t])})),e},Ma=function(e){var t=Y(e),n=Ea.call(this,t);return!(this===ba&&N(Ta,t)&&!N(Ia,t))&&(!(n||!N(this,t)||!N(Ta,t)||N(this,ga)&&this[ga][t])||n)},Na=function(e,t){var n=b(e),r=Y(t);if(n!==ba||!N(Ta,r)||N(Ia,r)){var o=Sa(n,r);return!o||!N(Ta,r)||N(n,ga)&&n[ga][r]||(o.enumerable=!0),o}},Va=function(e){var t=Oa(b(e)),n=[];return da(t,(function(e){N(Ta,e)||N(ge,e)||n.push(e)})),n},Fa=function(e){var t=e===ba,n=Oa(t?Ia:b(e)),r=[];return da(n,(function(e){!N(Ta,e)||t&&!N(ba,e)||r.push(Ta[e])})),r};if(R||(Oe((ma=function(){if(this instanceof ma)throw TypeError("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Xe(arguments[0]):void 0,t=U(e),n=function(e){this===ba&&n.call(Ia,e),N(this,ga)&&N(this[ga],t)&&(this[ga][t]=!1),ja(this,t,d(1,e))};return l&&Aa&&ja(ba,t,{configurable:!0,set:n}),Da(t,e)}).prototype,"toString",(function(){return ya(this).tag})),Oe(ma,"withoutSetter",(function(e){return Da(U(e),e)})),p.f=Ma,re.f=La,ee.f=Na,Ve.f=ua.f=Va,Fe.f=Fa,la.f=function(e){return Da(H(e),e)},l&&(Pa(ma.prototype,"description",{configurable:!0,get:function(){return ya(this).description}}),Oe(ba,"propertyIsEnumerable",Ma,{unsafe:!0}))),Qe({global:!0,wrap:!0,forced:!R,sham:!R},{Symbol:ma}),da(nt(Ca),(function(e){pa(e)})),Qe({target:_a,stat:!0,forced:!R},{for:function(e){var t=Xe(e);if(N(xa,t))return xa[t];var n=ma(t);return xa[t]=n,Ra[n]=t,n},keyFor:function(e){if(!k(e))throw TypeError(e+" is not a symbol");if(N(Ra,e))return Ra[e]},useSetter:function(){Aa=!0},useSimple:function(){Aa=!1}}),Qe({target:"Object",stat:!0,forced:!R,sham:!l},{create:function(e,t){return void 0===t?ft(e):Ba(ft(e),t)},defineProperty:La,defineProperties:Ba,getOwnPropertyDescriptor:Na}),Qe({target:"Object",stat:!0,forced:!R},{getOwnPropertyNames:Va,getOwnPropertySymbols:Fa}),Qe({target:"Object",stat:!0,forced:u((function(){Fe.f(1)}))},{getOwnPropertySymbols:function(e){return Fe.f(B(e))}}),wa){var Ua=!R||u((function(){var e=ma();return"[null]"!=wa([e])||"{}"!=wa({a:e})||"{}"!=wa(Object(e))}));Qe({target:"JSON",stat:!0,forced:Ua},{stringify:function(e,t,n){for(var r,o=[e],i=1;arguments.length>i;)o.push(arguments[i++]);if(r=t,(m(t)||void 0!==e)&&!k(e))return Dt(t)||(t=function(e,t){if("function"==typeof r&&(t=r.call(this,e,t)),!k(t))return t}),o[1]=t,wa.apply(null,o)}})}ma.prototype[ha]||oe(ma.prototype,ha,ma.prototype.valueOf),En(ma,_a),ge[ga]=!0;var $a=re.f,Ga=c.Symbol;if(l&&"function"==typeof Ga&&(!("description"in Ga.prototype)||void 0!==Ga().description)){var Ka={},Ha=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:String(arguments[0]),t=this instanceof Ha?new Ga(e):void 0===e?Ga():Ga(e);return""===e&&(Ka[t]=!0),t};$e(Ha,Ga);var Wa=Ha.prototype=Ga.prototype;Wa.constructor=Ha;var Ja=Wa.toString,Ya="Symbol(test)"==String(Ga("test")),qa=/^Symbol\((.*)\)[^)]+$/;$a(Wa,"description",{configurable:!0,get:function(){var e=m(this)?this.valueOf():this,t=Ja.call(e);if(N(Ka,e))return"";var n=Ya?t.slice(7,-1):t.replace(qa,"$1");return""===n?void 0:n}}),Qe({global:!0,forced:!0},{Symbol:Ha})}var za=H("isConcatSpreadable"),Qa=9007199254740991,Xa="Maximum allowed index exceeded",Za=x>=51||!u((function(){var e=[];return e[za]=!1,e.concat()[0]!==e})),ec=zo("concat"),tc=function(e){if(!m(e))return!1;var t=e[za];return void 0!==t?!!t:Dt(e)};Qe({target:"Array",proto:!0,forced:!Za||!ec},{concat:function(e){var t,n,r,o,i,a=B(this),c=Bt(a,0),u=0;for(t=-1,r=arguments.length;t<r;t++)if(tc(i=-1===t?a:arguments[t])){if(u+(o=Re(i.length))>Qa)throw TypeError(Xa);for(n=0;n<o;n++,u++)n in i&&Yo(c,u,i[n])}else{if(u>=Qa)throw TypeError(Xa);Yo(c,u++,i)}return c.length=u,c}});var nc=u((function(){bo(1)}));Qe({target:"Object",stat:!0,forced:nc,sham:!ho},{getPrototypeOf:function(e){return bo(B(e))}}),pa("iterator");var rc=function(e,t,n,r){try{return r?t(te(n)[0],n[1]):t(n)}catch(t){throw Dn(e),t}},oc=!Hn((function(e){Array.from(e)}));Qe({target:"Array",stat:!0,forced:oc},{from:function(e){var t,n,r,o,i,a,c=B(e),u="function"==typeof this?this:Array,l=arguments.length,f=l>1?arguments[1]:void 0,s=void 0!==f,p=jn(c),d=0;if(s&&(f=jt(f,l>2?arguments[2]:void 0,2)),null==p||u==Array&&kn(p))for(n=new u(t=Re(c.length));t>d;d++)a=s?f(c[d],d):c[d],Yo(n,d,a);else for(i=(o=p.call(c)).next,n=new u;!(r=i.call(o)).done;d++)a=s?rc(o,f,[r.value,d],!0):r.value,Yo(n,d,a);return n.length=d,n}});var ic=Object.prototype.toString;function ac(e){return!!/(?:^|\/)__(dd|plugin)__\//.test(e)||!!("undefined"!=typeof __ddAppCode__&&__ddAppCode__[e+".json"]||{}).usingComponents}function cc(){}function uc(t){var n=e(t);return null!==t&&"object"!==n&&"function"!==n?t:null}function lc(e,t){if("function"!=typeof t)throw new TypeError("customizer is must be a Function");if("function"==typeof e)return e;var n=ic.call(e);if("[object Array]"===n)return[];if("[object Object]"===n&&e.constructor===Object)return{};if("[object Date]"===n)return new Date(e.getTime());if("[object RegExp]"===n){var r=String(e),o=r.lastIndexOf("/");return new RegExp(r.slice(1,o),r.slice(o+1))}var i=t(e);return void 0!==i?i:null}var fc="function"==typeof Object.keys?function(e){return Object.keys(e)}:function(t){var n,r=e(t);if(null===t||"function"!==r&&"object"!==r)throw new TypeError("obj must be an Object");var o=[];for(n in t)Object.prototype.hasOwnProperty.call(t,n)&&o.push(n);return o};function sc(e,t){if("[object Array]"!==ic.call(e))throw new TypeError("array must be an Array");for(var n,r=e.length,o=0;o<r;++o)if((n=e[o])===t||n!=n&&t!=t)return o;return-1}function pc(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var o=0<n.length&&void 0!==n[0]?n[0]:cc;if(null===t)return null;var i=uc(t);if(null!==i)return i;var a=lc(t,o),c=null!==a?a:t,u=function t(n,r,o,i,a){if(null===n)return null;var c=uc(n);if(null!==c)return c;for(var u,l,f,s,p,d,g,_,h,v="function"==typeof Symbol?function(e){return Object.getOwnPropertySymbols(e)}:function(){return[]},y=fc(n).concat(v(n)),b=y.length,m=0;m<b;++m)d=p=s=void 0,-1===(f=sc(i,l=n[u=y[m]]))?(_=r,p=null!==(s=null!==(h=uc(g=l))?h:lc(g,_))?s:l,null!==l&&/^(?:function|object)$/.test(e(l))&&(i.push(l),a.push(p))):d=a[f],o[u]=d||t(l,r,p,i,a);return o};return u(t,o,c,[t],[c])}function dc(e){var t;return((t=e).options||{}).addGlobalClass,t.pageLifetimes,t.lifetimes,t.definitionFilter,t.behaviors&&t.behaviors.forEach((function(e){})),t}function gc(e,t){(null===t||t>e.length)&&(t=e.length);for(var n=new Array(t),r=0;r<t;r++)n[r]=e[r];return n}var _c=__virtualDOM__.convertComponentAliasToRoute,hc=__virtualDOM__.convertRouteToComponentAlias;function vc(e){return"[object Object]"===Object.prototype.toString.call(e)}function yc(e,t){return e.__ddExparserNodeId__&&Object.prototype.hasOwnProperty.call(Object.getPrototypeOf(e),t)||Object.prototype.hasOwnProperty.call(e,t)}function bc(e,t){for(var n,r={},o=e,i=0;i<t.length;i++)Number(t[i])===t[i]&&t[i]%1==0?Array.isArray(o)||(r[n]=[],o=r[n]):vc(o)||(r[n]={},o=r[n]),n=t[i],o=(r=o)[t[i]];return{obj:r,key:n}}var mc,wc={hostAppId:null},Sc=null,Pc={scene:0,scene_note:null,sessionid:null,usedstate:null,referpagepath:null,clickTimestamp:null,prescene:null,prescene_note:null,publicLibVersion:null,hostAppId:null},Oc=function(){function e(){this.isInitialLoading=!0,this.orientationChangeCount=0,this.startCostTime=null,this.startType=null}return e.prototype.setQuery=function(e){this.query=e},e.prototype.setOnAppShow=function(n){wc=t(wc,n),e._assignForClientOnShow(wc,n)},e.prototype.setOnAppHide=function(e){Sc=t(Sc,e)},e.prototype.setOnLaunch=function(n){(Pc=t(Pc,n)).hostAppId=__ddConfig.host&&__ddConfig.host.appId||"",e._assignForClientOnShow(Pc,n)},e.prototype.reportShowPage=function(){e._checkDeferred(),e.checkShowOptions()},e.prototype.setReadyTime=function(t){this.pageReadyTime=t,e._checkDeferred()},e.prototype.reportHidePage=function(){e._checkDeferred(),e.checkShowOptions()},e.checkShowOptions=function(){var t=Pc,n=e.showOptions||{};n.scene=t.scene||0,n.scene_note=t.scene_note,n.sessionid=t.sessionid,n.usedstate=t.usedstate,n.referpagepath=t.referpagepath,n.clickTimestamp=t.clickTimestamp,n.prescene=t.prescene,n.prescene_note=t.prescene_note,n.publicLibVersion=t.publicLibVersion;var r=e.query,o=[];r&&Object.keys(r)&&Object.keys(r).forEach((function(e){o.push(encodeURIComponent(e)+"="+encodeURIComponent(r[e]))})),n.query=o.join("&")},e._checkDeferred=function(){if(this.deferred&&this.deferred.length)for(var e=this.deferred;e.length;)e.pop()()},e._assignForClientOnShow=function(e,t){e.scene_note=t.scene_note||t.sceneNote||"",e.referpagepath=t.referpagepath||"",e.usedstate=t.usedstate||t.usedState,e.prescene=t.prescene,e.prescene_note=t.prescene_note||t.presceneNote||"",e.clickTimestamp=Date.now()},e}(),Ec=["onLoad","onReady","onShow","onHide","onUnload","onResize","onStackShow","onStackHide"],Tc=0,Ic=1,xc=5,Rc=6,Cc=7,kc={appLaunchTime:0,appFgTime:0,appRouteTime:0,newPageTime:0,pageReadyTime:0},Ac=function(){},jc=function(){function e(){}return e.create=function(e,t){var n=__virtualDOM__.addView(e?Number(e):1,t),r=exparser.Element.getMethodCaller(n);if(r.__ddWebViewId__=Number(e)||1,r.__route__=t,r.route=t,r.__displayReporter=new Oc,n.__customConstructor__===__virtualDOM__.Page){var o=n.getRootBehavior().methods,i=r.__freeData__;for(var a in o)r[a]=o[a].bind(r);for(var a in i)r[a]=pc(i[a])}var c=!0;return r.__callPageLifeTime__=function(e){for(var t,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];var a=this[e]||Ac;if(e)switch(e){case"onLoad":var u=r.__displayReporter;u.setQuery.apply(u,o);break;case"onShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("show",o);break;case"onReady":r.__displayReporter.setReadyTime(Date.now());break;case"onHide":case"onUnload":var l=this.__toRoute__,f=this.__isBack__,s=this.__notReportHide__;delete this.__toRoute__,delete this.__isBack__,delete this.__notReportHide__,s||r.__displayReporter.reportHidePage(l,f),"onHide"===e&&n.triggerPageLifeTime("hide",o),"onUnload"===e&&(null===(t=null===__appServiceSDK__||void 0===__appServiceSDK__?void 0:__appServiceSDK__.dd)||void 0===t||t.skiaCanvasRemove(r.__ddWebViewId__));break;case"onResize":var p=o[0]||{};c!==p.deviceOrientation&&(c=p.deviceOrientation,r.__displayReporter.addOrientationChangeCount()),n.triggerPageLifeTime("resize",o);break;case"onStackShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackShow",o);break;case"onStackHide":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackHide",o)}this.__route__;var d=a.apply(this,o);return d},Ec.forEach((function(e){var t=r[e];r[e]=function(){for(var e,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];var o=t||Ac;try{e=o.apply(this,n)}catch(e){}return e}.bind(r)})),{page:r,node:n}},e.destroy=function(t){var n=t&&t.__ddWebViewId__;"number"==typeof n&&n>0&&(__virtualDOM__.removeView(n),e.safeDestroyLifeCycleWithContext(t))},e.safeDestroyLifeCycleWithContext=function(e){try{for(var t=void 0,n=0,r=Ec;n<r.length;n++)e[t=r[n]]=null;e.__displayReporter=null;var o=__virtualDOM__.TreeManager.get(e&&e.__ddWebViewId__);if(o&&o.root){var i=o.root.getRootBehavior().methods;for(t in i)e[t]=null}if(e.__freeData__)for(t in e.__freeData__)e[t]=null;e.__callPageLifeTime__=null}catch(e){}},e}();
/*! *****************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */
function Dc(e,t,n,r){return new(n||(n=Promise))((function(o,i){function a(e){try{u(r.next(e))}catch(e){i(e)}}function c(e){try{u(r.throw(e))}catch(e){i(e)}}function u(e){var t;e.done?o(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,c)}u((r=r.apply(e,t||[])).next())}))}function Lc(e,t){var n,r,o,i,a={label:0,sent:function(){if(1&o[0])throw o[1];return o[1]},trys:[],ops:[]};return i={next:c(0),throw:c(1),return:c(2)},"function"==typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function c(i){return function(c){return function(i){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(o=2&i[0]?r.return:i[0]?r.throw||((o=r.return)&&o.call(r),0):r.next)&&!(o=o.call(r,i[1])).done)return o;switch(r=0,o&&(i=[2&i[0],o.value]),i[0]){case 0:case 1:o=i;break;case 4:return a.label++,{value:i[1],done:!1};case 5:a.label++,r=i[1],i=[0];continue;case 7:i=a.ops.pop(),a.trys.pop();continue;default:if(!(o=a.trys,(o=o.length>0&&o[o.length-1])||6!==i[0]&&2!==i[0])){a=0;continue}if(3===i[0]&&(!o||i[1]>o[0]&&i[1]<o[3])){a.label=i[1];break}if(6===i[0]&&a.label<o[1]){a.label=o[1],o=i;break}if(o&&a.label<o[2]){a.label=o[2],a.ops.push(i);break}o[2]&&a.ops.pop(),a.trys.pop();continue}i=t.call(e,a)}catch(e){i=[6,e],r=0}finally{n=o=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}([i,c])}}}function Bc(e,t){return Dc(this,void 0,void 0,(function(){var n,r,o,i,a,c,u,l,f,s;return Lc(this,(function(p){switch(p.label){case 0:if(n=t[e],d=n.packages,"[object Array]"!==Object.prototype.toString.call(d))return[2,Promise.reject("packages must be an array.")];for(r=[],o=[],i=0,a=n.packages;i<a.length;i++)c=a[i],__subPackageNames__&&Object.prototype.hasOwnProperty.call(__subPackageNames__,c)&&(c=__subPackageNames__[c]),__appServiceSDK__.getPackageLoadStatus(c)?r.push(c):o.push(c);if(0===o.length)return[2,n.packages.length!==o.length?"These packages have already been loaded ["+r.join(", ")+"]":"Packages empty."];p.label=1;case 1:return p.trys.push([1,5,,6]),u=[],[4,Promise.all(o.map((function(e){return new Promise((function(t){didiJsBridge.invoke({method:"preloadSubPackage",data:{package:e},callback:function(n){var r=e;__appServiceSDK__.getPackageLoadStatus(e)?r+=" loaded.":n&&n.data&&n.data.success||u.push(n.data.errMsg),t(r)}})}))})))];case 2:return l=p.sent(),u.length?[4,Promise.reject(u.join("\r\n"))]:[3,4];case 3:return[2,p.sent()];case 4:return f="(Rule page: "+e+") Loaded subPackages ["+l.join(", ")+"]",r.length&&(f+="\r\nignore subPackages ["+r.join(", ")+"]"),[2,f];case 5:return s=p.sent(),[2,Promise.reject(s)];case 6:return[2]}var d}))}))}var Mc,Nc,Vc={},Fc={},Uc={},$c=[],Gc="",Kc=null,Hc={},Wc=["onLaunch","onShow","onHide","onUnlaunch","onError"],Jc=[],Yc={},qc=null,zc=[],Qc={click:null},Xc=[],Zc=!1,eu=[],tu=!1,nu=Object.prototype.hasOwnProperty,ru=0,ou=0,iu=0,au=0,cu=0,uu=0,lu=null,fu=null,su=!0,pu=!1,du={},gu={},_u=[],hu=function(e){"string"==typeof e&&(Gc=e)},vu=!1,yu=function(){},bu=function(){function e(){}return e.App=function(e){t(e,Yc),Yc={},qc=new Pu(e)},e.Page=function(e){mu(e,"/")},e.Component=function(e){dc(e),function(e,t,n,r,o){var i;i=void 0!==o?o:{};var a=!1;(i.__wxRouteBegin||mc)&&(a=!0);i.__wxRouteBegin?i.__wxRouteBegin=!1:mc=!1;var c=__virtualDOM__.Component(e,t,n,r),u=_c(c);c&&(Hc[u]=exparser.Component._list[c]),Uc[u]=a,String(c)}(e,"/")},e.Behavior=function(e){return dc(e),__virtualDOM__.Behavior(e)},e.getCurrentRoute=function(){return Gc},e.hasPageRoute=function(e){return!!function(e){for(var t=0;t<__ddConfig.pages.length;t++)if(__ddConfig.pages[t]===e)return!0;return!1}(e)||void 0!==Uc[e]},e.getCurrentPagesByDomain=function(e){var t=[];return $c.forEach((function(n){e&&function(e){if(/^__dd__\//.test(e||""))return"//";var t=e.match(/(?:^|\/)__plugin__\/(.*?)\//);return t?t[1]:"/"}(n.route)!==e?t.push(null):t.push(n.page)})),t},e.getCurrentPages=function(){return e.getCurrentPagesByDomain("/")},e.setCurrentRoute=function(e){Gc=e},e.getPageByWebviewId=function(e){return nu.call(Vc,e)?Vc[e].page:null},e.getCurrentPageWithAdditionalInfo=function(){return Mc},e.registerGetApp=function(e){Pu(e)},e.getApp=function(e){return(arguments.length>0&&void 0!==e?e:{}).allowDefault?qc||Yc:qc},e.__createPluginGlobal=function(t,n){var r={__wxAppCode__:{},__wxAppCurrentFile__:""},o=t+"/"+n;return{__wxAppCode__:{},__wxAppCurrentFile__:"",Page:function(e){mu(e,o,r.__wxAppCode__,r.__wxAppCurrentFile__,r)},getCurrentPages:function(){return e.getCurrentPagesByDomain(t)},Behavior:function(e){return __virtualDOM__.Behavior(e)},publishDomainComponents:function(e){return __virtualDOM__.publishDomainComponents(o,e)},beforeFactory:function(){}}},e}();function mu(e,t,n,r,o){var i={__wxRoute:!1,__wxRouteBegin:!1};arguments.length<4&&void 0!==o&&(i=o);var a=i.__wxRoute?"":__ddAppCurrentFile__&&__ddAppCurrentFile__.replace(/\.js$/,""),c=hc(a),u=_c(c),l=ac(u),f=__virtualDOM__.Page(e,t,n,a+".js");Hc[u]=e,l&&(Hc[u]=exparser.Component._list[f]),Uc[u]=!0}var wu=[];function Su(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list||[];if(!t&&!t.length)return!1;t.forEach((function(e){wu.push(e.pagePath)}));var n=-1!==wu.indexOf(e.route)||-1!==wu.indexOf(e.route+".html");return wu=[],n}function Pu(e){var t=this;void 0===e&&(e={});var n=this,r=this;function o(e){for(var t=0;t<Wc.length;++t)if(Wc[t]===e)return!0;return!1}for(var i in Wc.forEach((function(r){n[r]=function(){for(var n=[],o=0;o<arguments.length;o++)n[o]=arguments[o];var i=e[r]||yu;try{i.apply(t,n)}catch(e){}}.bind(n)})),e)"getCurrentPage"===i||o(i)||("function"==typeof e[i]?n[i]=function(n){for(var r,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];try{r=e[n].apply(t,o)}catch(e){}return r}.bind(n,i):n[i]=e[i]);var a=__appServiceSDK__.getLaunchOptionsSync(),c=__appServiceSDK__.getEnterOptionsSync();r.onLaunch(a),r.onShow(c),Jc.push({app:r,preventOnShow:!0,preventStackOnShow:!0})}function Ou(e){try{!function(e,t,n,r,o,i,a){t=Number(t),kc.appRouteTime=Date.now();var c=Object.keys(n).map((function(e){return encodeURIComponent(e)+" = "+n[e]})).join("&"),u="/"+e+(c?"?"+c:""),l=a.stackId||-1;if("navigateTo"===r){if(Reporter.traceBeginEvent("framework","onnavigateto"),Su({route:e}))return;o?(Mc&&Eu(Mc,e),"min"===o?(Kc=$c[$c.length-1],nu.call(Vc,t)||xu(e,u,t,n)):"max"===o&&Kc&&(hu(e),Mc=Kc,$c.push(Mc),Mc.page.__callPageLifeTime__("onShow"),Kc=null)):(Mc&&Eu(Mc,e),nu.call(Vc,t)||xu(e,u,t,n,{initialRenderingCacheData:i})),Reporter.traceEndEvent()}else if("redirectTo"===r){if(Reporter.traceBeginEvent("framework","onredirectto"),Su({route:e}))return;Mc&&Ru(Mc,e),nu.call(Vc,t)||xu(e,u,t,n,{initialRenderingCacheData:i}),Reporter.traceEndEvent()}else if("navigateBack"===r)-1===t&&(Kc=null),o?"min"===o?(Kc=$c[$c.length-1],ku(t,!0)):"max"===o&&(Kc=null,ku(t)):ku(t);else if("switchTab"===r){if(!Su({route:e}))return;if(Reporter.traceBeginEvent("framework","onswitchtab"),$c&&$c.length&&$c[$c.length-1].webViewId===t)return;var f=void 0,s=void 0,p=!0,d=!0;if(0===$c.length)return xu(e,u,t,n,{initialRenderingCacheData:i}),void Du();for(;1<$c.length;)Kc&&Kc.webViewId===$c[$c.length-1].webViewId?($c=$c.slice(0,$c.length-1)).length?hu($c[$c.length-1].route):hu(""):Ru($c[$c.length-1],e),p=!1;if($c[0].webViewId===t)Mc=$c[0],Kc=$c[0],p||(Mc.page.__callPageLifeTime__("onShow"),Du());else if(Su($c[0])?(d=!1,p&&Eu($c[0],e)):Kc&&Kc.webViewId===$c[0].webViewId?($c=$c.slice(0,$c.length-1),hu("")):Ru($c[0],e),nu.call(Vc,t)){var g=void 0;f=(g=Vc[t]).page,s=g.node,$c=[Mc={webViewId:t,route:e,page:f,node:s}],f.__callPageLifeTime__("onShow"),Du(),Kc=$c[0],Lu("enterPage",f),Lu("switchTab",f)}else $c=[],xu(e,u,t,n,{isMainTabBarPage:d,initialRenderingCacheData:i}),Du();Reporter.traceEndEvent()}else if("pageReload"===r)Reporter.traceBeginEvent("framework","onpagereload"),y=e,b=u,m=t,w=n,S=i,P=a.prerender,kc.appLaunchTime=Date.now(),kc.appFgTime=Date.now(),xu(y,b,m,w,{initialRenderingCacheData:S,prerender:P},!0),Reporter.traceEndEvent();else if("appLaunch"===r||"appLaunchStack"===r)Reporter.traceBeginEvent("framework","onapplaunch"),kc.appLaunchTime=Date.now(),kc.appFgTime=Date.now(),nu.call(Vc,t)||xu(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender},!1,l),Reporter.traceEndEvent();else if("reLaunch"===r||"autoReLaunch"===r){Reporter.traceBeginEvent("framework","onrelaunch");var _=!1;for("reLaunch"===r&&(_=!0);0<$c.length;){var h=!0;_=_&&(h=!1),Ru($c[$c.length-1],e,!1,h)}xu(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender}),Reporter.traceEndEvent()}else"dismissPip"===r&&Kc&&(v=Kc)&&(0<=$c.findIndex((function(e){return e.webViewId===Kc.webViewId}))?Kc=null:(v.page.__callPageLifeTime__("onUnload"),v.node&&jc.destroy(v.page),delete Vc[v.webViewId],Lu("pageUnload",v.page),Lu("leavePage",v.page)));var v;var y,b,m,w,S,P}(e.path,e.webViewId,e.query||{},e.openType,e.pipMode,e.initialRenderingCacheData,e)}catch(e){Reporter.errorReport({key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : "+e}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : "+e,fail:function(e){}})}}didiJsBridge.on({event:"destroyInstance",callback:function(){try{didiJsBridge.clearAll(),(__virtualDOM__.TreeManager.listViewId()||[]).forEach((function(e){__virtualDOM__.removeView(e)})),__ddAppCode__=null,__appServiceEngine__=null,__WXML_GLOBAL__=null,__appServiceSDK__=null}catch(e){}}}),didiJsBridge.on({event:"showStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n){currentStackId=n;var r,o=__appServiceSDK__.getEnterOptionsSync();void 0===(r=o)&&(r={}),Jc.forEach((function(e){e.preventStackOnShow||e.app.onShow(r),e.preventStackOnShow=!1})),Fc[n]?($c=Fc[n],(Mc=$c&&$c.length&&$c[$c.length-1]||null)&&Mc.page&&Mc.page.__callPageLifeTime__("onStackShow",o),Mc&&Mc.page&&Mc.page.__callPageLifeTime__("onShow")):(Fc[n]=[],$c=Fc[n],hu(""))}}}),didiJsBridge.on({event:"hideStack",callback:function(e){var t,n,r,o=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;o&&Fc[o]&&(Fc[o]=$c,Mc&&(null===(n=null==Mc?void 0:Mc.page)||void 0===n||n.__callPageLifeTime__("onHide")),null===(r=null==Mc?void 0:Mc.page)||void 0===r||r.__callPageLifeTime__("onStackHide"))}}),didiJsBridge.on({event:"removeStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n&&Fc[n]){for(var r=Fc[n],o=r.length-1;o>=0;o--)Ru(r[o],r[o].path);delete Fc[n]}}}),didiJsBridge.on({event:"onAppError",callback:function(e){var t=__appServiceEngine__.getApp();t&&t.onError&&t.onError(e.data)}}),didiJsBridge.on({event:"switchTabLoadJSFileToDataThreadRequire"},(function(e){var t=e.data.route,n=e.data.index;e.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[n]&&tabBarTapList.push({index:n,pagePath:(__ddConfig.tabBar.list[n].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[n].text}),__appServiceSDK__.installPackageByRoute(t,(function(){didiJsBridge.invoke({method:"switchTabLoadJSFileToDataThreadFinish",data:{index:n}})}))})),__appServiceSDK__.onPageReload((function(e){e.path;!function(e,t){if(nu.call(Vc,t)){var n=Vc[t].statesData;Vc[t].statesData=void 0,__virtualDOM__.restoreView(t),Iu(Vc[t],t,Date.now(),n||{},!0)}}(0,e.webViewId)})),__appServiceSDK__.onAppShow((function(e){void 0===e&&(e={isLaunch:!1,path:""}),e.isLaunch&&Lu("launch"),hu(e.path),function(e){e=e||gu,Jc.forEach((function(t){t.preventOnShow||t.app.onShow(e),t.preventOnShow=!1})),gu=e}(__appServiceSDK__.getEnterOptionsSync()),Lu("foreground");var t=void 0;(t=bu.getCurrentPagesByDomain("")).length&&("function"==typeof t[t.length-1].__callPageLifeTime__&&t[t.length-1].__callPageLifeTime__("onShow"),Lu("enterPage",t[t.length-1],!0))})),__appServiceSDK__.onAppRoute((function(e){__ddConfig&&__ddConfig.preloadRule&&Object.prototype.hasOwnProperty.call(__ddConfig.preloadRule,e.path)&&dd.nextTick((function(){Bc(e.path,__ddConfig.preloadRule).then((function(e){})).catch((function(e){}))}));var t=__appServiceSDK__.RouteTask.getCurrentTask();null===t||t.resolved?Ou(e):t.rejected?(Reporter.errorReport({key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error"}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error",fail:function(e){}})):t.pending&&t.addTask(Ou.bind(void 0,e))})),__appServiceSDK__.onAppRouteDone((function(){pu=!0,Xc.forEach((function(e){Lu.apply(void 0,function(e){return function(e){if(Array.isArray(e))return gc(e)}(e)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return gc(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(n):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?gc(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(e))})),Xc=[]})),__appServiceSDK__.onPullDownRefresh((function(){var e=bu.getCurrentPagesByDomain("");if(e.length){var t=e[e.length-1];"function"==typeof t.__callPageLifeTime__&&t.__callPageLifeTime__("onPullDownRefresh");var n=bu.getCurrentPageWithAdditionalInfo().page;n&&Lu("pullDownRefresh",n,!0)}}));function Eu(e,t){Reporter.traceBeginEvent("framework","onhidepage"),e.page.__toRoute__=t,e.page.__callPageLifeTime__("onHide"),Lu("leavePage",e.page),Reporter.traceEndEvent()}didiJsBridge.subscribe({event:"initReadyForPrerender",callback:function(e){__appServiceSDK__.onAppRouteInit(e)}}),didiJsBridge.subscribe({event:"onShareAppMessage",callback:function(e){var t={};Mc.page.onShareAppMessage&&(t=Mc.page.onShareAppMessage.apply(Mc.page,[e.data||{}])||{});var n,r=t.promise;delete t.promise,"Promise"!==(n=r,Object.prototype.toString.call(n).split(" ")[1].split("]")[0])&&(r=Promise.resolve(t));var o=new Promise((function(e){setTimeout((function(){e(t)}),3e3)}));Promise.race([o,r]).then((function(e){void 0===e&&(e={}),dd.customShare({type:"miniApp",title:e.title,content:e.title,image:e.imageUrl,ext:{path:e.path}})}))}}),didiJsBridge.subscribe({event:"PAGE_EVENT",callback:function(e){if("__DOMReady"===(e=e.data||{}).eventName&&Mc&&Mc.page&&(Reporter.pageLoadReport(Mc.page.route,Mc.page.__ddWebViewId__),Mc.page.__callPageLifeTime__&&Mc.page.__callPageLifeTime__("onReady")),Mc.page&&Mc.page[e.eventName])return Mc.page[e.eventName].apply(Mc.page,[e.data])}}),didiJsBridge.on({event:"onPageScroll"},(function(e){if(Mc.page&&"function"==typeof Mc.page.onPageScroll)return Mc.page.onPageScroll.apply(Mc.page,[e.data])})),didiJsBridge.invoke({method:"getSdkReportPoint",data:{event:"tech_saga_launch_app"},callback:function(e){try{e.data.data&&Reporter.reportAppLaunchTime(e.data.data)}catch(e){}}}),__appServiceSDK__.onAppHide((function(e){void 0===e&&(e={mode:""});var t,n=bu.getCurrentPagesByDomain("");n.length&&("function"==typeof n[n.length-1].__callPageLifeTime__&&n[n.length-1].__callPageLifeTime__("onHide"),Lu("leavePage",bu.getCurrentPageWithAdditionalInfo().page,!0)),t=e,Jc&&Jc.forEach((function(e){7===__ddConfig.appType?e.app.onHide(t):e.app.onHide()})),Lu("background")})),__appServiceSDK__.onAppEnterBackground();var Tu={emit:function(e,t,n){__appServiceSDK__.invokeWebviewMethod("appDataChange",e,t,n)}};function Iu(e,t,n,r,o,i){var a=e.page,c=Object();c.webViewId=t,c.enablePullUpRefresh=yc(a,"onReachBottom"),c.enablePageScroll=yc(a,"onPageScroll"),c.onReachBottomDistance=function(e){try{var t=__ddConfig.page[e].window&&__ddConfig.page[e].window.onReachBottomDistance;if(__ddConfig.page[e].onReachBottomDistance&&(t=__ddConfig.page[e].onReachBottomDistance),"number"==typeof t)return t}catch(e){}}(a.__route__),c.statesData=r,c.scene=undefined,c.route=a.__route__,c.query=a.options,c.lastRoute=e.lastRoute,c.lastQuery=e.lastQuery,c.wxConfig={accountInfo:__ddConfig&&__ddConfig.accountInfo||{},appContactInfo:__ddConfig&&__ddConfig.appContactInfo||{},appLaunchInfo:__ddConfig&&__ddConfig.appLaunchInfo||{},plugins:__ddConfig&&__ddConfig.plugins||{}},c.windowConfig=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].window||{},c.onPageScrollThrottle=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].onPageScrollThrottle||null,c.keyScrollTop=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].keyScrollTop||null,c.debug=__ddConfig&&__ddConfig.debug,c.appId=__ddConfig&&__ddConfig.accountInfo&&__ddConfig.accountInfo.appId,c.appLaunchTime=kc.appLaunchTime,c.appFgTime=kc.appFgTime,c.isTabBarPage=e.isTabBarPage,c.isMainTabBarPage=e.isMainTabBarPage,c.navigationStyle=__ddConfig&&__ddConfig.global&&__ddConfig.global.window&&__ddConfig.global.window.navigationStyle,c.needGetSubjectInfo=!vu,c.perfData=(zc[xc]=Date.now(),zc[Tc]=su?1:0,zc[Cc]=__ddConfig.isSubContext?1:0,zc[Ic]=__ddConfig.onReadyStart,zc[Rc]=__ddConfig.onReadyEnd||0,su=!1,zc),c.isReload=o,c.fontFaceRecords=__appServiceSDK__.fontFaceRecords,c.prerender=i;var u={ext:c,options:{firstRender:!0,timestamp:n,path:a.__route__}};Tu.emit(u,t),Lu("pageReady",a)}function xu(e,t,n,r,o,i,a){void 0===o&&(o={}),void 0===i&&(i=!1);var c=function(e){void 0===e&&(e=-1);if(e<0)return $c;return Fc[e]=Fc[e]||[],Fc[e]}(a);Reporter.traceBeginEvent("framework","pushpageinfostask");var u=Nc;Nc=void 0;var l=ac(e);kc.newPageTime=Date.now(),hu(e);var f=jc.create(n,e),s=f.page,p=pc(r);if((Mc={page:s,webViewId:n,route:e,rawPath:t,lastRoute:Mc?Mc.route:"",lastQuery:Mc?Mc.page.options:{},node:f.node,isTabBarPage:null}).isMainTabBarPage=o.isMainTabBarPage||!1,i){for(var d=-1,g=0;g<c.length;g++)c[g].webViewId===n&&(d=g);-1!==d&&c.splice(d,1,Mc)}else c.push(Mc);s.__exitState__=u;var _={};Object.keys(p).forEach((function(e){var t=p[e];try{_[e]=decodeURIComponent(t)}catch(n){_[e]=t}})),__virtualDOM__.attachView(n,_),/^__dd__\//.test(e)&&n.setData(undefined),s.options=p,Iu(Mc,n,kc.newPageTime,!0,!1,o.prerender||!1),o.initialRenderingCacheData&&s.setData(o.initialRenderingCacheData),s.__callPageLifeTime__("onLoad",r),s.__callPageLifeTime__("onShow"),Vc[n]={page:s,route:e,rawPath:t,webViewId:n,statesData:null,node:l?f.node:void 0},Lu("pageLoad",s),Lu("enterPage",s),Reporter.traceEndEvent()}function Ru(e,t,n,r){Reporter.traceBeginEvent("framework","unloadpage"),e.page.__toRoute__=t,e.page.__isBack__=n,e.page.__notReportHide__=r,e.page.__callPageLifeTime__("onUnload"),e.node&&jc.destroy(e.page),delete Vc[e.webViewId],($c=$c.slice(0,$c.length-1)).length?hu($c[$c.length-1].route):hu(""),Lu("pageUnload",e.page),Lu("leavePage",e.page),Fc[currentStackId]=null,Fc[currentStackId]=$c,Reporter.traceEndEvent()}function Cu(e){e.__ddSlotChildren&&e.__ddSlotChildren.length>0&&e.__ddSlotChildren.forEach((function(e){Cu(e),"dd-web-view"===e.is&&e.__methodCaller&&e.__methodCaller.triggerEvent("message",{data:_u})}))}function ku(e,t){Reporter.traceBeginEvent("framework","navigateback");for(var n,r=1<arguments.length&&void 0!==t&&t,o=!1,i=$c.length-1,a=Vc&&Vc[e]&&Vc[e].route||"";0<i;i--){var c=$c[i];if(c&&_u.length&&c.node&&(Cu(c.node),_u.length=0),c.webViewId===e){o=!0,Mc=c;break}if(!r&&Kc&&Kc.webViewId===c.webViewId)$c=$c.slice(0,$c.length-1);else{r&&Kc&&Kc.webViewId===c.webViewId?(Eu(c),($c=$c.slice(0,$c.length-1)).length?hu($c[$c.length-1].route):hu("")):Ru(c,a,!0)}}1!==$c.length||o||(n=$c[0]).webViewId===e&&(o=!0,Mc=n),o&&(Mc.page.__callPageLifeTime__("onShow"),Lu("enterPage",Mc.page)),Reporter.traceEndEvent()}function Au(e,t){Object.keys(e.data||{}).forEach((function(n){var r,o,i,a,c,u,l,f,s=e.data[n],p=t&&t.data||{};if("$"!==s.charAt(0)||void 0===(r=function(e){var t=0;switch(e){case"PAGE_TIME":return 0<=(t=iu?Date.now()-iu-au:0)?t:null;case"APP_TIME":return 0<=(t=ru?Date.now()-ru-ou:0)?t:null;case"CURRENT_PAGE":return fu||null;case"LAST_PAGE":return lu||null;default:return}}(s.substr(1)))){if(0===s.indexOf("$APP"))return i=n,c=(o=e).data[i],void((u=bc((f&&f.allowDefault?qc||Yc:qc)||{},c.replace("$APP.",""))).obj&&void 0!==u.obj[u.key]&&("number"!=typeof(a=u.obj[u.key])&&"string"!=typeof a&&"boolean"!=typeof a||(du[o.eventID].data[i]=a)));if(t&&(e.page===t.__route__||"ANY_PAGE"===e.page)){if(0===s.indexOf("$DATASET")&&(l=s.replace("$DATASET.",""),(r=bc(e.dataset||{},function(e){for(var t=[],n=e.length,r="",o=0,i=!1,a=0;a<n;a++){var c=e[a];"\\"===c?a+1<n&&("."===e[a+1]||"["===e[a+1]||"]"===e[a+1])?(r+=e[a+1],a++):r+="\\":"."===c?r&&(t.push(r),r=""):"["===c?i=!0:"]"===c?(i=!1,t.push(o),o=0):i?o=10*o+c.charCodeAt(0)-48:r+=c}return t}(l))).obj&&void 0!==r.obj[r.key]&&(du[e.eventID].data[n]=r.obj[r.key],!0)),0===s.indexOf("$COMP")&&"number"==typeof e.nodeId){var d=__virtualDOM__.getNoapproutedeById(e.nodeId,e.webViewId);if(!(d=__virtualDOM__.getNodeById(e.nodeId,e.webViewId)))return;var g=exparser.Element.getMethodCaller(d);g&&(s=s.replace("$COMP.",""),p=g.data)}if(-1<s.indexOf("[]")){if((e.index||[]).forEach((function(e){s=s.replace("[]","["+e+"]")})),-1<s.indexOf("[-1]")||-1<s.indexOf("[]"))return;var _=s.match(/\[(\d+)\]\.\$INDEX$/);_&&(du[e.eventID].data[n]=Number(_[1]),!0)}if(void 0===(r=bc(p,s)).obj||void 0===r.key||void 0===r.obj[r.key])return;du[e.eventID].data[n]=r.obj[r.key]}}else null!==r&&(du[e.eventID].data[n]=r)}))}function ju(e,t){if("start"!==e.action&&("start_and_report"!==e.action||(du[e.eventID]={eventID:e.eventID,data:{},extra:e.extra})),du[e.eventID]){var n,r,o=t||bu.getCurrentPageWithAdditionalInfo()&&bu.getCurrentPageWithAdditionalInfo().page;Au(e,o),"report"!==e.action&&"start_and_report"!==e.action||(n=e.eventID,r=[],Object.keys(du[n].data).forEach((function(e){r.push({id:e,value:du[n].data[e]})})),du[n].data=r,du[n].page=o,du[n].version=("undefined"!=typeof __libVersionInfo__?__libVersionInfo__.version:0)||0,du[n].uid=Date.now().toString(16)+Math.random().toString(16).substr(2),du[n].type=0)}}function Du(){for(var e=0;e<tabBarTapList.length;e++){var t=tabBarTapList.shift();if(t.pagePath===Mc.route||t.pagePath==="/"+Mc.route||"/"+t.pagePath===Mc.route){Mc.page.onTabItemTap&&Mc.page.onTabItemTap.call(Mc.page,t);break}}}function Lu(e,t,n){var r,o;if("pageReady"===e&&t){if(t){var i=t.__route__,a=Qc.click;r=[],a&&(a.forEach((function(e){e.page!==i&&"ANY_PAGE"!==e.page||!e.element||r.push({eventID:e.eventID,page:e.page,element:e.element,action:e.action})})),0!==r.length&&__appServiceSDK__.publishAnalyticsConfig(r,[Number(t&&t.__ddWebViewId__)]))}}else if(tu)eu.push(e);else{if("launch"===e&&!Zc)return ru=Date.now(),tu=Zc=!0,eu.push(e),void __appServiceSDK__.getAppConfig({type:1,complete:function(e){tu=!1,e.data&&function(e,t){var n={};try{n=JSON.parse(e.data)}catch(e){n={}}var r={},o=bu.getCurrentPageWithAdditionalInfo(),i=n;"[object Array]"===Object.prototype.toString.call(i)&&i.forEach((function(e){var t=e.eventTarget;"[object Object]"===Object.prototype.toString.call(t)&&(t=[t]),t&&t.length&&t.forEach((function(t){var n=t.trigger||"click";r[n]||(r[n]=[]),("click"!==n||/^([.#][a-zA-Z_][^.#]* ?)+$/.test(t.element&&t.element.trim()))&&r[n].push({eventID:e.eventID,page:t.page,element:t.element&&t.element.trim(),data:t.data,action:t.action,extra:e.extra})}))})),Qc=r,r={},t||(eu.forEach((function(e){Lu(e,o&&o.page,!0)})),eu=[]),Lu("pageReady",o&&o.page)}(e)}});if(pu){n||("enterPage"===e?(iu=Date.now(),au=0,fu=t&&t.__route__):"leavePage"===e?lu=t&&t.__route__:"background"===e?cu=Date.now():"foreground"===e&&(uu=Date.now(),cu&&cu<uu&&(au+=uu-cu,ou+=uu-cu)));var c=["enterPage","leavePage","pageLoad","pageUnload","pullDownRefresh","switchTab"];(o=Qc[e])&&("enterPage"===e&&t&&"page/component/index"===t.__route__&&__ddConfig.accountInfo&&o.map((function(e){return e.eventID})),o.forEach((function(n){n&&(-1<c.indexOf(e)?(t&&n.page===(t&&t.__route__)||"ANY_PAGE"===n.page)&&ju(n,t):ju(n))})))}}}return didiJsBridge.subscribe({event:"h5PostMessage"},(function(e){var t=e&&e.data&&e.data.params;if(t&&t.data){var n=t.data;for(var r in"string"==typeof n&&(n=JSON.parse(n)),n)"data"===r&&_u.push(n[r])}})),{App:bu.App,Component:bu.Component,Page:bu.Page,Behavior:bu.Behavior,getApp:bu.getApp,__createPluginGlobal:bu.__createPluginGlobal,getCurrentRoute:bu.getCurrentRoute,getCurrentPagesByDomain:bu.getCurrentPagesByDomain,getCurrentPages:bu.getCurrentPages,getCurrentPageWithAdditionalInfo:bu.getCurrentPageWithAdditionalInfo}}();

!function(global) {
  /**
   * 将 page 等挂在 global 上
   */
  global.navigateBack = __appServiceSDK__.navigateBackNative;
  global.App = __appServiceEngine__.App;
  global.Page = __appServiceEngine__.Page;
  global.Behavior = __appServiceEngine__.Behavior;
  global.Component = __appServiceEngine__.Component;
  global.getApp = __appServiceEngine__.getApp;
  global.getCurrentPages = __appServiceEngine__.getCurrentPages;
  // global.wx = global.dd = __appServiceSDK__.dd;
  global.wx = global.dd = __appServiceSDK__.proxySDK;
  /**
   * 将 wx 的方法挂在全局上
   */
  var wxApiMap = [
    "drawCanvas",
    "createContext",
    "createCanvasContext",
    "canvasToTempFilePath",
    "canvasGetImageData",
    "canvasPutImageData",
    "createOffscreenCanvas",
    "getAccountInfoSync",
    "getShareInfo",
    "authPrivateMessage",
    "pageScrollTo",
    "chooseInvoiceTitle",
    "chooseInvoice",
    "arrayBufferToBase64",
    "base64ToArrayBuffer",
    "openSetting",
    "getExtConfig",
    "chooseMedia",
    "previewMedia",
    "chooseMultiMedia",
    "chooseMessageFile",
    "chooseWeChatContact",
    "uploadEncryptedFileToCDN",
    "onUploadEncryptedFileToCDNProgress",
    "uploadToCommonCDN",
    "getExtConfigSync",
    "showShareMenu",
    "hideShareMenu",
    "updateShareMenu",
    "shareAppMessageForFakeNative",
    "openUrl",
    "setNavigationBarColor",
    "setNavigationBarAlpha",
    "showShareImageMenu",
    "vibrateShort",
    "vibrateLong",
    "getSetting",
    "checkIsSupportFacialRecognition",
    "startFacialRecognitionVerify",
    "startFacialRecognitionVerifyAndUploadVideo",
    "startCustomFacialRecognitionVerify",
    "startCustomFacialRecognitionVerifyAndUploadVideo",
    "sendBizRedPacket",
    "sendGoldenRedPacket",
    "openGoldenRedPacketDetail",
    "showRedPackage",
    "addPhoneContact",
    "setScreenBrightness",
    "getScreenBrightness",
    "shareToWeRun",
    "getWeRunData",
    "uploadWeRunData",
    "addWeRunData",
    "canIUse",
    "setPageStyle",
    "triggerGettingWidgetData",
    "navigateToMiniProgram",
    "navigateToMiniProgramDirectly",
    "navigateToDevMiniProgram",
    "navigateBackMiniProgram",
    "launchMiniProgram",
    "launchApplicationDirectly",
    "launchApplicationForNative",
    "setNavigationBarRightButton",
    "onTapNavigationBarRightButton",
    "setTopBarText",
    "setTabBarBadge",
    "removeTabBarBadge",
    "showTabBarRedDot",
    "hideTabBarRedDot",
    "showTabBar",
    "hideTabBar",
    "setTabBarStyle",
    "setTabBarItem",
    "setBackgroundColor",
    "setBackgroundTextStyle",
    "setEnableDebug",
    "captureScreen",
    "onUserCaptureScreen",
    "offUserCaptureScreen",
    "setKeepScreenOn",
    "checkIsSupportSoterAuthentication",
    "startSoterAuthentication",
    "checkIsSoterEnrolledInDevice",
    "openDeliveryList",
    "navigateBackH5",
    "openBusinessView",
    "navigateBackApplication",
    "navigateBackNative",
    "reportIDKey",
    "reportKeyValue",
    "setWindowSize",
    "setNavigationBarTitle",
    "showNavigationBarLoading",
    "hideNavigationBarLoading",
    "hideHomeButton",
    "startPullDownRefresh",
    "stopPullDownRefresh",
    "operateWXData",
    "getOpenDeviceId",
    "getMenuButtonBoundingClientRect",
    "getSelectedTextRange",
    "enableAlertBeforeUnload",
    "disableAlertBeforeUnload",
    "makeBluetoothPair",
    "openBluetoothAdapter",
    "closeBluetoothAdapter",
    "getBluetoothAdapterState",
    "onBluetoothAdapterStateChange",
    "offBluetoothAdapterStateChange",
    "startBluetoothDevicesDiscovery",
    "stopBluetoothDevicesDiscovery",
    "getBluetoothDevices",
    "getConnectedBluetoothDevices",
    "createBLEConnection",
    "setBLEMTU",
    "closeBLEConnection",
    "getBLEDeviceServices",
    "getBLEDeviceRSSI",
    "getBLEDeviceCharacteristics",
    "createBLEPeripheralServer",
    "onBLEPeripheralConnectionStateChanged",
    "offBLEPeripheralConnectionStateChanged",
    "notifyBLECharacteristicValueChanged",
    "notifyBLECharacteristicValueChange",
    "readBLECharacteristicValue",
    "writeBLECharacteristicValue",
    "onBluetoothDeviceFound",
    "offBluetoothDeviceFound",
    "onBLEConnectionStateChanged",
    "onBLEConnectionStateChange",
    "onBLECharacteristicValueChange",
    "offBLEConnectionStateChanged",
    "offBLEConnectionStateChange",
    "offBLECharacteristicValueChange",
    "startBeaconDiscovery",
    "stopBeaconDiscovery",
    "getBeacons",
    "onBeaconUpdate",
    "offBeaconUpdate",
    "onBeaconServiceChange",
    "offBeaconServiceChange",
    "startWifi",
    "stopWifi",
    "getWifiList",
    "getConnectedWifi",
    "connectWifi",
    "presetWifiList",
    "setWifiList",
    "onGetWifiList",
    "onWifiConnected",
    "offGetWifiList",
    "offWifiConnected",
    "onEvaluateWifi",
    "getHCEState",
    "startHCE",
    "stopHCE",
    "sendHCEMessage",
    "onHCEMessage",
    "offHCEMessage",
    "getNFCAdapter",
    "startLocalServiceDiscovery",
    "stopLocalServiceDiscovery",
    "onLocalServiceFound",
    "offLocalServiceFound",
    "onLocalServiceLost",
    "offLocalServiceLost",
    "onLocalServiceDiscoveryStop",
    "offLocalServiceDiscoveryStop",
    "onLocalServiceResolveFail",
    "offLocalServiceResolveFail",
    "redirectTo",
    "reLaunch",
    "navigateTo",
    "switchTab",
    "navigateBack",
    "onAppShow",
    "offAppShow",
    "onAppHide",
    "offAppHide",
    "onError",
    "offError",
    "onUnhandledRejection",
    "offUnhandledRejection",
    "getLaunchOptionsSync",
    "getEnterOptionsSync",
    "onWindowResize",
    "offWindowResize",
    "setPageOrientation",
    "getStorage",
    "getStorageSync",
    "setStorage",
    "setStorageSync",
    "removeStorage",
    "removeStorageSync",
    "clearStorage",
    "clearStorageSync",
    "getStorageInfo",
    "getStorageInfoSync",
    "getBackgroundFetchData",
    "onBackgroundFetchData",
    "setBackgroundFetchToken",
    "getBackgroundFetchToken",
    "request",
    "connectSocket",
    "closeSocket",
    "sendSocketMessage",
    "onSocketOpen",
    "onSocketClose",
    "onSocketMessage",
    "onSocketError",
    "uploadFile",
    "downloadFile",
    "addNativeDownloadTask",
    "downloadApp",
    "installDownloadApp",
    "getAppInstallState",
    "queryDownloadAppTask",
    "cancelDownloadAppTask",
    "resumeDownloadAppTask",
    "pauseDownloadAppTask",
    "onDownloadAppStateChange",
    "downloadAppForIOS",
    "calRqt",
    "secureTunnel",
    "chooseImage",
    "previewImage",
    "getImageInfo",
    "saveImageToPhotosAlbum",
    "compressImage",
    "startRecord",
    "stopRecord",
    "playVoice",
    "pauseVoice",
    "stopVoice",
    "onVoicePlayEnd",
    "chooseVideo",
    "saveVideoToPhotosAlbum",
    "getVideoInfo",
    "compressVideo",
    "loadFontFace",
    "createMediaContainer",
    "createMediaRecorder",
    "createVideoDecoder",
    "openVideoEditor",
    "createMediaAudioPlayer",
    "getLocation",
    "openLocation",
    "chooseLocation",
    "onLocationChange",
    "offLocationChange",
    "startLocationUpdateBackground",
    "startLocationUpdate",
    "stopLocationUpdate",
    "getNetworkType",
    "onNetworkStatusChange",
    "offNetworkStatusChange",
    "getSystemInfo",
    "getSystemInfoSync",
    "getSystemInfoAsync",
    "getBatteryInfo",
    "getBatteryInfoSync",
    "startAccelerometer",
    "stopAccelerometer",
    "onAccelerometerChange",
    "offAccelerometerChange",
    "startCompass",
    "stopCompass",
    "onCompassChange",
    "offCompassChange",
    "startDeviceMotionListening",
    "stopDeviceMotionListening",
    "onDeviceMotionChange",
    "offDeviceMotionChange",
    "startGyroscope",
    "stopGyroscope",
    "onGyroscopeChange",
    "offGyroscopeChange",
    "checkIsOpenAccessibility",
    "reportAction",
    "getBackgroundAudioManager",
    "getRecorderManager",
    "getBackgroundAudioPlayerState",
    "playBackgroundAudio",
    "pauseBackgroundAudio",
    "seekBackgroundAudio",
    "stopBackgroundAudio",
    "onBackgroundAudioPlay",
    "onBackgroundAudioPause",
    "onBackgroundAudioStop",
    "joinVoIPChat",
    "exitVoIPChat",
    "updateVoIPChatMuteConfig",
    "onVoIPChatMembersChanged",
    "onVoIPChatSpeakersChanged",
    "onVoIPChatInterrupted",
    "offVoIPChatMembersChanged",
    "offVoIPChatSpeakersChanged",
    "offVoIPChatInterrupted",
    "subscribeVoIPVideoMembers",
    "onVoIPVideoMembersChanged",
    "offVoIPVideoMembersChanged",
    "join1v1Chat",
    "setEnable1v1Chat",
    "requestSubscribeMessage",
    "login",
    "logout",
    "checkSession",
    "authorize",
    "getUserInfo",
    "requestPayment",
    "verifyPaymentPassword",
    "bindPaymentCard",
    "requestPaymentToBank",
    "requestVirtualPayment",
    "openOfflinePayView",
    "openWCPayCardList",
    "requestMallPayment",
    "setCurrentPaySpeech",
    "loadPaySpeechDialectConfig",
    "requestJointPayment",
    "getWCPayOverseaPrepayRequest",
    "requestH5Transaction",
    "openWCPayOverseaPaymentReceive",
    "handleWCPayOverseaWalletBuffer",
    "requestVerifyUserIdentity",
    "phoneBindCardVerifySms",
    "faceVerifyForPay",
    "openOfficialAccountProfile",
    "openUserProfile",
    "requestBizSplitBillPayment",
    "openSelectPayment",
    "requestEntrustAuthorization",
    "requestFacetoFacePayment",
    "requestQueryCashier",
    "openMiniProgramProfile",
    "openMiniProgramSearch",
    "openMiniProgramHistoryList",
    "openMiniProgramStarList",
    "batchGetContactDirectly",
    "preloadMiniProgramEnvDirectly",
    "predownloadMiniProgramPackageDirectly",
    "preventApplePayUI",
    "getWxSecData",
    "addCard",
    "openCard",
    "checkTrafficCardConditions",
    "queryTrafficCardInfo",
    "issueTrafficCard",
    "rechargeTrafficCard",
    "setDefaultTrafficCard",
    "scanCode",
    "openQRCode",
    "scanItem",
    "chooseAddress",
    "saveFile",
    "openDocument",
    "getSavedFileList",
    "getSavedFileInfo",
    "getFileInfo",
    "removeSavedFile",
    "getFileSystemManager",
    "saveFileToDisk",
    "getABTestConfig",
    "chooseContact",
    "removeUserCloudStorage",
    "setUserCloudStorage",
    "makePhoneCall",
    "makeVoIPCall",
    "onAppRoute",
    "onAppRouteDone",
    "onAppEnterBackground",
    "onAppEnterForeground",
    "onAppUnhang",
    "onPageReload",
    "onPageNotFound",
    "offPageNotFound",
    "onThemeChange",
    "offThemeChange",
    "onCopyUrl",
    "offCopyUrl",
    "createAnimation",
    "createInnerAudioContext",
    "getAvailableAudioSources",
    "onAudioInterruptionBegin",
    "offAudioInterruptionBegin",
    "onAudioInterruptionEnd",
    "offAudioInterruptionEnd",
    "setInnerAudioOption",
    "createAudioContext",
    "createVideoContext",
    "createMapContext",
    "createCameraContext",
    "createLivePlayerContext",
    "createLivePusherContext",
    "onWebviewEvent",
    "onNativeEvent",
    "hideKeyboard",
    "onKeyboardHeightChange",
    "offKeyboardHeightChange",
    "getPublicLibVersion",
    "showModal",
    "showToast",
    "hideToast",
    "showLoading",
    "hideLoading",
    "showActionSheet",
    "showShareActionSheet",
    "reportAnalytics",
    "reportMonitor",
    "getClipboardData",
    "setClipboardData",
    "createSelectorQuery",
    "createIntersectionObserver",
    "createMediaQueryObserver",
    "nextTick",
    "updatePerfData",
    "traceEvent",
    "onMemoryWarning",
    "offMemoryWarning",
    "reportPerformance",
    "getPerformance",
    "getUpdateManager",
    "updateWeChatApp",
    "createWorker",
    "voiceSplitJoint",
    "uploadSilkVoice",
    "downloadSilkVoice",
    "getResPath",
    "setResPath",
    "setCookies",
    "getCookies",
    "faceDetect",
    "initFaceDetect",
    "stopFaceDetect",
    "createBufferURL",
    "revokeBufferURL",
    "createSignal",
    "bindGroup",
    "joinGroup",
    "getLabInfo",
    "setLabInfo",
    "createUDPSocket",
    "env",
    "error",
    "isSystemError",
    "isSDKError",
    "isThirdError",
    "createRewardedVideoAd",
    "createInterstitialAd",
    "createCustomAd",
    "preloadVideoAd",
    "preloadAd",
    "getLogManager",
    "getRealtimeLogManager",
    "getExptInfoSync",
    "reportEvent",
    "getChannelsLiveInfo",
    "openChannelsLive",
    "openChannelsActivity",
    "openChannelsUserProfile",
    "cloud",
    "serviceMarket",
    "version",
    "chooseShareGroup",
    "enterContact",
    "getGroupEnterInfo",
    "getBaseMethods",
    "updateCoverView",
  ];
  var noop = function() {

  };
  for (var key of wxApiMap) {
    if (!wx.hasOwnProperty(key)) {
      wx[key] = noop;
    }
  }

  /**
   * Modules Logic (__wxModule__)
   */

  // 开发者的 JS 逻辑模块
  var JSModules = {};
  var exportPackages = {}; // 存储导出模块
  var MODULES_STATUS_UNLOAD = 1; // 未加载
  var MODULES_STATUS_LOADED = 2; // 已加载
  var MAIN_PACKAGE_NAME = '';

  /**
   * require & define
   */
  /**
   * @param path 文件路径
   * @returns string[] 每一级的文件名列表
   */
  function getFolderNameList(path) {
    var result = []
    var n = path.split("/")
    for (var i = 0, len = n.length; i < len; ++i) {
      var token = n[i];
      if ("" !== token && "." !== token)
        if (".." === token) {
          if (0 === result.length) {
            result = null;
            break
          }
          result.pop()
        } else {
          i + 1 < len && ".." === n[i + 1]
            ? i++
            : result.push(token)
        }
    }
    return result
  }

  function p(e) {
    var t = getFolderNameList(e + "/index.js").join("/");
    return getFolderNameList[t]
      ? t
      : (t = getFolderNameList(e).join("/"), /\.js$/.test(t) || (t += ".js"), getFolderNameList[t] ? t : "")
  }

  /**
   * 返回 define 内部 code 运行时的 require 函数
   * @param name {string} 声明的模块名
   * @returns {Function}
   */
  function requireFactory(name) {
    // var matchVal = name.match(/(.*)\/([^/]+)?$/)
    // var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
    /**
     * 业务代码中的 require 函数
     * @param modulePath {string} 引用的模块名
     */
    return function(requireModulePath) {
      var matchVal = name.match(/(.*)\/([^/]+)?$/)
      var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
      if (typeof requireModulePath !== 'string') {
        throw new Error("require args must be a string")
      }
      var absFolderNameList = getFolderNameList(modulePath + '/' + requireModulePath)
      try {
        var __requirePath = absFolderNameList.join("/")
        __requirePath = function(e, t, n) {
          var r = e;
          if (!(/\.js$/.test(r))) {
            r += ".js"
          }
          if ("string" == typeof r && JSModules[r]) {
            return r
          }
          var o = getFolderNameList(t);
          if (!o) {
            throw new Error("can not find module : " + n)
          }
          for (var i = e.substring(o.join("/").length); o.length;) {
            var a, s = o.join("/") + "/miniprogram_npm" + i;
            if (a = p(s)) break;
            o.pop()
          }
          return a || (i = "/" === i[0] ? i : "/" + i, a = p(s = "miniprogram_npm" + i)), a || e
        }(__requirePath, modulePath, requireModulePath);

        return require(__requirePath)
      } catch (e) {
        throw e
      }
    }
  }

  /**
   * 定义 js 逻辑模块
   * @param name {string}
   * @param factoryLogicContent {Function} 包装开发者 JS 文件逻辑的可执行函数 (使用形参占位来屏蔽敏感变量)
   */
  var define = function(name, factoryLogicContent) {
    JSModules[name] = {
      status: MODULES_STATUS_UNLOAD,
      factory: factoryLogicContent,
      exports: undefined
    }
  }

  // let require_ts = 0
  // let now = 0
  // let ts = 0
  /**
   * 执行某 js 逻辑模块
   * @param name {string}
   * @param multi {boolean} 是否会引用多次
   */
  var require = function(name, multi = true) {
    if (typeof name !== 'string') {
      throw new Error("require args must be a string")
    }
    name.endsWith('.js') || (name += '.js');
    var requireModule = JSModules[name] // 反解此处还有不少 npm 包的加载与其他 check 逻辑，暂时省略
    if (!requireModule) {
      throw new Error('module "' + name + '" is not defined')
    }
    var module = {
      exports: {}
    }
    var factory = requireModule.factory

    // 如果仅引用一次
    if (!multi || exportPackages[name]) {
      delete requireModule.exports
      requireModule.status = MODULES_STATUS_UNLOAD
      exportPackages[name] = true;
      factory && factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
      return module.exports
    }

    if (requireModule.status === MODULES_STATUS_UNLOAD) {
      requireModule.exports = module.exports
      requireModule.status = MODULES_STATUS_LOADED
      var result
      try {
        if (factory) {
          result = factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
        }
      } catch (e) {
        requireModule.status = MODULES_STATUS_UNLOAD
        __appServiceSDK__.traceCoreDotting('app_error', {
          info: e.message + e.stack,
          isError: true
        })
        var app = __appServiceEngine__.getApp()
        app && app.onError && app.onError(e.message + e.stack)
      }
      requireModule.exports = module.exports === undefined
        ? result
        : module.exports
    }

    return requireModule.exports
  }

  var definePackageLogicMap = {}; // 定义 js 模块的代码块

  /**
   * 收集代码包的逻辑
   * @param packageName {string} 代码包名
   * @param define {Function} 定义 (js 运行时代码)
   */
  function blockPackageLogic(packageName, define) {
    definePackageLogicMap[packageName] = define
  }

  /**
   * 释放代码包逻辑
   * @param state
   * @param packageDir
   */
  function flushPackageLogic(packageDir = __MAIN_PKG_DIR__) {
    if (typeof definePackageLogicMap[packageDir] === 'function') {
      definePackageLogicMap[packageDir]()
      definePackageLogicMap[packageDir] = null
      delete definePackageLogicMap[packageDir]
    }
  }

  global.require = require;
  global.define = define;
  global.__block__ = blockPackageLogic;
  global.__define__ = flushPackageLogic; //  定义代码包
}(globalThis);
// 由于Foundation模块会改写__ddConfig的引用,所以__wxConfig最后赋值
__wxConfig = __ddConfig
var __ddAppCode__ = __ddAppCode__ || {};
typeof __ddLibrary.onEnd === 'function' && __ddLibrary.onEnd();
__ddLibrary = undefined;
